{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "ff8a63c1-317c-4890-a059-85f7e2c9f1e6",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "# Building systems\n",
    "\n",
    "This section several ways to construct an initial molecular structure. Common choices include:\n",
    "\n",
    "- Specifying the structure using the simplified molecular-input line-entry system ([SMILES](https://en.wikipedia.org/wiki/Simplified_molecular-input_line-entry_system)) line notation. A presentation of this technique using VeloxChem is given below\n",
    "\n",
    "- Downloading a structure from the protein data bank ([PDB](https://www.rcsb.org/))\n",
    "\n",
    "- Using a graphical molecular editor, such as [Avogadro](https://avogadro.cc/)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "ef9ec4dd",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [],
   "source": [
    "import veloxchem as vlx"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "da4f7b09",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "\n",
    "(sec:from_smiles)=\n",
    "## Using SMILES\n",
    "\n",
    "The interaction with SMILES strings in VeloxChem uses functionalities from the [Open Babel](http://openbabel.org/) package. We will illustrate some of basic SMILES string features.\n",
    "\n",
    "```{note}\n",
    "Remember to make sure to visualize the resulting geometries and ensure they correspond to what you are interested in.\n",
    "```\n",
    "\n",
    "We can obtain the SMILES string of caffeine from [Wikipedia](https://en.wikipedia.org/wiki/Caffeine) and construct a force-field optimized structure."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "af2bcbc2",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "smiles_str = \"CN1C=NC2=C1C(=O)N(C(=O)N2C)C\"\n",
    "\n",
    "caffeine_molecule = vlx.Molecule.read_smiles(smiles_str)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9f40beef-d939-4ab9-a624-daeb1d94dff5",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "In `vlx.Molecule.read_smiles` we:\n",
    "\n",
    "1. Build the molecule, excluding implicit atoms (hydrogens)\n",
    "2. Add hydrogens\n",
    "3. Generate conformer\n",
    "4. Optimize using the MMFF94 force field\n",
    "5. Return the `molecule` object\n",
    "\n",
    "A graphical illustration of the molecule is obtained with the `show` method."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "id": "66d104ff",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745455473811\"  style=\"position: relative; width: 400px; height: 300px;\">\n        <p id=\"3dmolwarning_1705745455473811\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745455473811 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745455473811\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_1705745455473811 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_1705745455473811\"),{backgroundColor:\"white\"});\nviewer_1705745455473811.zoomTo();\n\tviewer_1705745455473811.addModel(\"24\\n\\nC             -3.246030000000        -1.130310000000         0.025980000000\\nN             -2.262080000000        -0.077920000000         0.007760000000\\nC             -2.516750000000         1.268080000000        -0.001470000000\\nN             -1.402970000000         1.973590000000        -0.005660000000\\nC             -0.410650000000         1.040380000000        -0.000280000000\\nC             -0.905090000000        -0.228440000000         0.004840000000\\nC             -0.080570000000        -1.385890000000         0.010530000000\\nO             -0.536520000000        -2.525370000000         0.015670000000\\nN              1.283180000000        -1.078550000000         0.010220000000\\nC              1.833810000000         0.220410000000         0.006860000000\\nO              3.056760000000         0.390670000000         0.007920000000\\nN              0.939960000000         1.291810000000         0.003250000000\\nC              1.425170000000         2.659750000000         0.004880000000\\nC              2.230720000000        -2.175770000000         0.018140000000\\nH             -4.247690000000        -0.693450000000         0.002350000000\\nH             -3.117910000000        -1.709050000000         0.944170000000\\nH             -3.099090000000        -1.761210000000        -0.854070000000\\nH             -3.519330000000         1.677350000000        -0.002970000000\\nH              2.517080000000         2.705220000000         0.028990000000\\nH              1.035370000000         3.176560000000         0.887670000000\\nH              1.073890000000         3.164310000000        -0.900700000000\\nH              1.742510000000        -3.153400000000         0.018220000000\\nH              2.861160000000        -2.094140000000         0.909710000000\\nH              2.871610000000        -2.099260000000        -0.866370000000\\n\");\n\tviewer_1705745455473811.setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewer_1705745455473811.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewer_1705745455473811.zoomTo();\nviewer_1705745455473811.render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745455473811\"  style=\"position: relative; width: 400px; height: 300px;\">\n",
       "        <p id=\"3dmolwarning_1705745455473811\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745455473811 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745455473811\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "viewer_1705745455473811 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_1705745455473811\"),{backgroundColor:\"white\"});\n",
       "viewer_1705745455473811.zoomTo();\n",
       "\tviewer_1705745455473811.addModel(\"24\\n\\nC             -3.246030000000        -1.130310000000         0.025980000000\\nN             -2.262080000000        -0.077920000000         0.007760000000\\nC             -2.516750000000         1.268080000000        -0.001470000000\\nN             -1.402970000000         1.973590000000        -0.005660000000\\nC             -0.410650000000         1.040380000000        -0.000280000000\\nC             -0.905090000000        -0.228440000000         0.004840000000\\nC             -0.080570000000        -1.385890000000         0.010530000000\\nO             -0.536520000000        -2.525370000000         0.015670000000\\nN              1.283180000000        -1.078550000000         0.010220000000\\nC              1.833810000000         0.220410000000         0.006860000000\\nO              3.056760000000         0.390670000000         0.007920000000\\nN              0.939960000000         1.291810000000         0.003250000000\\nC              1.425170000000         2.659750000000         0.004880000000\\nC              2.230720000000        -2.175770000000         0.018140000000\\nH             -4.247690000000        -0.693450000000         0.002350000000\\nH             -3.117910000000        -1.709050000000         0.944170000000\\nH             -3.099090000000        -1.761210000000        -0.854070000000\\nH             -3.519330000000         1.677350000000        -0.002970000000\\nH              2.517080000000         2.705220000000         0.028990000000\\nH              1.035370000000         3.176560000000         0.887670000000\\nH              1.073890000000         3.164310000000        -0.900700000000\\nH              1.742510000000        -3.153400000000         0.018220000000\\nH              2.861160000000        -2.094140000000         0.909710000000\\nH              2.871610000000        -2.099260000000        -0.866370000000\\n\");\n",
       "\tviewer_1705745455473811.setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewer_1705745455473811.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewer_1705745455473811.zoomTo();\n",
       "viewer_1705745455473811.render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "caffeine_molecule.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "17f42666-c6ac-4ff9-83d3-91ca84ecbf4e",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "The molecular coordinates can be retrieved as an xyz-string using the `get_xyz_string` method."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "id": "e22acbc7-1f18-46f6-997d-fdfa751b0039",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "24\n",
      "\n",
      "C             -3.246030000000        -1.130310000000         0.025980000000\n",
      "N             -2.262080000000        -0.077920000000         0.007760000000\n",
      "C             -2.516750000000         1.268080000000        -0.001470000000\n",
      "N             -1.402970000000         1.973590000000        -0.005660000000\n",
      "C             -0.410650000000         1.040380000000        -0.000280000000\n",
      "C             -0.905090000000        -0.228440000000         0.004840000000\n",
      "C             -0.080570000000        -1.385890000000         0.010530000000\n",
      "O             -0.536520000000        -2.525370000000         0.015670000000\n",
      "N              1.283180000000        -1.078550000000         0.010220000000\n",
      "C              1.833810000000         0.220410000000         0.006860000000\n",
      "O              3.056760000000         0.390670000000         0.007920000000\n",
      "N              0.939960000000         1.291810000000         0.003250000000\n",
      "C              1.425170000000         2.659750000000         0.004880000000\n",
      "C              2.230720000000        -2.175770000000         0.018140000000\n",
      "H             -4.247690000000        -0.693450000000         0.002350000000\n",
      "H             -3.117910000000        -1.709050000000         0.944170000000\n",
      "H             -3.099090000000        -1.761210000000        -0.854070000000\n",
      "H             -3.519330000000         1.677350000000        -0.002970000000\n",
      "H              2.517080000000         2.705220000000         0.028990000000\n",
      "H              1.035370000000         3.176560000000         0.887670000000\n",
      "H              1.073890000000         3.164310000000        -0.900700000000\n",
      "H              1.742510000000        -3.153400000000         0.018220000000\n",
      "H              2.861160000000        -2.094140000000         0.909710000000\n",
      "H              2.871610000000        -2.099260000000        -0.866370000000\n",
      "\n"
     ]
    }
   ],
   "source": [
    "caffeine_xyz = caffeine_molecule.get_xyz_string()\n",
    "\n",
    "print(caffeine_xyz)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2d3efe54-1ebb-478d-8d7c-015e6a6cdc65",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "In order to immediately get the xyz-object, we can also use:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "ec283686-a2ab-4e44-9e10-1d87910b1a06",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "caffeine_xyz = vlx.Molecule.smiles_to_xyz(smiles_str)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3255561a-6b98-466d-bb99-de75e32bf7f4",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "For a 2D-representation:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "33797b98",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:cml=\"http://www.xml-cml.org/schema\" version=\"1.1\" id=\"topsvg\" x=\"0\" y=\"0\" width=\"200px\" height=\"200px\" viewBox=\"0 0 100 100\">\n",
       "<title> - Open Babel Depiction</title>\n",
       "<rect x=\"0\" y=\"0\" width=\"100\" height=\"100\" fill=\"white\"/>\n",
       "<g transform=\"translate(0,0)\">\n",
       "<svg width=\"100\" height=\"100\" x=\"0\" y=\"0\" viewBox=\"0 0 245.477 240\" font-family=\"sans-serif\" stroke=\"rgb(0,0,0)\" stroke-width=\"2\" stroke-linecap=\"round\">\n",
       "<line x1=\"109.3\" y1=\"173.0\" x2=\"109.3\" y2=\"187.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"76.1\" y1=\"142.6\" x2=\"52.8\" y2=\"156.1\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"73.1\" y1=\"137.4\" x2=\"49.8\" y2=\"150.9\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"186.0\" y1=\"75.3\" x2=\"190.3\" y2=\"62.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"63.4\" y1=\"93.5\" x2=\"51.3\" y2=\"86.5\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"106.3\" y1=\"80.0\" x2=\"106.3\" y2=\"53.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"112.3\" y1=\"80.0\" x2=\"112.3\" y2=\"53.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"189.6\" y1=\"98.2\" x2=\"205.5\" y2=\"120.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"205.5\" y1=\"120.0\" x2=\"189.7\" y2=\"141.7\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"196.1\" y1=\"120.6\" x2=\"185.1\" y2=\"135.8\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"169.6\" y1=\"148.3\" x2=\"143.9\" y2=\"140.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"143.9\" y1=\"140.0\" x2=\"143.9\" y2=\"100.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"151.1\" y1=\"134.0\" x2=\"151.1\" y2=\"106.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"143.9\" y1=\"100.0\" x2=\"169.6\" y2=\"91.7\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"109.3\" y1=\"80.0\" x2=\"85.9\" y2=\"93.5\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"74.6\" y1=\"113.0\" x2=\"74.6\" y2=\"140.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"74.6\" y1=\"140.0\" x2=\"98.0\" y2=\"153.5\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"120.5\" y1=\"153.5\" x2=\"143.9\" y2=\"140.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<line x1=\"143.9\" y1=\"100.0\" x2=\"109.3\" y2=\"80.0\" opacity=\"1.0\" stroke=\"rgb(0,0,0)\" stroke-width=\"2.0\"/>\n",
       "<text x=\"190.325989\" y=\"57.597060\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">CH</text>\n",
       "<text x=\"214.325989\" y=\"61.277060\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"13\">3</text>\n",
       "<text x=\"175.965309\" y=\"95.639320\" fill=\"rgb(12,12,255)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">N</text>\n",
       "<text x=\"175.965309\" y=\"160.360680\" fill=\"rgb(12,12,255)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">N</text>\n",
       "<text x=\"103.282032\" y=\"48.000000\" fill=\"rgb(255,12,12)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">O</text>\n",
       "<text x=\"68.641016\" y=\"108.000000\" fill=\"rgb(12,12,255)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">N</text>\n",
       "<text x=\"34.000000\" y=\"168.000000\" fill=\"rgb(255,12,12)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">O</text>\n",
       "<text x=\"103.282032\" y=\"168.000000\" fill=\"rgb(12,12,255)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">N</text>\n",
       "<text x=\"105.282032\" y=\"208.000000\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">CH</text>\n",
       "<text x=\"129.282032\" y=\"211.680000\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"13\">3</text>\n",
       "<text x=\"14.000000\" y=\"88.000000\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">H</text>\n",
       "<text x=\"26.000000\" y=\"91.680000\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"13\">3</text>\n",
       "<text x=\"32.500000\" y=\"88.000000\" fill=\"rgb(102,102,102)\" stroke-width=\"0\" font-weight=\"bold\" font-size=\"16\">C</text>\n",
       "</svg>\n",
       "</g>\n",
       "<text font-size=\"18.000000\" fill=\"black\" font-family=\"sans-serif\" x=\"10.000000\" y=\"20.000000\"/>\n",
       "</svg>"
      ],
      "text/plain": [
       "<IPython.core.display.SVG object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from IPython.display import SVG\n",
    "\n",
    "caffeine_molecule.draw_2d(width=300, height=300)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "4cd42682",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Since the initial conformer and force field optimized structure will have different orientations, the image will look somewhat different each time and this will affect the projection to 2D, particularly so for larger molecules extending in all three dimensions. Still, for many molecules this will work quite well, and you can save the .svg-figure with right-click save.\n",
    "\n",
    "### Bond type\n",
    "\n",
    "The basic principle of SMILES is to start at a suitable part of the molecule, and build the full molecule by sequentially describing the connections of each atom/functional group in turn. Hydrogens are typically added implicitly, and thus do not need to be specified. As such, the first four alkanes can simply be written with an increasing number of \"C\"."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "b246d31d",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745296425948\"  style=\"position: relative; width: 500px; height: 300px;\">\n        <p id=\"3dmolwarning_1705745296425948\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745296425948 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745296425948\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745296425948 = null;\nviewergrid_1705745296425948 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745296425948\"),{rows: 2, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745296425948 = viewergrid_1705745296425948[0][0];\nviewergrid_1705745296425948[0][0].zoomTo();viewergrid_1705745296425948[0][1].zoomTo();viewergrid_1705745296425948[1][0].zoomTo();viewergrid_1705745296425948[1][1].zoomTo();\tviewergrid_1705745296425948[0][0].addModel(\"5\\n\\nC          1.08281       -0.04220       -0.03689\\nH          2.17501       -0.04220       -0.03689\\nH          0.71875       -0.81820       -0.71378\\nH          0.71875        0.93200       -0.37048\\nH          0.71875       -0.24041        0.97359\\n\",\"xyz\");\n\tviewergrid_1705745296425948[0][1].addModel(\"8\\n\\nC          1.08258       -0.04645        0.04082\\nC          2.59460       -0.04645        0.04082\\nH          0.69824        0.54116       -0.79824\\nH          0.69824        0.38639        0.96923\\nH          0.69824       -1.06690       -0.04854\\nH          2.97894        0.97400        0.13017\\nH          2.97894       -0.47929       -0.88760\\nH          2.97894       -0.63406        0.87988\\n\",\"xyz\");\n\tviewergrid_1705745296425948[1][0].addModel(\"11\\n\\nC          0.97482        0.07684       -0.04375\\nC          2.49386        0.10439       -0.03720\\nC          3.02690        1.48858        0.29168\\nH          0.61434       -0.92853       -0.28262\\nH          0.57334        0.76851       -0.79132\\nH          0.57334        0.35832        0.93505\\nH          2.86881       -0.20752       -1.01831\\nH          2.86881       -0.61550        0.69875\\nH          2.68920        2.22413       -0.44546\\nH          4.12132        1.48412        0.29062\\nH          2.68920        1.81394        1.28091\\n\",\"xyz\");\n\tviewergrid_1705745296425948[1][1].addModel(\"14\\n\\nC          0.92242        0.06839       -0.03129\\nC          2.44266        0.06990       -0.04588\\nC          2.98834        0.21658       -1.46484\\nC          4.50858        0.21809       -1.47942\\nH          0.55326       -0.03755        0.99359\\nH          0.52529       -0.76252       -0.62309\\nH          0.52529        1.00280       -0.44060\\nH          2.80763       -0.86316        0.39907\\nH          2.80763        0.89222        0.58053\\nH          2.62337        1.14965       -1.90979\\nH          2.62337       -0.60573       -2.09125\\nH          4.90571        1.04901       -0.88763\\nH          4.87774        0.32404       -2.50431\\nH          4.90571       -0.71631       -1.07012\\n\",\"xyz\");\n\tviewergrid_1705745296425948[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745296425948[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745296425948[1][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745296425948[1][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745296425948[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745296425948[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745296425948[1][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745296425948[1][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745296425948[0][0].zoomTo();\n\tviewergrid_1705745296425948[0][1].zoomTo();\n\tviewergrid_1705745296425948[1][0].zoomTo();\n\tviewergrid_1705745296425948[1][1].zoomTo();\nviewergrid_1705745296425948[1][1].render();\nviewergrid_1705745296425948[1][0].render();\nviewergrid_1705745296425948[0][1].render();\nviewergrid_1705745296425948[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745296425948\"  style=\"position: relative; width: 500px; height: 300px;\">\n",
       "        <p id=\"3dmolwarning_1705745296425948\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745296425948 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745296425948\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745296425948 = null;\n",
       "viewergrid_1705745296425948 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745296425948\"),{rows: 2, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745296425948 = viewergrid_1705745296425948[0][0];\n",
       "viewergrid_1705745296425948[0][0].zoomTo();viewergrid_1705745296425948[0][1].zoomTo();viewergrid_1705745296425948[1][0].zoomTo();viewergrid_1705745296425948[1][1].zoomTo();\tviewergrid_1705745296425948[0][0].addModel(\"5\\n\\nC          1.08281       -0.04220       -0.03689\\nH          2.17501       -0.04220       -0.03689\\nH          0.71875       -0.81820       -0.71378\\nH          0.71875        0.93200       -0.37048\\nH          0.71875       -0.24041        0.97359\\n\",\"xyz\");\n",
       "\tviewergrid_1705745296425948[0][1].addModel(\"8\\n\\nC          1.08258       -0.04645        0.04082\\nC          2.59460       -0.04645        0.04082\\nH          0.69824        0.54116       -0.79824\\nH          0.69824        0.38639        0.96923\\nH          0.69824       -1.06690       -0.04854\\nH          2.97894        0.97400        0.13017\\nH          2.97894       -0.47929       -0.88760\\nH          2.97894       -0.63406        0.87988\\n\",\"xyz\");\n",
       "\tviewergrid_1705745296425948[1][0].addModel(\"11\\n\\nC          0.97482        0.07684       -0.04375\\nC          2.49386        0.10439       -0.03720\\nC          3.02690        1.48858        0.29168\\nH          0.61434       -0.92853       -0.28262\\nH          0.57334        0.76851       -0.79132\\nH          0.57334        0.35832        0.93505\\nH          2.86881       -0.20752       -1.01831\\nH          2.86881       -0.61550        0.69875\\nH          2.68920        2.22413       -0.44546\\nH          4.12132        1.48412        0.29062\\nH          2.68920        1.81394        1.28091\\n\",\"xyz\");\n",
       "\tviewergrid_1705745296425948[1][1].addModel(\"14\\n\\nC          0.92242        0.06839       -0.03129\\nC          2.44266        0.06990       -0.04588\\nC          2.98834        0.21658       -1.46484\\nC          4.50858        0.21809       -1.47942\\nH          0.55326       -0.03755        0.99359\\nH          0.52529       -0.76252       -0.62309\\nH          0.52529        1.00280       -0.44060\\nH          2.80763       -0.86316        0.39907\\nH          2.80763        0.89222        0.58053\\nH          2.62337        1.14965       -1.90979\\nH          2.62337       -0.60573       -2.09125\\nH          4.90571        1.04901       -0.88763\\nH          4.87774        0.32404       -2.50431\\nH          4.90571       -0.71631       -1.07012\\n\",\"xyz\");\n",
       "\tviewergrid_1705745296425948[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745296425948[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745296425948[1][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745296425948[1][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745296425948[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745296425948[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745296425948[1][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745296425948[1][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745296425948[0][0].zoomTo();\n",
       "\tviewergrid_1705745296425948[0][1].zoomTo();\n",
       "\tviewergrid_1705745296425948[1][0].zoomTo();\n",
       "\tviewergrid_1705745296425948[1][1].zoomTo();\n",
       "viewergrid_1705745296425948[1][1].render();\n",
       "viewergrid_1705745296425948[1][0].render();\n",
       "viewergrid_1705745296425948[0][1].render();\n",
       "viewergrid_1705745296425948[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import py3Dmol as p3d\n",
    "\n",
    "methane_xyz = vlx.Molecule.smiles_to_xyz(\"C\")\n",
    "ethane_xyz = vlx.Molecule.smiles_to_xyz(\"CC\")\n",
    "propane_xyz = vlx.Molecule.smiles_to_xyz(\"CCC\")\n",
    "butane_xyz = vlx.Molecule.smiles_to_xyz(\"CCCC\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(2, 2), width=500, height=300, linked=False)\n",
    "viewer.addModel(methane_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(ethane_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.addModel(propane_xyz, \"xyz\", viewer=(1, 0))\n",
    "viewer.addModel(butane_xyz, \"xyz\", viewer=(1, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "dfcdffbd",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Bond types are specified with different symbols between two atoms, with `-`, `=`, and `#`, for single-, double-, and triple-bonds, respectively, and other bond types are possible (see, *e.g.*, [Wikipedia](https://en.wikipedia.org/wiki/Simplified_molecular-input_line-entry_system)). Single bonds is assumed if no bond type is specified.\n",
    "\n",
    "For example, ethane, ethene, and ethyne are constructed as:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "fc73aeeb",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745297571646\"  style=\"position: relative; width: 400px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745297571646\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745297571646 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745297571646\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745297571646 = null;\nviewergrid_1705745297571646 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745297571646\"),{rows: 1, cols: 3, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745297571646 = viewergrid_1705745297571646[0][0];\nviewergrid_1705745297571646[0][0].zoomTo();viewergrid_1705745297571646[0][1].zoomTo();viewergrid_1705745297571646[0][2].zoomTo();\tviewergrid_1705745297571646[0][0].addModel(\"8\\n\\nC          0.95679        0.08694        0.01459\\nC          2.46881        0.08694        0.01459\\nH          0.57245        0.89755        0.64087\\nH          0.57245       -0.86073        0.40346\\nH          0.57245        0.22401       -1.00055\\nH          2.85315       -0.05012        1.02974\\nH          2.85315        1.03462       -0.37428\\nH          2.85315       -0.72367       -0.61168\\n\",\"xyz\");\n\tviewergrid_1705745297571646[0][1].addModel(\"6\\n\\nC          1.08509        0.06836       -0.00553\\nC          2.42086        0.06836       -0.00553\\nH          0.52527        0.47589        0.83043\\nH          0.52527       -0.33916       -0.84148\\nH          2.98068        0.47589        0.83043\\nH          2.98068       -0.33916       -0.84148\\n\",\"xyz\");\n\tviewergrid_1705745297571646[0][2].addModel(\"4\\n\\nC          1.11206       -0.04481       -0.06602\\nC          2.31236       -0.04481       -0.06602\\nH          0.04625       -0.04481       -0.06602\\nH          3.37816       -0.04481       -0.06602\\n\",\"xyz\");\n\tviewergrid_1705745297571646[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745297571646[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745297571646[0][2].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745297571646[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745297571646[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745297571646[0][2].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745297571646[0][0].zoomTo();\n\tviewergrid_1705745297571646[0][1].zoomTo();\n\tviewergrid_1705745297571646[0][2].zoomTo();\nviewergrid_1705745297571646[0][2].render();\nviewergrid_1705745297571646[0][1].render();\nviewergrid_1705745297571646[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745297571646\"  style=\"position: relative; width: 400px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745297571646\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745297571646 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745297571646\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745297571646 = null;\n",
       "viewergrid_1705745297571646 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745297571646\"),{rows: 1, cols: 3, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745297571646 = viewergrid_1705745297571646[0][0];\n",
       "viewergrid_1705745297571646[0][0].zoomTo();viewergrid_1705745297571646[0][1].zoomTo();viewergrid_1705745297571646[0][2].zoomTo();\tviewergrid_1705745297571646[0][0].addModel(\"8\\n\\nC          0.95679        0.08694        0.01459\\nC          2.46881        0.08694        0.01459\\nH          0.57245        0.89755        0.64087\\nH          0.57245       -0.86073        0.40346\\nH          0.57245        0.22401       -1.00055\\nH          2.85315       -0.05012        1.02974\\nH          2.85315        1.03462       -0.37428\\nH          2.85315       -0.72367       -0.61168\\n\",\"xyz\");\n",
       "\tviewergrid_1705745297571646[0][1].addModel(\"6\\n\\nC          1.08509        0.06836       -0.00553\\nC          2.42086        0.06836       -0.00553\\nH          0.52527        0.47589        0.83043\\nH          0.52527       -0.33916       -0.84148\\nH          2.98068        0.47589        0.83043\\nH          2.98068       -0.33916       -0.84148\\n\",\"xyz\");\n",
       "\tviewergrid_1705745297571646[0][2].addModel(\"4\\n\\nC          1.11206       -0.04481       -0.06602\\nC          2.31236       -0.04481       -0.06602\\nH          0.04625       -0.04481       -0.06602\\nH          3.37816       -0.04481       -0.06602\\n\",\"xyz\");\n",
       "\tviewergrid_1705745297571646[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745297571646[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745297571646[0][2].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745297571646[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745297571646[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745297571646[0][2].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745297571646[0][0].zoomTo();\n",
       "\tviewergrid_1705745297571646[0][1].zoomTo();\n",
       "\tviewergrid_1705745297571646[0][2].zoomTo();\n",
       "viewergrid_1705745297571646[0][2].render();\n",
       "viewergrid_1705745297571646[0][1].render();\n",
       "viewergrid_1705745297571646[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "ethane_xyz = vlx.Molecule.smiles_to_xyz(\"C-C\")  # or 'CC'\n",
    "ethene_xyz = vlx.Molecule.smiles_to_xyz(\"C=C\")\n",
    "ethyne_xyz = vlx.Molecule.smiles_to_xyz(\"C#C\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 3), width=400, height=200, linked=False)\n",
    "viewer.addModel(ethane_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(ethene_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.addModel(ethyne_xyz, \"xyz\", viewer=(0, 2))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7f573fda",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "### Branching and substitutions\n",
    "\n",
    "Branches are given within paranthesis, as connected to the atom just before the paranthesis. These branches can be nested, for more complex molecules.\n",
    "\n",
    "```{note}\n",
    "Several valid SMILES strings can typically be written for the same molecule.\n",
    "```\n",
    "\n",
    "\n",
    "Hexane and 3-ethylheptane are then written as:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "b8510007",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745298896159\"  style=\"position: relative; width: 500px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745298896159\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745298896159 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745298896159\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745298896159 = null;\nviewergrid_1705745298896159 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745298896159\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745298896159 = viewergrid_1705745298896159[0][0];\nviewergrid_1705745298896159[0][0].zoomTo();viewergrid_1705745298896159[0][1].zoomTo();\tviewergrid_1705745298896159[0][0].addModel(\"20\\n\\nC          0.95072        0.10536        0.03225\\nC          2.47092        0.10046        0.01156\\nC          3.01073       -0.22935       -1.37986\\nC          4.54013       -0.23333       -1.39669\\nC          5.07994       -0.56314       -2.78811\\nC          6.60014       -0.56803       -2.80881\\nH          0.58606        0.34336        1.03638\\nH          0.55140       -0.87373       -0.25105\\nH          0.55140        0.85314       -0.66036\\nH          2.83805       -0.63442        0.73743\\nH          2.83805        1.08294        0.33037\\nH          2.63717        0.50621       -2.10270\\nH          2.63717       -1.21107       -1.69566\\nH          4.91369       -0.96889       -0.67386\\nH          4.91369        0.74840       -1.08089\\nH          4.71281        0.17174       -3.51398\\nH          4.71281       -1.54561       -3.10692\\nH          6.99946        0.41105       -2.52550\\nH          6.96480       -0.80604       -3.81294\\nH          6.99946       -1.31581       -2.11620\\n\",\"xyz\");\n\tviewergrid_1705745298896159[0][1].addModel(\"29\\n\\nC          1.05249        0.05743       -0.41094\\nC          2.56737        0.08154       -0.26575\\nC          2.97249        0.22991        1.20225\\nC          4.48036        0.06698        1.39874\\nC          4.99215        0.30086        2.84438\\nC          4.57982       -0.80160        3.84886\\nC          3.10945       -0.82945        4.24177\\nC          6.53990        0.41559        2.77797\\nC          7.20865        0.80483        4.09085\\nH          0.77074       -0.06765       -1.46066\\nH          0.60742        0.98732       -0.04381\\nH          0.61996       -0.77485        0.15542\\nH          2.97940        0.90876       -0.85528\\nH          2.97784       -0.84845       -0.67521\\nH          2.43540       -0.53269        1.76503\\nH          2.64987        1.20786        1.57702\\nH          4.97619        0.78664        0.73248\\nH          4.78953       -0.92933        1.05948\\nH          4.60285        1.26424        3.19851\\nH          5.12941       -0.65515        4.78401\\nH          4.87573       -1.78704        3.47006\\nH          2.67247        0.17320        4.26200\\nH          2.99881       -1.26360        5.24140\\nH          2.52932       -1.46650        3.56982\\nH          6.80924        1.17736        2.03522\\nH          6.96884       -0.53095        2.42659\\nH          6.74942        1.70103        4.51846\\nH          8.26989        1.01491        3.92086\\nH          7.15861       -0.00108        4.82846\\n\",\"xyz\");\n\tviewergrid_1705745298896159[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745298896159[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745298896159[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745298896159[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745298896159[0][0].zoomTo();\n\tviewergrid_1705745298896159[0][1].zoomTo();\nviewergrid_1705745298896159[0][1].render();\nviewergrid_1705745298896159[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745298896159\"  style=\"position: relative; width: 500px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745298896159\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745298896159 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745298896159\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745298896159 = null;\n",
       "viewergrid_1705745298896159 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745298896159\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745298896159 = viewergrid_1705745298896159[0][0];\n",
       "viewergrid_1705745298896159[0][0].zoomTo();viewergrid_1705745298896159[0][1].zoomTo();\tviewergrid_1705745298896159[0][0].addModel(\"20\\n\\nC          0.95072        0.10536        0.03225\\nC          2.47092        0.10046        0.01156\\nC          3.01073       -0.22935       -1.37986\\nC          4.54013       -0.23333       -1.39669\\nC          5.07994       -0.56314       -2.78811\\nC          6.60014       -0.56803       -2.80881\\nH          0.58606        0.34336        1.03638\\nH          0.55140       -0.87373       -0.25105\\nH          0.55140        0.85314       -0.66036\\nH          2.83805       -0.63442        0.73743\\nH          2.83805        1.08294        0.33037\\nH          2.63717        0.50621       -2.10270\\nH          2.63717       -1.21107       -1.69566\\nH          4.91369       -0.96889       -0.67386\\nH          4.91369        0.74840       -1.08089\\nH          4.71281        0.17174       -3.51398\\nH          4.71281       -1.54561       -3.10692\\nH          6.99946        0.41105       -2.52550\\nH          6.96480       -0.80604       -3.81294\\nH          6.99946       -1.31581       -2.11620\\n\",\"xyz\");\n",
       "\tviewergrid_1705745298896159[0][1].addModel(\"29\\n\\nC          1.05249        0.05743       -0.41094\\nC          2.56737        0.08154       -0.26575\\nC          2.97249        0.22991        1.20225\\nC          4.48036        0.06698        1.39874\\nC          4.99215        0.30086        2.84438\\nC          4.57982       -0.80160        3.84886\\nC          3.10945       -0.82945        4.24177\\nC          6.53990        0.41559        2.77797\\nC          7.20865        0.80483        4.09085\\nH          0.77074       -0.06765       -1.46066\\nH          0.60742        0.98732       -0.04381\\nH          0.61996       -0.77485        0.15542\\nH          2.97940        0.90876       -0.85528\\nH          2.97784       -0.84845       -0.67521\\nH          2.43540       -0.53269        1.76503\\nH          2.64987        1.20786        1.57702\\nH          4.97619        0.78664        0.73248\\nH          4.78953       -0.92933        1.05948\\nH          4.60285        1.26424        3.19851\\nH          5.12941       -0.65515        4.78401\\nH          4.87573       -1.78704        3.47006\\nH          2.67247        0.17320        4.26200\\nH          2.99881       -1.26360        5.24140\\nH          2.52932       -1.46650        3.56982\\nH          6.80924        1.17736        2.03522\\nH          6.96884       -0.53095        2.42659\\nH          6.74942        1.70103        4.51846\\nH          8.26989        1.01491        3.92086\\nH          7.15861       -0.00108        4.82846\\n\",\"xyz\");\n",
       "\tviewergrid_1705745298896159[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745298896159[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745298896159[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745298896159[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745298896159[0][0].zoomTo();\n",
       "\tviewergrid_1705745298896159[0][1].zoomTo();\n",
       "viewergrid_1705745298896159[0][1].render();\n",
       "viewergrid_1705745298896159[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "hexane_xyz = vlx.Molecule.smiles_to_xyz(\"CCCCCC\")\n",
    "ethylheptane_xyz = vlx.Molecule.smiles_to_xyz(\"CCCCC(CC)CC\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 2), width=500, height=200, linked=False)\n",
    "viewer.addModel(hexane_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(ethylheptane_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7176cee2",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Substitutions are done by replacing the relevant atom, or adding it to replace an implicit hydrogen. For example, methanol, 1,1-difluoroethene, and 1,2-difluoroethene can be given as:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "1513d76d",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745302221333\"  style=\"position: relative; width: 400px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745302221333\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745302221333 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745302221333\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745302221333 = null;\nviewergrid_1705745302221333 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745302221333\"),{rows: 1, cols: 3, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745302221333 = viewergrid_1705745302221333[0][0];\nviewergrid_1705745302221333[0][0].zoomTo();viewergrid_1705745302221333[0][1].zoomTo();viewergrid_1705745302221333[0][2].zoomTo();\tviewergrid_1705745302221333[0][0].addModel(\"6\\n\\nC          0.94282        0.02623       -0.06736\\nO          2.35849        0.02180       -0.08114\\nH          0.58267        1.03559        0.14620\\nH          0.58267       -0.66948        0.69449\\nH          0.57703       -0.28892       -1.04741\\nH          2.65387        0.30540        0.80080\\n\",\"xyz\");\n\tviewergrid_1705745302221333[0][1].addModel(\"6\\n\\nC          0.99058       -0.02575        0.09098\\nC          2.32230       -0.02575        0.09098\\nF          2.99378        0.67275        1.02815\\nF          2.99378       -0.72425       -0.84618\\nH          0.44176        0.53199        0.83929\\nH          0.44176       -0.58349       -0.65733\\n\",\"xyz\");\n\tviewergrid_1705745302221333[0][2].addModel(\"6\\n\\nF          0.91457       -0.00578        0.07006\\nC          2.25810        0.03679        0.02722\\nC          2.90391        0.85313       -0.79424\\nF          4.24743        0.89570       -0.83708\\nH          2.70479       -0.65577        0.72412\\nH          2.45722        1.54569       -1.49114\\n\",\"xyz\");\n\tviewergrid_1705745302221333[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745302221333[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745302221333[0][2].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745302221333[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745302221333[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745302221333[0][2].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745302221333[0][0].zoomTo();\n\tviewergrid_1705745302221333[0][1].zoomTo();\n\tviewergrid_1705745302221333[0][2].zoomTo();\nviewergrid_1705745302221333[0][2].render();\nviewergrid_1705745302221333[0][1].render();\nviewergrid_1705745302221333[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745302221333\"  style=\"position: relative; width: 400px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745302221333\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745302221333 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745302221333\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745302221333 = null;\n",
       "viewergrid_1705745302221333 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745302221333\"),{rows: 1, cols: 3, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745302221333 = viewergrid_1705745302221333[0][0];\n",
       "viewergrid_1705745302221333[0][0].zoomTo();viewergrid_1705745302221333[0][1].zoomTo();viewergrid_1705745302221333[0][2].zoomTo();\tviewergrid_1705745302221333[0][0].addModel(\"6\\n\\nC          0.94282        0.02623       -0.06736\\nO          2.35849        0.02180       -0.08114\\nH          0.58267        1.03559        0.14620\\nH          0.58267       -0.66948        0.69449\\nH          0.57703       -0.28892       -1.04741\\nH          2.65387        0.30540        0.80080\\n\",\"xyz\");\n",
       "\tviewergrid_1705745302221333[0][1].addModel(\"6\\n\\nC          0.99058       -0.02575        0.09098\\nC          2.32230       -0.02575        0.09098\\nF          2.99378        0.67275        1.02815\\nF          2.99378       -0.72425       -0.84618\\nH          0.44176        0.53199        0.83929\\nH          0.44176       -0.58349       -0.65733\\n\",\"xyz\");\n",
       "\tviewergrid_1705745302221333[0][2].addModel(\"6\\n\\nF          0.91457       -0.00578        0.07006\\nC          2.25810        0.03679        0.02722\\nC          2.90391        0.85313       -0.79424\\nF          4.24743        0.89570       -0.83708\\nH          2.70479       -0.65577        0.72412\\nH          2.45722        1.54569       -1.49114\\n\",\"xyz\");\n",
       "\tviewergrid_1705745302221333[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745302221333[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745302221333[0][2].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745302221333[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745302221333[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745302221333[0][2].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745302221333[0][0].zoomTo();\n",
       "\tviewergrid_1705745302221333[0][1].zoomTo();\n",
       "\tviewergrid_1705745302221333[0][2].zoomTo();\n",
       "viewergrid_1705745302221333[0][2].render();\n",
       "viewergrid_1705745302221333[0][1].render();\n",
       "viewergrid_1705745302221333[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "methanol_xyz = vlx.Molecule.smiles_to_xyz(\"CO\")\n",
    "difluoro11_xyz = vlx.Molecule.smiles_to_xyz(\"C=C(F)F\")\n",
    "difluoro12_xyz = vlx.Molecule.smiles_to_xyz(\"FC=CF\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 3), width=400, height=200, linked=False)\n",
    "viewer.addModel(methanol_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(difluoro11_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.addModel(difluoro12_xyz, \"xyz\", viewer=(0, 2))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d63f5cd9",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "### Optimization using force field\n",
    "\n",
    "Following the construction of a conformer from a SMILES string, it is generally advised to perform a short optimization to obtain a structure close to a local minimum.\n",
    "\n",
    "As an example, for ethanol the initial conformer will have the OH-group with any rotation to CH$_3$, and following a force field optimization it takes on the staggered conformation:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "d7828af2",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745304060448\"  style=\"position: relative; width: 400px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745304060448\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745304060448 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745304060448\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745304060448 = null;\nviewergrid_1705745304060448 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745304060448\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745304060448 = viewergrid_1705745304060448[0][0];\nviewergrid_1705745304060448[0][0].zoomTo();viewergrid_1705745304060448[0][1].zoomTo();\tviewergrid_1705745304060448[0][0].addModel(\"6\\n\\nC          0.93787       -0.00097        0.07143\\nO          2.35355       -0.01482        0.06725\\nH          0.57771        0.74806       -0.63806\\nH          0.57771        0.23095        1.07673\\nH          0.57210       -0.98661       -0.22580\\nH          2.64894        0.87211        0.33471\\n\",\"xyz\");\n\tviewergrid_1705745304060448[0][1].addModel(\"6\\n\\nC          0.92806        0.04323        0.03816\\nO          2.34372        0.03793        0.05164\\nH          0.56790       -0.60272       -0.76631\\nH          0.56790        1.06411       -0.11089\\nH          0.56227       -0.33349        0.99623\\nH          2.63910        0.37694       -0.81052\\n\",\"xyz\");\n\tviewergrid_1705745304060448[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745304060448[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745304060448[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745304060448[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745304060448[0][0].zoomTo();\n\tviewergrid_1705745304060448[0][1].zoomTo();\nviewergrid_1705745304060448[0][1].render();\nviewergrid_1705745304060448[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745304060448\"  style=\"position: relative; width: 400px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745304060448\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745304060448 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745304060448\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745304060448 = null;\n",
       "viewergrid_1705745304060448 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745304060448\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745304060448 = viewergrid_1705745304060448[0][0];\n",
       "viewergrid_1705745304060448[0][0].zoomTo();viewergrid_1705745304060448[0][1].zoomTo();\tviewergrid_1705745304060448[0][0].addModel(\"6\\n\\nC          0.93787       -0.00097        0.07143\\nO          2.35355       -0.01482        0.06725\\nH          0.57771        0.74806       -0.63806\\nH          0.57771        0.23095        1.07673\\nH          0.57210       -0.98661       -0.22580\\nH          2.64894        0.87211        0.33471\\n\",\"xyz\");\n",
       "\tviewergrid_1705745304060448[0][1].addModel(\"6\\n\\nC          0.92806        0.04323        0.03816\\nO          2.34372        0.03793        0.05164\\nH          0.56790       -0.60272       -0.76631\\nH          0.56790        1.06411       -0.11089\\nH          0.56227       -0.33349        0.99623\\nH          2.63910        0.37694       -0.81052\\n\",\"xyz\");\n",
       "\tviewergrid_1705745304060448[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745304060448[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745304060448[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745304060448[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745304060448[0][0].zoomTo();\n",
       "\tviewergrid_1705745304060448[0][1].zoomTo();\n",
       "viewergrid_1705745304060448[0][1].render();\n",
       "viewergrid_1705745304060448[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "ethanol_initial_xyz = vlx.Molecule.smiles_to_xyz(\"CO\", optimize=False)\n",
    "ethanol_xyz = vlx.Molecule.smiles_to_xyz(\"CO\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 2), width=400, height=200, linked=False)\n",
    "viewer.addModel(ethanol_initial_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(ethanol_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "349eccfa",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "### Ring systems\n",
    "\n",
    "Ring systems are constructed by labeling part(s) of the ring and then closing the ring by having the SMILES string go back to the labeled atom(s). This can be performed several time, so that, *e.g.* cyclohexane and norbornane are written as:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "8ed2c3e1",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745306615229\"  style=\"position: relative; width: 400px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745306615229\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745306615229 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745306615229\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745306615229 = null;\nviewergrid_1705745306615229 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745306615229\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745306615229 = viewergrid_1705745306615229[0][0];\nviewergrid_1705745306615229[0][0].zoomTo();viewergrid_1705745306615229[0][1].zoomTo();\tviewergrid_1705745306615229[0][0].addModel(\"18\\n\\nC         -1.42267        0.32823       -0.22166\\nC         -0.42645        1.39452        0.22593\\nC          0.99237        1.06705       -0.23172\\nC          1.42068       -0.32755        0.21696\\nC          0.42472       -1.39349       -0.23189\\nC         -0.99393       -1.06642        0.22652\\nH         -1.51111        0.34835       -1.31490\\nH         -2.41481        0.55711        0.18337\\nH         -0.44672        1.47572        1.31974\\nH         -0.72660        2.37021       -0.17244\\nH          1.68969        1.81294        0.16597\\nH          1.04602        1.13026       -1.32559\\nH          1.50787       -0.34776        1.31031\\nH          2.41324       -0.55651       -0.18698\\nH          0.72499       -2.36964        0.16525\\nH          0.44482       -1.47330       -1.32581\\nH         -1.04702       -1.12992        1.32040\\nH         -1.69131       -1.81233       -0.17101\\n\",\"xyz\");\n\tviewergrid_1705745306615229[0][1].addModel(\"19\\n\\nC         -1.25911       -0.76757       -0.51749\\nC         -0.00790       -1.11168        0.30819\\nC          1.24245       -0.77138       -0.52049\\nC          1.24554        0.76477       -0.52415\\nC         -0.00434        1.11388        0.30143\\nC         -0.00528        0.00428        1.35227\\nC         -1.25602        0.76857       -0.52316\\nH         -2.16502       -1.14019       -0.02613\\nH         -1.22345       -1.18321       -1.52942\\nH         -0.00901       -2.12944        0.70288\\nH          1.20204       -1.18536       -1.53295\\nH          2.14830       -1.14838       -0.03244\\nH          1.20823        1.17424       -1.53854\\nH          2.15223        1.14037       -0.03654\\nH         -0.00261        2.13403        0.68993\\nH         -0.90001        0.00765        1.98366\\nH          0.89046        0.00474        1.98223\\nH         -1.21722        1.17638       -1.53819\\nH         -2.16109        1.14853       -0.03597\\n\",\"xyz\");\n\tviewergrid_1705745306615229[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745306615229[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745306615229[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745306615229[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745306615229[0][0].zoomTo();\n\tviewergrid_1705745306615229[0][1].zoomTo();\nviewergrid_1705745306615229[0][1].render();\nviewergrid_1705745306615229[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745306615229\"  style=\"position: relative; width: 400px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745306615229\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745306615229 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745306615229\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745306615229 = null;\n",
       "viewergrid_1705745306615229 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745306615229\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745306615229 = viewergrid_1705745306615229[0][0];\n",
       "viewergrid_1705745306615229[0][0].zoomTo();viewergrid_1705745306615229[0][1].zoomTo();\tviewergrid_1705745306615229[0][0].addModel(\"18\\n\\nC         -1.42267        0.32823       -0.22166\\nC         -0.42645        1.39452        0.22593\\nC          0.99237        1.06705       -0.23172\\nC          1.42068       -0.32755        0.21696\\nC          0.42472       -1.39349       -0.23189\\nC         -0.99393       -1.06642        0.22652\\nH         -1.51111        0.34835       -1.31490\\nH         -2.41481        0.55711        0.18337\\nH         -0.44672        1.47572        1.31974\\nH         -0.72660        2.37021       -0.17244\\nH          1.68969        1.81294        0.16597\\nH          1.04602        1.13026       -1.32559\\nH          1.50787       -0.34776        1.31031\\nH          2.41324       -0.55651       -0.18698\\nH          0.72499       -2.36964        0.16525\\nH          0.44482       -1.47330       -1.32581\\nH         -1.04702       -1.12992        1.32040\\nH         -1.69131       -1.81233       -0.17101\\n\",\"xyz\");\n",
       "\tviewergrid_1705745306615229[0][1].addModel(\"19\\n\\nC         -1.25911       -0.76757       -0.51749\\nC         -0.00790       -1.11168        0.30819\\nC          1.24245       -0.77138       -0.52049\\nC          1.24554        0.76477       -0.52415\\nC         -0.00434        1.11388        0.30143\\nC         -0.00528        0.00428        1.35227\\nC         -1.25602        0.76857       -0.52316\\nH         -2.16502       -1.14019       -0.02613\\nH         -1.22345       -1.18321       -1.52942\\nH         -0.00901       -2.12944        0.70288\\nH          1.20204       -1.18536       -1.53295\\nH          2.14830       -1.14838       -0.03244\\nH          1.20823        1.17424       -1.53854\\nH          2.15223        1.14037       -0.03654\\nH         -0.00261        2.13403        0.68993\\nH         -0.90001        0.00765        1.98366\\nH          0.89046        0.00474        1.98223\\nH         -1.21722        1.17638       -1.53819\\nH         -2.16109        1.14853       -0.03597\\n\",\"xyz\");\n",
       "\tviewergrid_1705745306615229[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745306615229[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745306615229[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745306615229[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745306615229[0][0].zoomTo();\n",
       "\tviewergrid_1705745306615229[0][1].zoomTo();\n",
       "viewergrid_1705745306615229[0][1].render();\n",
       "viewergrid_1705745306615229[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "cyclohexane_xyz = vlx.Molecule.smiles_to_xyz(\"C1CCCCC1\")\n",
    "norborane_xyz = vlx.Molecule.smiles_to_xyz(\"C1C2CCC(C2)C1\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 2), width=400, height=200, linked=False)\n",
    "viewer.addModel(cyclohexane_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(norborane_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1a1a1f74",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "Aromatic rings can be written by using alternating single and double bonds or using lower-case for the contributing atoms. For example, p-cymene can be written as both:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "id": "3878a714",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745308281437\"  style=\"position: relative; width: 500px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745308281437\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745308281437 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745308281437\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745308281437 = null;\nviewergrid_1705745308281437 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745308281437\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745308281437 = viewergrid_1705745308281437[0][0];\nviewergrid_1705745308281437[0][0].zoomTo();viewergrid_1705745308281437[0][1].zoomTo();\tviewergrid_1705745308281437[0][0].addModel(\"22\\n\\nC          0.90358        0.13890        0.04205\\nC          2.24733        0.05576        0.02827\\nC          3.04426        1.33790       -0.00073\\nC          2.99105       -1.24262        0.03825\\nC          4.39698       -1.27357        0.04833\\nC          5.11191       -2.47979        0.04789\\nC          4.44080       -3.70164        0.03809\\nC          5.18845       -5.00058        0.03010\\nC          3.04588       -3.69507        0.03271\\nC          2.33606       -2.48598        0.03232\\nH          0.40340        1.10363        0.03209\\nH          0.24235       -0.71766        0.06401\\nH          2.39978        2.22433       -0.02140\\nH          3.67508        1.38480       -0.89499\\nH          3.67445        1.42513        0.89092\\nH          4.97989       -0.35663        0.05545\\nH          6.19910       -2.44804        0.05353\\nH          6.27172       -4.84102        0.03405\\nH          4.93743       -5.57415       -0.86804\\nH          4.93238       -5.58942        0.91670\\nH          2.49396       -4.63251        0.02630\\nH          1.25297       -2.55435        0.02419\\n\",\"xyz\");\n\tviewergrid_1705745308281437[0][1].addModel(\"22\\n\\nC          0.93821        0.16776       -0.01066\\nC          2.28195        0.08461       -0.02444\\nC          3.07888        1.36675       -0.05344\\nC          3.02567       -1.21377       -0.01446\\nC          4.43160       -1.24472       -0.00438\\nC          5.14653       -2.45094       -0.00482\\nC          4.47543       -3.67278       -0.01462\\nC          5.22308       -4.97173       -0.02261\\nC          3.08050       -3.66622       -0.01999\\nC          2.37068       -2.45713       -0.02038\\nH          0.43802        1.13249       -0.02062\\nH          0.27697       -0.68881        0.01131\\nH          2.43441        2.25318       -0.07411\\nH          3.70971        1.41366       -0.94769\\nH          3.70907        1.45399        0.83821\\nH          5.01452       -0.32778        0.00274\\nH          6.23373       -2.41919        0.00082\\nH          6.30635       -4.81216       -0.01866\\nH          4.97206       -5.54529       -0.92074\\nH          4.96701       -5.56056        0.86400\\nH          2.52858       -4.60366       -0.02640\\nH          1.28759       -2.52549       -0.02851\\n\",\"xyz\");\n\tviewergrid_1705745308281437[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745308281437[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745308281437[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745308281437[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745308281437[0][0].zoomTo();\n\tviewergrid_1705745308281437[0][1].zoomTo();\nviewergrid_1705745308281437[0][1].render();\nviewergrid_1705745308281437[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745308281437\"  style=\"position: relative; width: 500px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745308281437\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745308281437 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745308281437\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745308281437 = null;\n",
       "viewergrid_1705745308281437 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745308281437\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745308281437 = viewergrid_1705745308281437[0][0];\n",
       "viewergrid_1705745308281437[0][0].zoomTo();viewergrid_1705745308281437[0][1].zoomTo();\tviewergrid_1705745308281437[0][0].addModel(\"22\\n\\nC          0.90358        0.13890        0.04205\\nC          2.24733        0.05576        0.02827\\nC          3.04426        1.33790       -0.00073\\nC          2.99105       -1.24262        0.03825\\nC          4.39698       -1.27357        0.04833\\nC          5.11191       -2.47979        0.04789\\nC          4.44080       -3.70164        0.03809\\nC          5.18845       -5.00058        0.03010\\nC          3.04588       -3.69507        0.03271\\nC          2.33606       -2.48598        0.03232\\nH          0.40340        1.10363        0.03209\\nH          0.24235       -0.71766        0.06401\\nH          2.39978        2.22433       -0.02140\\nH          3.67508        1.38480       -0.89499\\nH          3.67445        1.42513        0.89092\\nH          4.97989       -0.35663        0.05545\\nH          6.19910       -2.44804        0.05353\\nH          6.27172       -4.84102        0.03405\\nH          4.93743       -5.57415       -0.86804\\nH          4.93238       -5.58942        0.91670\\nH          2.49396       -4.63251        0.02630\\nH          1.25297       -2.55435        0.02419\\n\",\"xyz\");\n",
       "\tviewergrid_1705745308281437[0][1].addModel(\"22\\n\\nC          0.93821        0.16776       -0.01066\\nC          2.28195        0.08461       -0.02444\\nC          3.07888        1.36675       -0.05344\\nC          3.02567       -1.21377       -0.01446\\nC          4.43160       -1.24472       -0.00438\\nC          5.14653       -2.45094       -0.00482\\nC          4.47543       -3.67278       -0.01462\\nC          5.22308       -4.97173       -0.02261\\nC          3.08050       -3.66622       -0.01999\\nC          2.37068       -2.45713       -0.02038\\nH          0.43802        1.13249       -0.02062\\nH          0.27697       -0.68881        0.01131\\nH          2.43441        2.25318       -0.07411\\nH          3.70971        1.41366       -0.94769\\nH          3.70907        1.45399        0.83821\\nH          5.01452       -0.32778        0.00274\\nH          6.23373       -2.41919        0.00082\\nH          6.30635       -4.81216       -0.01866\\nH          4.97206       -5.54529       -0.92074\\nH          4.96701       -5.56056        0.86400\\nH          2.52858       -4.60366       -0.02640\\nH          1.28759       -2.52549       -0.02851\\n\",\"xyz\");\n",
       "\tviewergrid_1705745308281437[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745308281437[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745308281437[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745308281437[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745308281437[0][0].zoomTo();\n",
       "\tviewergrid_1705745308281437[0][1].zoomTo();\n",
       "viewergrid_1705745308281437[0][1].render();\n",
       "viewergrid_1705745308281437[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "pcymene1_xyz = vlx.Molecule.smiles_to_xyz(\"C=C(C)C1=CC=C(C)C=C1\")\n",
    "pcymene2_xyz = vlx.Molecule.smiles_to_xyz(\"C=C(C)c1ccc(C)cc1\")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 2), width=500, height=200, linked=False)\n",
    "viewer.addModel(pcymene1_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(pcymene2_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "b152e821",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "### More complex systems\n",
    "\n",
    "For more complex molecules, the easiest option is to check if Wikipedia, [ChemSpider](http://www.chemspider.com/), or any other digital resources provide the SMILES string. This will work for many common molecules, and for the rest you can either consult more detailed guides on using SMILES and go from there, or use a graphical interface.\n",
    "\n",
    "```{note}\n",
    "No matter which option is chosen, we stress that you should always check that the structure you obtain is reasonably close to what is sought. For some systems you may need to sample many different conformers, and for PDB-files you might have to add hydrogens.\n",
    "```\n",
    "\n",
    "As an example, the structures NADH (left) and NAD$^+$ (right) are illustrated below, using the SMILES string from [Wikipedia](https://en.wikipedia.org/wiki/Nicotinamide_adenine_dinucleotide). Nicotinamide adenine dinucleotide partake in metabolism through the redox reaction:\n",
    "\n",
    "$$\n",
    "\\mathrm{NADH} \\Longleftrightarrow \\mathrm{NAD}^+ +  \\mathrm{H}^+ + 2\\mathrm{e}^- \n",
    "$$\n",
    "\n",
    "The resulting conformers need to be corrected, but we see that the general structure and the location of the hydrogen at the nicotinamide ring is correct."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "id": "3e331e6a",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745309937566\"  style=\"position: relative; width: 600px; height: 200px;\">\n        <p id=\"3dmolwarning_1705745309937566\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745309937566 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745309937566\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nvar viewergrid_1705745309937566 = null;\nviewergrid_1705745309937566 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745309937566\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\nviewer_1705745309937566 = viewergrid_1705745309937566[0][0];\nviewergrid_1705745309937566[0][0].zoomTo();viewergrid_1705745309937566[0][1].zoomTo();\tviewergrid_1705745309937566[0][0].addModel(\"71\\n\\nO          1.02530        0.21520        0.17036\\nC          2.22066       -0.01483        0.01792\\nN          2.95117       -0.69562        0.94095\\nC          2.99813        0.55492       -1.10148\\nC          2.65507        1.95653       -1.52191\\nC          3.66610        2.53680       -2.48106\\nC          4.63743        1.77092       -3.00218\\nN          4.80524        0.41986       -2.69864\\nC          3.97425       -0.13356       -1.72008\\nC          5.77611       -0.39820       -3.46112\\nO          5.08368       -1.35084       -4.29149\\nC          5.74210       -2.63158       -4.16116\\nC          7.09422       -2.34825       -3.50280\\nO          8.06316       -1.85263       -4.46905\\nC          6.79093       -1.16551       -2.59356\\nO          7.98154       -0.40434       -2.32769\\nC          4.84296       -3.57879       -3.37572\\nO          5.40739       -4.87562       -3.34765\\nP          4.38622       -5.97673       -2.48876\\nO          4.96665       -7.07093       -3.38578\\nO          5.06054       -5.49961       -1.19042\\nO          3.36505       -7.07783       -1.62988\\nP          2.68739       -8.51954       -1.81349\\nO          3.68995       -9.65700       -1.78577\\nO          1.52906       -8.61441       -0.82729\\nO          1.92952       -8.53032       -3.28395\\nC          1.83202       -9.85745       -3.81416\\nC          0.56908      -10.26130       -4.61676\\nO          0.22963       -9.39938       -5.73184\\nC          0.51607      -10.09773       -6.96130\\nN          1.11896       -9.19443       -7.91307\\nC          0.67297       -8.93134       -9.18233\\nN          1.47402       -8.10492       -9.82712\\nC          2.48504       -7.82920       -8.91967\\nC          3.64382       -7.04036       -8.98270\\nN          4.41953       -6.92808       -7.87939\\nC          4.07130       -7.62403       -6.76564\\nN          3.02894       -8.46029       -6.63076\\nC          2.26813       -8.48978       -7.72742\\nN          4.02181       -6.33093      -10.12425\\nC          1.36787      -11.31661       -6.61732\\nO          1.18940      -12.39017       -7.55230\\nC          0.80178      -11.65742       -5.24416\\nO         -0.41927      -12.40092       -5.47664\\nH          2.46777       -1.12990        1.71446\\nH          3.94540       -0.85857        0.85102\\nH          2.59605        2.60393       -0.64012\\nH          1.67178        1.96158       -2.00857\\nH          3.57815        3.58144       -2.75311\\nH          5.35645        2.17919       -3.70606\\nH          4.17945       -1.16994       -1.47380\\nH          6.32990        0.25413       -4.14996\\nH          5.88455       -3.03425       -5.17055\\nH          7.54711       -3.19874       -2.98663\\nH          7.77580       -2.16274       -5.34722\\nH          6.37394       -1.49727       -1.63954\\nH          8.58730       -0.64951       -3.06000\\nH          3.86075       -3.63016       -3.86085\\nH          4.67714       -3.21644       -2.35755\\nH          1.84192      -10.57165       -2.97931\\nH          2.73461      -10.02957       -4.40397\\nH         -0.30523      -10.26468       -3.95560\\nH         -0.44469      -10.41406       -7.39068\\nH         -0.23046       -9.37079       -9.58563\\nH          4.70135       -7.50172       -5.88537\\nH          3.22195       -6.12934      -10.71220\\nH          4.60968       -5.55517       -9.84637\\nH          2.43508      -11.08408       -6.55569\\nH          0.58552      -13.01947       -7.10680\\nH          1.46076      -12.31122       -4.66561\\nH         -1.16721      -11.79030       -5.34693\\n\",\"xyz\");\n\tviewergrid_1705745309937566[0][1].addModel(\"70\\n\\nO          1.11799        0.54356       -0.29101\\nC          2.26688        0.23769       -0.02982\\nN          2.98572        0.83644        0.96668\\nC          2.94371       -0.81215       -0.81031\\nC          2.71003       -0.94481       -2.17291\\nC          3.34178       -1.97162       -2.86775\\nC          4.16945       -2.86298       -2.18138\\nN          4.35190       -2.73973       -0.84453\\nC          3.75592       -1.72976       -0.17128\\nC          5.17262       -3.74260       -0.10259\\nO          4.37396       -4.41405        0.88623\\nC          5.06177       -4.31069        2.21422\\nC          6.52676       -4.02199        1.76588\\nO          7.11008       -5.21835        1.15025\\nC          6.37777       -3.09123        0.57016\\nO          7.49089       -3.08501       -0.34074\\nC          4.17330       -3.26110        2.98740\\nO          4.00896       -3.17519        4.41194\\nP          5.38277       -2.72767        5.19204\\nO          6.04200       -4.09963        5.20738\\nO          5.87600       -1.62055        4.25677\\nO          4.88829       -2.07817        6.71871\\nP          6.27335       -1.49277        7.57419\\nO          5.67215       -2.01239        8.88788\\nO          7.29161       -2.22007        6.71046\\nO          7.65840       -0.90737        8.42966\\nC          8.34783       -2.08657        9.04085\\nC          9.66838       -1.84376        9.77936\\nO         10.15771       -3.09467       10.45038\\nC         11.56421       -3.22161       10.13414\\nN         12.18785       -4.55494       10.22758\\nC         13.47684       -4.70489        9.72260\\nN         13.84730       -5.95225        9.61189\\nC         12.91672       -6.60828       10.36363\\nC         12.93930       -7.94823       10.77578\\nN         12.11831       -8.31845       11.77317\\nC         11.24641       -7.38227       12.23282\\nN         11.05357       -6.09320       11.82892\\nC         11.93760       -5.74958       10.87161\\nN         13.88703       -8.83728       10.25507\\nC         11.63698       -2.66258        8.69815\\nO         12.95525       -2.30522        8.26058\\nC         10.78251       -1.41279        8.82410\\nO         11.66311       -0.40868        9.39468\\nH          2.51036        1.53358        1.53073\\nH          3.96483        0.69611        1.18480\\nH          2.04155       -0.25250       -2.68256\\nH          3.17824       -2.08262       -3.93765\\nH          4.67083       -3.67937       -2.69429\\nH          3.92144       -1.67296        0.89073\\nH          5.48804       -4.49464       -0.83989\\nH          4.99619       -5.30059        2.67740\\nH          7.22378       -3.67277        2.52812\\nH          7.03269       -5.93565        1.81039\\nH          6.20272       -2.06064        0.88363\\nH          8.03136       -3.87027       -0.09897\\nH          3.15228       -3.41930        2.62404\\nH          4.44471       -2.26795        2.63905\\nH          8.57585       -2.83600        8.27438\\nH          7.67143       -2.57362        9.74838\\nH          9.50606       -1.10042       10.56613\\nH         12.12364       -2.60736       10.85212\\nH         14.08686       -3.85893        9.44110\\nH         10.63356       -7.71640       13.06755\\nH         14.55639       -8.32526        9.68089\\nH         14.28493       -9.41607       10.98027\\nH         11.20371       -3.37717        7.98771\\nH         13.00120       -1.33159        8.36163\\nH         10.44827       -1.03387        7.85462\\nH         11.28655       -0.12685       10.24641\\n\",\"xyz\");\n\tviewergrid_1705745309937566[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745309937566[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n\tviewergrid_1705745309937566[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745309937566[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewergrid_1705745309937566[0][0].zoomTo();\n\tviewergrid_1705745309937566[0][1].zoomTo();\nviewergrid_1705745309937566[0][1].render();\nviewergrid_1705745309937566[0][0].render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745309937566\"  style=\"position: relative; width: 600px; height: 200px;\">\n",
       "        <p id=\"3dmolwarning_1705745309937566\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745309937566 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745309937566\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "var viewergrid_1705745309937566 = null;\n",
       "viewergrid_1705745309937566 = $3Dmol.createViewerGrid(document.getElementById(\"3dmolviewer_1705745309937566\"),{rows: 1, cols: 2, control_all: false},{backgroundColor:\"white\"});\n",
       "viewer_1705745309937566 = viewergrid_1705745309937566[0][0];\n",
       "viewergrid_1705745309937566[0][0].zoomTo();viewergrid_1705745309937566[0][1].zoomTo();\tviewergrid_1705745309937566[0][0].addModel(\"71\\n\\nO          1.02530        0.21520        0.17036\\nC          2.22066       -0.01483        0.01792\\nN          2.95117       -0.69562        0.94095\\nC          2.99813        0.55492       -1.10148\\nC          2.65507        1.95653       -1.52191\\nC          3.66610        2.53680       -2.48106\\nC          4.63743        1.77092       -3.00218\\nN          4.80524        0.41986       -2.69864\\nC          3.97425       -0.13356       -1.72008\\nC          5.77611       -0.39820       -3.46112\\nO          5.08368       -1.35084       -4.29149\\nC          5.74210       -2.63158       -4.16116\\nC          7.09422       -2.34825       -3.50280\\nO          8.06316       -1.85263       -4.46905\\nC          6.79093       -1.16551       -2.59356\\nO          7.98154       -0.40434       -2.32769\\nC          4.84296       -3.57879       -3.37572\\nO          5.40739       -4.87562       -3.34765\\nP          4.38622       -5.97673       -2.48876\\nO          4.96665       -7.07093       -3.38578\\nO          5.06054       -5.49961       -1.19042\\nO          3.36505       -7.07783       -1.62988\\nP          2.68739       -8.51954       -1.81349\\nO          3.68995       -9.65700       -1.78577\\nO          1.52906       -8.61441       -0.82729\\nO          1.92952       -8.53032       -3.28395\\nC          1.83202       -9.85745       -3.81416\\nC          0.56908      -10.26130       -4.61676\\nO          0.22963       -9.39938       -5.73184\\nC          0.51607      -10.09773       -6.96130\\nN          1.11896       -9.19443       -7.91307\\nC          0.67297       -8.93134       -9.18233\\nN          1.47402       -8.10492       -9.82712\\nC          2.48504       -7.82920       -8.91967\\nC          3.64382       -7.04036       -8.98270\\nN          4.41953       -6.92808       -7.87939\\nC          4.07130       -7.62403       -6.76564\\nN          3.02894       -8.46029       -6.63076\\nC          2.26813       -8.48978       -7.72742\\nN          4.02181       -6.33093      -10.12425\\nC          1.36787      -11.31661       -6.61732\\nO          1.18940      -12.39017       -7.55230\\nC          0.80178      -11.65742       -5.24416\\nO         -0.41927      -12.40092       -5.47664\\nH          2.46777       -1.12990        1.71446\\nH          3.94540       -0.85857        0.85102\\nH          2.59605        2.60393       -0.64012\\nH          1.67178        1.96158       -2.00857\\nH          3.57815        3.58144       -2.75311\\nH          5.35645        2.17919       -3.70606\\nH          4.17945       -1.16994       -1.47380\\nH          6.32990        0.25413       -4.14996\\nH          5.88455       -3.03425       -5.17055\\nH          7.54711       -3.19874       -2.98663\\nH          7.77580       -2.16274       -5.34722\\nH          6.37394       -1.49727       -1.63954\\nH          8.58730       -0.64951       -3.06000\\nH          3.86075       -3.63016       -3.86085\\nH          4.67714       -3.21644       -2.35755\\nH          1.84192      -10.57165       -2.97931\\nH          2.73461      -10.02957       -4.40397\\nH         -0.30523      -10.26468       -3.95560\\nH         -0.44469      -10.41406       -7.39068\\nH         -0.23046       -9.37079       -9.58563\\nH          4.70135       -7.50172       -5.88537\\nH          3.22195       -6.12934      -10.71220\\nH          4.60968       -5.55517       -9.84637\\nH          2.43508      -11.08408       -6.55569\\nH          0.58552      -13.01947       -7.10680\\nH          1.46076      -12.31122       -4.66561\\nH         -1.16721      -11.79030       -5.34693\\n\",\"xyz\");\n",
       "\tviewergrid_1705745309937566[0][1].addModel(\"70\\n\\nO          1.11799        0.54356       -0.29101\\nC          2.26688        0.23769       -0.02982\\nN          2.98572        0.83644        0.96668\\nC          2.94371       -0.81215       -0.81031\\nC          2.71003       -0.94481       -2.17291\\nC          3.34178       -1.97162       -2.86775\\nC          4.16945       -2.86298       -2.18138\\nN          4.35190       -2.73973       -0.84453\\nC          3.75592       -1.72976       -0.17128\\nC          5.17262       -3.74260       -0.10259\\nO          4.37396       -4.41405        0.88623\\nC          5.06177       -4.31069        2.21422\\nC          6.52676       -4.02199        1.76588\\nO          7.11008       -5.21835        1.15025\\nC          6.37777       -3.09123        0.57016\\nO          7.49089       -3.08501       -0.34074\\nC          4.17330       -3.26110        2.98740\\nO          4.00896       -3.17519        4.41194\\nP          5.38277       -2.72767        5.19204\\nO          6.04200       -4.09963        5.20738\\nO          5.87600       -1.62055        4.25677\\nO          4.88829       -2.07817        6.71871\\nP          6.27335       -1.49277        7.57419\\nO          5.67215       -2.01239        8.88788\\nO          7.29161       -2.22007        6.71046\\nO          7.65840       -0.90737        8.42966\\nC          8.34783       -2.08657        9.04085\\nC          9.66838       -1.84376        9.77936\\nO         10.15771       -3.09467       10.45038\\nC         11.56421       -3.22161       10.13414\\nN         12.18785       -4.55494       10.22758\\nC         13.47684       -4.70489        9.72260\\nN         13.84730       -5.95225        9.61189\\nC         12.91672       -6.60828       10.36363\\nC         12.93930       -7.94823       10.77578\\nN         12.11831       -8.31845       11.77317\\nC         11.24641       -7.38227       12.23282\\nN         11.05357       -6.09320       11.82892\\nC         11.93760       -5.74958       10.87161\\nN         13.88703       -8.83728       10.25507\\nC         11.63698       -2.66258        8.69815\\nO         12.95525       -2.30522        8.26058\\nC         10.78251       -1.41279        8.82410\\nO         11.66311       -0.40868        9.39468\\nH          2.51036        1.53358        1.53073\\nH          3.96483        0.69611        1.18480\\nH          2.04155       -0.25250       -2.68256\\nH          3.17824       -2.08262       -3.93765\\nH          4.67083       -3.67937       -2.69429\\nH          3.92144       -1.67296        0.89073\\nH          5.48804       -4.49464       -0.83989\\nH          4.99619       -5.30059        2.67740\\nH          7.22378       -3.67277        2.52812\\nH          7.03269       -5.93565        1.81039\\nH          6.20272       -2.06064        0.88363\\nH          8.03136       -3.87027       -0.09897\\nH          3.15228       -3.41930        2.62404\\nH          4.44471       -2.26795        2.63905\\nH          8.57585       -2.83600        8.27438\\nH          7.67143       -2.57362        9.74838\\nH          9.50606       -1.10042       10.56613\\nH         12.12364       -2.60736       10.85212\\nH         14.08686       -3.85893        9.44110\\nH         10.63356       -7.71640       13.06755\\nH         14.55639       -8.32526        9.68089\\nH         14.28493       -9.41607       10.98027\\nH         11.20371       -3.37717        7.98771\\nH         13.00120       -1.33159        8.36163\\nH         10.44827       -1.03387        7.85462\\nH         11.28655       -0.12685       10.24641\\n\",\"xyz\");\n",
       "\tviewergrid_1705745309937566[0][0].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745309937566[0][1].setViewStyle({\"style\": \"outline\", \"width\": 0.05});\n",
       "\tviewergrid_1705745309937566[0][0].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745309937566[0][1].setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewergrid_1705745309937566[0][0].zoomTo();\n",
       "\tviewergrid_1705745309937566[0][1].zoomTo();\n",
       "viewergrid_1705745309937566[0][1].render();\n",
       "viewergrid_1705745309937566[0][0].render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "nadh_xyz = vlx.Molecule.smiles_to_xyz(\n",
    "    \"O=C(N)C1CC=C[N](C=1)[C@@H]2O[C@@H]([C@@H](O)[C@H]2O)COP([O-])(=O)OP(=O)([O-])OC[C@H]5O[C@@H](n4cnc3c(ncnc34)N)[C@H](O)[C@@H]5O\"\n",
    ")\n",
    "nadp_xyz = vlx.Molecule.smiles_to_xyz(\n",
    "    \"O=C(N)c1ccc[n+](c1)[C@@H]2O[C@@H]([C@@H](O)[C@H]2O)COP([O-])(=O)OP(=O)([O-])OC[C@H]5O[C@@H](n4cnc3c(ncnc34)N)[C@H](O)[C@@H]5O\"\n",
    ")\n",
    "\n",
    "viewer = p3d.view(viewergrid=(1, 2), width=600, height=200, linked=False)\n",
    "viewer.addModel(nadh_xyz, \"xyz\", viewer=(0, 0))\n",
    "viewer.addModel(nadp_xyz, \"xyz\", viewer=(0, 1))\n",
    "viewer.setViewStyle({\"style\": \"outline\", \"width\": 0.05})\n",
    "viewer.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "viewer.zoomTo()\n",
    "viewer.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "ca3e62d5",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "# Using a structure downloaded from the PDB databank "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "id": "36c06819",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1705745312876235\"  style=\"position: relative; width: 640px; height: 480px;\">\n        <p id=\"3dmolwarning_1705745312876235\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    //this is to ignore the existence of requirejs amd\n    var savedexports, savedmodule;\n    if (typeof exports !== 'undefined') savedexports = exports;\n    else exports = {}\n    if (typeof module !== 'undefined') savedmodule = module;\n    else module = {}\n\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n        exports = savedexports;\n        module = savedmodule;\n        resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n}\n\nvar viewer_1705745312876235 = null;\nvar warn = document.getElementById(\"3dmolwarning_1705745312876235\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_1705745312876235 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_1705745312876235\"),{backgroundColor:\"white\"});\nviewer_1705745312876235.zoomTo();\n\tviewer_1705745312876235.addModel(\"HEADER    DNA BINDING PROTEIN/DNA                 03-JUL-97   1AOI              \\nTITLE     COMPLEX BETWEEN NUCLEOSOME CORE PARTICLE (H3,H4,H2A,H2B)              \\nTITLE    2 AND 146 BP LONG DNA FRAGMENT                                         \\nCOMPND    MOL_ID: 1;                                                            \\nCOMPND   2 MOLECULE: PALINDROMIC 146 BP DNA REPEAT 8/9 FROM HUMAN X-            \\nCOMPND   3 CHROMOSOME ALPHA SATELLITE DNA;                                      \\nCOMPND   4 CHAIN: I, J;                                                         \\nCOMPND   5 ENGINEERED: YES;                                                     \\nCOMPND   6 MOL_ID: 2;                                                           \\nCOMPND   7 MOLECULE: HISTONE H3;                                                \\nCOMPND   8 CHAIN: A, E;                                                         \\nCOMPND   9 FRAGMENT: HISTONE H3;                                                \\nCOMPND  10 ENGINEERED: YES;                                                     \\nCOMPND  11 MOL_ID: 3;                                                           \\nCOMPND  12 MOLECULE: HISTONE H4;                                                \\nCOMPND  13 CHAIN: B, F;                                                         \\nCOMPND  14 FRAGMENT: HISTONE H4;                                                \\nCOMPND  15 ENGINEERED: YES;                                                     \\nCOMPND  16 MOL_ID: 4;                                                           \\nCOMPND  17 MOLECULE: HISTONE H2A;                                               \\nCOMPND  18 CHAIN: C, G;                                                         \\nCOMPND  19 FRAGMENT: HISTONE H2A;                                               \\nCOMPND  20 ENGINEERED: YES;                                                     \\nCOMPND  21 MOL_ID: 5;                                                           \\nCOMPND  22 MOLECULE: HISTONE H2B;                                               \\nCOMPND  23 CHAIN: D, H;                                                         \\nCOMPND  24 FRAGMENT: HISTONE H2B;                                               \\nCOMPND  25 ENGINEERED: YES;                                                     \\nCOMPND  26 MUTATION: YES                                                        \\nSOURCE    MOL_ID: 1;                                                            \\nSOURCE   2 SYNTHETIC: YES;                                                      \\nSOURCE   3 MOL_ID: 2;                                                           \\nSOURCE   4 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE   5 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE   6 ORGANISM_TAXID: 8355;                                                \\nSOURCE   7 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE   8 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE   9 MOL_ID: 3;                                                           \\nSOURCE  10 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  11 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  12 ORGANISM_TAXID: 8355;                                                \\nSOURCE  13 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  14 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE  15 OTHER_DETAILS: SYNTHETIC GENE, OPTIMIZED CODON USAGE FOR             \\nSOURCE  16 ESCHERICHIA COLI;                                                    \\nSOURCE  17 MOL_ID: 4;                                                           \\nSOURCE  18 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  19 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  20 ORGANISM_TAXID: 8355;                                                \\nSOURCE  21 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  22 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE  23 MOL_ID: 5;                                                           \\nSOURCE  24 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  25 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  26 ORGANISM_TAXID: 8355;                                                \\nSOURCE  27 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  28 EXPRESSION_SYSTEM_TAXID: 562                                         \\nKEYWDS    NUCLEOSOME, CHROMATIN, HISTONE, PROTEIN DNA INTERACTION,              \\nKEYWDS   2 NUCLEOPROTEIN, SUPERCOILED DNA, DNA BINDING PROTEIN/DNA              \\nKEYWDS   3 COMPLEX                                                              \\nEXPDTA    X-RAY DIFFRACTION                                                     \\nAUTHOR    K.LUGER,A.W.MAEDER,R.K.RICHMOND,D.F.SARGENT,T.J.RICHMOND              \\nREVDAT   3   24-FEB-09 1AOI    1       VERSN                                    \\nREVDAT   2   01-APR-03 1AOI    1       JRNL                                     \\nREVDAT   1   30-SEP-98 1AOI    0                                                \\nJRNL        AUTH   K.LUGER,A.W.MADER,R.K.RICHMOND,D.F.SARGENT,                  \\nJRNL        AUTH 2 T.J.RICHMOND                                                 \\nJRNL        TITL   CRYSTAL STRUCTURE OF THE NUCLEOSOME CORE PARTICLE            \\nJRNL        TITL 2 AT 2.8 A RESOLUTION.                                         \\nJRNL        REF    NATURE                        V. 389   251 1997              \\nJRNL        REFN                   ISSN 0028-0836                               \\nJRNL        PMID   9305837                                                      \\nJRNL        DOI    10.1038/38444                                                \\nREMARK   1                                                                      \\nREMARK   2                                                                      \\nREMARK   2 RESOLUTION.    2.80 ANGSTROMS.                                       \\nREMARK   3                                                                      \\nREMARK   3 REFINEMENT.                                                          \\nREMARK   3   PROGRAM     : X-PLOR 3.843                                         \\nREMARK   3   AUTHORS     : BRUNGER                                              \\nREMARK   3                                                                      \\nREMARK   3  DATA USED IN REFINEMENT.                                            \\nREMARK   3   RESOLUTION RANGE HIGH (ANGSTROMS) : 2.80                           \\nREMARK   3   RESOLUTION RANGE LOW  (ANGSTROMS) : 25.00                          \\nREMARK   3   DATA CUTOFF            (SIGMA(F)) : NULL                           \\nREMARK   3   DATA CUTOFF HIGH         (ABS(F)) : NULL                           \\nREMARK   3   DATA CUTOFF LOW          (ABS(F)) : NULL                           \\nREMARK   3   COMPLETENESS (WORKING+TEST)   (%) : NULL                           \\nREMARK   3   NUMBER OF REFLECTIONS             : 51237                          \\nREMARK   3                                                                      \\nREMARK   3  FIT TO DATA USED IN REFINEMENT.                                     \\nREMARK   3   CROSS-VALIDATION METHOD          : THROUGHOUT                      \\nREMARK   3   FREE R VALUE TEST SET SELECTION  : RANDOM                          \\nREMARK   3   R VALUE            (WORKING SET) : 0.224                           \\nREMARK   3   FREE R VALUE                     : 0.302                           \\nREMARK   3   FREE R VALUE TEST SET SIZE   (%) : NULL                            \\nREMARK   3   FREE R VALUE TEST SET COUNT      : NULL                            \\nREMARK   3   ESTIMATED ERROR OF FREE R VALUE  : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  FIT IN THE HIGHEST RESOLUTION BIN.                                  \\nREMARK   3   TOTAL NUMBER OF BINS USED           : NULL                         \\nREMARK   3   BIN RESOLUTION RANGE HIGH       (A) : NULL                         \\nREMARK   3   BIN RESOLUTION RANGE LOW        (A) : NULL                         \\nREMARK   3   BIN COMPLETENESS (WORKING+TEST) (%) : NULL                         \\nREMARK   3   REFLECTIONS IN BIN    (WORKING SET) : NULL                         \\nREMARK   3   BIN R VALUE           (WORKING SET) : NULL                         \\nREMARK   3   BIN FREE R VALUE                    : NULL                         \\nREMARK   3   BIN FREE R VALUE TEST SET SIZE  (%) : NULL                         \\nREMARK   3   BIN FREE R VALUE TEST SET COUNT     : NULL                         \\nREMARK   3   ESTIMATED ERROR OF BIN FREE R VALUE : NULL                         \\nREMARK   3                                                                      \\nREMARK   3  NUMBER OF NON-HYDROGEN ATOMS USED IN REFINEMENT.                    \\nREMARK   3   PROTEIN ATOMS            : 6387                                    \\nREMARK   3   NUCLEIC ACID ATOMS       : 5980                                    \\nREMARK   3   HETEROGEN ATOMS          : 6                                       \\nREMARK   3   SOLVENT ATOMS            : 13                                      \\nREMARK   3                                                                      \\nREMARK   3  B VALUES.                                                           \\nREMARK   3   FROM WILSON PLOT           (A**2) : NULL                           \\nREMARK   3   MEAN B VALUE      (OVERALL, A**2) : NULL                           \\nREMARK   3   OVERALL ANISOTROPIC B VALUE.                                       \\nREMARK   3    B11 (A**2) : NULL                                                 \\nREMARK   3    B22 (A**2) : NULL                                                 \\nREMARK   3    B33 (A**2) : NULL                                                 \\nREMARK   3    B12 (A**2) : NULL                                                 \\nREMARK   3    B13 (A**2) : NULL                                                 \\nREMARK   3    B23 (A**2) : NULL                                                 \\nREMARK   3                                                                      \\nREMARK   3  ESTIMATED COORDINATE ERROR.                                         \\nREMARK   3   ESD FROM LUZZATI PLOT        (A) : NULL                            \\nREMARK   3   ESD FROM SIGMAA              (A) : NULL                            \\nREMARK   3   LOW RESOLUTION CUTOFF        (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  CROSS-VALIDATED ESTIMATED COORDINATE ERROR.                         \\nREMARK   3   ESD FROM C-V LUZZATI PLOT    (A) : NULL                            \\nREMARK   3   ESD FROM C-V SIGMAA          (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  RMS DEVIATIONS FROM IDEAL VALUES.                                   \\nREMARK   3   BOND LENGTHS                 (A) : 0.009                           \\nREMARK   3   BOND ANGLES            (DEGREES) : 1.30                            \\nREMARK   3   DIHEDRAL ANGLES        (DEGREES) : NULL                            \\nREMARK   3   IMPROPER ANGLES        (DEGREES) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL MODEL : RESTRAINED                                \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL FACTOR RESTRAINTS.    RMS    SIGMA                \\nREMARK   3   MAIN-CHAIN BOND              (A**2) : NULL  ; NULL                 \\nREMARK   3   MAIN-CHAIN ANGLE             (A**2) : NULL  ; NULL                 \\nREMARK   3   SIDE-CHAIN BOND              (A**2) : NULL  ; NULL                 \\nREMARK   3   SIDE-CHAIN ANGLE             (A**2) : NULL  ; NULL                 \\nREMARK   3                                                                      \\nREMARK   3  NCS MODEL : NULL                                                    \\nREMARK   3                                                                      \\nREMARK   3  NCS RESTRAINTS.                         RMS   SIGMA/WEIGHT          \\nREMARK   3   GROUP  1  POSITIONAL            (A) : NULL  ; NULL                 \\nREMARK   3   GROUP  1  B-FACTOR           (A**2) : NULL  ; NULL                 \\nREMARK   3                                                                      \\nREMARK   3  PARAMETER FILE  1  : NULL                                           \\nREMARK   3  TOPOLOGY FILE  1   : NULL                                           \\nREMARK   3                                                                      \\nREMARK   3  OTHER REFINEMENT REMARKS: BULK SOLVENT MODEL USED                   \\nREMARK   4                                                                      \\nREMARK   4 1AOI COMPLIES WITH FORMAT V. 3.15, 01-DEC-08                         \\nREMARK 100                                                                      \\nREMARK 100 THIS ENTRY HAS BEEN PROCESSED BY BNL.                                \\nREMARK 200                                                                      \\nREMARK 200 EXPERIMENTAL DETAILS                                                 \\nREMARK 200  EXPERIMENT TYPE                : X-RAY DIFFRACTION                  \\nREMARK 200  DATE OF DATA COLLECTION        : 15-AUG-95                          \\nREMARK 200  TEMPERATURE           (KELVIN) : 110.0                              \\nREMARK 200  PH                             : NULL                               \\nREMARK 200  NUMBER OF CRYSTALS USED        : 1                                  \\nREMARK 200                                                                      \\nREMARK 200  SYNCHROTRON              (Y/N) : Y                                  \\nREMARK 200  RADIATION SOURCE               : ESRF                               \\nREMARK 200  BEAMLINE                       : ID13                               \\nREMARK 200  X-RAY GENERATOR MODEL          : NULL                               \\nREMARK 200  MONOCHROMATIC OR LAUE    (M/L) : M                                  \\nREMARK 200  WAVELENGTH OR RANGE        (A) : NULL                               \\nREMARK 200  MONOCHROMATOR                  : NULL                               \\nREMARK 200  OPTICS                         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  DETECTOR TYPE                  : IMAGE PLATE                        \\nREMARK 200  DETECTOR MANUFACTURER          : MARRESEARCH                        \\nREMARK 200  INTENSITY-INTEGRATION SOFTWARE : IN-HOUSE SOFTWARE                  \\nREMARK 200  DATA SCALING SOFTWARE          : IN-HOUSE SOFTWARE                  \\nREMARK 200                                                                      \\nREMARK 200  NUMBER OF UNIQUE REFLECTIONS   : 52487                              \\nREMARK 200  RESOLUTION RANGE HIGH      (A) : 2.800                              \\nREMARK 200  RESOLUTION RANGE LOW       (A) : 25.000                             \\nREMARK 200  REJECTION CRITERIA  (SIGMA(I)) : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 OVERALL.                                                             \\nREMARK 200  COMPLETENESS FOR RANGE     (%) : 99.0                               \\nREMARK 200  DATA REDUNDANCY                : 5.700                              \\nREMARK 200  R MERGE                    (I) : 0.05600                            \\nREMARK 200  R SYM                      (I) : 3.60000                            \\nREMARK 200  <I/SIGMA(I)> FOR THE DATA SET  : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 IN THE HIGHEST RESOLUTION SHELL.                                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE HIGH (A) : 2.80                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE LOW  (A) : 2.85                     \\nREMARK 200  COMPLETENESS FOR SHELL     (%) : 95.0                               \\nREMARK 200  DATA REDUNDANCY IN SHELL       : 6.30                               \\nREMARK 200  R MERGE FOR SHELL          (I) : 0.13200                            \\nREMARK 200  R SYM FOR SHELL            (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR SHELL         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 DIFFRACTION PROTOCOL: SINGLE WAVELENGTH                              \\nREMARK 200 METHOD USED TO DETERMINE THE STRUCTURE: MIR                          \\nREMARK 200 SOFTWARE USED: IN-HOUSE SOFTWARE                                     \\nREMARK 200 STARTING MODEL: NULL                                                 \\nREMARK 200                                                                      \\nREMARK 200 REMARK: NULL                                                         \\nREMARK 280                                                                      \\nREMARK 280 CRYSTAL                                                              \\nREMARK 280 SOLVENT CONTENT, VS   (%): 56.54                                     \\nREMARK 280 MATTHEWS COEFFICIENT, VM (ANGSTROMS**3/DA): 2.83                     \\nREMARK 280                                                                      \\nREMARK 280 CRYSTALLIZATION CONDITIONS: NULL                                     \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY                                            \\nREMARK 290 SYMMETRY OPERATORS FOR SPACE GROUP: P 21 21 21                       \\nREMARK 290                                                                      \\nREMARK 290      SYMOP   SYMMETRY                                                \\nREMARK 290     NNNMMM   OPERATOR                                                \\nREMARK 290       1555   X,Y,Z                                                   \\nREMARK 290       2555   -X+1/2,-Y,Z+1/2                                         \\nREMARK 290       3555   -X,Y+1/2,-Z+1/2                                         \\nREMARK 290       4555   X+1/2,-Y+1/2,-Z                                         \\nREMARK 290                                                                      \\nREMARK 290     WHERE NNN -> OPERATOR NUMBER                                     \\nREMARK 290           MMM -> TRANSLATION VECTOR                                  \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY TRANSFORMATIONS                            \\nREMARK 290 THE FOLLOWING TRANSFORMATIONS OPERATE ON THE ATOM/HETATM             \\nREMARK 290 RECORDS IN THIS ENTRY TO PRODUCE CRYSTALLOGRAPHICALLY                \\nREMARK 290 RELATED MOLECULES.                                                   \\nREMARK 290   SMTRY1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 290   SMTRY1   2 -1.000000  0.000000  0.000000       53.02000            \\nREMARK 290   SMTRY2   2  0.000000 -1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   2  0.000000  0.000000  1.000000       55.06000            \\nREMARK 290   SMTRY1   3 -1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   3  0.000000  1.000000  0.000000       90.89000            \\nREMARK 290   SMTRY3   3  0.000000  0.000000 -1.000000       55.06000            \\nREMARK 290   SMTRY1   4  1.000000  0.000000  0.000000       53.02000            \\nREMARK 290   SMTRY2   4  0.000000 -1.000000  0.000000       90.89000            \\nREMARK 290   SMTRY3   4  0.000000  0.000000 -1.000000        0.00000            \\nREMARK 290                                                                      \\nREMARK 290 REMARK: NULL                                                         \\nREMARK 300                                                                      \\nREMARK 300 BIOMOLECULE: 1                                                       \\nREMARK 300 SEE REMARK 350 FOR THE AUTHOR PROVIDED AND/OR PROGRAM                \\nREMARK 300 GENERATED ASSEMBLY INFORMATION FOR THE STRUCTURE IN                  \\nREMARK 300 THIS ENTRY. THE REMARK MAY ALSO PROVIDE INFORMATION ON               \\nREMARK 300 BURIED SURFACE AREA.                                                 \\nREMARK 350                                                                      \\nREMARK 350 COORDINATES FOR A COMPLETE MULTIMER REPRESENTING THE KNOWN           \\nREMARK 350 BIOLOGICALLY SIGNIFICANT OLIGOMERIZATION STATE OF THE                \\nREMARK 350 MOLECULE CAN BE GENERATED BY APPLYING BIOMT TRANSFORMATIONS          \\nREMARK 350 GIVEN BELOW.  BOTH NON-CRYSTALLOGRAPHIC AND                          \\nREMARK 350 CRYSTALLOGRAPHIC OPERATIONS ARE GIVEN.                               \\nREMARK 350                                                                      \\nREMARK 350 BIOMOLECULE: 1                                                       \\nREMARK 350 AUTHOR DETERMINED BIOLOGICAL UNIT: DECAMERIC                         \\nREMARK 350 APPLY THE FOLLOWING TO CHAINS: I, J, A, B, C, D, E, F, G, H          \\nREMARK 350   BIOMT1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 350   BIOMT2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 350   BIOMT3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 465                                                                      \\nREMARK 465 MISSING RESIDUES                                                     \\nREMARK 465 THE FOLLOWING RESIDUES WERE NOT LOCATED IN THE                       \\nREMARK 465 EXPERIMENT. (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN               \\nREMARK 465 IDENTIFIER; SSSEQ=SEQUENCE NUMBER; I=INSERTION CODE.)                \\nREMARK 465                                                                      \\nREMARK 465   M RES C SSSEQI                                                     \\nREMARK 465     LEU A    20                                                      \\nREMARK 465     ALA A    21                                                      \\nREMARK 465     THR A    22                                                      \\nREMARK 465     LYS A    23                                                      \\nREMARK 465     ALA A    24                                                      \\nREMARK 465     ALA A    25                                                      \\nREMARK 465     ARG A    26                                                      \\nREMARK 465     LYS A    27                                                      \\nREMARK 465     SER A    28                                                      \\nREMARK 465     ALA A    29                                                      \\nREMARK 465     PRO A    30                                                      \\nREMARK 465     ALA A    31                                                      \\nREMARK 465     THR A    32                                                      \\nREMARK 465     GLY A    33                                                      \\nREMARK 465     GLY A    34                                                      \\nREMARK 465     VAL A    35                                                      \\nREMARK 465     LYS A    36                                                      \\nREMARK 465     LYS A    37                                                      \\nREMARK 465     LYS B    16                                                      \\nREMARK 465     ARG B    17                                                      \\nREMARK 465     HIS B    18                                                      \\nREMARK 465     ARG B    19                                                      \\nREMARK 465     LYS C   119                                                      \\nREMARK 465     GLY G     4                                                      \\nREMARK 465     LYS G     5                                                      \\nREMARK 465     GLN G     6                                                      \\nREMARK 465     GLY G     7                                                      \\nREMARK 465     GLY G     8                                                      \\nREMARK 465     LYS G     9                                                      \\nREMARK 465     THR G    10                                                      \\nREMARK 465     ARG G    11                                                      \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS                                             \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS THAT ARE RELATED BY CRYSTALLOGRAPHIC             \\nREMARK 500 SYMMETRY ARE IN CLOSE CONTACT.  AN ATOM LOCATED WITHIN 0.15          \\nREMARK 500 ANGSTROMS OF A SYMMETRY RELATED ATOM IS ASSUMED TO BE ON A           \\nREMARK 500 SPECIAL POSITION AND IS, THEREFORE, LISTED IN REMARK 375             \\nREMARK 500 INSTEAD OF REMARK 500.  ATOMS WITH NON-BLANK ALTERNATE               \\nREMARK 500 LOCATION INDICATORS ARE NOT INCLUDED IN THE CALCULATIONS.            \\nREMARK 500                                                                      \\nREMARK 500 DISTANCE CUTOFF:                                                     \\nREMARK 500 2.2 ANGSTROMS FOR CONTACTS NOT INVOLVING HYDROGEN ATOMS              \\nREMARK 500 1.6 ANGSTROMS FOR CONTACTS INVOLVING HYDROGEN ATOMS                  \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI  SSYMOP   DISTANCE          \\nREMARK 500   O    VAL D    45     O    HOH E     6     2565     2.17            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: TORSION ANGLES                                             \\nREMARK 500                                                                      \\nREMARK 500 TORSION ANGLES OUTSIDE THE EXPECTED RAMACHANDRAN REGIONS:            \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500 STANDARD TABLE:                                                      \\nREMARK 500 FORMAT:(10X,I3,1X,A3,1X,A1,I4,A1,4X,F7.2,3X,F7.2)                    \\nREMARK 500                                                                      \\nREMARK 500 EXPECTED VALUES: GJ KLEYWEGT AND TA JONES (1996). PHI/PSI-           \\nREMARK 500 CHOLOGY: RAMACHANDRAN REVISITED. STRUCTURE 4, 1395 - 1400            \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        PSI       PHI                                   \\nREMARK 500    THR A  58       -0.56   -140.04                                   \\nREMARK 500    VAL B  21      -56.84   -168.14                                   \\nREMARK 500    THR B  96      123.60    -28.14                                   \\nREMARK 500    LYS C   9     -153.63   -150.77                                   \\nREMARK 500    THR C  10      166.13    -48.94                                   \\nREMARK 500    ARG C  11      158.27     62.51                                   \\nREMARK 500    ALA C  12      -85.54     77.55                                   \\nREMARK 500    LYS C  13      134.79     73.65                                   \\nREMARK 500    ALA C  14      170.84    -36.88                                   \\nREMARK 500    LYS C  36        0.65    -65.94                                   \\nREMARK 500    ASN C  38       74.42     50.34                                   \\nREMARK 500    VAL C 114        2.88    -68.57                                   \\nREMARK 500    PRO C 117     -177.41    -65.56                                   \\nREMARK 500    LYS D  28     -152.63    -76.88                                   \\nREMARK 500    THR D  29      -63.57   -156.41                                   \\nREMARK 500    ARG D  30      115.48     56.44                                   \\nREMARK 500    ALA E  21      -23.68   -142.38                                   \\nREMARK 500    THR E  22      171.32    -40.96                                   \\nREMARK 500    LYS E  23      -84.48    -42.26                                   \\nREMARK 500    ALA E  25      -21.97    159.76                                   \\nREMARK 500    ARG E  26      107.78    -33.89                                   \\nREMARK 500    LYS E  27       50.96     24.91                                   \\nREMARK 500    LYS E  37      -94.57    -68.87                                   \\nREMARK 500    PRO E  38     -153.92   -109.18                                   \\nREMARK 500    ARG E 134       44.52   -172.12                                   \\nREMARK 500    ARG F  17      -90.19    -66.91                                   \\nREMARK 500    HIS F  18     -155.92   -148.34                                   \\nREMARK 500    ARG F  19      127.24     76.29                                   \\nREMARK 500    THR F  96      120.55    -19.56                                   \\nREMARK 500    THR G  16      161.78    -23.63                                   \\nREMARK 500    LYS H  25      -97.48     53.01                                   \\nREMARK 500    ARG H  26       95.08     75.97                                   \\nREMARK 500    ARG H  27      124.56   -178.79                                   \\nREMARK 500    THR H  29      -85.15     91.54                                   \\nREMARK 500    ARG H  30      132.30     83.76                                   \\nREMARK 500    ALA H 121      127.26    111.53                                   \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: PLANAR GROUPS                                              \\nREMARK 500                                                                      \\nREMARK 500 PLANAR GROUPS IN THE FOLLOWING RESIDUES HAVE A TOTAL                 \\nREMARK 500 RMS DISTANCE OF ALL ATOMS FROM THE BEST-FIT PLANE                    \\nREMARK 500 BY MORE THAN AN EXPECTED VALUE OF 6*RMSD, WITH AN                    \\nREMARK 500 RMSD 0.02 ANGSTROMS, OR AT LEAST ONE ATOM HAS                        \\nREMARK 500 AN RMSD GREATER THAN THIS VALUE                                      \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        RMS     TYPE                                    \\nREMARK 500     DT I  96         0.06    SIDE_CHAIN                              \\nREMARK 500     DG I 131         0.07    SIDE_CHAIN                              \\nREMARK 500     DA I 145         0.07    SIDE_CHAIN                              \\nREMARK 500     DA J 147         0.06    SIDE_CHAIN                              \\nREMARK 500     DC J 158         0.06    SIDE_CHAIN                              \\nREMARK 500     DG J 185         0.06    SIDE_CHAIN                              \\nREMARK 500     DG J 214         0.06    SIDE_CHAIN                              \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 800                                                                      \\nREMARK 800 SITE                                                                 \\nREMARK 800 SITE_IDENTIFIER: AC1                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE MN J 400                  \\nDBREF  1AOI A   20   135  UNP    P02302   H32_XENLA       20    135             \\nDBREF  1AOI B   16   102  UNP    P62799   H4_XENLA        17    103             \\nDBREF  1AOI C    4   119  UNP    P06897   H2A1_XENLA       4    119             \\nDBREF  1AOI D   24   122  UNP    P02281   H2B1_XENLA      27    125             \\nDBREF  1AOI E   20   135  UNP    P02302   H32_XENLA       21    136             \\nDBREF  1AOI F   16   102  UNP    P62799   H4_XENLA        17    103             \\nDBREF  1AOI G    4   119  UNP    P06897   H2A1_XENLA       4    119             \\nDBREF  1AOI H   24   122  UNP    P02281   H2B1_XENLA      27    125             \\nDBREF  1AOI I    1   146  PDB    1AOI     1AOI             1    146             \\nDBREF  1AOI J  147   292  PDB    1AOI     1AOI           147    292             \\nSEQADV 1AOI ALA A   21  UNP  P02302    VAL    21 CONFLICT                       \\nSEQADV 1AOI ARG A   26  UNP  P02302    LYS    26 CONFLICT                       \\nSEQADV 1AOI SER A   28  UNP  P02302    CYS    28 CONFLICT                       \\nSEQADV 1AOI SER A   86  UNP  P02302    ARG    86 CONFLICT                       \\nSEQADV 1AOI ARG C   99  UNP  P06897    GLY    99 CONFLICT                       \\nSEQADV 1AOI THR D   29  UNP  P02281    SER    32 CONFLICT                       \\nSEQADV 1AOI ALA E   21  UNP  P02302    VAL    21 CONFLICT                       \\nSEQADV 1AOI ARG E   26  UNP  P02302    LYS    26 CONFLICT                       \\nSEQADV 1AOI SER E   28  UNP  P02302    CYS    28 CONFLICT                       \\nSEQADV 1AOI SER E   86  UNP  P02302    ARG    86 CONFLICT                       \\nSEQADV 1AOI ARG G   99  UNP  P06897    GLY    99 CONFLICT                       \\nSEQADV 1AOI THR H   29  UNP  P02281    SER    32 CONFLICT                       \\nSEQRES   1 I  146   DA  DT  DC  DA  DA  DT  DA  DT  DC  DC  DA  DC  DC          \\nSEQRES   2 I  146   DT  DG  DC  DA  DG  DA  DT  DT  DC  DT  DA  DC  DC          \\nSEQRES   3 I  146   DA  DA  DA  DA  DG  DT  DG  DT  DA  DT  DT  DT  DG          \\nSEQRES   4 I  146   DG  DA  DA  DA  DC  DT  DG  DC  DT  DC  DC  DA  DT          \\nSEQRES   5 I  146   DC  DA  DA  DA  DA  DG  DG  DC  DA  DT  DG  DT  DT          \\nSEQRES   6 I  146   DC  DA  DG  DC  DT  DG  DA  DA  DT  DT  DC  DA  DG          \\nSEQRES   7 I  146   DC  DT  DG  DA  DA  DC  DA  DT  DG  DC  DC  DT  DT          \\nSEQRES   8 I  146   DT  DT  DG  DA  DT  DG  DG  DA  DG  DC  DA  DG  DT          \\nSEQRES   9 I  146   DT  DT  DC  DC  DA  DA  DA  DT  DA  DC  DA  DC  DT          \\nSEQRES  10 I  146   DT  DT  DT  DG  DG  DT  DA  DG  DA  DA  DT  DC  DT          \\nSEQRES  11 I  146   DG  DC  DA  DG  DG  DT  DG  DG  DA  DT  DA  DT  DT          \\nSEQRES  12 I  146   DG  DA  DT                                                  \\nSEQRES   1 J  146   DA  DT  DC  DA  DA  DT  DA  DT  DC  DC  DA  DC  DC          \\nSEQRES   2 J  146   DT  DG  DC  DA  DG  DA  DT  DT  DC  DT  DA  DC  DC          \\nSEQRES   3 J  146   DA  DA  DA  DA  DG  DT  DG  DT  DA  DT  DT  DT  DG          \\nSEQRES   4 J  146   DG  DA  DA  DA  DC  DT  DG  DC  DT  DC  DC  DA  DT          \\nSEQRES   5 J  146   DC  DA  DA  DA  DA  DG  DG  DC  DA  DT  DG  DT  DT          \\nSEQRES   6 J  146   DC  DA  DG  DC  DT  DG  DA  DA  DT  DT  DC  DA  DG          \\nSEQRES   7 J  146   DC  DT  DG  DA  DA  DC  DA  DT  DG  DC  DC  DT  DT          \\nSEQRES   8 J  146   DT  DT  DG  DA  DT  DG  DG  DA  DG  DC  DA  DG  DT          \\nSEQRES   9 J  146   DT  DT  DC  DC  DA  DA  DA  DT  DA  DC  DA  DC  DT          \\nSEQRES  10 J  146   DT  DT  DT  DG  DG  DT  DA  DG  DA  DA  DT  DC  DT          \\nSEQRES  11 J  146   DG  DC  DA  DG  DG  DT  DG  DG  DA  DT  DA  DT  DT          \\nSEQRES  12 J  146   DG  DA  DT                                                  \\nSEQRES   1 A  116  LEU ALA THR LYS ALA ALA ARG LYS SER ALA PRO ALA THR          \\nSEQRES   2 A  116  GLY GLY VAL LYS LYS PRO HIS ARG TYR ARG PRO GLY THR          \\nSEQRES   3 A  116  VAL ALA LEU ARG GLU ILE ARG ARG TYR GLN LYS SER THR          \\nSEQRES   4 A  116  GLU LEU LEU ILE ARG LYS LEU PRO PHE GLN ARG LEU VAL          \\nSEQRES   5 A  116  ARG GLU ILE ALA GLN ASP PHE LYS THR ASP LEU ARG PHE          \\nSEQRES   6 A  116  GLN SER SER ALA VAL MET ALA LEU GLN GLU ALA SER GLU          \\nSEQRES   7 A  116  ALA TYR LEU VAL ALA LEU PHE GLU ASP THR ASN LEU CYS          \\nSEQRES   8 A  116  ALA ILE HIS ALA LYS ARG VAL THR ILE MET PRO LYS ASP          \\nSEQRES   9 A  116  ILE GLN LEU ALA ARG ARG ILE ARG GLY GLU ARG ALA              \\nSEQRES   1 B   87  LYS ARG HIS ARG LYS VAL LEU ARG ASP ASN ILE GLN GLY          \\nSEQRES   2 B   87  ILE THR LYS PRO ALA ILE ARG ARG LEU ALA ARG ARG GLY          \\nSEQRES   3 B   87  GLY VAL LYS ARG ILE SER GLY LEU ILE TYR GLU GLU THR          \\nSEQRES   4 B   87  ARG GLY VAL LEU LYS VAL PHE LEU GLU ASN VAL ILE ARG          \\nSEQRES   5 B   87  ASP ALA VAL THR TYR THR GLU HIS ALA LYS ARG LYS THR          \\nSEQRES   6 B   87  VAL THR ALA MET ASP VAL VAL TYR ALA LEU LYS ARG GLN          \\nSEQRES   7 B   87  GLY ARG THR LEU TYR GLY PHE GLY GLY                          \\nSEQRES   1 C  116  GLY LYS GLN GLY GLY LYS THR ARG ALA LYS ALA LYS THR          \\nSEQRES   2 C  116  ARG SER SER ARG ALA GLY LEU GLN PHE PRO VAL GLY ARG          \\nSEQRES   3 C  116  VAL HIS ARG LEU LEU ARG LYS GLY ASN TYR ALA GLU ARG          \\nSEQRES   4 C  116  VAL GLY ALA GLY ALA PRO VAL TYR LEU ALA ALA VAL LEU          \\nSEQRES   5 C  116  GLU TYR LEU THR ALA GLU ILE LEU GLU LEU ALA GLY ASN          \\nSEQRES   6 C  116  ALA ALA ARG ASP ASN LYS LYS THR ARG ILE ILE PRO ARG          \\nSEQRES   7 C  116  HIS LEU GLN LEU ALA VAL ARG ASN ASP GLU GLU LEU ASN          \\nSEQRES   8 C  116  LYS LEU LEU GLY ARG VAL THR ILE ALA GLN GLY GLY VAL          \\nSEQRES   9 C  116  LEU PRO ASN ILE GLN SER VAL LEU LEU PRO LYS LYS              \\nSEQRES   1 D   99  LYS LYS ARG ARG LYS THR ARG LYS GLU SER TYR ALA ILE          \\nSEQRES   2 D   99  TYR VAL TYR LYS VAL LEU LYS GLN VAL HIS PRO ASP THR          \\nSEQRES   3 D   99  GLY ILE SER SER LYS ALA MET SER ILE MET ASN SER PHE          \\nSEQRES   4 D   99  VAL ASN ASP VAL PHE GLU ARG ILE ALA GLY GLU ALA SER          \\nSEQRES   5 D   99  ARG LEU ALA HIS TYR ASN LYS ARG SER THR ILE THR SER          \\nSEQRES   6 D   99  ARG GLU ILE GLN THR ALA VAL ARG LEU LEU LEU PRO GLY          \\nSEQRES   7 D   99  GLU LEU ALA LYS HIS ALA VAL SER GLU GLY THR LYS ALA          \\nSEQRES   8 D   99  VAL THR LYS TYR THR SER ALA LYS                              \\nSEQRES   1 E  116  LEU ALA THR LYS ALA ALA ARG LYS SER ALA PRO ALA THR          \\nSEQRES   2 E  116  GLY GLY VAL LYS LYS PRO HIS ARG TYR ARG PRO GLY THR          \\nSEQRES   3 E  116  VAL ALA LEU ARG GLU ILE ARG ARG TYR GLN LYS SER THR          \\nSEQRES   4 E  116  GLU LEU LEU ILE ARG LYS LEU PRO PHE GLN ARG LEU VAL          \\nSEQRES   5 E  116  ARG GLU ILE ALA GLN ASP PHE LYS THR ASP LEU ARG PHE          \\nSEQRES   6 E  116  GLN SER SER ALA VAL MET ALA LEU GLN GLU ALA SER GLU          \\nSEQRES   7 E  116  ALA TYR LEU VAL ALA LEU PHE GLU ASP THR ASN LEU CYS          \\nSEQRES   8 E  116  ALA ILE HIS ALA LYS ARG VAL THR ILE MET PRO LYS ASP          \\nSEQRES   9 E  116  ILE GLN LEU ALA ARG ARG ILE ARG GLY GLU ARG ALA              \\nSEQRES   1 F   87  LYS ARG HIS ARG LYS VAL LEU ARG ASP ASN ILE GLN GLY          \\nSEQRES   2 F   87  ILE THR LYS PRO ALA ILE ARG ARG LEU ALA ARG ARG GLY          \\nSEQRES   3 F   87  GLY VAL LYS ARG ILE SER GLY LEU ILE TYR GLU GLU THR          \\nSEQRES   4 F   87  ARG GLY VAL LEU LYS VAL PHE LEU GLU ASN VAL ILE ARG          \\nSEQRES   5 F   87  ASP ALA VAL THR TYR THR GLU HIS ALA LYS ARG LYS THR          \\nSEQRES   6 F   87  VAL THR ALA MET ASP VAL VAL TYR ALA LEU LYS ARG GLN          \\nSEQRES   7 F   87  GLY ARG THR LEU TYR GLY PHE GLY GLY                          \\nSEQRES   1 G  116  GLY LYS GLN GLY GLY LYS THR ARG ALA LYS ALA LYS THR          \\nSEQRES   2 G  116  ARG SER SER ARG ALA GLY LEU GLN PHE PRO VAL GLY ARG          \\nSEQRES   3 G  116  VAL HIS ARG LEU LEU ARG LYS GLY ASN TYR ALA GLU ARG          \\nSEQRES   4 G  116  VAL GLY ALA GLY ALA PRO VAL TYR LEU ALA ALA VAL LEU          \\nSEQRES   5 G  116  GLU TYR LEU THR ALA GLU ILE LEU GLU LEU ALA GLY ASN          \\nSEQRES   6 G  116  ALA ALA ARG ASP ASN LYS LYS THR ARG ILE ILE PRO ARG          \\nSEQRES   7 G  116  HIS LEU GLN LEU ALA VAL ARG ASN ASP GLU GLU LEU ASN          \\nSEQRES   8 G  116  LYS LEU LEU GLY ARG VAL THR ILE ALA GLN GLY GLY VAL          \\nSEQRES   9 G  116  LEU PRO ASN ILE GLN SER VAL LEU LEU PRO LYS LYS              \\nSEQRES   1 H   99  LYS LYS ARG ARG LYS THR ARG LYS GLU SER TYR ALA ILE          \\nSEQRES   2 H   99  TYR VAL TYR LYS VAL LEU LYS GLN VAL HIS PRO ASP THR          \\nSEQRES   3 H   99  GLY ILE SER SER LYS ALA MET SER ILE MET ASN SER PHE          \\nSEQRES   4 H   99  VAL ASN ASP VAL PHE GLU ARG ILE ALA GLY GLU ALA SER          \\nSEQRES   5 H   99  ARG LEU ALA HIS TYR ASN LYS ARG SER THR ILE THR SER          \\nSEQRES   6 H   99  ARG GLU ILE GLN THR ALA VAL ARG LEU LEU LEU PRO GLY          \\nSEQRES   7 H   99  GLU LEU ALA LYS HIS ALA VAL SER GLU GLY THR LYS ALA          \\nSEQRES   8 H   99  VAL THR LYS TYR THR SER ALA LYS                              \\nHET     MN  I 147       1                                                       \\nHET     MN  J 293       1                                                       \\nHET     MN  J 300       1                                                       \\nHET     MN  J 400       1                                                       \\nHET     MN  I 500       1                                                       \\nHET     MN  I 600       1                                                       \\nHETNAM      MN MANGANESE (II) ION                                               \\nFORMUL  11   MN    6(MN 2+)                                                     \\nFORMUL  17  HOH   *13(H2 O)                                                     \\nHELIX    1   1 THR A   45  LYS A   56  1                                  12    \\nHELIX    2   2 LYS A   64  PHE A   78  1                                  15    \\nHELIX    3   3 SER A   86  HIS A  113  1                                  28    \\nHELIX    4   4 PRO A  121  ARG A  131  1                                  11    \\nHELIX    5   5 ILE B   26  GLY B   28  5                                   3    \\nHELIX    6   6 LYS B   31  ARG B   40  1                                  10    \\nHELIX    7   7 GLY B   48  HIS B   75  5                                  28    \\nHELIX    8   8 ALA B   83  GLN B   93  1                                  11    \\nHELIX    9   9 LYS C    5  GLY C    7  5                                   3    \\nHELIX   10  10 ARG C   17  ALA C   21  1                                   5    \\nHELIX   11  11 VAL C   27  ARG C   35  1                                   9    \\nHELIX   12  12 ALA C   45  ASP C   72  1                                  28    \\nHELIX   13  13 PRO C   80  ARG C   88  1                                   9    \\nHELIX   14  14 GLU C   91  LEU C   96  1                                   6    \\nHELIX   15  15 SER C  113  LEU C  115  5                                   3    \\nHELIX   16  16 ALA D   35  VAL D   45  1                                  11    \\nHELIX   17  17 SER D   53  ASN D   81  1                                  29    \\nHELIX   18  18 SER D   88  LEU D   98  1                                  11    \\nHELIX   19  19 GLY D  101  THR D  119  1                                  19    \\nHELIX   20  20 THR E   45  LYS E   56  1                                  12    \\nHELIX   21  21 LYS E   64  ASP E   77  1                                  14    \\nHELIX   22  22 SER E   86  ALA E  114  1                                  29    \\nHELIX   23  23 PRO E  121  ARG E  131  1                                  11    \\nHELIX   24  24 ASN F   25  GLY F   28  5                                   4    \\nHELIX   25  25 LYS F   31  ARG F   40  1                                  10    \\nHELIX   26  26 ILE F   50  ALA F   76  1                                  27    \\nHELIX   27  27 ALA F   83  ARG F   92  1                                  10    \\nHELIX   28  28 ARG G   17  ALA G   21  1                                   5    \\nHELIX   29  29 VAL G   27  GLY G   37  1                                  11    \\nHELIX   30  30 ALA G   47  ASN G   73  1                                  27    \\nHELIX   31  31 PRO G   80  ARG G   88  1                                   9    \\nHELIX   32  32 GLU G   91  LEU G   96  1                                   6    \\nHELIX   33  33 SER G  113  LEU G  115  5                                   3    \\nHELIX   34  34 TYR H   34  VAL H   45  5                                  12    \\nHELIX   35  35 SER H   53  TYR H   80  1                                  28    \\nHELIX   36  36 SER H   88  LEU H   98  1                                  11    \\nHELIX   37  37 GLY H  101  THR H  119  1                                  19    \\nSHEET    1   A 2 ARG A  83  PHE A  84  0                                        \\nSHEET    2   A 2 THR B  80  VAL B  81  1  N  VAL B  81   O  ARG A  83           \\nSHEET    1   B 2 THR A 118  ILE A 119  0                                        \\nSHEET    2   B 2 ARG B  45  ILE B  46  1  O  ARG B  45   N  ILE A 119           \\nSHEET    1   C 2 LEU B  97  TYR B  98  0                                        \\nSHEET    2   C 2 THR G 101  ILE G 102  1  O  THR G 101   N  TYR B  98           \\nSHEET    1   D 2 ARG C  42  VAL C  43  0                                        \\nSHEET    2   D 2 THR D  85  ILE D  86  1  N  ILE D  86   O  ARG C  42           \\nSHEET    1   E 2 ARG C  77  ILE C  78  0                                        \\nSHEET    2   E 2 GLY D  50  ILE D  51  1  O  GLY D  50   N  ILE C  78           \\nSHEET    1   F 2 THR C 101  ILE C 102  0                                        \\nSHEET    2   F 2 LEU F  97  TYR F  98  1  N  TYR F  98   O  THR C 101           \\nSHEET    1   G 2 ARG E  83  PHE E  84  0                                        \\nSHEET    2   G 2 THR F  80  VAL F  81  1  N  VAL F  81   O  ARG E  83           \\nSHEET    1   H 2 THR E 118  ILE E 119  0                                        \\nSHEET    2   H 2 ARG F  45  ILE F  46  1  O  ARG F  45   N  ILE E 119           \\nSHEET    1   I 2 ARG G  42  VAL G  43  0                                        \\nSHEET    2   I 2 THR H  85  ILE H  86  1  N  ILE H  86   O  ARG G  42           \\nSHEET    1   J 2 ARG G  77  ILE G  78  0                                        \\nSHEET    2   J 2 GLY H  50  ILE H  51  1  O  GLY H  50   N  ILE G  78           \\nSITE     1 AC1  1  DT J 167                                                     \\nCRYST1  106.040  181.780  110.120  90.00  90.00  90.00 P 21 21 21    8          \\nORIGX1      1.000000  0.000000  0.000000        0.00000                         \\nORIGX2      0.000000  1.000000  0.000000        0.00000                         \\nORIGX3      0.000000  0.000000  1.000000        0.00000                         \\nSCALE1      0.009430  0.000000  0.000000        0.00000                         \\nSCALE2      0.000000  0.005501  0.000000        0.00000                         \\nSCALE3      0.000000  0.000000  0.009081        0.00000                         \\nATOM      1  O5'  DA I   1      25.537 137.838  26.891  1.00170.35           O  \\nATOM      2  C5'  DA I   1      25.358 139.192  27.309  1.00170.35           C  \\nATOM      3  C4'  DA I   1      24.106 139.813  26.732  1.00170.35           C  \\nATOM      4  O4'  DA I   1      24.251 139.999  25.303  1.00170.35           O  \\nATOM      5  C3'  DA I   1      22.837 138.982  26.918  1.00170.35           C  \\nATOM      6  O3'  DA I   1      21.723 139.844  27.145  1.00170.35           O  \\nATOM      7  C2'  DA I   1      22.671 138.294  25.577  1.00170.35           C  \\nATOM      8  C1'  DA I   1      23.178 139.357  24.621  1.00170.35           C  \\nATOM      9  N9   DA I   1      23.690 138.834  23.351  1.00 66.50           N  \\nATOM     10  C8   DA I   1      24.833 138.084  23.152  1.00 66.50           C  \\nATOM     11  N7   DA I   1      25.045 137.760  21.893  1.00 66.50           N  \\nATOM     12  C5   DA I   1      23.973 138.331  21.217  1.00 66.50           C  \\nATOM     13  C6   DA I   1      23.622 138.348  19.863  1.00 66.50           C  \\nATOM     14  N6   DA I   1      24.335 137.759  18.911  1.00 66.50           N  \\nATOM     15  N1   DA I   1      22.498 139.000  19.515  1.00 66.50           N  \\nATOM     16  C2   DA I   1      21.776 139.597  20.476  1.00 66.50           C  \\nATOM     17  N3   DA I   1      21.999 139.653  21.789  1.00 66.50           N  \\nATOM     18  C4   DA I   1      23.128 138.993  22.101  1.00 66.50           C  \\nATOM     19  P    DT I   2      20.372 139.246  27.770  1.00153.90           P  \\nATOM     20  OP1  DT I   2      19.269 140.187  27.450  1.00153.90           O  \\nATOM     21  OP2  DT I   2      20.642 138.887  29.184  1.00153.90           O  \\nATOM     22  O5'  DT I   2      20.132 137.896  26.960  1.00143.36           O  \\nATOM     23  C5'  DT I   2      18.812 137.465  26.669  1.00143.36           C  \\nATOM     24  C4'  DT I   2      18.134 138.494  25.799  1.00143.36           C  \\nATOM     25  O4'  DT I   2      18.881 138.676  24.575  1.00143.36           O  \\nATOM     26  C3'  DT I   2      16.716 138.152  25.378  1.00143.36           C  \\nATOM     27  O3'  DT I   2      15.970 139.359  25.318  1.00143.36           O  \\nATOM     28  C2'  DT I   2      16.894 137.543  24.000  1.00143.36           C  \\nATOM     29  C1'  DT I   2      18.110 138.274  23.447  1.00143.36           C  \\nATOM     30  N1   DT I   2      18.984 137.435  22.594  1.00111.90           N  \\nATOM     31  C2   DT I   2      18.877 137.512  21.215  1.00111.90           C  \\nATOM     32  O2   DT I   2      18.051 138.207  20.637  1.00111.90           O  \\nATOM     33  N3   DT I   2      19.783 136.727  20.535  1.00111.90           N  \\nATOM     34  C4   DT I   2      20.742 135.888  21.077  1.00111.90           C  \\nATOM     35  O4   DT I   2      21.507 135.270  20.340  1.00111.90           O  \\nATOM     36  C5   DT I   2      20.764 135.827  22.514  1.00111.90           C  \\nATOM     37  C7   DT I   2      21.733 134.908  23.184  1.00111.90           C  \\nATOM     38  C6   DT I   2      19.904 136.597  23.192  1.00111.90           C  \\nATOM     39  P    DC I   3      14.379 139.291  25.262  1.00107.76           P  \\nATOM     40  OP1  DC I   3      13.828 140.650  25.481  1.00107.76           O  \\nATOM     41  OP2  DC I   3      13.978 138.173  26.157  1.00107.76           O  \\nATOM     42  O5'  DC I   3      14.089 138.888  23.754  1.00118.45           O  \\nATOM     43  C5'  DC I   3      12.936 138.141  23.418  1.00118.45           C  \\nATOM     44  C4'  DC I   3      12.930 137.834  21.940  1.00118.45           C  \\nATOM     45  O4'  DC I   3      14.256 137.451  21.485  1.00118.45           O  \\nATOM     46  C3'  DC I   3      12.012 136.668  21.591  1.00118.45           C  \\nATOM     47  O3'  DC I   3      11.331 136.941  20.374  1.00118.45           O  \\nATOM     48  C2'  DC I   3      12.968 135.505  21.409  1.00118.45           C  \\nATOM     49  C1'  DC I   3      14.174 136.202  20.809  1.00118.45           C  \\nATOM     50  N1   DC I   3      15.460 135.479  20.962  1.00 75.97           N  \\nATOM     51  C2   DC I   3      16.324 135.391  19.854  1.00 75.97           C  \\nATOM     52  O2   DC I   3      15.992 135.941  18.786  1.00 75.97           O  \\nATOM     53  N3   DC I   3      17.488 134.707  19.977  1.00 75.97           N  \\nATOM     54  C4   DC I   3      17.803 134.126  21.137  1.00 75.97           C  \\nATOM     55  N4   DC I   3      18.956 133.459  21.209  1.00 75.97           N  \\nATOM     56  C5   DC I   3      16.951 134.203  22.277  1.00 75.97           C  \\nATOM     57  C6   DC I   3      15.803 134.887  22.149  1.00 75.97           C  \\nATOM     58  P    DA I   4      10.135 135.984  19.919  1.00160.30           P  \\nATOM     59  OP1  DA I   4       8.961 136.812  19.543  1.00160.30           O  \\nATOM     60  OP2  DA I   4       9.995 134.924  20.951  1.00160.30           O  \\nATOM     61  O5'  DA I   4      10.695 135.303  18.605  1.00 81.02           O  \\nATOM     62  C5'  DA I   4      11.008 136.087  17.464  1.00 81.02           C  \\nATOM     63  C4'  DA I   4      11.360 135.178  16.314  1.00 81.02           C  \\nATOM     64  O4'  DA I   4      12.608 134.502  16.617  1.00 81.02           O  \\nATOM     65  C3'  DA I   4      10.325 134.082  16.068  1.00 81.02           C  \\nATOM     66  O3'  DA I   4      10.124 133.930  14.655  1.00 81.02           O  \\nATOM     67  C2'  DA I   4      10.911 132.865  16.771  1.00 81.02           C  \\nATOM     68  C1'  DA I   4      12.418 133.096  16.719  1.00 81.02           C  \\nATOM     69  N9   DA I   4      13.169 132.630  17.896  1.00 51.15           N  \\nATOM     70  C8   DA I   4      12.795 132.662  19.227  1.00 51.15           C  \\nATOM     71  N7   DA I   4      13.706 132.185  20.050  1.00 51.15           N  \\nATOM     72  C5   DA I   4      14.750 131.810  19.209  1.00 51.15           C  \\nATOM     73  C6   DA I   4      16.022 131.230  19.461  1.00 51.15           C  \\nATOM     74  N6   DA I   4      16.481 130.921  20.684  1.00 51.15           N  \\nATOM     75  N1   DA I   4      16.813 130.977  18.393  1.00 51.15           N  \\nATOM     76  C2   DA I   4      16.358 131.279  17.163  1.00 51.15           C  \\nATOM     77  N3   DA I   4      15.195 131.822  16.799  1.00 51.15           N  \\nATOM     78  C4   DA I   4      14.429 132.070  17.878  1.00 51.15           C  \\nATOM     79  P    DA I   5       9.609 132.531  14.056  1.00 87.05           P  \\nATOM     80  OP1  DA I   5       9.312 132.719  12.606  1.00 87.05           O  \\nATOM     81  OP2  DA I   5       8.566 131.973  14.959  1.00 87.05           O  \\nATOM     82  O5'  DA I   5      10.915 131.637  14.161  1.00 98.96           O  \\nATOM     83  C5'  DA I   5      12.078 132.005  13.433  1.00 98.96           C  \\nATOM     84  C4'  DA I   5      12.698 130.776  12.830  1.00 98.96           C  \\nATOM     85  O4'  DA I   5      13.515 130.138  13.830  1.00 98.96           O  \\nATOM     86  C3'  DA I   5      11.646 129.755  12.416  1.00 98.96           C  \\nATOM     87  O3'  DA I   5      12.047 129.134  11.192  1.00 98.96           O  \\nATOM     88  C2'  DA I   5      11.567 128.817  13.610  1.00 98.96           C  \\nATOM     89  C1'  DA I   5      12.949 128.909  14.244  1.00 98.96           C  \\nATOM     90  N9   DA I   5      12.939 128.919  15.704  1.00 67.55           N  \\nATOM     91  C8   DA I   5      12.001 129.467  16.539  1.00 67.55           C  \\nATOM     92  N7   DA I   5      12.272 129.310  17.816  1.00 67.55           N  \\nATOM     93  C5   DA I   5      13.473 128.613  17.820  1.00 67.55           C  \\nATOM     94  C6   DA I   5      14.305 128.132  18.868  1.00 67.55           C  \\nATOM     95  N6   DA I   5      14.047 128.275  20.168  1.00 67.55           N  \\nATOM     96  N1   DA I   5      15.430 127.486  18.520  1.00 67.55           N  \\nATOM     97  C2   DA I   5      15.706 127.331  17.220  1.00 67.55           C  \\nATOM     98  N3   DA I   5      15.013 127.731  16.151  1.00 67.55           N  \\nATOM     99  C4   DA I   5      13.896 128.371  16.524  1.00 67.55           C  \\nATOM    100  P    DT I   6      11.383 127.747  10.728  1.00 83.50           P  \\nATOM    101  OP1  DT I   6      11.100 127.761   9.264  1.00 83.50           O  \\nATOM    102  OP2  DT I   6      10.304 127.367  11.690  1.00 83.50           O  \\nATOM    103  O5'  DT I   6      12.580 126.733  10.927  1.00 51.12           O  \\nATOM    104  C5'  DT I   6      12.298 125.377  11.121  1.00 51.12           C  \\nATOM    105  C4'  DT I   6      13.441 124.704  11.824  1.00 51.12           C  \\nATOM    106  O4'  DT I   6      13.678 125.269  13.139  1.00 51.12           O  \\nATOM    107  C3'  DT I   6      13.085 123.244  12.038  1.00 51.12           C  \\nATOM    108  O3'  DT I   6      14.152 122.451  11.602  1.00 51.12           O  \\nATOM    109  C2'  DT I   6      12.874 123.121  13.531  1.00 51.12           C  \\nATOM    110  C1'  DT I   6      13.764 124.211  14.071  1.00 51.12           C  \\nATOM    111  N1   DT I   6      13.310 124.691  15.377  1.00 45.37           N  \\nATOM    112  C2   DT I   6      14.170 124.552  16.448  1.00 45.37           C  \\nATOM    113  O2   DT I   6      15.308 124.125  16.342  1.00 45.37           O  \\nATOM    114  N3   DT I   6      13.654 124.944  17.650  1.00 45.37           N  \\nATOM    115  C4   DT I   6      12.414 125.476  17.893  1.00 45.37           C  \\nATOM    116  O4   DT I   6      12.106 125.793  19.036  1.00 45.37           O  \\nATOM    117  C5   DT I   6      11.566 125.618  16.724  1.00 45.37           C  \\nATOM    118  C7   DT I   6      10.190 126.179  16.893  1.00 45.37           C  \\nATOM    119  C6   DT I   6      12.055 125.230  15.534  1.00 45.37           C  \\nATOM    120  P    DA I   7      13.889 120.932  11.248  1.00 74.79           P  \\nATOM    121  OP1  DA I   7      14.268 120.761   9.825  1.00 74.79           O  \\nATOM    122  OP2  DA I   7      12.521 120.577  11.702  1.00 74.79           O  \\nATOM    123  O5'  DA I   7      14.950 120.232  12.187  1.00 52.17           O  \\nATOM    124  C5'  DA I   7      16.221 120.840  12.345  1.00 52.17           C  \\nATOM    125  C4'  DA I   7      16.803 120.492  13.688  1.00 52.17           C  \\nATOM    126  O4'  DA I   7      16.096 121.186  14.740  1.00 52.17           O  \\nATOM    127  C3'  DA I   7      16.673 119.009  13.986  1.00 52.17           C  \\nATOM    128  O3'  DA I   7      17.892 118.529  14.549  1.00 52.17           O  \\nATOM    129  C2'  DA I   7      15.503 118.950  14.952  1.00 52.17           C  \\nATOM    130  C1'  DA I   7      15.645 120.260  15.699  1.00 52.17           C  \\nATOM    131  N9   DA I   7      14.398 120.769  16.264  1.00 49.10           N  \\nATOM    132  C8   DA I   7      13.226 121.025  15.607  1.00 49.10           C  \\nATOM    133  N7   DA I   7      12.265 121.456  16.392  1.00 49.10           N  \\nATOM    134  C5   DA I   7      12.849 121.493  17.653  1.00 49.10           C  \\nATOM    135  C6   DA I   7      12.353 121.853  18.926  1.00 49.10           C  \\nATOM    136  N6   DA I   7      11.110 122.277  19.150  1.00 49.10           N  \\nATOM    137  N1   DA I   7      13.195 121.760  19.977  1.00 49.10           N  \\nATOM    138  C2   DA I   7      14.441 121.340  19.761  1.00 49.10           C  \\nATOM    139  N3   DA I   7      15.024 120.980  18.621  1.00 49.10           N  \\nATOM    140  C4   DA I   7      14.164 121.077  17.589  1.00 49.10           C  \\nATOM    141  P    DT I   8      18.069 116.959  14.813  1.00 86.12           P  \\nATOM    142  OP1  DT I   8      19.483 116.581  14.578  1.00 86.12           O  \\nATOM    143  OP2  DT I   8      16.993 116.242  14.077  1.00 86.12           O  \\nATOM    144  O5'  DT I   8      17.791 116.882  16.375  1.00113.81           O  \\nATOM    145  C5'  DT I   8      18.502 117.743  17.265  1.00113.81           C  \\nATOM    146  C4'  DT I   8      18.194 117.379  18.696  1.00113.81           C  \\nATOM    147  O4'  DT I   8      16.965 118.008  19.130  1.00113.81           O  \\nATOM    148  C3'  DT I   8      18.007 115.876  18.910  1.00113.81           C  \\nATOM    149  O3'  DT I   8      18.613 115.463  20.139  1.00113.81           O  \\nATOM    150  C2'  DT I   8      16.498 115.724  18.965  1.00113.81           C  \\nATOM    151  C1'  DT I   8      16.090 117.019  19.633  1.00113.81           C  \\nATOM    152  N1   DT I   8      14.722 117.444  19.349  1.00 39.29           N  \\nATOM    153  C2   DT I   8      13.987 117.959  20.396  1.00 39.29           C  \\nATOM    154  O2   DT I   8      14.443 118.105  21.524  1.00 39.29           O  \\nATOM    155  N3   DT I   8      12.696 118.307  20.079  1.00 39.29           N  \\nATOM    156  C4   DT I   8      12.089 118.215  18.837  1.00 39.29           C  \\nATOM    157  O4   DT I   8      10.910 118.574  18.694  1.00 39.29           O  \\nATOM    158  C5   DT I   8      12.935 117.680  17.778  1.00 39.29           C  \\nATOM    159  C7   DT I   8      12.373 117.552  16.396  1.00 39.29           C  \\nATOM    160  C6   DT I   8      14.191 117.324  18.087  1.00 39.29           C  \\nATOM    161  P    DC I   9      19.367 114.043  20.220  1.00106.25           P  \\nATOM    162  OP1  DC I   9      20.794 114.287  20.554  1.00106.25           O  \\nATOM    163  OP2  DC I   9      19.014 113.254  19.011  1.00106.25           O  \\nATOM    164  O5'  DC I   9      18.681 113.342  21.464  1.00 79.01           O  \\nATOM    165  C5'  DC I   9      17.286 113.478  21.675  1.00 79.01           C  \\nATOM    166  C4'  DC I   9      17.032 114.198  22.977  1.00 79.01           C  \\nATOM    167  O4'  DC I   9      16.057 115.243  22.765  1.00 79.01           O  \\nATOM    168  C3'  DC I   9      16.463 113.299  24.064  1.00 79.01           C  \\nATOM    169  O3'  DC I   9      17.019 113.654  25.331  1.00 79.01           O  \\nATOM    170  C2'  DC I   9      14.962 113.520  23.966  1.00 79.01           C  \\nATOM    171  C1'  DC I   9      14.808 114.903  23.339  1.00 79.01           C  \\nATOM    172  N1   DC I   9      13.819 114.932  22.252  1.00 51.82           N  \\nATOM    173  C2   DC I   9      12.506 115.293  22.536  1.00 51.82           C  \\nATOM    174  O2   DC I   9      12.212 115.609  23.702  1.00 51.82           O  \\nATOM    175  N3   DC I   9      11.586 115.294  21.536  1.00 51.82           N  \\nATOM    176  C4   DC I   9      11.951 114.957  20.294  1.00 51.82           C  \\nATOM    177  N4   DC I   9      11.014 114.969  19.327  1.00 51.82           N  \\nATOM    178  C5   DC I   9      13.291 114.595  19.980  1.00 51.82           C  \\nATOM    179  C6   DC I   9      14.181 114.600  20.978  1.00 51.82           C  \\nATOM    180  P    DC I  10      17.479 112.498  26.348  1.00106.94           P  \\nATOM    181  OP1  DC I  10      18.638 112.983  27.145  1.00106.94           O  \\nATOM    182  OP2  DC I  10      17.596 111.231  25.571  1.00106.94           O  \\nATOM    183  O5'  DC I  10      16.231 112.375  27.320  1.00121.81           O  \\nATOM    184  C5'  DC I  10      15.124 113.264  27.187  1.00121.81           C  \\nATOM    185  C4'  DC I  10      13.852 112.568  27.603  1.00121.81           C  \\nATOM    186  O4'  DC I  10      12.791 112.874  26.663  1.00121.81           O  \\nATOM    187  C3'  DC I  10      13.959 111.041  27.646  1.00121.81           C  \\nATOM    188  O3'  DC I  10      13.202 110.551  28.757  1.00121.81           O  \\nATOM    189  C2'  DC I  10      13.313 110.618  26.340  1.00121.81           C  \\nATOM    190  C1'  DC I  10      12.227 111.666  26.184  1.00121.81           C  \\nATOM    191  N1   DC I  10      11.794 111.878  24.797  1.00 76.30           N  \\nATOM    192  C2   DC I  10      10.484 112.317  24.549  1.00 76.30           C  \\nATOM    193  O2   DC I  10       9.740 112.574  25.510  1.00 76.30           O  \\nATOM    194  N3   DC I  10      10.065 112.458  23.267  1.00 76.30           N  \\nATOM    195  C4   DC I  10      10.905 112.199  22.259  1.00 76.30           C  \\nATOM    196  N4   DC I  10      10.451 112.339  21.009  1.00 76.30           N  \\nATOM    197  C5   DC I  10      12.249 111.782  22.487  1.00 76.30           C  \\nATOM    198  C6   DC I  10      12.647 111.635  23.759  1.00 76.30           C  \\nATOM    199  P    DA I  11      13.541 109.119  29.408  1.00115.40           P  \\nATOM    200  OP1  DA I  11      14.519 109.334  30.509  1.00115.40           O  \\nATOM    201  OP2  DA I  11      13.866 108.156  28.322  1.00115.40           O  \\nATOM    202  O5'  DA I  11      12.134 108.719  30.046  1.00 77.48           O  \\nATOM    203  C5'  DA I  11      11.439 109.648  30.876  1.00 77.48           C  \\nATOM    204  C4'  DA I  11       9.959 109.658  30.564  1.00 77.48           C  \\nATOM    205  O4'  DA I  11       9.708 110.198  29.243  1.00 77.48           O  \\nATOM    206  C3'  DA I  11       9.225 108.311  30.619  1.00 77.48           C  \\nATOM    207  O3'  DA I  11       7.947 108.503  31.257  1.00 77.48           O  \\nATOM    208  C2'  DA I  11       9.011 107.983  29.154  1.00 77.48           C  \\nATOM    209  C1'  DA I  11       8.757 109.367  28.595  1.00 77.48           C  \\nATOM    210  N9   DA I  11       8.933 109.483  27.147  1.00 78.90           N  \\nATOM    211  C8   DA I  11      10.079 109.297  26.409  1.00 78.90           C  \\nATOM    212  N7   DA I  11       9.909 109.455  25.117  1.00 78.90           N  \\nATOM    213  C5   DA I  11       8.562 109.769  24.993  1.00 78.90           C  \\nATOM    214  C6   DA I  11       7.758 110.054  23.874  1.00 78.90           C  \\nATOM    215  N6   DA I  11       8.217 110.064  22.624  1.00 78.90           N  \\nATOM    216  N1   DA I  11       6.453 110.333  24.089  1.00 78.90           N  \\nATOM    217  C2   DA I  11       5.999 110.325  25.350  1.00 78.90           C  \\nATOM    218  N3   DA I  11       6.655 110.070  26.486  1.00 78.90           N  \\nATOM    219  C4   DA I  11       7.948 109.796  26.235  1.00 78.90           C  \\nATOM    220  P    DC I  12       6.964 107.249  31.520  1.00121.14           P  \\nATOM    221  OP1  DC I  12       6.367 107.434  32.865  1.00121.14           O  \\nATOM    222  OP2  DC I  12       7.724 106.007  31.224  1.00121.14           O  \\nATOM    223  O5'  DC I  12       5.801 107.415  30.430  1.00119.74           O  \\nATOM    224  C5'  DC I  12       4.968 108.587  30.391  1.00119.74           C  \\nATOM    225  C4'  DC I  12       3.790 108.372  29.464  1.00119.74           C  \\nATOM    226  O4'  DC I  12       4.219 108.494  28.081  1.00119.74           O  \\nATOM    227  C3'  DC I  12       3.131 106.992  29.571  1.00119.74           C  \\nATOM    228  O3'  DC I  12       1.714 107.081  29.357  1.00119.74           O  \\nATOM    229  C2'  DC I  12       3.748 106.229  28.417  1.00119.74           C  \\nATOM    230  C1'  DC I  12       3.849 107.316  27.369  1.00119.74           C  \\nATOM    231  N1   DC I  12       4.860 107.046  26.328  1.00 64.88           N  \\nATOM    232  C2   DC I  12       4.544 107.322  24.985  1.00 64.88           C  \\nATOM    233  O2   DC I  12       3.423 107.801  24.716  1.00 64.88           O  \\nATOM    234  N3   DC I  12       5.466 107.056  24.017  1.00 64.88           N  \\nATOM    235  C4   DC I  12       6.655 106.538  24.348  1.00 64.88           C  \\nATOM    236  N4   DC I  12       7.527 106.286  23.366  1.00 64.88           N  \\nATOM    237  C5   DC I  12       7.001 106.254  25.705  1.00 64.88           C  \\nATOM    238  C6   DC I  12       6.084 106.522  26.653  1.00 64.88           C  \\nATOM    239  P    DC I  13       0.814 105.740  29.365  1.00104.25           P  \\nATOM    240  OP1  DC I  13      -0.177 105.851  30.464  1.00104.25           O  \\nATOM    241  OP2  DC I  13       1.729 104.573  29.329  1.00104.25           O  \\nATOM    242  O5'  DC I  13       0.016 105.787  27.984  1.00111.59           O  \\nATOM    243  C5'  DC I  13       0.679 106.078  26.757  1.00111.59           C  \\nATOM    244  C4'  DC I  13      -0.001 105.370  25.607  1.00111.59           C  \\nATOM    245  O4'  DC I  13       0.961 105.230  24.532  1.00111.59           O  \\nATOM    246  C3'  DC I  13      -0.482 103.951  25.927  1.00111.59           C  \\nATOM    247  O3'  DC I  13      -1.689 103.625  25.212  1.00111.59           O  \\nATOM    248  C2'  DC I  13       0.669 103.084  25.461  1.00111.59           C  \\nATOM    249  C1'  DC I  13       1.222 103.856  24.274  1.00111.59           C  \\nATOM    250  N1   DC I  13       2.676 103.686  24.123  1.00 54.47           N  \\nATOM    251  C2   DC I  13       3.256 103.833  22.853  1.00 54.47           C  \\nATOM    252  O2   DC I  13       2.529 104.135  21.889  1.00 54.47           O  \\nATOM    253  N3   DC I  13       4.596 103.644  22.713  1.00 54.47           N  \\nATOM    254  C4   DC I  13       5.343 103.327  23.779  1.00 54.47           C  \\nATOM    255  N4   DC I  13       6.655 103.140  23.597  1.00 54.47           N  \\nATOM    256  C5   DC I  13       4.778 103.187  25.078  1.00 54.47           C  \\nATOM    257  C6   DC I  13       3.454 103.375  25.204  1.00 54.47           C  \\nATOM    258  P    DT I  14      -2.344 102.153  25.363  1.00125.22           P  \\nATOM    259  OP1  DT I  14      -3.808 102.262  25.143  1.00125.22           O  \\nATOM    260  OP2  DT I  14      -1.833 101.511  26.605  1.00125.22           O  \\nATOM    261  O5'  DT I  14      -1.753 101.346  24.130  1.00124.34           O  \\nATOM    262  C5'  DT I  14      -2.111 101.693  22.799  1.00124.34           C  \\nATOM    263  C4'  DT I  14      -1.647 100.615  21.851  1.00124.34           C  \\nATOM    264  O4'  DT I  14      -0.201 100.585  21.823  1.00124.34           O  \\nATOM    265  C3'  DT I  14      -2.085  99.207  22.256  1.00124.34           C  \\nATOM    266  O3'  DT I  14      -2.267  98.432  21.071  1.00124.34           O  \\nATOM    267  C2'  DT I  14      -0.875  98.680  23.002  1.00124.34           C  \\nATOM    268  C1'  DT I  14       0.239  99.280  22.165  1.00124.34           C  \\nATOM    269  N1   DT I  14       1.549  99.397  22.826  1.00 91.68           N  \\nATOM    270  C2   DT I  14       2.660  99.581  22.028  1.00 91.68           C  \\nATOM    271  O2   DT I  14       2.610  99.666  20.807  1.00 91.68           O  \\nATOM    272  N3   DT I  14       3.840  99.664  22.713  1.00 91.68           N  \\nATOM    273  C4   DT I  14       4.021  99.595  24.083  1.00 91.68           C  \\nATOM    274  O4   DT I  14       5.147  99.693  24.558  1.00 91.68           O  \\nATOM    275  C5   DT I  14       2.813  99.408  24.856  1.00 91.68           C  \\nATOM    276  C7   DT I  14       2.903  99.325  26.346  1.00 91.68           C  \\nATOM    277  C6   DT I  14       1.654  99.318  24.196  1.00 91.68           C  \\nATOM    278  P    DG I  15      -3.569  98.662  20.165  1.00141.01           P  \\nATOM    279  OP1  DG I  15      -3.788 100.123  20.002  1.00141.01           O  \\nATOM    280  OP2  DG I  15      -4.639  97.809  20.745  1.00141.01           O  \\nATOM    281  O5'  DG I  15      -3.156  98.075  18.745  1.00150.37           O  \\nATOM    282  C5'  DG I  15      -2.439  98.869  17.800  1.00150.37           C  \\nATOM    283  C4'  DG I  15      -1.445  98.011  17.052  1.00150.37           C  \\nATOM    284  O4'  DG I  15      -0.303  97.721  17.897  1.00150.37           O  \\nATOM    285  C3'  DG I  15      -1.998  96.657  16.610  1.00150.37           C  \\nATOM    286  O3'  DG I  15      -1.475  96.314  15.327  1.00150.37           O  \\nATOM    287  C2'  DG I  15      -1.489  95.705  17.680  1.00150.37           C  \\nATOM    288  C1'  DG I  15      -0.143  96.313  18.041  1.00150.37           C  \\nATOM    289  N9   DG I  15       0.325  96.053  19.402  1.00 92.86           N  \\nATOM    290  C8   DG I  15      -0.424  95.682  20.498  1.00 92.86           C  \\nATOM    291  N7   DG I  15       0.285  95.578  21.591  1.00 92.86           N  \\nATOM    292  C5   DG I  15       1.578  95.895  21.191  1.00 92.86           C  \\nATOM    293  C6   DG I  15       2.782  95.989  21.943  1.00 92.86           C  \\nATOM    294  O6   DG I  15       2.949  95.842  23.163  1.00 92.86           O  \\nATOM    295  N1   DG I  15       3.866  96.313  21.133  1.00 92.86           N  \\nATOM    296  C2   DG I  15       3.800  96.534  19.780  1.00 92.86           C  \\nATOM    297  N2   DG I  15       4.957  96.799  19.162  1.00 92.86           N  \\nATOM    298  N3   DG I  15       2.685  96.490  19.078  1.00 92.86           N  \\nATOM    299  C4   DG I  15       1.621  96.164  19.839  1.00 92.86           C  \\nATOM    300  P    DC I  16      -1.837  94.895  14.667  1.00126.38           P  \\nATOM    301  OP1  DC I  16      -2.490  95.151  13.359  1.00126.38           O  \\nATOM    302  OP2  DC I  16      -2.521  94.042  15.680  1.00126.38           O  \\nATOM    303  O5'  DC I  16      -0.406  94.265  14.377  1.00137.65           O  \\nATOM    304  C5'  DC I  16       0.746  95.101  14.296  1.00137.65           C  \\nATOM    305  C4'  DC I  16       1.968  94.281  13.962  1.00137.65           C  \\nATOM    306  O4'  DC I  16       2.794  94.142  15.141  1.00137.65           O  \\nATOM    307  C3'  DC I  16       1.681  92.864  13.475  1.00137.65           C  \\nATOM    308  O3'  DC I  16       2.576  92.569  12.396  1.00137.65           O  \\nATOM    309  C2'  DC I  16       1.866  92.009  14.719  1.00137.65           C  \\nATOM    310  C1'  DC I  16       2.875  92.783  15.552  1.00137.65           C  \\nATOM    311  N1   DC I  16       2.614  92.747  17.003  1.00 78.10           N  \\nATOM    312  C2   DC I  16       3.575  93.276  17.865  1.00 78.10           C  \\nATOM    313  O2   DC I  16       4.611  93.760  17.378  1.00 78.10           O  \\nATOM    314  N3   DC I  16       3.354  93.256  19.207  1.00 78.10           N  \\nATOM    315  C4   DC I  16       2.218  92.742  19.689  1.00 78.10           C  \\nATOM    316  N4   DC I  16       2.035  92.756  21.014  1.00 78.10           N  \\nATOM    317  C5   DC I  16       1.220  92.194  18.830  1.00 78.10           C  \\nATOM    318  C6   DC I  16       1.459  92.214  17.506  1.00 78.10           C  \\nATOM    319  P    DA I  17       3.113  91.076  12.163  1.00 99.08           P  \\nATOM    320  OP1  DA I  17       3.084  90.769  10.712  1.00 99.08           O  \\nATOM    321  OP2  DA I  17       2.490  90.135  13.130  1.00 99.08           O  \\nATOM    322  O5'  DA I  17       4.639  91.204  12.561  1.00122.04           O  \\nATOM    323  C5'  DA I  17       5.341  92.430  12.396  1.00122.04           C  \\nATOM    324  C4'  DA I  17       6.693  92.290  13.041  1.00122.04           C  \\nATOM    325  O4'  DA I  17       6.451  91.923  14.419  1.00122.04           O  \\nATOM    326  C3'  DA I  17       7.467  91.120  12.445  1.00122.04           C  \\nATOM    327  O3'  DA I  17       8.868  91.320  12.611  1.00122.04           O  \\nATOM    328  C2'  DA I  17       6.984  89.934  13.258  1.00122.04           C  \\nATOM    329  C1'  DA I  17       6.751  90.546  14.628  1.00122.04           C  \\nATOM    330  N9   DA I  17       5.629  89.962  15.358  1.00 88.59           N  \\nATOM    331  C8   DA I  17       4.535  89.291  14.865  1.00 88.59           C  \\nATOM    332  N7   DA I  17       3.684  88.921  15.791  1.00 88.59           N  \\nATOM    333  C5   DA I  17       4.263  89.370  16.972  1.00 88.59           C  \\nATOM    334  C6   DA I  17       3.855  89.298  18.313  1.00 88.59           C  \\nATOM    335  N6   DA I  17       2.713  88.748  18.705  1.00 88.59           N  \\nATOM    336  N1   DA I  17       4.667  89.830  19.248  1.00 88.59           N  \\nATOM    337  C2   DA I  17       5.803  90.411  18.851  1.00 88.59           C  \\nATOM    338  N3   DA I  17       6.290  90.555  17.623  1.00 88.59           N  \\nATOM    339  C4   DA I  17       5.463  90.004  16.719  1.00 88.59           C  \\nATOM    340  P    DG I  18       9.888  90.166  12.173  1.00 81.03           P  \\nATOM    341  OP1  DG I  18      11.066  90.842  11.585  1.00 81.03           O  \\nATOM    342  OP2  DG I  18       9.142  89.158  11.372  1.00 81.03           O  \\nATOM    343  O5'  DG I  18      10.288  89.457  13.540  1.00 78.56           O  \\nATOM    344  C5'  DG I  18      10.697  90.206  14.667  1.00 78.56           C  \\nATOM    345  C4'  DG I  18      10.813  89.303  15.872  1.00 78.56           C  \\nATOM    346  O4'  DG I  18       9.508  88.917  16.371  1.00 78.56           O  \\nATOM    347  C3'  DG I  18      11.583  87.996  15.654  1.00 78.56           C  \\nATOM    348  O3'  DG I  18      12.331  87.704  16.842  1.00 78.56           O  \\nATOM    349  C2'  DG I  18      10.469  86.968  15.540  1.00 78.56           C  \\nATOM    350  C1'  DG I  18       9.516  87.516  16.580  1.00 78.56           C  \\nATOM    351  N9   DG I  18       8.140  87.029  16.563  1.00 76.83           N  \\nATOM    352  C8   DG I  18       7.433  86.494  15.512  1.00 76.83           C  \\nATOM    353  N7   DG I  18       6.227  86.121  15.848  1.00 76.83           N  \\nATOM    354  C5   DG I  18       6.136  86.437  17.198  1.00 76.83           C  \\nATOM    355  C6   DG I  18       5.069  86.260  18.121  1.00 76.83           C  \\nATOM    356  O6   DG I  18       3.950  85.759  17.927  1.00 76.83           O  \\nATOM    357  N1   DG I  18       5.410  86.733  19.386  1.00 76.83           N  \\nATOM    358  C2   DG I  18       6.615  87.302  19.722  1.00 76.83           C  \\nATOM    359  N2   DG I  18       6.738  87.716  20.989  1.00 76.83           N  \\nATOM    360  N3   DG I  18       7.614  87.457  18.880  1.00 76.83           N  \\nATOM    361  C4   DG I  18       7.306  87.008  17.645  1.00 76.83           C  \\nATOM    362  P    DA I  19      13.927  87.540  16.780  1.00 58.59           P  \\nATOM    363  OP1  DA I  19      14.588  88.759  16.222  1.00 58.59           O  \\nATOM    364  OP2  DA I  19      14.200  86.205  16.169  1.00 58.59           O  \\nATOM    365  O5'  DA I  19      14.297  87.474  18.320  1.00 68.39           O  \\nATOM    366  C5'  DA I  19      14.018  86.309  19.075  1.00 68.39           C  \\nATOM    367  C4'  DA I  19      13.206  86.660  20.297  1.00 68.39           C  \\nATOM    368  O4'  DA I  19      11.799  86.633  19.949  1.00 68.39           O  \\nATOM    369  C3'  DA I  19      13.398  85.616  21.391  1.00 68.39           C  \\nATOM    370  O3'  DA I  19      13.546  86.218  22.672  1.00 68.39           O  \\nATOM    371  C2'  DA I  19      12.183  84.717  21.275  1.00 68.39           C  \\nATOM    372  C1'  DA I  19      11.118  85.608  20.663  1.00 68.39           C  \\nATOM    373  N9   DA I  19      10.253  84.889  19.723  1.00 77.32           N  \\nATOM    374  C8   DA I  19      10.555  84.463  18.455  1.00 77.32           C  \\nATOM    375  N7   DA I  19       9.565  83.847  17.852  1.00 77.32           N  \\nATOM    376  C5   DA I  19       8.539  83.865  18.790  1.00 77.32           C  \\nATOM    377  C6   DA I  19       7.205  83.374  18.766  1.00 77.32           C  \\nATOM    378  N6   DA I  19       6.652  82.751  17.722  1.00 77.32           N  \\nATOM    379  N1   DA I  19       6.451  83.555  19.871  1.00 77.32           N  \\nATOM    380  C2   DA I  19       6.994  84.188  20.917  1.00 77.32           C  \\nATOM    381  N3   DA I  19       8.219  84.696  21.058  1.00 77.32           N  \\nATOM    382  C4   DA I  19       8.951  84.499  19.948  1.00 77.32           C  \\nATOM    383  P    DT I  20      14.460  85.492  23.778  1.00105.51           P  \\nATOM    384  OP1  DT I  20      14.871  86.502  24.789  1.00105.51           O  \\nATOM    385  OP2  DT I  20      15.501  84.729  23.049  1.00105.51           O  \\nATOM    386  O5'  DT I  20      13.447  84.464  24.452  1.00114.59           O  \\nATOM    387  C5'  DT I  20      12.263  84.947  25.080  1.00114.59           C  \\nATOM    388  C4'  DT I  20      11.269  83.832  25.314  1.00114.59           C  \\nATOM    389  O4'  DT I  20      10.515  83.500  24.118  1.00114.59           O  \\nATOM    390  C3'  DT I  20      11.805  82.511  25.878  1.00114.59           C  \\nATOM    391  O3'  DT I  20      11.043  82.163  27.051  1.00114.59           O  \\nATOM    392  C2'  DT I  20      11.567  81.524  24.742  1.00114.59           C  \\nATOM    393  C1'  DT I  20      10.316  82.098  24.103  1.00114.59           C  \\nATOM    394  N1   DT I  20      10.002  81.663  22.715  1.00 90.06           N  \\nATOM    395  C2   DT I  20       8.671  81.422  22.414  1.00 90.06           C  \\nATOM    396  O2   DT I  20       7.769  81.578  23.220  1.00 90.06           O  \\nATOM    397  N3   DT I  20       8.435  80.985  21.128  1.00 90.06           N  \\nATOM    398  C4   DT I  20       9.370  80.777  20.131  1.00 90.06           C  \\nATOM    399  O4   DT I  20       9.002  80.376  19.025  1.00 90.06           O  \\nATOM    400  C5   DT I  20      10.748  81.059  20.508  1.00 90.06           C  \\nATOM    401  C7   DT I  20      11.832  80.861  19.493  1.00 90.06           C  \\nATOM    402  C6   DT I  20      10.989  81.485  21.763  1.00 90.06           C  \\nATOM    403  P    DT I  21      11.154  80.688  27.691  1.00126.32           P  \\nATOM    404  OP1  DT I  21      10.943  80.800  29.162  1.00126.32           O  \\nATOM    405  OP2  DT I  21      12.389  80.041  27.181  1.00126.32           O  \\nATOM    406  O5'  DT I  21       9.899  79.947  27.051  1.00163.70           O  \\nATOM    407  C5'  DT I  21       8.621  80.585  27.034  1.00163.70           C  \\nATOM    408  C4'  DT I  21       7.527  79.570  26.804  1.00163.70           C  \\nATOM    409  O4'  DT I  21       7.376  79.291  25.393  1.00163.70           O  \\nATOM    410  C3'  DT I  21       7.773  78.226  27.486  1.00163.70           C  \\nATOM    411  O3'  DT I  21       6.562  77.732  28.072  1.00163.70           O  \\nATOM    412  C2'  DT I  21       8.257  77.339  26.350  1.00163.70           C  \\nATOM    413  C1'  DT I  21       7.510  77.898  25.152  1.00163.70           C  \\nATOM    414  N1   DT I  21       8.201  77.739  23.859  1.00 99.19           N  \\nATOM    415  C2   DT I  21       7.427  77.570  22.728  1.00 99.19           C  \\nATOM    416  O2   DT I  21       6.206  77.504  22.755  1.00 99.19           O  \\nATOM    417  N3   DT I  21       8.136  77.477  21.555  1.00 99.19           N  \\nATOM    418  C4   DT I  21       9.515  77.536  21.403  1.00 99.19           C  \\nATOM    419  O4   DT I  21      10.013  77.467  20.276  1.00 99.19           O  \\nATOM    420  C5   DT I  21      10.265  77.687  22.639  1.00 99.19           C  \\nATOM    421  C7   DT I  21      11.759  77.740  22.583  1.00 99.19           C  \\nATOM    422  C6   DT I  21       9.579  77.776  23.786  1.00 99.19           C  \\nATOM    423  P    DC I  22       6.608  76.434  29.020  1.00136.78           P  \\nATOM    424  OP1  DC I  22       5.224  76.149  29.481  1.00136.78           O  \\nATOM    425  OP2  DC I  22       7.697  76.612  30.024  1.00136.78           O  \\nATOM    426  O5'  DC I  22       7.054  75.292  28.004  1.00140.75           O  \\nATOM    427  C5'  DC I  22       6.977  73.922  28.363  1.00140.75           C  \\nATOM    428  C4'  DC I  22       5.903  73.236  27.554  1.00140.75           C  \\nATOM    429  O4'  DC I  22       5.877  73.783  26.208  1.00140.75           O  \\nATOM    430  C3'  DC I  22       6.117  71.730  27.404  1.00140.75           C  \\nATOM    431  O3'  DC I  22       4.886  71.032  27.586  1.00140.75           O  \\nATOM    432  C2'  DC I  22       6.632  71.580  25.985  1.00140.75           C  \\nATOM    433  C1'  DC I  22       5.957  72.730  25.261  1.00140.75           C  \\nATOM    434  N1   DC I  22       6.722  73.202  24.093  1.00101.08           N  \\nATOM    435  C2   DC I  22       6.027  73.618  22.940  1.00101.08           C  \\nATOM    436  O2   DC I  22       4.785  73.677  22.967  1.00101.08           O  \\nATOM    437  N3   DC I  22       6.733  73.951  21.832  1.00101.08           N  \\nATOM    438  C4   DC I  22       8.071  73.906  21.852  1.00101.08           C  \\nATOM    439  N4   DC I  22       8.721  74.214  20.729  1.00101.08           N  \\nATOM    440  C5   DC I  22       8.797  73.537  23.023  1.00101.08           C  \\nATOM    441  C6   DC I  22       8.091  73.200  24.109  1.00101.08           C  \\nATOM    442  P    DT I  23       4.647  69.641  26.828  1.00129.19           P  \\nATOM    443  OP1  DT I  23       3.556  68.917  27.525  1.00129.19           O  \\nATOM    444  OP2  DT I  23       5.967  68.979  26.639  1.00129.19           O  \\nATOM    445  O5'  DT I  23       4.118  70.099  25.398  1.00186.42           O  \\nATOM    446  C5'  DT I  23       2.793  69.789  24.974  1.00186.42           C  \\nATOM    447  C4'  DT I  23       2.812  68.525  24.150  1.00186.42           C  \\nATOM    448  O4'  DT I  23       3.551  68.786  22.929  1.00186.42           O  \\nATOM    449  C3'  DT I  23       3.545  67.385  24.859  1.00186.42           C  \\nATOM    450  O3'  DT I  23       2.896  66.128  24.646  1.00186.42           O  \\nATOM    451  C2'  DT I  23       4.936  67.417  24.252  1.00186.42           C  \\nATOM    452  C1'  DT I  23       4.694  67.943  22.845  1.00186.42           C  \\nATOM    453  N1   DT I  23       5.829  68.743  22.319  1.00147.51           N  \\nATOM    454  C2   DT I  23       5.844  69.121  20.983  1.00147.51           C  \\nATOM    455  O2   DT I  23       4.940  68.864  20.195  1.00147.51           O  \\nATOM    456  N3   DT I  23       6.972  69.821  20.604  1.00147.51           N  \\nATOM    457  C4   DT I  23       8.044  70.183  21.403  1.00147.51           C  \\nATOM    458  O4   DT I  23       8.982  70.815  20.917  1.00147.51           O  \\nATOM    459  C5   DT I  23       7.951  69.766  22.788  1.00147.51           C  \\nATOM    460  C7   DT I  23       9.062  70.109  23.730  1.00147.51           C  \\nATOM    461  C6   DT I  23       6.866  69.082  23.168  1.00147.51           C  \\nATOM    462  P    DA I  24       3.720  64.764  24.850  1.00165.21           P  \\nATOM    463  OP1  DA I  24       2.745  63.647  24.950  1.00165.21           O  \\nATOM    464  OP2  DA I  24       4.711  64.972  25.939  1.00165.21           O  \\nATOM    465  O5'  DA I  24       4.515  64.631  23.477  1.00147.31           O  \\nATOM    466  C5'  DA I  24       3.838  64.796  22.230  1.00147.31           C  \\nATOM    467  C4'  DA I  24       4.669  64.224  21.106  1.00147.31           C  \\nATOM    468  O4'  DA I  24       5.723  65.149  20.741  1.00147.31           O  \\nATOM    469  C3'  DA I  24       5.352  62.909  21.473  1.00147.31           C  \\nATOM    470  O3'  DA I  24       5.216  61.949  20.411  1.00147.31           O  \\nATOM    471  C2'  DA I  24       6.787  63.317  21.766  1.00147.31           C  \\nATOM    472  C1'  DA I  24       7.001  64.540  20.886  1.00147.31           C  \\nATOM    473  N9   DA I  24       7.916  65.528  21.474  1.00172.68           N  \\nATOM    474  C8   DA I  24       8.090  65.795  22.814  1.00172.68           C  \\nATOM    475  N7   DA I  24       8.993  66.716  23.061  1.00172.68           N  \\nATOM    476  C5   DA I  24       9.444  67.087  21.801  1.00172.68           C  \\nATOM    477  C6   DA I  24      10.411  68.025  21.380  1.00172.68           C  \\nATOM    478  N6   DA I  24      11.125  68.785  22.218  1.00172.68           N  \\nATOM    479  N1   DA I  24      10.622  68.155  20.051  1.00172.68           N  \\nATOM    480  C2   DA I  24       9.909  67.391  19.211  1.00172.68           C  \\nATOM    481  N3   DA I  24       8.977  66.476  19.483  1.00172.68           N  \\nATOM    482  C4   DA I  24       8.788  66.368  20.811  1.00172.68           C  \\nATOM    483  P    DC I  25       6.450  60.996  20.018  1.00158.27           P  \\nATOM    484  OP1  DC I  25       5.942  59.910  19.140  1.00158.27           O  \\nATOM    485  OP2  DC I  25       7.226  60.647  21.240  1.00158.27           O  \\nATOM    486  O5'  DC I  25       7.328  61.975  19.129  1.00113.15           O  \\nATOM    487  C5'  DC I  25       6.902  62.340  17.821  1.00113.15           C  \\nATOM    488  C4'  DC I  25       7.865  61.754  16.824  1.00113.15           C  \\nATOM    489  O4'  DC I  25       9.040  62.594  16.813  1.00113.15           O  \\nATOM    490  C3'  DC I  25       8.344  60.384  17.293  1.00113.15           C  \\nATOM    491  O3'  DC I  25       8.695  59.567  16.179  1.00113.15           O  \\nATOM    492  C2'  DC I  25       9.540  60.715  18.160  1.00113.15           C  \\nATOM    493  C1'  DC I  25      10.112  61.955  17.493  1.00113.15           C  \\nATOM    494  N1   DC I  25      10.671  62.913  18.457  1.00101.19           N  \\nATOM    495  C2   DC I  25      11.388  64.007  17.979  1.00101.19           C  \\nATOM    496  O2   DC I  25      11.494  64.162  16.748  1.00101.19           O  \\nATOM    497  N3   DC I  25      11.948  64.866  18.867  1.00101.19           N  \\nATOM    498  C4   DC I  25      11.811  64.657  20.179  1.00101.19           C  \\nATOM    499  N4   DC I  25      12.415  65.501  21.014  1.00101.19           N  \\nATOM    500  C5   DC I  25      11.058  63.566  20.690  1.00101.19           C  \\nATOM    501  C6   DC I  25      10.507  62.728  19.803  1.00101.19           C  \\nATOM    502  P    DC I  26       9.667  58.307  16.389  1.00113.18           P  \\nATOM    503  OP1  DC I  26       8.977  57.107  15.857  1.00113.18           O  \\nATOM    504  OP2  DC I  26      10.157  58.306  17.795  1.00113.18           O  \\nATOM    505  O5'  DC I  26      10.887  58.644  15.424  1.00 99.13           O  \\nATOM    506  C5'  DC I  26      11.056  59.966  14.906  1.00 99.13           C  \\nATOM    507  C4'  DC I  26      12.524  60.281  14.754  1.00 99.13           C  \\nATOM    508  O4'  DC I  26      12.984  61.154  15.815  1.00 99.13           O  \\nATOM    509  C3'  DC I  26      13.426  59.054  14.813  1.00 99.13           C  \\nATOM    510  O3'  DC I  26      14.501  59.285  13.925  1.00 99.13           O  \\nATOM    511  C2'  DC I  26      13.941  59.066  16.241  1.00 99.13           C  \\nATOM    512  C1'  DC I  26      14.089  60.554  16.478  1.00 99.13           C  \\nATOM    513  N1   DC I  26      14.062  60.985  17.884  1.00 92.40           N  \\nATOM    514  C2   DC I  26      14.545  62.267  18.200  1.00 92.40           C  \\nATOM    515  O2   DC I  26      15.014  62.974  17.285  1.00 92.40           O  \\nATOM    516  N3   DC I  26      14.488  62.699  19.487  1.00 92.40           N  \\nATOM    517  C4   DC I  26      13.972  61.908  20.434  1.00 92.40           C  \\nATOM    518  N4   DC I  26      13.890  62.391  21.673  1.00 92.40           N  \\nATOM    519  C5   DC I  26      13.505  60.589  20.145  1.00 92.40           C  \\nATOM    520  C6   DC I  26      13.569  60.172  18.868  1.00 92.40           C  \\nATOM    521  P    DA I  27      15.095  58.079  13.067  1.00120.75           P  \\nATOM    522  OP1  DA I  27      14.285  57.973  11.824  1.00120.75           O  \\nATOM    523  OP2  DA I  27      15.225  56.904  13.964  1.00120.75           O  \\nATOM    524  O5'  DA I  27      16.548  58.615  12.690  1.00109.52           O  \\nATOM    525  C5'  DA I  27      16.740  59.972  12.272  1.00109.52           C  \\nATOM    526  C4'  DA I  27      18.049  60.510  12.803  1.00109.52           C  \\nATOM    527  O4'  DA I  27      17.969  60.769  14.226  1.00109.52           O  \\nATOM    528  C3'  DA I  27      19.241  59.582  12.606  1.00109.52           C  \\nATOM    529  O3'  DA I  27      20.359  60.379  12.266  1.00109.52           O  \\nATOM    530  C2'  DA I  27      19.436  58.958  13.978  1.00109.52           C  \\nATOM    531  C1'  DA I  27      18.988  60.062  14.926  1.00109.52           C  \\nATOM    532  N9   DA I  27      18.417  59.583  16.194  1.00108.29           N  \\nATOM    533  C8   DA I  27      17.881  58.341  16.435  1.00108.29           C  \\nATOM    534  N7   DA I  27      17.409  58.190  17.651  1.00108.29           N  \\nATOM    535  C5   DA I  27      17.655  59.411  18.261  1.00108.29           C  \\nATOM    536  C6   DA I  27      17.377  59.894  19.557  1.00108.29           C  \\nATOM    537  N6   DA I  27      16.763  59.178  20.498  1.00108.29           N  \\nATOM    538  N1   DA I  27      17.751  61.155  19.850  1.00108.29           N  \\nATOM    539  C2   DA I  27      18.358  61.879  18.898  1.00108.29           C  \\nATOM    540  N3   DA I  27      18.670  61.541  17.642  1.00108.29           N  \\nATOM    541  C4   DA I  27      18.286  60.279  17.381  1.00108.29           C  \\nATOM    542  P    DA I  28      21.563  59.758  11.411  1.00119.93           P  \\nATOM    543  OP1  DA I  28      21.216  59.808   9.968  1.00119.93           O  \\nATOM    544  OP2  DA I  28      21.962  58.470  12.031  1.00119.93           O  \\nATOM    545  O5'  DA I  28      22.701  60.828  11.679  1.00 78.84           O  \\nATOM    546  C5'  DA I  28      22.332  62.144  12.072  1.00 78.84           C  \\nATOM    547  C4'  DA I  28      22.784  62.423  13.486  1.00 78.84           C  \\nATOM    548  O4'  DA I  28      22.049  61.656  14.484  1.00 78.84           O  \\nATOM    549  C3'  DA I  28      24.265  62.141  13.728  1.00 78.84           C  \\nATOM    550  O3'  DA I  28      24.852  63.280  14.339  1.00 78.84           O  \\nATOM    551  C2'  DA I  28      24.259  60.972  14.698  1.00 78.84           C  \\nATOM    552  C1'  DA I  28      22.975  61.221  15.468  1.00 78.84           C  \\nATOM    553  N9   DA I  28      22.434  60.052  16.172  1.00 82.33           N  \\nATOM    554  C8   DA I  28      22.463  58.738  15.776  1.00 82.33           C  \\nATOM    555  N7   DA I  28      21.965  57.903  16.662  1.00 82.33           N  \\nATOM    556  C5   DA I  28      21.562  58.723  17.706  1.00 82.33           C  \\nATOM    557  C6   DA I  28      20.963  58.448  18.960  1.00 82.33           C  \\nATOM    558  N6   DA I  28      20.660  57.228  19.395  1.00 82.33           N  \\nATOM    559  N1   DA I  28      20.688  59.492  19.765  1.00 82.33           N  \\nATOM    560  C2   DA I  28      21.001  60.724  19.341  1.00 82.33           C  \\nATOM    561  N3   DA I  28      21.569  61.111  18.192  1.00 82.33           N  \\nATOM    562  C4   DA I  28      21.829  60.052  17.410  1.00 82.33           C  \\nATOM    563  P    DA I  29      26.400  63.591  14.103  1.00114.27           P  \\nATOM    564  OP1  DA I  29      26.512  65.025  13.724  1.00114.27           O  \\nATOM    565  OP2  DA I  29      26.930  62.535  13.201  1.00114.27           O  \\nATOM    566  O5'  DA I  29      27.025  63.367  15.543  1.00 60.34           O  \\nATOM    567  C5'  DA I  29      26.294  62.644  16.502  1.00 60.34           C  \\nATOM    568  C4'  DA I  29      26.061  63.493  17.723  1.00 60.34           C  \\nATOM    569  O4'  DA I  29      25.053  62.838  18.516  1.00 60.34           O  \\nATOM    570  C3'  DA I  29      27.295  63.578  18.605  1.00 60.34           C  \\nATOM    571  O3'  DA I  29      27.341  64.809  19.316  1.00 60.34           O  \\nATOM    572  C2'  DA I  29      27.153  62.384  19.534  1.00 60.34           C  \\nATOM    573  C1'  DA I  29      25.650  62.115  19.592  1.00 60.34           C  \\nATOM    574  N9   DA I  29      25.291  60.698  19.424  1.00 64.40           N  \\nATOM    575  C8   DA I  29      25.639  59.865  18.380  1.00 64.40           C  \\nATOM    576  N7   DA I  29      25.125  58.662  18.469  1.00 64.40           N  \\nATOM    577  C5   DA I  29      24.400  58.695  19.655  1.00 64.40           C  \\nATOM    578  C6   DA I  29      23.606  57.738  20.301  1.00 64.40           C  \\nATOM    579  N6   DA I  29      23.394  56.512  19.827  1.00 64.40           N  \\nATOM    580  N1   DA I  29      23.024  58.089  21.465  1.00 64.40           N  \\nATOM    581  C2   DA I  29      23.231  59.317  21.941  1.00 64.40           C  \\nATOM    582  N3   DA I  29      23.948  60.309  21.427  1.00 64.40           N  \\nATOM    583  C4   DA I  29      24.511  59.934  20.265  1.00 64.40           C  \\nATOM    584  P    DA I  30      28.615  65.141  20.233  1.00 65.58           P  \\nATOM    585  OP1  DA I  30      28.470  66.541  20.735  1.00 65.58           O  \\nATOM    586  OP2  DA I  30      29.860  64.708  19.536  1.00 65.58           O  \\nATOM    587  O5'  DA I  30      28.424  64.178  21.464  1.00 43.90           O  \\nATOM    588  C5'  DA I  30      27.349  64.393  22.334  1.00 43.90           C  \\nATOM    589  C4'  DA I  30      27.453  63.427  23.475  1.00 43.90           C  \\nATOM    590  O4'  DA I  30      26.976  62.128  23.047  1.00 43.90           O  \\nATOM    591  C3'  DA I  30      28.892  63.243  23.947  1.00 43.90           C  \\nATOM    592  O3'  DA I  30      28.867  63.290  25.373  1.00 43.90           O  \\nATOM    593  C2'  DA I  30      29.285  61.888  23.373  1.00 43.90           C  \\nATOM    594  C1'  DA I  30      27.954  61.140  23.315  1.00 43.90           C  \\nATOM    595  N9   DA I  30      27.821  60.079  22.302  1.00 64.74           N  \\nATOM    596  C8   DA I  30      28.370  60.013  21.042  1.00 64.74           C  \\nATOM    597  N7   DA I  30      28.093  58.901  20.399  1.00 64.74           N  \\nATOM    598  C5   DA I  30      27.303  58.184  21.291  1.00 64.74           C  \\nATOM    599  C6   DA I  30      26.698  56.902  21.222  1.00 64.74           C  \\nATOM    600  N6   DA I  30      26.814  56.073  20.182  1.00 64.74           N  \\nATOM    601  N1   DA I  30      25.966  56.495  22.283  1.00 64.74           N  \\nATOM    602  C2   DA I  30      25.858  57.309  23.337  1.00 64.74           C  \\nATOM    603  N3   DA I  30      26.386  58.520  23.530  1.00 64.74           N  \\nATOM    604  C4   DA I  30      27.109  58.905  22.459  1.00 64.74           C  \\nATOM    605  P    DG I  31      30.215  63.124  26.224  1.00 63.08           P  \\nATOM    606  OP1  DG I  31      30.311  64.256  27.187  1.00 63.08           O  \\nATOM    607  OP2  DG I  31      31.348  62.853  25.297  1.00 63.08           O  \\nATOM    608  O5'  DG I  31      29.884  61.808  27.054  1.00 76.79           O  \\nATOM    609  C5'  DG I  31      28.530  61.519  27.428  1.00 76.79           C  \\nATOM    610  C4'  DG I  31      28.379  60.063  27.803  1.00 76.79           C  \\nATOM    611  O4'  DG I  31      28.172  59.215  26.644  1.00 76.79           O  \\nATOM    612  C3'  DG I  31      29.592  59.503  28.535  1.00 76.79           C  \\nATOM    613  O3'  DG I  31      29.187  58.826  29.703  1.00 76.79           O  \\nATOM    614  C2'  DG I  31      30.218  58.534  27.547  1.00 76.79           C  \\nATOM    615  C1'  DG I  31      29.040  58.091  26.703  1.00 76.79           C  \\nATOM    616  N9   DG I  31      29.413  57.732  25.336  1.00 90.91           N  \\nATOM    617  C8   DG I  31      29.986  58.555  24.396  1.00 90.91           C  \\nATOM    618  N7   DG I  31      30.228  57.952  23.262  1.00 90.91           N  \\nATOM    619  C5   DG I  31      29.786  56.651  23.461  1.00 90.91           C  \\nATOM    620  C6   DG I  31      29.791  55.529  22.580  1.00 90.91           C  \\nATOM    621  O6   DG I  31      30.204  55.461  21.412  1.00 90.91           O  \\nATOM    622  N1   DG I  31      29.245  54.406  23.189  1.00 90.91           N  \\nATOM    623  C2   DG I  31      28.757  54.362  24.471  1.00 90.91           C  \\nATOM    624  N2   DG I  31      28.268  53.178  24.859  1.00 90.91           N  \\nATOM    625  N3   DG I  31      28.746  55.393  25.301  1.00 90.91           N  \\nATOM    626  C4   DG I  31      29.273  56.498  24.735  1.00 90.91           C  \\nATOM    627  P    DT I  32      30.300  58.267  30.696  1.00 67.38           P  \\nATOM    628  OP1  DT I  32      29.819  58.513  32.076  1.00 67.38           O  \\nATOM    629  OP2  DT I  32      31.628  58.787  30.275  1.00 67.38           O  \\nATOM    630  O5'  DT I  32      30.242  56.711  30.396  1.00115.84           O  \\nATOM    631  C5'  DT I  32      29.011  56.012  30.519  1.00115.84           C  \\nATOM    632  C4'  DT I  32      29.258  54.525  30.485  1.00115.84           C  \\nATOM    633  O4'  DT I  32      29.426  54.087  29.117  1.00115.84           O  \\nATOM    634  C3'  DT I  32      30.518  54.096  31.236  1.00115.84           C  \\nATOM    635  O3'  DT I  32      30.260  52.906  31.981  1.00115.84           O  \\nATOM    636  C2'  DT I  32      31.528  53.855  30.128  1.00115.84           C  \\nATOM    637  C1'  DT I  32      30.654  53.393  28.973  1.00115.84           C  \\nATOM    638  N1   DT I  32      31.190  53.713  27.639  1.00 94.85           N  \\nATOM    639  C2   DT I  32      30.973  52.827  26.602  1.00 94.85           C  \\nATOM    640  O2   DT I  32      30.386  51.762  26.737  1.00 94.85           O  \\nATOM    641  N3   DT I  32      31.477  53.236  25.392  1.00 94.85           N  \\nATOM    642  C4   DT I  32      32.164  54.405  25.124  1.00 94.85           C  \\nATOM    643  O4   DT I  32      32.531  54.646  23.979  1.00 94.85           O  \\nATOM    644  C5   DT I  32      32.383  55.267  26.262  1.00 94.85           C  \\nATOM    645  C7   DT I  32      33.158  56.534  26.077  1.00 94.85           C  \\nATOM    646  C6   DT I  32      31.886  54.887  27.443  1.00 94.85           C  \\nATOM    647  P    DG I  33      31.445  52.210  32.805  1.00112.46           P  \\nATOM    648  OP1  DG I  33      30.842  51.593  34.013  1.00112.46           O  \\nATOM    649  OP2  DG I  33      32.552  53.193  32.957  1.00112.46           O  \\nATOM    650  O5'  DG I  33      31.920  51.054  31.819  1.00121.33           O  \\nATOM    651  C5'  DG I  33      30.973  50.141  31.269  1.00121.33           C  \\nATOM    652  C4'  DG I  33      31.673  49.093  30.437  1.00121.33           C  \\nATOM    653  O4'  DG I  33      31.996  49.612  29.124  1.00121.33           O  \\nATOM    654  C3'  DG I  33      32.982  48.587  31.040  1.00121.33           C  \\nATOM    655  O3'  DG I  33      33.053  47.162  30.957  1.00121.33           O  \\nATOM    656  C2'  DG I  33      34.054  49.249  30.190  1.00121.33           C  \\nATOM    657  C1'  DG I  33      33.373  49.412  28.840  1.00121.33           C  \\nATOM    658  N9   DG I  33      33.847  50.570  28.087  1.00135.78           N  \\nATOM    659  C8   DG I  33      34.136  51.812  28.598  1.00135.78           C  \\nATOM    660  N7   DG I  33      34.558  52.653  27.694  1.00135.78           N  \\nATOM    661  C5   DG I  33      34.544  51.928  26.511  1.00135.78           C  \\nATOM    662  C6   DG I  33      34.904  52.314  25.190  1.00135.78           C  \\nATOM    663  O6   DG I  33      35.314  53.409  24.791  1.00135.78           O  \\nATOM    664  N1   DG I  33      34.748  51.268  24.290  1.00135.78           N  \\nATOM    665  C2   DG I  33      34.300  50.018  24.611  1.00135.78           C  \\nATOM    666  N2   DG I  33      34.235  49.162  23.586  1.00135.78           N  \\nATOM    667  N3   DG I  33      33.952  49.640  25.834  1.00135.78           N  \\nATOM    668  C4   DG I  33      34.102  50.640  26.731  1.00135.78           C  \\nATOM    669  P    DT I  34      34.339  46.397  31.539  1.00160.78           P  \\nATOM    670  OP1  DT I  34      33.898  45.094  32.102  1.00160.78           O  \\nATOM    671  OP2  DT I  34      35.112  47.339  32.389  1.00160.78           O  \\nATOM    672  O5'  DT I  34      35.193  46.129  30.229  1.00118.03           O  \\nATOM    673  C5'  DT I  34      36.430  45.460  30.300  1.00118.03           C  \\nATOM    674  C4'  DT I  34      36.575  44.548  29.110  1.00118.03           C  \\nATOM    675  O4'  DT I  34      36.219  45.289  27.919  1.00118.03           O  \\nATOM    676  C3'  DT I  34      38.011  44.087  28.917  1.00118.03           C  \\nATOM    677  O3'  DT I  34      38.063  42.774  28.375  1.00118.03           O  \\nATOM    678  C2'  DT I  34      38.569  45.091  27.930  1.00118.03           C  \\nATOM    679  C1'  DT I  34      37.360  45.464  27.087  1.00118.03           C  \\nATOM    680  N1   DT I  34      37.407  46.877  26.679  1.00125.56           N  \\nATOM    681  C2   DT I  34      37.681  47.191  25.361  1.00125.56           C  \\nATOM    682  O2   DT I  34      37.853  46.352  24.491  1.00125.56           O  \\nATOM    683  N3   DT I  34      37.748  48.536  25.100  1.00125.56           N  \\nATOM    684  C4   DT I  34      37.564  49.570  25.996  1.00125.56           C  \\nATOM    685  O4   DT I  34      37.664  50.732  25.609  1.00125.56           O  \\nATOM    686  C5   DT I  34      37.264  49.167  27.355  1.00125.56           C  \\nATOM    687  C7   DT I  34      37.042  50.217  28.398  1.00125.56           C  \\nATOM    688  C6   DT I  34      37.199  47.859  27.621  1.00125.56           C  \\nATOM    689  P    DA I  35      39.487  42.141  28.005  1.00141.32           P  \\nATOM    690  OP1  DA I  35      39.298  40.709  27.665  1.00141.32           O  \\nATOM    691  OP2  DA I  35      40.414  42.526  29.104  1.00141.32           O  \\nATOM    692  O5'  DA I  35      39.910  42.921  26.681  1.00139.14           O  \\nATOM    693  C5'  DA I  35      39.244  42.669  25.443  1.00139.14           C  \\nATOM    694  C4'  DA I  35      40.075  43.171  24.284  1.00139.14           C  \\nATOM    695  O4'  DA I  35      39.979  44.615  24.175  1.00139.14           O  \\nATOM    696  C3'  DA I  35      41.570  42.844  24.362  1.00139.14           C  \\nATOM    697  O3'  DA I  35      42.055  42.430  23.075  1.00139.14           O  \\nATOM    698  C2'  DA I  35      42.196  44.163  24.781  1.00139.14           C  \\nATOM    699  C1'  DA I  35      41.283  45.178  24.112  1.00139.14           C  \\nATOM    700  N9   DA I  35      41.252  46.492  24.763  1.00 97.78           N  \\nATOM    701  C8   DA I  35      40.977  46.775  26.082  1.00 97.78           C  \\nATOM    702  N7   DA I  35      41.037  48.053  26.376  1.00 97.78           N  \\nATOM    703  C5   DA I  35      41.373  48.655  25.172  1.00 97.78           C  \\nATOM    704  C6   DA I  35      41.589  49.996  24.818  1.00 97.78           C  \\nATOM    705  N6   DA I  35      41.492  51.013  25.678  1.00 97.78           N  \\nATOM    706  N1   DA I  35      41.910  50.261  23.534  1.00 97.78           N  \\nATOM    707  C2   DA I  35      42.002  49.240  22.671  1.00 97.78           C  \\nATOM    708  N3   DA I  35      41.820  47.939  22.882  1.00 97.78           N  \\nATOM    709  C4   DA I  35      41.505  47.707  24.168  1.00 97.78           C  \\nATOM    710  P    DT I  36      43.628  42.158  22.851  1.00101.49           P  \\nATOM    711  OP1  DT I  36      43.776  41.036  21.889  1.00101.49           O  \\nATOM    712  OP2  DT I  36      44.300  42.084  24.183  1.00101.49           O  \\nATOM    713  O5'  DT I  36      44.113  43.476  22.103  1.00154.52           O  \\nATOM    714  C5'  DT I  36      43.501  43.874  20.876  1.00154.52           C  \\nATOM    715  C4'  DT I  36      44.323  44.945  20.200  1.00154.52           C  \\nATOM    716  O4'  DT I  36      44.177  46.212  20.885  1.00154.52           O  \\nATOM    717  C3'  DT I  36      45.824  44.661  20.164  1.00154.52           C  \\nATOM    718  O3'  DT I  36      46.347  45.102  18.907  1.00154.52           O  \\nATOM    719  C2'  DT I  36      46.361  45.498  21.311  1.00154.52           C  \\nATOM    720  C1'  DT I  36      45.459  46.713  21.234  1.00154.52           C  \\nATOM    721  N1   DT I  36      45.326  47.482  22.485  1.00 70.72           N  \\nATOM    722  C2   DT I  36      45.451  48.860  22.415  1.00 70.72           C  \\nATOM    723  O2   DT I  36      45.702  49.463  21.375  1.00 70.72           O  \\nATOM    724  N3   DT I  36      45.276  49.508  23.616  1.00 70.72           N  \\nATOM    725  C4   DT I  36      45.001  48.937  24.848  1.00 70.72           C  \\nATOM    726  O4   DT I  36      44.856  49.658  25.833  1.00 70.72           O  \\nATOM    727  C5   DT I  36      44.906  47.487  24.850  1.00 70.72           C  \\nATOM    728  C7   DT I  36      44.630  46.777  26.139  1.00 70.72           C  \\nATOM    729  C6   DT I  36      45.072  46.843  23.684  1.00 70.72           C  \\nATOM    730  P    DT I  37      47.906  45.455  18.770  1.00 91.25           P  \\nATOM    731  OP1  DT I  37      48.352  45.027  17.415  1.00 91.25           O  \\nATOM    732  OP2  DT I  37      48.624  44.959  19.977  1.00 91.25           O  \\nATOM    733  O5'  DT I  37      47.927  47.047  18.808  1.00109.41           O  \\nATOM    734  C5'  DT I  37      47.139  47.811  17.892  1.00109.41           C  \\nATOM    735  C4'  DT I  37      47.698  49.209  17.759  1.00109.41           C  \\nATOM    736  O4'  DT I  37      47.557  49.903  19.019  1.00109.41           O  \\nATOM    737  C3'  DT I  37      49.184  49.274  17.405  1.00109.41           C  \\nATOM    738  O3'  DT I  37      49.423  50.358  16.508  1.00109.41           O  \\nATOM    739  C2'  DT I  37      49.863  49.508  18.742  1.00109.41           C  \\nATOM    740  C1'  DT I  37      48.826  50.314  19.503  1.00109.41           C  \\nATOM    741  N1   DT I  37      48.832  50.077  20.946  1.00 69.00           N  \\nATOM    742  C2   DT I  37      48.636  51.152  21.778  1.00 69.00           C  \\nATOM    743  O2   DT I  37      48.461  52.292  21.372  1.00 69.00           O  \\nATOM    744  N3   DT I  37      48.652  50.849  23.113  1.00 69.00           N  \\nATOM    745  C4   DT I  37      48.839  49.606  23.686  1.00 69.00           C  \\nATOM    746  O4   DT I  37      48.831  49.493  24.908  1.00 69.00           O  \\nATOM    747  C5   DT I  37      49.036  48.519  22.752  1.00 69.00           C  \\nATOM    748  C7   DT I  37      49.239  47.132  23.279  1.00 69.00           C  \\nATOM    749  C6   DT I  37      49.026  48.809  21.444  1.00 69.00           C  \\nATOM    750  P    DT I  38      50.924  50.708  16.076  1.00 80.38           P  \\nATOM    751  OP1  DT I  38      50.921  51.167  14.658  1.00 80.38           O  \\nATOM    752  OP2  DT I  38      51.793  49.574  16.494  1.00 80.38           O  \\nATOM    753  O5'  DT I  38      51.287  51.952  16.992  1.00 49.42           O  \\nATOM    754  C5'  DT I  38      50.454  53.102  17.003  1.00 49.42           C  \\nATOM    755  C4'  DT I  38      51.025  54.140  17.933  1.00 49.42           C  \\nATOM    756  O4'  DT I  38      50.810  53.752  19.309  1.00 49.42           O  \\nATOM    757  C3'  DT I  38      52.536  54.312  17.770  1.00 49.42           C  \\nATOM    758  O3'  DT I  38      52.877  55.692  17.908  1.00 49.42           O  \\nATOM    759  C2'  DT I  38      53.094  53.520  18.935  1.00 49.42           C  \\nATOM    760  C1'  DT I  38      52.047  53.818  19.977  1.00 49.42           C  \\nATOM    761  N1   DT I  38      52.007  52.914  21.121  1.00 62.92           N  \\nATOM    762  C2   DT I  38      51.769  53.506  22.327  1.00 62.92           C  \\nATOM    763  O2   DT I  38      51.523  54.698  22.434  1.00 62.92           O  \\nATOM    764  N3   DT I  38      51.816  52.659  23.406  1.00 62.92           N  \\nATOM    765  C4   DT I  38      52.054  51.304  23.392  1.00 62.92           C  \\nATOM    766  O4   DT I  38      52.103  50.691  24.452  1.00 62.92           O  \\nATOM    767  C5   DT I  38      52.240  50.723  22.073  1.00 62.92           C  \\nATOM    768  C7   DT I  38      52.436  49.243  21.948  1.00 62.92           C  \\nATOM    769  C6   DT I  38      52.216  51.554  21.013  1.00 62.92           C  \\nATOM    770  P    DG I  39      53.144  56.573  16.599  1.00 63.21           P  \\nATOM    771  OP1  DG I  39      52.078  56.277  15.611  1.00 63.21           O  \\nATOM    772  OP2  DG I  39      54.565  56.380  16.227  1.00 63.21           O  \\nATOM    773  O5'  DG I  39      52.969  58.068  17.104  1.00 51.08           O  \\nATOM    774  C5'  DG I  39      51.739  58.509  17.651  1.00 51.08           C  \\nATOM    775  C4'  DG I  39      51.980  59.154  18.995  1.00 51.08           C  \\nATOM    776  O4'  DG I  39      52.429  58.139  19.923  1.00 51.08           O  \\nATOM    777  C3'  DG I  39      53.065  60.232  18.980  1.00 51.08           C  \\nATOM    778  O3'  DG I  39      52.713  61.335  19.827  1.00 51.08           O  \\nATOM    779  C2'  DG I  39      54.291  59.513  19.508  1.00 51.08           C  \\nATOM    780  C1'  DG I  39      53.706  58.469  20.442  1.00 51.08           C  \\nATOM    781  N9   DG I  39      54.498  57.243  20.503  1.00 87.19           N  \\nATOM    782  C8   DG I  39      55.218  56.655  19.484  1.00 87.19           C  \\nATOM    783  N7   DG I  39      55.871  55.589  19.864  1.00 87.19           N  \\nATOM    784  C5   DG I  39      55.552  55.460  21.209  1.00 87.19           C  \\nATOM    785  C6   DG I  39      55.969  54.505  22.156  1.00 87.19           C  \\nATOM    786  O6   DG I  39      56.740  53.554  21.995  1.00 87.19           O  \\nATOM    787  N1   DG I  39      55.398  54.741  23.405  1.00 87.19           N  \\nATOM    788  C2   DG I  39      54.542  55.773  23.701  1.00 87.19           C  \\nATOM    789  N2   DG I  39      54.092  55.826  24.959  1.00 87.19           N  \\nATOM    790  N3   DG I  39      54.156  56.679  22.829  1.00 87.19           N  \\nATOM    791  C4   DG I  39      54.694  56.464  21.612  1.00 87.19           C  \\nATOM    792  P    DG I  40      53.333  62.797  19.541  1.00 42.89           P  \\nATOM    793  OP1  DG I  40      52.226  63.782  19.665  1.00 42.89           O  \\nATOM    794  OP2  DG I  40      54.122  62.726  18.271  1.00 42.89           O  \\nATOM    795  O5'  DG I  40      54.324  63.014  20.772  1.00 51.93           O  \\nATOM    796  C5'  DG I  40      53.829  62.954  22.107  1.00 51.93           C  \\nATOM    797  C4'  DG I  40      54.924  62.572  23.078  1.00 51.93           C  \\nATOM    798  O4'  DG I  40      55.341  61.189  22.926  1.00 51.93           O  \\nATOM    799  C3'  DG I  40      56.206  63.410  23.040  1.00 51.93           C  \\nATOM    800  O3'  DG I  40      56.574  63.718  24.381  1.00 51.93           O  \\nATOM    801  C2'  DG I  40      57.235  62.450  22.464  1.00 51.93           C  \\nATOM    802  C1'  DG I  40      56.752  61.143  23.063  1.00 51.93           C  \\nATOM    803  N9   DG I  40      57.256  59.895  22.483  1.00 80.43           N  \\nATOM    804  C8   DG I  40      57.638  59.655  21.182  1.00 80.43           C  \\nATOM    805  N7   DG I  40      58.088  58.441  20.993  1.00 80.43           N  \\nATOM    806  C5   DG I  40      57.990  57.837  22.243  1.00 80.43           C  \\nATOM    807  C6   DG I  40      58.333  56.511  22.670  1.00 80.43           C  \\nATOM    808  O6   DG I  40      58.817  55.579  22.008  1.00 80.43           O  \\nATOM    809  N1   DG I  40      58.058  56.323  24.023  1.00 80.43           N  \\nATOM    810  C2   DG I  40      57.528  57.277  24.863  1.00 80.43           C  \\nATOM    811  N2   DG I  40      57.328  56.899  26.144  1.00 80.43           N  \\nATOM    812  N3   DG I  40      57.213  58.508  24.482  1.00 80.43           N  \\nATOM    813  C4   DG I  40      57.468  58.717  23.171  1.00 80.43           C  \\nATOM    814  P    DA I  41      56.605  65.242  24.872  1.00 63.87           P  \\nATOM    815  OP1  DA I  41      55.245  65.826  24.743  1.00 63.87           O  \\nATOM    816  OP2  DA I  41      57.758  65.904  24.210  1.00 63.87           O  \\nATOM    817  O5'  DA I  41      56.929  65.112  26.422  1.00 64.83           O  \\nATOM    818  C5'  DA I  41      55.987  64.509  27.298  1.00 64.83           C  \\nATOM    819  C4'  DA I  41      56.686  63.618  28.299  1.00 64.83           C  \\nATOM    820  O4'  DA I  41      57.196  62.425  27.669  1.00 64.83           O  \\nATOM    821  C3'  DA I  41      57.862  64.241  29.041  1.00 64.83           C  \\nATOM    822  O3'  DA I  41      57.761  63.859  30.414  1.00 64.83           O  \\nATOM    823  C2'  DA I  41      59.078  63.637  28.355  1.00 64.83           C  \\nATOM    824  C1'  DA I  41      58.577  62.264  27.951  1.00 64.83           C  \\nATOM    825  N9   DA I  41      59.187  61.682  26.755  1.00 75.11           N  \\nATOM    826  C8   DA I  41      59.343  62.266  25.521  1.00 75.11           C  \\nATOM    827  N7   DA I  41      59.855  61.467  24.616  1.00 75.11           N  \\nATOM    828  C5   DA I  41      60.069  60.278  25.304  1.00 75.11           C  \\nATOM    829  C6   DA I  41      60.585  59.026  24.900  1.00 75.11           C  \\nATOM    830  N6   DA I  41      60.994  58.758  23.656  1.00 75.11           N  \\nATOM    831  N1   DA I  41      60.664  58.049  25.833  1.00 75.11           N  \\nATOM    832  C2   DA I  41      60.250  58.318  27.085  1.00 75.11           C  \\nATOM    833  N3   DA I  41      59.747  59.450  27.584  1.00 75.11           N  \\nATOM    834  C4   DA I  41      59.679  60.403  26.630  1.00 75.11           C  \\nATOM    835  P    DA I  42      58.968  64.163  31.410  1.00 91.67           P  \\nATOM    836  OP1  DA I  42      58.504  63.871  32.788  1.00 91.67           O  \\nATOM    837  OP2  DA I  42      59.532  65.501  31.084  1.00 91.67           O  \\nATOM    838  O5'  DA I  42      60.020  63.061  30.982  1.00 94.41           O  \\nATOM    839  C5'  DA I  42      59.786  61.697  31.288  1.00 94.41           C  \\nATOM    840  C4'  DA I  42      61.108  60.994  31.447  1.00 94.41           C  \\nATOM    841  O4'  DA I  42      61.532  60.456  30.172  1.00 94.41           O  \\nATOM    842  C3'  DA I  42      62.208  61.950  31.908  1.00 94.41           C  \\nATOM    843  O3'  DA I  42      63.029  61.332  32.896  1.00 94.41           O  \\nATOM    844  C2'  DA I  42      62.981  62.235  30.633  1.00 94.41           C  \\nATOM    845  C1'  DA I  42      62.818  60.947  29.847  1.00 94.41           C  \\nATOM    846  N9   DA I  42      62.866  61.124  28.400  1.00 91.43           N  \\nATOM    847  C8   DA I  42      62.506  62.235  27.675  1.00 91.43           C  \\nATOM    848  N7   DA I  42      62.664  62.094  26.381  1.00 91.43           N  \\nATOM    849  C5   DA I  42      63.160  60.804  26.244  1.00 91.43           C  \\nATOM    850  C6   DA I  42      63.527  60.045  25.118  1.00 91.43           C  \\nATOM    851  N6   DA I  42      63.455  60.498  23.860  1.00 91.43           N  \\nATOM    852  N1   DA I  42      63.975  58.786  25.331  1.00 91.43           N  \\nATOM    853  C2   DA I  42      64.046  58.332  26.590  1.00 91.43           C  \\nATOM    854  N3   DA I  42      63.731  58.949  27.725  1.00 91.43           N  \\nATOM    855  C4   DA I  42      63.289  60.195  27.481  1.00 91.43           C  \\nATOM    856  P    DA I  43      64.215  62.164  33.590  1.00109.59           P  \\nATOM    857  OP1  DA I  43      64.016  62.064  35.058  1.00109.59           O  \\nATOM    858  OP2  DA I  43      64.320  63.508  32.955  1.00109.59           O  \\nATOM    859  O5'  DA I  43      65.504  61.316  33.193  1.00114.51           O  \\nATOM    860  C5'  DA I  43      65.494  59.895  33.323  1.00114.51           C  \\nATOM    861  C4'  DA I  43      66.658  59.276  32.584  1.00114.51           C  \\nATOM    862  O4'  DA I  43      66.441  59.344  31.152  1.00114.51           O  \\nATOM    863  C3'  DA I  43      68.021  59.921  32.855  1.00114.51           C  \\nATOM    864  O3'  DA I  43      69.024  58.921  33.094  1.00114.51           O  \\nATOM    865  C2'  DA I  43      68.310  60.688  31.577  1.00114.51           C  \\nATOM    866  C1'  DA I  43      67.599  59.862  30.521  1.00114.51           C  \\nATOM    867  N9   DA I  43      67.179  60.644  29.357  1.00 76.76           N  \\nATOM    868  C8   DA I  43      66.604  61.893  29.344  1.00 76.76           C  \\nATOM    869  N7   DA I  43      66.390  62.364  28.140  1.00 76.76           N  \\nATOM    870  C5   DA I  43      66.841  61.352  27.300  1.00 76.76           C  \\nATOM    871  C6   DA I  43      66.900  61.241  25.900  1.00 76.76           C  \\nATOM    872  N6   DA I  43      66.487  62.199  25.067  1.00 76.76           N  \\nATOM    873  N1   DA I  43      67.408  60.101  25.379  1.00 76.76           N  \\nATOM    874  C2   DA I  43      67.825  59.145  26.217  1.00 76.76           C  \\nATOM    875  N3   DA I  43      67.825  59.133  27.547  1.00 76.76           N  \\nATOM    876  C4   DA I  43      67.316  60.281  28.035  1.00 76.76           C  \\nATOM    877  P    DC I  44      70.375  59.307  33.889  1.00135.14           P  \\nATOM    878  OP1  DC I  44      70.648  58.274  34.932  1.00135.14           O  \\nATOM    879  OP2  DC I  44      70.286  60.734  34.289  1.00135.14           O  \\nATOM    880  O5'  DC I  44      71.487  59.201  32.753  1.00105.23           O  \\nATOM    881  C5'  DC I  44      71.352  59.935  31.539  1.00105.23           C  \\nATOM    882  C4'  DC I  44      72.003  59.193  30.396  1.00105.23           C  \\nATOM    883  O4'  DC I  44      71.201  59.412  29.212  1.00105.23           O  \\nATOM    884  C3'  DC I  44      73.402  59.708  30.060  1.00105.23           C  \\nATOM    885  O3'  DC I  44      74.259  58.644  29.606  1.00105.23           O  \\nATOM    886  C2'  DC I  44      73.142  60.738  28.977  1.00105.23           C  \\nATOM    887  C1'  DC I  44      71.908  60.201  28.262  1.00105.23           C  \\nATOM    888  N1   DC I  44      71.006  61.273  27.794  1.00 73.33           N  \\nATOM    889  C2   DC I  44      70.648  61.332  26.426  1.00 73.33           C  \\nATOM    890  O2   DC I  44      71.066  60.461  25.644  1.00 73.33           O  \\nATOM    891  N3   DC I  44      69.852  62.342  25.996  1.00 73.33           N  \\nATOM    892  C4   DC I  44      69.408  63.261  26.861  1.00 73.33           C  \\nATOM    893  N4   DC I  44      68.633  64.244  26.385  1.00 73.33           N  \\nATOM    894  C5   DC I  44      69.739  63.215  28.252  1.00 73.33           C  \\nATOM    895  C6   DC I  44      70.532  62.213  28.670  1.00 73.33           C  \\nATOM    896  P    DT I  45      75.851  58.894  29.471  1.00 89.38           P  \\nATOM    897  OP1  DT I  45      76.577  57.597  29.503  1.00 89.38           O  \\nATOM    898  OP2  DT I  45      76.229  59.968  30.424  1.00 89.38           O  \\nATOM    899  O5'  DT I  45      76.000  59.474  28.004  1.00120.01           O  \\nATOM    900  C5'  DT I  45      75.826  58.629  26.878  1.00120.01           C  \\nATOM    901  C4'  DT I  45      76.193  59.380  25.625  1.00120.01           C  \\nATOM    902  O4'  DT I  45      75.170  60.370  25.343  1.00120.01           O  \\nATOM    903  C3'  DT I  45      77.505  60.153  25.771  1.00120.01           C  \\nATOM    904  O3'  DT I  45      78.235  60.113  24.545  1.00120.01           O  \\nATOM    905  C2'  DT I  45      77.042  61.567  26.071  1.00120.01           C  \\nATOM    906  C1'  DT I  45      75.769  61.652  25.248  1.00120.01           C  \\nATOM    907  N1   DT I  45      74.797  62.660  25.715  1.00 82.12           N  \\nATOM    908  C2   DT I  45      74.039  63.324  24.768  1.00 82.12           C  \\nATOM    909  O2   DT I  45      74.106  63.089  23.568  1.00 82.12           O  \\nATOM    910  N3   DT I  45      73.191  64.278  25.282  1.00 82.12           N  \\nATOM    911  C4   DT I  45      73.023  64.618  26.615  1.00 82.12           C  \\nATOM    912  O4   DT I  45      72.228  65.506  26.927  1.00 82.12           O  \\nATOM    913  C5   DT I  45      73.834  63.866  27.552  1.00 82.12           C  \\nATOM    914  C7   DT I  45      73.707  64.151  29.017  1.00 82.12           C  \\nATOM    915  C6   DT I  45      74.668  62.937  27.059  1.00 82.12           C  \\nATOM    916  P    DG I  46      79.678  60.811  24.450  1.00 84.74           P  \\nATOM    917  OP1  DG I  46      80.673  59.813  24.907  1.00 84.74           O  \\nATOM    918  OP2  DG I  46      79.627  62.145  25.103  1.00 84.74           O  \\nATOM    919  O5'  DG I  46      79.867  61.037  22.885  1.00 85.38           O  \\nATOM    920  C5'  DG I  46      78.959  60.458  21.942  1.00 85.38           C  \\nATOM    921  C4'  DG I  46      78.583  61.472  20.885  1.00 85.38           C  \\nATOM    922  O4'  DG I  46      77.621  62.433  21.388  1.00 85.38           O  \\nATOM    923  C3'  DG I  46      79.747  62.296  20.335  1.00 85.38           C  \\nATOM    924  O3'  DG I  46      79.546  62.497  18.939  1.00 85.38           O  \\nATOM    925  C2'  DG I  46      79.631  63.612  21.085  1.00 85.38           C  \\nATOM    926  C1'  DG I  46      78.125  63.755  21.227  1.00 85.38           C  \\nATOM    927  N9   DG I  46      77.688  64.537  22.378  1.00 97.88           N  \\nATOM    928  C8   DG I  46      78.163  64.465  23.667  1.00 97.88           C  \\nATOM    929  N7   DG I  46      77.543  65.268  24.487  1.00 97.88           N  \\nATOM    930  C5   DG I  46      76.607  65.913  23.690  1.00 97.88           C  \\nATOM    931  C6   DG I  46      75.631  66.892  24.022  1.00 97.88           C  \\nATOM    932  O6   DG I  46      75.373  67.384  25.127  1.00 97.88           O  \\nATOM    933  N1   DG I  46      74.904  67.286  22.903  1.00 97.88           N  \\nATOM    934  C2   DG I  46      75.077  66.790  21.635  1.00 97.88           C  \\nATOM    935  N2   DG I  46      74.266  67.302  20.700  1.00 97.88           N  \\nATOM    936  N3   DG I  46      75.970  65.869  21.314  1.00 97.88           N  \\nATOM    937  C4   DG I  46      76.696  65.481  22.383  1.00 97.88           C  \\nATOM    938  P    DC I  47      80.741  63.063  18.033  1.00 93.20           P  \\nATOM    939  OP1  DC I  47      81.229  61.973  17.141  1.00 93.20           O  \\nATOM    940  OP2  DC I  47      81.685  63.769  18.941  1.00 93.20           O  \\nATOM    941  O5'  DC I  47      80.014  64.138  17.117  1.00 97.12           O  \\nATOM    942  C5'  DC I  47      78.600  64.306  17.195  1.00 97.12           C  \\nATOM    943  C4'  DC I  47      78.243  65.761  17.028  1.00 97.12           C  \\nATOM    944  O4'  DC I  47      77.992  66.360  18.323  1.00 97.12           O  \\nATOM    945  C3'  DC I  47      79.360  66.570  16.384  1.00 97.12           C  \\nATOM    946  O3'  DC I  47      78.784  67.452  15.428  1.00 97.12           O  \\nATOM    947  C2'  DC I  47      80.009  67.292  17.557  1.00 97.12           C  \\nATOM    948  C1'  DC I  47      78.861  67.458  18.542  1.00 97.12           C  \\nATOM    949  N1   DC I  47      79.222  67.479  19.980  1.00 65.35           N  \\nATOM    950  C2   DC I  47      78.547  68.369  20.828  1.00 65.35           C  \\nATOM    951  O2   DC I  47      77.647  69.071  20.363  1.00 65.35           O  \\nATOM    952  N3   DC I  47      78.883  68.435  22.137  1.00 65.35           N  \\nATOM    953  C4   DC I  47      79.833  67.642  22.620  1.00 65.35           C  \\nATOM    954  N4   DC I  47      80.126  67.753  23.920  1.00 65.35           N  \\nATOM    955  C5   DC I  47      80.524  66.703  21.793  1.00 65.35           C  \\nATOM    956  C6   DC I  47      80.192  66.659  20.487  1.00 65.35           C  \\nATOM    957  P    DT I  48      79.374  67.515  13.931  1.00 93.31           P  \\nATOM    958  OP1  DT I  48      78.377  66.952  12.967  1.00 93.31           O  \\nATOM    959  OP2  DT I  48      80.757  66.979  13.957  1.00 93.31           O  \\nATOM    960  O5'  DT I  48      79.481  69.083  13.698  1.00 70.47           O  \\nATOM    961  C5'  DT I  48      79.382  69.971  14.814  1.00 70.47           C  \\nATOM    962  C4'  DT I  48      77.978  70.526  14.923  1.00 70.47           C  \\nATOM    963  O4'  DT I  48      77.591  70.556  16.309  1.00 70.47           O  \\nATOM    964  C3'  DT I  48      77.824  71.959  14.432  1.00 70.47           C  \\nATOM    965  O3'  DT I  48      76.489  72.177  13.945  1.00 70.47           O  \\nATOM    966  C2'  DT I  48      78.146  72.769  15.678  1.00 70.47           C  \\nATOM    967  C1'  DT I  48      77.682  71.875  16.822  1.00 70.47           C  \\nATOM    968  N1   DT I  48      78.590  71.815  17.978  1.00 98.38           N  \\nATOM    969  C2   DT I  48      78.271  72.519  19.112  1.00 98.38           C  \\nATOM    970  O2   DT I  48      77.308  73.260  19.187  1.00 98.38           O  \\nATOM    971  N3   DT I  48      79.125  72.320  20.166  1.00 98.38           N  \\nATOM    972  C4   DT I  48      80.243  71.518  20.197  1.00 98.38           C  \\nATOM    973  O4   DT I  48      80.890  71.416  21.237  1.00 98.38           O  \\nATOM    974  C5   DT I  48      80.543  70.839  18.955  1.00 98.38           C  \\nATOM    975  C7   DT I  48      81.748  69.956  18.877  1.00 98.38           C  \\nATOM    976  C6   DT I  48      79.716  71.026  17.922  1.00 98.38           C  \\nATOM    977  P    DC I  49      76.156  73.491  13.072  1.00 65.72           P  \\nATOM    978  OP1  DC I  49      74.862  73.290  12.362  1.00 65.72           O  \\nATOM    979  OP2  DC I  49      77.379  73.832  12.301  1.00 65.72           O  \\nATOM    980  O5'  DC I  49      75.873  74.590  14.174  1.00 37.82           O  \\nATOM    981  C5'  DC I  49      75.082  74.237  15.292  1.00 37.82           C  \\nATOM    982  C4'  DC I  49      74.887  75.434  16.177  1.00 37.82           C  \\nATOM    983  O4'  DC I  49      75.929  75.477  17.178  1.00 37.82           O  \\nATOM    984  C3'  DC I  49      74.985  76.743  15.413  1.00 37.82           C  \\nATOM    985  O3'  DC I  49      74.022  77.627  15.999  1.00 37.82           O  \\nATOM    986  C2'  DC I  49      76.438  77.149  15.615  1.00 37.82           C  \\nATOM    987  C1'  DC I  49      76.734  76.638  17.014  1.00 37.82           C  \\nATOM    988  N1   DC I  49      78.133  76.239  17.274  1.00 81.63           N  \\nATOM    989  C2   DC I  49      78.586  76.159  18.606  1.00 81.63           C  \\nATOM    990  O2   DC I  49      77.837  76.531  19.527  1.00 81.63           O  \\nATOM    991  N3   DC I  49      79.827  75.679  18.850  1.00 81.63           N  \\nATOM    992  C4   DC I  49      80.609  75.305  17.838  1.00 81.63           C  \\nATOM    993  N4   DC I  49      81.790  74.772  18.127  1.00 81.63           N  \\nATOM    994  C5   DC I  49      80.204  75.442  16.481  1.00 81.63           C  \\nATOM    995  C6   DC I  49      78.971  75.911  16.246  1.00 81.63           C  \\nATOM    996  P    DC I  50      74.239  79.206  15.947  1.00 53.70           P  \\nATOM    997  OP1  DC I  50      73.294  79.774  14.940  1.00 53.70           O  \\nATOM    998  OP2  DC I  50      75.688  79.497  15.807  1.00 53.70           O  \\nATOM    999  O5'  DC I  50      73.861  79.614  17.432  1.00 37.09           O  \\nATOM   1000  C5'  DC I  50      74.711  80.509  18.105  1.00 37.09           C  \\nATOM   1001  C4'  DC I  50      74.622  80.365  19.606  1.00 37.09           C  \\nATOM   1002  O4'  DC I  50      75.652  79.454  20.057  1.00 37.09           O  \\nATOM   1003  C3'  DC I  50      75.017  81.720  20.178  1.00 37.09           C  \\nATOM   1004  O3'  DC I  50      74.354  82.103  21.356  1.00 37.09           O  \\nATOM   1005  C2'  DC I  50      76.510  81.637  20.397  1.00 37.09           C  \\nATOM   1006  C1'  DC I  50      76.754  80.167  20.652  1.00 37.09           C  \\nATOM   1007  N1   DC I  50      78.008  79.715  20.004  1.00 51.49           N  \\nATOM   1008  C2   DC I  50      79.002  79.089  20.779  1.00 51.49           C  \\nATOM   1009  O2   DC I  50      78.833  78.962  22.001  1.00 51.49           O  \\nATOM   1010  N3   DC I  50      80.123  78.649  20.177  1.00 51.49           N  \\nATOM   1011  C4   DC I  50      80.290  78.824  18.866  1.00 51.49           C  \\nATOM   1012  N4   DC I  50      81.417  78.361  18.310  1.00 51.49           N  \\nATOM   1013  C5   DC I  50      79.313  79.477  18.061  1.00 51.49           C  \\nATOM   1014  C6   DC I  50      78.199  79.902  18.663  1.00 51.49           C  \\nATOM   1015  P    DA I  51      74.351  83.652  21.721  1.00 35.38           P  \\nATOM   1016  OP1  DA I  51      73.059  84.050  22.327  1.00 35.38           O  \\nATOM   1017  OP2  DA I  51      74.837  84.321  20.469  1.00 35.38           O  \\nATOM   1018  O5'  DA I  51      75.474  83.774  22.827  1.00 41.04           O  \\nATOM   1019  C5'  DA I  51      75.313  83.163  24.097  1.00 41.04           C  \\nATOM   1020  C4'  DA I  51      76.523  83.466  24.943  1.00 41.04           C  \\nATOM   1021  O4'  DA I  51      77.671  82.861  24.293  1.00 41.04           O  \\nATOM   1022  C3'  DA I  51      76.828  84.962  25.041  1.00 41.04           C  \\nATOM   1023  O3'  DA I  51      77.303  85.275  26.350  1.00 41.04           O  \\nATOM   1024  C2'  DA I  51      77.885  85.181  23.975  1.00 41.04           C  \\nATOM   1025  C1'  DA I  51      78.619  83.852  23.945  1.00 41.04           C  \\nATOM   1026  N9   DA I  51      79.185  83.484  22.648  1.00 73.66           N  \\nATOM   1027  C8   DA I  51      78.753  83.844  21.395  1.00 73.66           C  \\nATOM   1028  N7   DA I  51      79.484  83.353  20.424  1.00 73.66           N  \\nATOM   1029  C5   DA I  51      80.459  82.616  21.082  1.00 73.66           C  \\nATOM   1030  C6   DA I  51      81.540  81.854  20.617  1.00 73.66           C  \\nATOM   1031  N6   DA I  51      81.817  81.685  19.325  1.00 73.66           N  \\nATOM   1032  N1   DA I  51      82.336  81.261  21.534  1.00 73.66           N  \\nATOM   1033  C2   DA I  51      82.048  81.421  22.828  1.00 73.66           C  \\nATOM   1034  N3   DA I  51      81.055  82.104  23.389  1.00 73.66           N  \\nATOM   1035  C4   DA I  51      80.288  82.688  22.450  1.00 73.66           C  \\nATOM   1036  P    DT I  52      77.972  86.709  26.642  1.00 66.62           P  \\nATOM   1037  OP1  DT I  52      77.614  87.092  28.031  1.00 66.62           O  \\nATOM   1038  OP2  DT I  52      77.681  87.645  25.523  1.00 66.62           O  \\nATOM   1039  O5'  DT I  52      79.527  86.375  26.596  1.00 76.18           O  \\nATOM   1040  C5'  DT I  52      80.064  85.320  27.397  1.00 76.18           C  \\nATOM   1041  C4'  DT I  52      81.571  85.310  27.310  1.00 76.18           C  \\nATOM   1042  O4'  DT I  52      81.985  84.790  26.022  1.00 76.18           O  \\nATOM   1043  C3'  DT I  52      82.220  86.692  27.442  1.00 76.18           C  \\nATOM   1044  O3'  DT I  52      83.412  86.622  28.236  1.00 76.18           O  \\nATOM   1045  C2'  DT I  52      82.580  87.040  26.011  1.00 76.18           C  \\nATOM   1046  C1'  DT I  52      82.933  85.675  25.461  1.00 76.18           C  \\nATOM   1047  N1   DT I  52      82.848  85.582  24.004  1.00111.58           N  \\nATOM   1048  C2   DT I  52      83.806  84.852  23.334  1.00111.58           C  \\nATOM   1049  O2   DT I  52      84.692  84.220  23.897  1.00111.58           O  \\nATOM   1050  N3   DT I  52      83.683  84.880  21.971  1.00111.58           N  \\nATOM   1051  C4   DT I  52      82.708  85.524  21.232  1.00111.58           C  \\nATOM   1052  O4   DT I  52      82.728  85.461  20.012  1.00111.58           O  \\nATOM   1053  C5   DT I  52      81.722  86.239  22.001  1.00111.58           C  \\nATOM   1054  C7   DT I  52      80.616  86.949  21.285  1.00111.58           C  \\nATOM   1055  C6   DT I  52      81.841  86.235  23.332  1.00111.58           C  \\nATOM   1056  P    DC I  53      84.029  87.962  28.880  1.00 81.59           P  \\nATOM   1057  OP1  DC I  53      83.945  87.804  30.355  1.00 81.59           O  \\nATOM   1058  OP2  DC I  53      83.417  89.152  28.225  1.00 81.59           O  \\nATOM   1059  O5'  DC I  53      85.555  87.913  28.432  1.00 99.57           O  \\nATOM   1060  C5'  DC I  53      85.883  87.643  27.080  1.00 99.57           C  \\nATOM   1061  C4'  DC I  53      87.378  87.667  26.879  1.00 99.57           C  \\nATOM   1062  O4'  DC I  53      87.599  87.122  25.560  1.00 99.57           O  \\nATOM   1063  C3'  DC I  53      87.955  89.081  26.856  1.00 99.57           C  \\nATOM   1064  O3'  DC I  53      89.295  89.168  27.351  1.00 99.57           O  \\nATOM   1065  C2'  DC I  53      87.914  89.473  25.395  1.00 99.57           C  \\nATOM   1066  C1'  DC I  53      87.872  88.160  24.627  1.00 99.57           C  \\nATOM   1067  N1   DC I  53      86.749  88.224  23.691  1.00 94.23           N  \\nATOM   1068  C2   DC I  53      86.851  87.628  22.435  1.00 94.23           C  \\nATOM   1069  O2   DC I  53      87.870  86.980  22.150  1.00 94.23           O  \\nATOM   1070  N3   DC I  53      85.833  87.776  21.560  1.00 94.23           N  \\nATOM   1071  C4   DC I  53      84.752  88.480  21.907  1.00 94.23           C  \\nATOM   1072  N4   DC I  53      83.795  88.644  21.004  1.00 94.23           N  \\nATOM   1073  C5   DC I  53      84.610  89.058  23.195  1.00 94.23           C  \\nATOM   1074  C6   DC I  53      85.618  88.904  24.047  1.00 94.23           C  \\nATOM   1075  P    DA I  54      90.124  90.535  27.134  1.00113.09           P  \\nATOM   1076  OP1  DA I  54      91.235  90.566  28.116  1.00113.09           O  \\nATOM   1077  OP2  DA I  54      89.153  91.666  27.092  1.00113.09           O  \\nATOM   1078  O5'  DA I  54      90.744  90.372  25.672  1.00119.58           O  \\nATOM   1079  C5'  DA I  54      91.633  89.293  25.370  1.00119.58           C  \\nATOM   1080  C4'  DA I  54      92.247  89.475  23.999  1.00119.58           C  \\nATOM   1081  O4'  DA I  54      91.229  89.315  22.985  1.00119.58           O  \\nATOM   1082  C3'  DA I  54      92.874  90.848  23.752  1.00119.58           C  \\nATOM   1083  O3'  DA I  54      94.010  90.741  22.888  1.00119.58           O  \\nATOM   1084  C2'  DA I  54      91.771  91.602  23.042  1.00119.58           C  \\nATOM   1085  C1'  DA I  54      91.126  90.504  22.219  1.00119.58           C  \\nATOM   1086  N9   DA I  54      89.713  90.745  21.960  1.00120.14           N  \\nATOM   1087  C8   DA I  54      88.752  91.235  22.812  1.00120.14           C  \\nATOM   1088  N7   DA I  54      87.574  91.360  22.258  1.00120.14           N  \\nATOM   1089  C5   DA I  54      87.774  90.917  20.959  1.00120.14           C  \\nATOM   1090  C6   DA I  54      86.922  90.806  19.868  1.00120.14           C  \\nATOM   1091  N6   DA I  54      85.632  91.143  19.906  1.00120.14           N  \\nATOM   1092  N1   DA I  54      87.441  90.330  18.716  1.00120.14           N  \\nATOM   1093  C2   DA I  54      88.733  89.995  18.679  1.00120.14           C  \\nATOM   1094  N3   DA I  54      89.635  90.054  19.640  1.00120.14           N  \\nATOM   1095  C4   DA I  54      89.084  90.531  20.767  1.00120.14           C  \\nATOM   1096  P    DA I  55      94.915  92.038  22.604  1.00142.98           P  \\nATOM   1097  OP1  DA I  55      96.332  91.629  22.735  1.00142.98           O  \\nATOM   1098  OP2  DA I  55      94.396  93.163  23.427  1.00142.98           O  \\nATOM   1099  O5'  DA I  55      94.640  92.369  21.073  1.00156.61           O  \\nATOM   1100  C5'  DA I  55      95.199  91.558  20.046  1.00156.61           C  \\nATOM   1101  C4'  DA I  55      94.995  92.205  18.698  1.00156.61           C  \\nATOM   1102  O4'  DA I  55      93.563  92.257  18.472  1.00156.61           O  \\nATOM   1103  C3'  DA I  55      95.507  93.644  18.593  1.00156.61           C  \\nATOM   1104  O3'  DA I  55      96.477  93.871  17.530  1.00156.61           O  \\nATOM   1105  C2'  DA I  55      94.265  94.522  18.640  1.00156.61           C  \\nATOM   1106  C1'  DA I  55      93.104  93.592  18.285  1.00156.61           C  \\nATOM   1107  N9   DA I  55      91.904  93.784  19.115  1.00 79.18           N  \\nATOM   1108  C8   DA I  55      91.849  94.284  20.398  1.00 79.18           C  \\nATOM   1109  N7   DA I  55      90.630  94.382  20.878  1.00 79.18           N  \\nATOM   1110  C5   DA I  55      89.825  93.905  19.852  1.00 79.18           C  \\nATOM   1111  C6   DA I  55      88.429  93.756  19.734  1.00 79.18           C  \\nATOM   1112  N6   DA I  55      87.561  94.063  20.699  1.00 79.18           N  \\nATOM   1113  N1   DA I  55      87.948  93.265  18.573  1.00 79.18           N  \\nATOM   1114  C2   DA I  55      88.813  92.930  17.609  1.00 79.18           C  \\nATOM   1115  N3   DA I  55      90.143  93.013  17.600  1.00 79.18           N  \\nATOM   1116  C4   DA I  55      90.595  93.521  18.762  1.00 79.18           C  \\nATOM   1117  P    DA I  56      96.081  93.728  15.964  1.00118.11           P  \\nATOM   1118  OP1  DA I  56      96.610  92.425  15.487  1.00118.11           O  \\nATOM   1119  OP2  DA I  56      96.494  94.980  15.268  1.00118.11           O  \\nATOM   1120  O5'  DA I  56      94.493  93.640  15.931  1.00154.03           O  \\nATOM   1121  C5'  DA I  56      93.833  92.759  15.020  1.00154.03           C  \\nATOM   1122  C4'  DA I  56      93.035  93.554  14.014  1.00154.03           C  \\nATOM   1123  O4'  DA I  56      91.938  94.215  14.687  1.00154.03           O  \\nATOM   1124  C3'  DA I  56      93.830  94.658  13.319  1.00154.03           C  \\nATOM   1125  O3'  DA I  56      93.411  94.756  11.953  1.00154.03           O  \\nATOM   1126  C2'  DA I  56      93.483  95.897  14.125  1.00154.03           C  \\nATOM   1127  C1'  DA I  56      92.052  95.625  14.554  1.00154.03           C  \\nATOM   1128  N9   DA I  56      91.692  96.223  15.840  1.00103.77           N  \\nATOM   1129  C8   DA I  56      92.478  96.981  16.677  1.00103.77           C  \\nATOM   1130  N7   DA I  56      91.867  97.366  17.771  1.00103.77           N  \\nATOM   1131  C5   DA I  56      90.590  96.828  17.646  1.00103.77           C  \\nATOM   1132  C6   DA I  56      89.450  96.871  18.479  1.00103.77           C  \\nATOM   1133  N6   DA I  56      89.408  97.501  19.655  1.00103.77           N  \\nATOM   1134  N1   DA I  56      88.338  96.232  18.054  1.00103.77           N  \\nATOM   1135  C2   DA I  56      88.373  95.596  16.878  1.00103.77           C  \\nATOM   1136  N3   DA I  56      89.376  95.480  16.012  1.00103.77           N  \\nATOM   1137  C4   DA I  56      90.469  96.125  16.460  1.00103.77           C  \\nATOM   1138  P    DA I  57      93.607  96.130  11.140  1.00159.99           P  \\nATOM   1139  OP1  DA I  57      94.106  95.794   9.784  1.00159.99           O  \\nATOM   1140  OP2  DA I  57      94.359  97.101  11.981  1.00159.99           O  \\nATOM   1141  O5'  DA I  57      92.116  96.658  10.981  1.00157.02           O  \\nATOM   1142  C5'  DA I  57      91.087  95.773  10.547  1.00157.02           C  \\nATOM   1143  C4'  DA I  57      89.775  96.509  10.415  1.00157.02           C  \\nATOM   1144  O4'  DA I  57      89.276  96.859  11.729  1.00157.02           O  \\nATOM   1145  C3'  DA I  57      89.839  97.807   9.607  1.00157.02           C  \\nATOM   1146  O3'  DA I  57      88.719  97.868   8.714  1.00157.02           O  \\nATOM   1147  C2'  DA I  57      89.809  98.895  10.671  1.00157.02           C  \\nATOM   1148  C1'  DA I  57      89.038  98.255  11.822  1.00157.02           C  \\nATOM   1149  N9   DA I  57      89.455  98.694  13.160  1.00115.79           N  \\nATOM   1150  C8   DA I  57      90.734  98.743  13.666  1.00115.79           C  \\nATOM   1151  N7   DA I  57      90.802  99.194  14.896  1.00115.79           N  \\nATOM   1152  C5   DA I  57      89.480  99.459  15.227  1.00115.79           C  \\nATOM   1153  C6   DA I  57      88.884  99.967  16.391  1.00115.79           C  \\nATOM   1154  N6   DA I  57      89.568 100.308  17.485  1.00115.79           N  \\nATOM   1155  N1   DA I  57      87.544 100.118  16.395  1.00115.79           N  \\nATOM   1156  C2   DA I  57      86.856  99.775  15.303  1.00115.79           C  \\nATOM   1157  N3   DA I  57      87.300  99.285  14.148  1.00115.79           N  \\nATOM   1158  C4   DA I  57      88.639  99.152  14.172  1.00115.79           C  \\nATOM   1159  P    DG I  58      88.603  99.054   7.632  1.00 92.50           P  \\nATOM   1160  OP1  DG I  58      88.056  98.474   6.378  1.00 92.50           O  \\nATOM   1161  OP2  DG I  58      89.867  99.839   7.588  1.00 92.50           O  \\nATOM   1162  O5'  DG I  58      87.481  99.977   8.277  1.00109.15           O  \\nATOM   1163  C5'  DG I  58      86.292  99.389   8.800  1.00109.15           C  \\nATOM   1164  C4'  DG I  58      85.165 100.388   8.759  1.00109.15           C  \\nATOM   1165  O4'  DG I  58      85.153 101.172   9.972  1.00109.15           O  \\nATOM   1166  C3'  DG I  58      85.303 101.370   7.605  1.00109.15           C  \\nATOM   1167  O3'  DG I  58      84.092 101.431   6.841  1.00109.15           O  \\nATOM   1168  C2'  DG I  58      85.846 102.643   8.239  1.00109.15           C  \\nATOM   1169  C1'  DG I  58      85.604 102.501   9.746  1.00109.15           C  \\nATOM   1170  N9   DG I  58      86.822 102.670  10.540  1.00106.40           N  \\nATOM   1171  C8   DG I  58      88.110 102.697  10.055  1.00106.40           C  \\nATOM   1172  N7   DG I  58      89.014 102.788  10.994  1.00106.40           N  \\nATOM   1173  C5   DG I  58      88.286 102.837  12.177  1.00106.40           C  \\nATOM   1174  C6   DG I  58      88.731 102.919  13.527  1.00106.40           C  \\nATOM   1175  O6   DG I  58      89.890 102.936  13.957  1.00106.40           O  \\nATOM   1176  N1   DG I  58      87.664 102.970  14.417  1.00106.40           N  \\nATOM   1177  C2   DG I  58      86.339 102.927  14.059  1.00106.40           C  \\nATOM   1178  N2   DG I  58      85.462 103.000  15.072  1.00106.40           N  \\nATOM   1179  N3   DG I  58      85.906 102.825  12.805  1.00106.40           N  \\nATOM   1180  C4   DG I  58      86.928 102.789  11.919  1.00106.40           C  \\nATOM   1181  P    DG I  59      83.025 102.601   7.077  1.00 63.53           P  \\nATOM   1182  OP1  DG I  59      82.331 102.785   5.777  1.00 63.53           O  \\nATOM   1183  OP2  DG I  59      83.617 103.770   7.767  1.00 63.53           O  \\nATOM   1184  O5'  DG I  59      81.988 101.955   8.087  1.00 52.63           O  \\nATOM   1185  C5'  DG I  59      80.766 102.616   8.329  1.00 52.63           C  \\nATOM   1186  C4'  DG I  59      80.702 103.119   9.751  1.00 52.63           C  \\nATOM   1187  O4'  DG I  59      81.988 103.602  10.215  1.00 52.63           O  \\nATOM   1188  C3'  DG I  59      79.740 104.296   9.895  1.00 52.63           C  \\nATOM   1189  O3'  DG I  59      78.922 104.174  11.043  1.00 52.63           O  \\nATOM   1190  C2'  DG I  59      80.656 105.491  10.071  1.00 52.63           C  \\nATOM   1191  C1'  DG I  59      81.792 104.864  10.830  1.00 52.63           C  \\nATOM   1192  N9   DG I  59      83.050 105.591  10.778  1.00 82.27           N  \\nATOM   1193  C8   DG I  59      83.773 105.952   9.665  1.00 82.27           C  \\nATOM   1194  N7   DG I  59      84.910 106.517   9.961  1.00 82.27           N  \\nATOM   1195  C5   DG I  59      84.926 106.542  11.350  1.00 82.27           C  \\nATOM   1196  C6   DG I  59      85.916 106.999  12.251  1.00 82.27           C  \\nATOM   1197  O6   DG I  59      87.034 107.461  12.000  1.00 82.27           O  \\nATOM   1198  N1   DG I  59      85.509 106.857  13.573  1.00 82.27           N  \\nATOM   1199  C2   DG I  59      84.314 106.326  13.978  1.00 82.27           C  \\nATOM   1200  N2   DG I  59      84.104 106.289  15.301  1.00 82.27           N  \\nATOM   1201  N3   DG I  59      83.396 105.871  13.150  1.00 82.27           N  \\nATOM   1202  C4   DG I  59      83.768 106.007  11.862  1.00 82.27           C  \\nATOM   1203  P    DC I  60      77.616 105.077  11.146  1.00 41.85           P  \\nATOM   1204  OP1  DC I  60      76.489 104.163  11.475  1.00 41.85           O  \\nATOM   1205  OP2  DC I  60      77.535 105.942   9.942  1.00 41.85           O  \\nATOM   1206  O5'  DC I  60      77.909 106.039  12.373  1.00 45.42           O  \\nATOM   1207  C5'  DC I  60      77.704 105.583  13.703  1.00 45.42           C  \\nATOM   1208  C4'  DC I  60      78.129 106.640  14.695  1.00 45.42           C  \\nATOM   1209  O4'  DC I  60      79.468 107.086  14.381  1.00 45.42           O  \\nATOM   1210  C3'  DC I  60      77.265 107.898  14.729  1.00 45.42           C  \\nATOM   1211  O3'  DC I  60      77.252 108.375  16.056  1.00 45.42           O  \\nATOM   1212  C2'  DC I  60      78.034 108.873  13.861  1.00 45.42           C  \\nATOM   1213  C1'  DC I  60      79.477 108.494  14.182  1.00 45.42           C  \\nATOM   1214  N1   DC I  60      80.470 108.790  13.131  1.00 68.12           N  \\nATOM   1215  C2   DC I  60      81.694 109.385  13.498  1.00 68.12           C  \\nATOM   1216  O2   DC I  60      81.899 109.672  14.696  1.00 68.12           O  \\nATOM   1217  N3   DC I  60      82.616 109.634  12.539  1.00 68.12           N  \\nATOM   1218  C4   DC I  60      82.356 109.323  11.261  1.00 68.12           C  \\nATOM   1219  N4   DC I  60      83.302 109.581  10.346  1.00 68.12           N  \\nATOM   1220  C5   DC I  60      81.119 108.732  10.865  1.00 68.12           C  \\nATOM   1221  C6   DC I  60      80.215 108.484  11.821  1.00 68.12           C  \\nATOM   1222  P    DA I  61      75.898 108.925  16.681  1.00 63.86           P  \\nATOM   1223  OP1  DA I  61      75.188 107.821  17.365  1.00 63.86           O  \\nATOM   1224  OP2  DA I  61      75.207 109.732  15.646  1.00 63.86           O  \\nATOM   1225  O5'  DA I  61      76.413 109.917  17.801  1.00 44.23           O  \\nATOM   1226  C5'  DA I  61      77.549 109.579  18.582  1.00 44.23           C  \\nATOM   1227  C4'  DA I  61      78.461 110.772  18.714  1.00 44.23           C  \\nATOM   1228  O4'  DA I  61      79.233 110.978  17.504  1.00 44.23           O  \\nATOM   1229  C3'  DA I  61      77.711 112.072  18.978  1.00 44.23           C  \\nATOM   1230  O3'  DA I  61      78.218 112.687  20.151  1.00 44.23           O  \\nATOM   1231  C2'  DA I  61      77.948 112.912  17.731  1.00 44.23           C  \\nATOM   1232  C1'  DA I  61      79.214 112.342  17.138  1.00 44.23           C  \\nATOM   1233  N9   DA I  61      79.260 112.390  15.685  1.00 65.56           N  \\nATOM   1234  C8   DA I  61      78.279 112.036  14.800  1.00 65.56           C  \\nATOM   1235  N7   DA I  61      78.633 112.152  13.544  1.00 65.56           N  \\nATOM   1236  C5   DA I  61      79.933 112.620  13.611  1.00 65.56           C  \\nATOM   1237  C6   DA I  61      80.869 112.936  12.622  1.00 65.56           C  \\nATOM   1238  N6   DA I  61      80.628 112.828  11.317  1.00 65.56           N  \\nATOM   1239  N1   DA I  61      82.079 113.374  13.021  1.00 65.56           N  \\nATOM   1240  C2   DA I  61      82.318 113.486  14.331  1.00 65.56           C  \\nATOM   1241  N3   DA I  61      81.517 113.219  15.359  1.00 65.56           N  \\nATOM   1242  C4   DA I  61      80.326 112.782  14.924  1.00 65.56           C  \\nATOM   1243  P    DT I  62      77.371 113.842  20.867  1.00 52.42           P  \\nATOM   1244  OP1  DT I  62      77.499 113.652  22.335  1.00 52.42           O  \\nATOM   1245  OP2  DT I  62      76.019 113.952  20.250  1.00 52.42           O  \\nATOM   1246  O5'  DT I  62      78.210 115.111  20.433  1.00 50.64           O  \\nATOM   1247  C5'  DT I  62      79.058 115.034  19.292  1.00 50.64           C  \\nATOM   1248  C4'  DT I  62      79.950 116.245  19.233  1.00 50.64           C  \\nATOM   1249  O4'  DT I  62      80.631 116.207  17.960  1.00 50.64           O  \\nATOM   1250  C3'  DT I  62      79.147 117.538  19.260  1.00 50.64           C  \\nATOM   1251  O3'  DT I  62      79.763 118.512  20.100  1.00 50.64           O  \\nATOM   1252  C2'  DT I  62      79.049 117.956  17.804  1.00 50.64           C  \\nATOM   1253  C1'  DT I  62      80.190 117.240  17.104  1.00 50.64           C  \\nATOM   1254  N1   DT I  62      79.758 116.612  15.846  1.00 62.94           N  \\nATOM   1255  C2   DT I  62      80.637 116.597  14.792  1.00 62.94           C  \\nATOM   1256  O2   DT I  62      81.777 117.025  14.869  1.00 62.94           O  \\nATOM   1257  N3   DT I  62      80.134 116.056  13.635  1.00 62.94           N  \\nATOM   1258  C4   DT I  62      78.869 115.524  13.436  1.00 62.94           C  \\nATOM   1259  O4   DT I  62      78.553 115.079  12.336  1.00 62.94           O  \\nATOM   1260  C5   DT I  62      78.005 115.550  14.593  1.00 62.94           C  \\nATOM   1261  C7   DT I  62      76.617 114.999  14.473  1.00 62.94           C  \\nATOM   1262  C6   DT I  62      78.488 116.078  15.728  1.00 62.94           C  \\nATOM   1263  P    DG I  63      78.918 119.795  20.581  1.00 85.98           P  \\nATOM   1264  OP1  DG I  63      79.368 120.142  21.954  1.00 85.98           O  \\nATOM   1265  OP2  DG I  63      77.473 119.548  20.318  1.00 85.98           O  \\nATOM   1266  O5'  DG I  63      79.389 120.935  19.574  1.00 97.04           O  \\nATOM   1267  C5'  DG I  63      80.773 121.111  19.274  1.00 97.04           C  \\nATOM   1268  C4'  DG I  63      80.941 122.111  18.157  1.00 97.04           C  \\nATOM   1269  O4'  DG I  63      80.618 121.508  16.884  1.00 97.04           O  \\nATOM   1270  C3'  DG I  63      80.024 123.323  18.289  1.00 97.04           C  \\nATOM   1271  O3'  DG I  63      80.701 124.476  17.786  1.00 97.04           O  \\nATOM   1272  C2'  DG I  63      78.847 122.951  17.410  1.00 97.04           C  \\nATOM   1273  C1'  DG I  63      79.534 122.206  16.284  1.00 97.04           C  \\nATOM   1274  N9   DG I  63      78.682 121.224  15.625  1.00 65.42           N  \\nATOM   1275  C8   DG I  63      77.664 120.496  16.191  1.00 65.42           C  \\nATOM   1276  N7   DG I  63      77.097 119.673  15.352  1.00 65.42           N  \\nATOM   1277  C5   DG I  63      77.778 119.874  14.163  1.00 65.42           C  \\nATOM   1278  C6   DG I  63      77.612 119.262  12.898  1.00 65.42           C  \\nATOM   1279  O6   DG I  63      76.813 118.384  12.567  1.00 65.42           O  \\nATOM   1280  N1   DG I  63      78.504 119.773  11.964  1.00 65.42           N  \\nATOM   1281  C2   DG I  63      79.438 120.746  12.215  1.00 65.42           C  \\nATOM   1282  N2   DG I  63      80.180 121.105  11.163  1.00 65.42           N  \\nATOM   1283  N3   DG I  63      79.617 121.317  13.395  1.00 65.42           N  \\nATOM   1284  C4   DG I  63      78.755 120.837  14.314  1.00 65.42           C  \\nATOM   1285  P    DT I  64      79.892 125.845  17.538  1.00147.98           P  \\nATOM   1286  OP1  DT I  64      80.688 126.954  18.122  1.00147.98           O  \\nATOM   1287  OP2  DT I  64      78.480 125.651  17.968  1.00147.98           O  \\nATOM   1288  O5'  DT I  64      79.938 125.991  15.952  1.00116.41           O  \\nATOM   1289  C5'  DT I  64      81.176 125.873  15.250  1.00116.41           C  \\nATOM   1290  C4'  DT I  64      81.048 126.440  13.856  1.00116.41           C  \\nATOM   1291  O4'  DT I  64      80.364 125.499  12.993  1.00116.41           O  \\nATOM   1292  C3'  DT I  64      80.266 127.751  13.774  1.00116.41           C  \\nATOM   1293  O3'  DT I  64      80.946 128.685  12.922  1.00116.41           O  \\nATOM   1294  C2'  DT I  64      78.910 127.330  13.225  1.00116.41           C  \\nATOM   1295  C1'  DT I  64      79.242 126.116  12.371  1.00116.41           C  \\nATOM   1296  N1   DT I  64      78.161 125.100  12.268  1.00 69.74           N  \\nATOM   1297  C2   DT I  64      78.012 124.415  11.076  1.00 69.74           C  \\nATOM   1298  O2   DT I  64      78.692 124.632  10.087  1.00 69.74           O  \\nATOM   1299  N3   DT I  64      77.028 123.458  11.086  1.00 69.74           N  \\nATOM   1300  C4   DT I  64      76.187 123.130  12.130  1.00 69.74           C  \\nATOM   1301  O4   DT I  64      75.357 122.235  11.986  1.00 69.74           O  \\nATOM   1302  C5   DT I  64      76.375 123.900  13.337  1.00 69.74           C  \\nATOM   1303  C7   DT I  64      75.494 123.622  14.514  1.00 69.74           C  \\nATOM   1304  C6   DT I  64      77.338 124.836  13.346  1.00 69.74           C  \\nATOM   1305  P    DT I  65      80.183 130.002  12.396  1.00 73.21           P  \\nATOM   1306  OP1  DT I  65      81.204 130.970  11.897  1.00 73.21           O  \\nATOM   1307  OP2  DT I  65      79.172 130.442  13.405  1.00 73.21           O  \\nATOM   1308  O5'  DT I  65      79.413 129.443  11.128  1.00 77.01           O  \\nATOM   1309  C5'  DT I  65      80.148 128.867  10.053  1.00 77.01           C  \\nATOM   1310  C4'  DT I  65      79.303 128.863   8.806  1.00 77.01           C  \\nATOM   1311  O4'  DT I  65      78.413 127.725   8.798  1.00 77.01           O  \\nATOM   1312  C3'  DT I  65      78.413 130.097   8.708  1.00 77.01           C  \\nATOM   1313  O3'  DT I  65      78.346 130.503   7.352  1.00 77.01           O  \\nATOM   1314  C2'  DT I  65      77.069 129.595   9.196  1.00 77.01           C  \\nATOM   1315  C1'  DT I  65      77.085 128.177   8.669  1.00 77.01           C  \\nATOM   1316  N1   DT I  65      76.224 127.248   9.394  1.00 41.88           N  \\nATOM   1317  C2   DT I  65      75.715 126.175   8.696  1.00 41.88           C  \\nATOM   1318  O2   DT I  65      75.988 125.940   7.519  1.00 41.88           O  \\nATOM   1319  N3   DT I  65      74.861 125.386   9.424  1.00 41.88           N  \\nATOM   1320  C4   DT I  65      74.467 125.561  10.740  1.00 41.88           C  \\nATOM   1321  O4   DT I  65      73.652 124.777  11.253  1.00 41.88           O  \\nATOM   1322  C5   DT I  65      75.061 126.689  11.411  1.00 41.88           C  \\nATOM   1323  C7   DT I  65      74.696 126.949  12.835  1.00 41.88           C  \\nATOM   1324  C6   DT I  65      75.911 127.462  10.719  1.00 41.88           C  \\nATOM   1325  P    DC I  66      77.638 131.883   6.975  1.00 74.93           P  \\nATOM   1326  OP1  DC I  66      78.634 132.714   6.251  1.00 74.93           O  \\nATOM   1327  OP2  DC I  66      76.991 132.404   8.218  1.00 74.93           O  \\nATOM   1328  O5'  DC I  66      76.519 131.412   5.945  1.00 70.38           O  \\nATOM   1329  C5'  DC I  66      76.782 130.335   5.042  1.00 70.38           C  \\nATOM   1330  C4'  DC I  66      75.499 129.739   4.505  1.00 70.38           C  \\nATOM   1331  O4'  DC I  66      74.832 128.875   5.461  1.00 70.38           O  \\nATOM   1332  C3'  DC I  66      74.435 130.710   4.008  1.00 70.38           C  \\nATOM   1333  O3'  DC I  66      73.901 130.122   2.852  1.00 70.38           O  \\nATOM   1334  C2'  DC I  66      73.372 130.662   5.091  1.00 70.38           C  \\nATOM   1335  C1'  DC I  66      73.449 129.208   5.515  1.00 70.38           C  \\nATOM   1336  N1   DC I  66      72.968 128.924   6.879  1.00 44.13           N  \\nATOM   1337  C2   DC I  66      72.504 127.627   7.187  1.00 44.13           C  \\nATOM   1338  O2   DC I  66      72.452 126.764   6.284  1.00 44.13           O  \\nATOM   1339  N3   DC I  66      72.113 127.354   8.453  1.00 44.13           N  \\nATOM   1340  C4   DC I  66      72.155 128.309   9.384  1.00 44.13           C  \\nATOM   1341  N4   DC I  66      71.797 127.992  10.622  1.00 44.13           N  \\nATOM   1342  C5   DC I  66      72.579 129.633   9.089  1.00 44.13           C  \\nATOM   1343  C6   DC I  66      72.979 129.895   7.839  1.00 44.13           C  \\nATOM   1344  P    DA I  67      73.298 131.034   1.705  1.00 46.51           P  \\nATOM   1345  OP1  DA I  67      74.449 131.557   0.941  1.00 46.51           O  \\nATOM   1346  OP2  DA I  67      72.314 131.977   2.308  1.00 46.51           O  \\nATOM   1347  O5'  DA I  67      72.572 129.947   0.794  1.00 44.45           O  \\nATOM   1348  C5'  DA I  67      73.179 128.655   0.595  1.00 44.45           C  \\nATOM   1349  C4'  DA I  67      72.140 127.549   0.566  1.00 44.45           C  \\nATOM   1350  O4'  DA I  67      71.547 127.321   1.869  1.00 44.45           O  \\nATOM   1351  C3'  DA I  67      70.974 127.758  -0.397  1.00 44.45           C  \\nATOM   1352  O3'  DA I  67      70.680 126.507  -1.037  1.00 44.45           O  \\nATOM   1353  C2'  DA I  67      69.867 128.285   0.505  1.00 44.45           C  \\nATOM   1354  C1'  DA I  67      70.147 127.596   1.835  1.00 44.45           C  \\nATOM   1355  N9   DA I  67      69.833 128.364   3.042  1.00 36.56           N  \\nATOM   1356  C8   DA I  67      70.076 129.684   3.295  1.00 36.56           C  \\nATOM   1357  N7   DA I  67      69.778 130.055   4.523  1.00 36.56           N  \\nATOM   1358  C5   DA I  67      69.279 128.903   5.108  1.00 36.56           C  \\nATOM   1359  C6   DA I  67      68.801 128.617   6.417  1.00 36.56           C  \\nATOM   1360  N6   DA I  67      68.741 129.509   7.415  1.00 36.56           N  \\nATOM   1361  N1   DA I  67      68.379 127.357   6.666  1.00 36.56           N  \\nATOM   1362  C2   DA I  67      68.427 126.456   5.674  1.00 36.56           C  \\nATOM   1363  N3   DA I  67      68.851 126.601   4.415  1.00 36.56           N  \\nATOM   1364  C4   DA I  67      69.277 127.859   4.197  1.00 36.56           C  \\nATOM   1365  P    DG I  68      69.610 126.447  -2.234  1.00 39.82           P  \\nATOM   1366  OP1  DG I  68      69.972 125.447  -3.266  1.00 39.82           O  \\nATOM   1367  OP2  DG I  68      69.311 127.838  -2.638  1.00 39.82           O  \\nATOM   1368  O5'  DG I  68      68.356 125.849  -1.489  1.00 53.10           O  \\nATOM   1369  C5'  DG I  68      68.275 125.944  -0.083  1.00 53.10           C  \\nATOM   1370  C4'  DG I  68      67.105 125.136   0.386  1.00 53.10           C  \\nATOM   1371  O4'  DG I  68      66.638 125.669   1.636  1.00 53.10           O  \\nATOM   1372  C3'  DG I  68      65.958 125.302  -0.594  1.00 53.10           C  \\nATOM   1373  O3'  DG I  68      65.264 124.063  -0.661  1.00 53.10           O  \\nATOM   1374  C2'  DG I  68      65.178 126.483  -0.051  1.00 53.10           C  \\nATOM   1375  C1'  DG I  68      65.517 126.513   1.428  1.00 53.10           C  \\nATOM   1376  N9   DG I  68      65.910 127.846   1.859  1.00 48.31           N  \\nATOM   1377  C8   DG I  68      66.412 128.849   1.069  1.00 48.31           C  \\nATOM   1378  N7   DG I  68      66.669 129.945   1.731  1.00 48.31           N  \\nATOM   1379  C5   DG I  68      66.312 129.648   3.036  1.00 48.31           C  \\nATOM   1380  C6   DG I  68      66.350 130.457   4.205  1.00 48.31           C  \\nATOM   1381  O6   DG I  68      66.716 131.640   4.321  1.00 48.31           O  \\nATOM   1382  N1   DG I  68      65.892 129.757   5.321  1.00 48.31           N  \\nATOM   1383  C2   DG I  68      65.443 128.447   5.307  1.00 48.31           C  \\nATOM   1384  N2   DG I  68      65.023 127.959   6.493  1.00 48.31           N  \\nATOM   1385  N3   DG I  68      65.406 127.687   4.221  1.00 48.31           N  \\nATOM   1386  C4   DG I  68      65.848 128.349   3.132  1.00 48.31           C  \\nATOM   1387  P    DC I  69      63.763 124.009  -1.190  1.00 57.62           P  \\nATOM   1388  OP1  DC I  69      63.676 122.848  -2.106  1.00 57.62           O  \\nATOM   1389  OP2  DC I  69      63.378 125.361  -1.672  1.00 57.62           O  \\nATOM   1390  O5'  DC I  69      62.945 123.709   0.142  1.00 29.96           O  \\nATOM   1391  C5'  DC I  69      63.435 122.799   1.114  1.00 29.96           C  \\nATOM   1392  C4'  DC I  69      62.610 122.931   2.364  1.00 29.96           C  \\nATOM   1393  O4'  DC I  69      62.851 124.249   2.909  1.00 29.96           O  \\nATOM   1394  C3'  DC I  69      61.112 122.865   2.068  1.00 29.96           C  \\nATOM   1395  O3'  DC I  69      60.407 122.269   3.159  1.00 29.96           O  \\nATOM   1396  C2'  DC I  69      60.722 124.318   1.940  1.00 29.96           C  \\nATOM   1397  C1'  DC I  69      61.632 124.977   2.961  1.00 29.96           C  \\nATOM   1398  N1   DC I  69      61.917 126.389   2.638  1.00 24.77           N  \\nATOM   1399  C2   DC I  69      62.025 127.330   3.686  1.00 24.77           C  \\nATOM   1400  O2   DC I  69      61.911 126.946   4.856  1.00 24.77           O  \\nATOM   1401  N3   DC I  69      62.248 128.627   3.389  1.00 24.77           N  \\nATOM   1402  C4   DC I  69      62.378 129.006   2.110  1.00 24.77           C  \\nATOM   1403  N4   DC I  69      62.622 130.312   1.858  1.00 24.77           N  \\nATOM   1404  C5   DC I  69      62.276 128.069   1.028  1.00 24.77           C  \\nATOM   1405  C6   DC I  69      62.052 126.787   1.335  1.00 24.77           C  \\nATOM   1406  P    DT I  70      58.951 121.617   2.918  1.00 35.51           P  \\nATOM   1407  OP1  DT I  70      59.046 120.147   3.065  1.00 35.51           O  \\nATOM   1408  OP2  DT I  70      58.323 122.190   1.692  1.00 35.51           O  \\nATOM   1409  O5'  DT I  70      58.168 122.146   4.180  1.00 30.72           O  \\nATOM   1410  C5'  DT I  70      58.764 122.025   5.445  1.00 30.72           C  \\nATOM   1411  C4'  DT I  70      58.258 123.111   6.354  1.00 30.72           C  \\nATOM   1412  O4'  DT I  70      58.655 124.416   5.864  1.00 30.72           O  \\nATOM   1413  C3'  DT I  70      56.743 123.160   6.504  1.00 30.72           C  \\nATOM   1414  O3'  DT I  70      56.498 123.354   7.887  1.00 30.72           O  \\nATOM   1415  C2'  DT I  70      56.331 124.378   5.677  1.00 30.72           C  \\nATOM   1416  C1'  DT I  70      57.537 125.289   5.823  1.00 30.72           C  \\nATOM   1417  N1   DT I  70      57.780 126.264   4.741  1.00 23.69           N  \\nATOM   1418  C2   DT I  70      58.174 127.531   5.112  1.00 23.69           C  \\nATOM   1419  O2   DT I  70      58.259 127.886   6.276  1.00 23.69           O  \\nATOM   1420  N3   DT I  70      58.454 128.375   4.075  1.00 23.69           N  \\nATOM   1421  C4   DT I  70      58.362 128.101   2.730  1.00 23.69           C  \\nATOM   1422  O4   DT I  70      58.649 128.981   1.915  1.00 23.69           O  \\nATOM   1423  C5   DT I  70      57.914 126.750   2.400  1.00 23.69           C  \\nATOM   1424  C7   DT I  70      57.775 126.349   0.964  1.00 23.69           C  \\nATOM   1425  C6   DT I  70      57.647 125.916   3.414  1.00 23.69           C  \\nATOM   1426  P    DG I  71      55.098 122.939   8.518  1.00 34.42           P  \\nATOM   1427  OP1  DG I  71      55.286 121.749   9.384  1.00 34.42           O  \\nATOM   1428  OP2  DG I  71      54.055 122.937   7.435  1.00 34.42           O  \\nATOM   1429  O5'  DG I  71      54.855 124.114   9.542  1.00 46.23           O  \\nATOM   1430  C5'  DG I  71      53.679 124.851   9.472  1.00 46.23           C  \\nATOM   1431  C4'  DG I  71      53.985 126.323   9.418  1.00 46.23           C  \\nATOM   1432  O4'  DG I  71      54.709 126.695   8.218  1.00 46.23           O  \\nATOM   1433  C3'  DG I  71      52.660 127.061   9.352  1.00 46.23           C  \\nATOM   1434  O3'  DG I  71      52.666 128.103  10.286  1.00 46.23           O  \\nATOM   1435  C2'  DG I  71      52.557 127.551   7.925  1.00 46.23           C  \\nATOM   1436  C1'  DG I  71      54.003 127.732   7.568  1.00 46.23           C  \\nATOM   1437  N9   DG I  71      54.219 127.620   6.141  1.00 34.75           N  \\nATOM   1438  C8   DG I  71      54.009 126.542   5.321  1.00 34.75           C  \\nATOM   1439  N7   DG I  71      54.258 126.799   4.065  1.00 34.75           N  \\nATOM   1440  C5   DG I  71      54.663 128.119   4.075  1.00 34.75           C  \\nATOM   1441  C6   DG I  71      55.065 128.946   3.028  1.00 34.75           C  \\nATOM   1442  O6   DG I  71      55.145 128.668   1.830  1.00 34.75           O  \\nATOM   1443  N1   DG I  71      55.404 130.221   3.482  1.00 34.75           N  \\nATOM   1444  C2   DG I  71      55.357 130.622   4.793  1.00 34.75           C  \\nATOM   1445  N2   DG I  71      55.736 131.863   5.048  1.00 34.75           N  \\nATOM   1446  N3   DG I  71      54.975 129.856   5.779  1.00 34.75           N  \\nATOM   1447  C4   DG I  71      54.649 128.625   5.352  1.00 34.75           C  \\nATOM   1448  P    DA I  72      51.443 128.230  11.287  1.00 45.92           P  \\nATOM   1449  OP1  DA I  72      51.797 127.623  12.601  1.00 45.92           O  \\nATOM   1450  OP2  DA I  72      50.283 127.700  10.508  1.00 45.92           O  \\nATOM   1451  O5'  DA I  72      51.332 129.810  11.438  1.00 65.02           O  \\nATOM   1452  C5'  DA I  72      52.499 130.631  11.416  1.00 65.02           C  \\nATOM   1453  C4'  DA I  72      52.267 131.836  10.537  1.00 65.02           C  \\nATOM   1454  O4'  DA I  72      52.634 131.568   9.166  1.00 65.02           O  \\nATOM   1455  C3'  DA I  72      50.809 132.297  10.499  1.00 65.02           C  \\nATOM   1456  O3'  DA I  72      50.714 133.710  10.589  1.00 65.02           O  \\nATOM   1457  C2'  DA I  72      50.337 131.877   9.125  1.00 65.02           C  \\nATOM   1458  C1'  DA I  72      51.601 132.059   8.333  1.00 65.02           C  \\nATOM   1459  N9   DA I  72      51.611 131.290   7.102  1.00 51.41           N  \\nATOM   1460  C8   DA I  72      51.229 129.992   6.925  1.00 51.41           C  \\nATOM   1461  N7   DA I  72      51.332 129.577   5.687  1.00 51.41           N  \\nATOM   1462  C5   DA I  72      51.822 130.681   5.004  1.00 51.41           C  \\nATOM   1463  C6   DA I  72      52.152 130.894   3.645  1.00 51.41           C  \\nATOM   1464  N6   DA I  72      52.028 129.963   2.687  1.00 51.41           N  \\nATOM   1465  N1   DA I  72      52.613 132.115   3.301  1.00 51.41           N  \\nATOM   1466  C2   DA I  72      52.728 133.052   4.256  1.00 51.41           C  \\nATOM   1467  N3   DA I  72      52.449 132.971   5.559  1.00 51.41           N  \\nATOM   1468  C4   DA I  72      51.998 131.744   5.868  1.00 51.41           C  \\nATOM   1469  P    DA I  73      49.376 134.366  11.183  1.00 53.82           P  \\nATOM   1470  OP1  DA I  73      49.604 134.676  12.619  1.00 53.82           O  \\nATOM   1471  OP2  DA I  73      48.209 133.515  10.779  1.00 53.82           O  \\nATOM   1472  O5'  DA I  73      49.297 135.722  10.380  1.00 57.54           O  \\nATOM   1473  C5'  DA I  73      50.379 136.129   9.571  1.00 57.54           C  \\nATOM   1474  C4'  DA I  73      49.847 136.786   8.326  1.00 57.54           C  \\nATOM   1475  O4'  DA I  73      49.986 135.907   7.186  1.00 57.54           O  \\nATOM   1476  C3'  DA I  73      48.367 137.155   8.415  1.00 57.54           C  \\nATOM   1477  O3'  DA I  73      48.191 138.509   7.975  1.00 57.54           O  \\nATOM   1478  C2'  DA I  73      47.692 136.133   7.511  1.00 57.54           C  \\nATOM   1479  C1'  DA I  73      48.767 135.839   6.483  1.00 57.54           C  \\nATOM   1480  N9   DA I  73      48.693 134.516   5.881  1.00 53.60           N  \\nATOM   1481  C8   DA I  73      48.271 133.341   6.453  1.00 53.60           C  \\nATOM   1482  N7   DA I  73      48.312 132.309   5.639  1.00 53.60           N  \\nATOM   1483  C5   DA I  73      48.796 132.844   4.454  1.00 53.60           C  \\nATOM   1484  C6   DA I  73      49.063 132.272   3.195  1.00 53.60           C  \\nATOM   1485  N6   DA I  73      48.875 130.981   2.912  1.00 53.60           N  \\nATOM   1486  N1   DA I  73      49.538 133.087   2.222  1.00 53.60           N  \\nATOM   1487  C2   DA I  73      49.734 134.382   2.510  1.00 53.60           C  \\nATOM   1488  N3   DA I  73      49.523 135.034   3.656  1.00 53.60           N  \\nATOM   1489  C4   DA I  73      49.044 134.201   4.593  1.00 53.60           C  \\nATOM   1490  P    DT I  74      46.727 139.050   7.601  1.00 68.60           P  \\nATOM   1491  OP1  DT I  74      46.730 140.523   7.800  1.00 68.60           O  \\nATOM   1492  OP2  DT I  74      45.726 138.208   8.317  1.00 68.60           O  \\nATOM   1493  O5'  DT I  74      46.638 138.759   6.039  1.00 51.36           O  \\nATOM   1494  C5'  DT I  74      47.576 139.343   5.145  1.00 51.36           C  \\nATOM   1495  C4'  DT I  74      46.987 139.403   3.759  1.00 51.36           C  \\nATOM   1496  O4'  DT I  74      47.128 138.122   3.103  1.00 51.36           O  \\nATOM   1497  C3'  DT I  74      45.493 139.731   3.745  1.00 51.36           C  \\nATOM   1498  O3'  DT I  74      45.197 140.685   2.713  1.00 51.36           O  \\nATOM   1499  C2'  DT I  74      44.836 138.383   3.482  1.00 51.36           C  \\nATOM   1500  C1'  DT I  74      45.868 137.689   2.611  1.00 51.36           C  \\nATOM   1501  N1   DT I  74      45.844 136.222   2.691  1.00 29.80           N  \\nATOM   1502  C2   DT I  74      46.151 135.496   1.564  1.00 29.80           C  \\nATOM   1503  O2   DT I  74      46.377 136.004   0.471  1.00 29.80           O  \\nATOM   1504  N3   DT I  74      46.163 134.138   1.756  1.00 29.80           N  \\nATOM   1505  C4   DT I  74      45.880 133.452   2.922  1.00 29.80           C  \\nATOM   1506  O4   DT I  74      45.926 132.210   2.937  1.00 29.80           O  \\nATOM   1507  C5   DT I  74      45.537 134.277   4.048  1.00 29.80           C  \\nATOM   1508  C7   DT I  74      45.197 133.621   5.345  1.00 29.80           C  \\nATOM   1509  C6   DT I  74      45.538 135.602   3.881  1.00 29.80           C  \\nATOM   1510  P    DT I  75      43.668 141.066   2.388  1.00 76.25           P  \\nATOM   1511  OP1  DT I  75      43.641 142.499   1.985  1.00 76.25           O  \\nATOM   1512  OP2  DT I  75      42.805 140.590   3.509  1.00 76.25           O  \\nATOM   1513  O5'  DT I  75      43.370 140.182   1.104  1.00 63.46           O  \\nATOM   1514  C5'  DT I  75      44.292 140.199   0.030  1.00 63.46           C  \\nATOM   1515  C4'  DT I  75      43.765 139.398  -1.131  1.00 63.46           C  \\nATOM   1516  O4'  DT I  75      43.957 137.986  -0.907  1.00 63.46           O  \\nATOM   1517  C3'  DT I  75      42.282 139.591  -1.414  1.00 63.46           C  \\nATOM   1518  O3'  DT I  75      42.110 139.601  -2.817  1.00 63.46           O  \\nATOM   1519  C2'  DT I  75      41.652 138.333  -0.848  1.00 63.46           C  \\nATOM   1520  C1'  DT I  75      42.735 137.311  -1.132  1.00 63.46           C  \\nATOM   1521  N1   DT I  75      42.717 136.128  -0.262  1.00 40.15           N  \\nATOM   1522  C2   DT I  75      43.032 134.906  -0.823  1.00 40.15           C  \\nATOM   1523  O2   DT I  75      43.362 134.762  -2.002  1.00 40.15           O  \\nATOM   1524  N3   DT I  75      42.954 133.849   0.057  1.00 40.15           N  \\nATOM   1525  C4   DT I  75      42.620 133.897   1.399  1.00 40.15           C  \\nATOM   1526  O4   DT I  75      42.579 132.865   2.054  1.00 40.15           O  \\nATOM   1527  C5   DT I  75      42.337 135.205   1.917  1.00 40.15           C  \\nATOM   1528  C7   DT I  75      42.003 135.347   3.367  1.00 40.15           C  \\nATOM   1529  C6   DT I  75      42.390 136.243   1.074  1.00 40.15           C  \\nATOM   1530  P    DC I  76      40.900 140.419  -3.458  1.00 62.68           P  \\nATOM   1531  OP1  DC I  76      41.492 141.539  -4.231  1.00 62.68           O  \\nATOM   1532  OP2  DC I  76      39.921 140.704  -2.376  1.00 62.68           O  \\nATOM   1533  O5'  DC I  76      40.279 139.359  -4.471  1.00 64.72           O  \\nATOM   1534  C5'  DC I  76      41.083 138.290  -4.985  1.00 64.72           C  \\nATOM   1535  C4'  DC I  76      40.215 137.126  -5.404  1.00 64.72           C  \\nATOM   1536  O4'  DC I  76      40.309 136.057  -4.432  1.00 64.72           O  \\nATOM   1537  C3'  DC I  76      38.722 137.429  -5.540  1.00 64.72           C  \\nATOM   1538  O3'  DC I  76      38.201 136.628  -6.594  1.00 64.72           O  \\nATOM   1539  C2'  DC I  76      38.153 136.919  -4.229  1.00 64.72           C  \\nATOM   1540  C1'  DC I  76      39.001 135.685  -4.026  1.00 64.72           C  \\nATOM   1541  N1   DC I  76      39.074 135.183  -2.650  1.00 33.62           N  \\nATOM   1542  C2   DC I  76      39.438 133.834  -2.444  1.00 33.62           C  \\nATOM   1543  O2   DC I  76      39.686 133.125  -3.433  1.00 33.62           O  \\nATOM   1544  N3   DC I  76      39.506 133.345  -1.176  1.00 33.62           N  \\nATOM   1545  C4   DC I  76      39.224 134.147  -0.140  1.00 33.62           C  \\nATOM   1546  N4   DC I  76      39.286 133.627   1.098  1.00 33.62           N  \\nATOM   1547  C5   DC I  76      38.858 135.525  -0.325  1.00 33.62           C  \\nATOM   1548  C6   DC I  76      38.796 135.994  -1.584  1.00 33.62           C  \\nATOM   1549  P    DA I  77      37.324 137.297  -7.755  1.00 70.45           P  \\nATOM   1550  OP1  DA I  77      38.146 138.342  -8.418  1.00 70.45           O  \\nATOM   1551  OP2  DA I  77      35.997 137.652  -7.171  1.00 70.45           O  \\nATOM   1552  O5'  DA I  77      37.140 136.104  -8.796  1.00 46.80           O  \\nATOM   1553  C5'  DA I  77      38.281 135.437  -9.348  1.00 46.80           C  \\nATOM   1554  C4'  DA I  77      38.112 133.933  -9.283  1.00 46.80           C  \\nATOM   1555  O4'  DA I  77      38.084 133.471  -7.906  1.00 46.80           O  \\nATOM   1556  C3'  DA I  77      36.848 133.383  -9.939  1.00 46.80           C  \\nATOM   1557  O3'  DA I  77      37.170 132.193 -10.664  1.00 46.80           O  \\nATOM   1558  C2'  DA I  77      35.916 133.119  -8.764  1.00 46.80           C  \\nATOM   1559  C1'  DA I  77      36.870 132.776  -7.626  1.00 46.80           C  \\nATOM   1560  N9   DA I  77      36.417 133.208  -6.300  1.00 35.03           N  \\nATOM   1561  C8   DA I  77      35.781 134.383  -5.980  1.00 35.03           C  \\nATOM   1562  N7   DA I  77      35.533 134.524  -4.697  1.00 35.03           N  \\nATOM   1563  C5   DA I  77      36.033 133.359  -4.131  1.00 35.03           C  \\nATOM   1564  C6   DA I  77      36.086 132.900  -2.791  1.00 35.03           C  \\nATOM   1565  N6   DA I  77      35.641 133.599  -1.739  1.00 35.03           N  \\nATOM   1566  N1   DA I  77      36.629 131.684  -2.573  1.00 35.03           N  \\nATOM   1567  C2   DA I  77      37.099 130.990  -3.630  1.00 35.03           C  \\nATOM   1568  N3   DA I  77      37.121 131.319  -4.924  1.00 35.03           N  \\nATOM   1569  C4   DA I  77      36.567 132.529  -5.111  1.00 35.03           C  \\nATOM   1570  P    DG I  78      36.138 131.617 -11.755  1.00 59.13           P  \\nATOM   1571  OP1  DG I  78      36.912 130.980 -12.852  1.00 59.13           O  \\nATOM   1572  OP2  DG I  78      35.087 132.628 -12.067  1.00 59.13           O  \\nATOM   1573  O5'  DG I  78      35.406 130.459 -10.972  1.00 70.76           O  \\nATOM   1574  C5'  DG I  78      35.253 130.546  -9.572  1.00 70.76           C  \\nATOM   1575  C4'  DG I  78      35.096 129.166  -8.996  1.00 70.76           C  \\nATOM   1576  O4'  DG I  78      34.837 129.289  -7.593  1.00 70.76           O  \\nATOM   1577  C3'  DG I  78      33.887 128.440  -9.549  1.00 70.76           C  \\nATOM   1578  O3'  DG I  78      34.135 127.069  -9.306  1.00 70.76           O  \\nATOM   1579  C2'  DG I  78      32.760 128.998  -8.703  1.00 70.76           C  \\nATOM   1580  C1'  DG I  78      33.442 129.262  -7.366  1.00 70.76           C  \\nATOM   1581  N9   DG I  78      33.116 130.532  -6.739  1.00 48.59           N  \\nATOM   1582  C8   DG I  78      32.826 131.728  -7.346  1.00 48.59           C  \\nATOM   1583  N7   DG I  78      32.616 132.692  -6.491  1.00 48.59           N  \\nATOM   1584  C5   DG I  78      32.767 132.088  -5.252  1.00 48.59           C  \\nATOM   1585  C6   DG I  78      32.642 132.624  -3.950  1.00 48.59           C  \\nATOM   1586  O6   DG I  78      32.346 133.791  -3.616  1.00 48.59           O  \\nATOM   1587  N1   DG I  78      32.879 131.651  -2.976  1.00 48.59           N  \\nATOM   1588  C2   DG I  78      33.175 130.329  -3.234  1.00 48.59           C  \\nATOM   1589  N2   DG I  78      33.340 129.535  -2.168  1.00 48.59           N  \\nATOM   1590  N3   DG I  78      33.291 129.826  -4.441  1.00 48.59           N  \\nATOM   1591  C4   DG I  78      33.073 130.755  -5.394  1.00 48.59           C  \\nATOM   1592  P    DC I  79      33.379 125.945 -10.153  1.00 56.07           P  \\nATOM   1593  OP1  DC I  79      34.184 125.565 -11.344  1.00 56.07           O  \\nATOM   1594  OP2  DC I  79      31.978 126.382 -10.331  1.00 56.07           O  \\nATOM   1595  O5'  DC I  79      33.440 124.732  -9.127  1.00 36.59           O  \\nATOM   1596  C5'  DC I  79      34.666 124.429  -8.462  1.00 36.59           C  \\nATOM   1597  C4'  DC I  79      34.412 124.076  -7.018  1.00 36.59           C  \\nATOM   1598  O4'  DC I  79      33.836 125.183  -6.290  1.00 36.59           O  \\nATOM   1599  C3'  DC I  79      33.469 122.907  -6.793  1.00 36.59           C  \\nATOM   1600  O3'  DC I  79      33.963 122.232  -5.652  1.00 36.59           O  \\nATOM   1601  C2'  DC I  79      32.146 123.582  -6.480  1.00 36.59           C  \\nATOM   1602  C1'  DC I  79      32.610 124.789  -5.692  1.00 36.59           C  \\nATOM   1603  N1   DC I  79      31.725 125.957  -5.722  1.00 35.92           N  \\nATOM   1604  C2   DC I  79      31.571 126.710  -4.559  1.00 35.92           C  \\nATOM   1605  O2   DC I  79      32.127 126.321  -3.508  1.00 35.92           O  \\nATOM   1606  N3   DC I  79      30.824 127.840  -4.603  1.00 35.92           N  \\nATOM   1607  C4   DC I  79      30.241 128.213  -5.747  1.00 35.92           C  \\nATOM   1608  N4   DC I  79      29.546 129.350  -5.757  1.00 35.92           N  \\nATOM   1609  C5   DC I  79      30.352 127.442  -6.933  1.00 35.92           C  \\nATOM   1610  C6   DC I  79      31.092 126.329  -6.875  1.00 35.92           C  \\nATOM   1611  P    DT I  80      33.566 120.718  -5.404  1.00 33.22           P  \\nATOM   1612  OP1  DT I  80      34.800 120.115  -4.851  1.00 33.22           O  \\nATOM   1613  OP2  DT I  80      32.923 120.140  -6.627  1.00 33.22           O  \\nATOM   1614  O5'  DT I  80      32.502 120.835  -4.240  1.00 24.73           O  \\nATOM   1615  C5'  DT I  80      32.924 121.286  -2.976  1.00 24.73           C  \\nATOM   1616  C4'  DT I  80      31.735 121.661  -2.132  1.00 24.73           C  \\nATOM   1617  O4'  DT I  80      31.118 122.843  -2.699  1.00 24.73           O  \\nATOM   1618  C3'  DT I  80      30.635 120.598  -2.019  1.00 24.73           C  \\nATOM   1619  O3'  DT I  80      30.244 120.482  -0.638  1.00 24.73           O  \\nATOM   1620  C2'  DT I  80      29.520 121.156  -2.891  1.00 24.73           C  \\nATOM   1621  C1'  DT I  80      29.721 122.659  -2.753  1.00 24.73           C  \\nATOM   1622  N1   DT I  80      29.184 123.487  -3.862  1.00 35.42           N  \\nATOM   1623  C2   DT I  80      28.673 124.749  -3.582  1.00 35.42           C  \\nATOM   1624  O2   DT I  80      28.667 125.261  -2.466  1.00 35.42           O  \\nATOM   1625  N3   DT I  80      28.168 125.398  -4.672  1.00 35.42           N  \\nATOM   1626  C4   DT I  80      28.134 124.947  -5.980  1.00 35.42           C  \\nATOM   1627  O4   DT I  80      27.662 125.659  -6.863  1.00 35.42           O  \\nATOM   1628  C5   DT I  80      28.688 123.643  -6.195  1.00 35.42           C  \\nATOM   1629  C7   DT I  80      28.692 123.083  -7.579  1.00 35.42           C  \\nATOM   1630  C6   DT I  80      29.180 122.987  -5.143  1.00 35.42           C  \\nATOM   1631  P    DG I  81      29.165 119.385  -0.178  1.00 22.94           P  \\nATOM   1632  OP1  DG I  81      29.806 118.352   0.670  1.00 22.94           O  \\nATOM   1633  OP2  DG I  81      28.358 118.951  -1.338  1.00 22.94           O  \\nATOM   1634  O5'  DG I  81      28.253 120.254   0.780  1.00 25.83           O  \\nATOM   1635  C5'  DG I  81      28.852 121.127   1.739  1.00 25.83           C  \\nATOM   1636  C4'  DG I  81      27.818 122.081   2.285  1.00 25.83           C  \\nATOM   1637  O4'  DG I  81      27.408 123.006   1.255  1.00 25.83           O  \\nATOM   1638  C3'  DG I  81      26.543 121.381   2.742  1.00 25.83           C  \\nATOM   1639  O3'  DG I  81      25.987 122.115   3.810  1.00 25.83           O  \\nATOM   1640  C2'  DG I  81      25.630 121.471   1.538  1.00 25.83           C  \\nATOM   1641  C1'  DG I  81      26.035 122.800   0.924  1.00 25.83           C  \\nATOM   1642  N9   DG I  81      25.920 122.826  -0.529  1.00 33.91           N  \\nATOM   1643  C8   DG I  81      26.342 121.872  -1.421  1.00 33.91           C  \\nATOM   1644  N7   DG I  81      26.080 122.176  -2.661  1.00 33.91           N  \\nATOM   1645  C5   DG I  81      25.449 123.406  -2.580  1.00 33.91           C  \\nATOM   1646  C6   DG I  81      24.920 124.234  -3.600  1.00 33.91           C  \\nATOM   1647  O6   DG I  81      24.883 124.022  -4.820  1.00 33.91           O  \\nATOM   1648  N1   DG I  81      24.379 125.410  -3.080  1.00 33.91           N  \\nATOM   1649  C2   DG I  81      24.336 125.734  -1.740  1.00 33.91           C  \\nATOM   1650  N2   DG I  81      23.766 126.903  -1.429  1.00 33.91           N  \\nATOM   1651  N3   DG I  81      24.814 124.963  -0.779  1.00 33.91           N  \\nATOM   1652  C4   DG I  81      25.353 123.823  -1.269  1.00 33.91           C  \\nATOM   1653  P    DA I  82      24.787 121.496   4.638  1.00 20.26           P  \\nATOM   1654  OP1  DA I  82      25.090 121.643   6.089  1.00 20.26           O  \\nATOM   1655  OP2  DA I  82      24.505 120.157   4.058  1.00 20.26           O  \\nATOM   1656  O5'  DA I  82      23.586 122.450   4.257  1.00 24.82           O  \\nATOM   1657  C5'  DA I  82      23.628 123.827   4.594  1.00 24.82           C  \\nATOM   1658  C4'  DA I  82      22.362 124.504   4.132  1.00 24.82           C  \\nATOM   1659  O4'  DA I  82      22.374 124.607   2.691  1.00 24.82           O  \\nATOM   1660  C3'  DA I  82      21.071 123.768   4.497  1.00 24.82           C  \\nATOM   1661  O3'  DA I  82      20.104 124.750   4.866  1.00 24.82           O  \\nATOM   1662  C2'  DA I  82      20.692 123.082   3.198  1.00 24.82           C  \\nATOM   1663  C1'  DA I  82      21.181 124.073   2.166  1.00 24.82           C  \\nATOM   1664  N9   DA I  82      21.488 123.504   0.857  1.00 28.26           N  \\nATOM   1665  C8   DA I  82      21.929 122.241   0.568  1.00 28.26           C  \\nATOM   1666  N7   DA I  82      22.069 122.011  -0.718  1.00 28.26           N  \\nATOM   1667  C5   DA I  82      21.701 123.211  -1.314  1.00 28.26           C  \\nATOM   1668  C6   DA I  82      21.609 123.613  -2.663  1.00 28.26           C  \\nATOM   1669  N6   DA I  82      21.858 122.803  -3.697  1.00 28.26           N  \\nATOM   1670  N1   DA I  82      21.230 124.884  -2.916  1.00 28.26           N  \\nATOM   1671  C2   DA I  82      20.943 125.681  -1.886  1.00 28.26           C  \\nATOM   1672  N3   DA I  82      20.970 125.416  -0.575  1.00 28.26           N  \\nATOM   1673  C4   DA I  82      21.362 124.146  -0.355  1.00 28.26           C  \\nATOM   1674  P    DA I  83      18.702 124.312   5.518  1.00 28.62           P  \\nATOM   1675  OP1  DA I  83      18.459 125.303   6.622  1.00 28.62           O  \\nATOM   1676  OP2  DA I  83      18.706 122.836   5.808  1.00 28.62           O  \\nATOM   1677  O5'  DA I  83      17.676 124.593   4.333  1.00 31.28           O  \\nATOM   1678  C5'  DA I  83      17.777 125.795   3.576  1.00 31.28           C  \\nATOM   1679  C4'  DA I  83      16.861 125.745   2.377  1.00 31.28           C  \\nATOM   1680  O4'  DA I  83      17.498 125.148   1.220  1.00 31.28           O  \\nATOM   1681  C3'  DA I  83      15.550 124.989   2.593  1.00 31.28           C  \\nATOM   1682  O3'  DA I  83      14.465 125.769   2.077  1.00 31.28           O  \\nATOM   1683  C2'  DA I  83      15.747 123.725   1.773  1.00 31.28           C  \\nATOM   1684  C1'  DA I  83      16.602 124.230   0.632  1.00 31.28           C  \\nATOM   1685  N9   DA I  83      17.379 123.204  -0.063  1.00 38.29           N  \\nATOM   1686  C8   DA I  83      17.968 122.079   0.456  1.00 38.29           C  \\nATOM   1687  N7   DA I  83      18.593 121.349  -0.441  1.00 38.29           N  \\nATOM   1688  C5   DA I  83      18.405 122.045  -1.631  1.00 38.29           C  \\nATOM   1689  C6   DA I  83      18.823 121.799  -2.964  1.00 38.29           C  \\nATOM   1690  N6   DA I  83      19.591 120.777  -3.335  1.00 38.29           N  \\nATOM   1691  N1   DA I  83      18.429 122.666  -3.910  1.00 38.29           N  \\nATOM   1692  C2   DA I  83      17.701 123.721  -3.545  1.00 38.29           C  \\nATOM   1693  N3   DA I  83      17.269 124.079  -2.330  1.00 38.29           N  \\nATOM   1694  C4   DA I  83      17.654 123.184  -1.410  1.00 38.29           C  \\nATOM   1695  P    DC I  84      12.947 125.369   2.412  1.00 53.71           P  \\nATOM   1696  OP1  DC I  84      12.386 126.501   3.185  1.00 53.71           O  \\nATOM   1697  OP2  DC I  84      12.877 123.991   2.981  1.00 53.71           O  \\nATOM   1698  O5'  DC I  84      12.326 125.401   0.952  1.00 50.38           O  \\nATOM   1699  C5'  DC I  84      13.095 125.949  -0.125  1.00 50.38           C  \\nATOM   1700  C4'  DC I  84      12.440 125.628  -1.444  1.00 50.38           C  \\nATOM   1701  O4'  DC I  84      13.277 124.735  -2.222  1.00 50.38           O  \\nATOM   1702  C3'  DC I  84      11.121 124.900  -1.237  1.00 50.38           C  \\nATOM   1703  O3'  DC I  84      10.201 125.305  -2.248  1.00 50.38           O  \\nATOM   1704  C2'  DC I  84      11.512 123.442  -1.368  1.00 50.38           C  \\nATOM   1705  C1'  DC I  84      12.612 123.493  -2.414  1.00 50.38           C  \\nATOM   1706  N1   DC I  84      13.592 122.397  -2.271  1.00 33.88           N  \\nATOM   1707  C2   DC I  84      14.262 121.905  -3.424  1.00 33.88           C  \\nATOM   1708  O2   DC I  84      14.055 122.446  -4.533  1.00 33.88           O  \\nATOM   1709  N3   DC I  84      15.117 120.851  -3.290  1.00 33.88           N  \\nATOM   1710  C4   DC I  84      15.322 120.299  -2.080  1.00 33.88           C  \\nATOM   1711  N4   DC I  84      16.154 119.251  -1.997  1.00 33.88           N  \\nATOM   1712  C5   DC I  84      14.677 120.796  -0.902  1.00 33.88           C  \\nATOM   1713  C6   DC I  84      13.833 121.836  -1.043  1.00 33.88           C  \\nATOM   1714  P    DA I  85       8.677 124.783  -2.210  1.00 57.81           P  \\nATOM   1715  OP1  DA I  85       7.808 125.989  -2.154  1.00 57.81           O  \\nATOM   1716  OP2  DA I  85       8.533 123.724  -1.169  1.00 57.81           O  \\nATOM   1717  O5'  DA I  85       8.518 124.116  -3.646  1.00 56.09           O  \\nATOM   1718  C5'  DA I  85       8.990 124.788  -4.807  1.00 56.09           C  \\nATOM   1719  C4'  DA I  85       9.030 123.832  -5.971  1.00 56.09           C  \\nATOM   1720  O4'  DA I  85      10.131 122.911  -5.790  1.00 56.09           O  \\nATOM   1721  C3'  DA I  85       7.769 122.971  -6.103  1.00 56.09           C  \\nATOM   1722  O3'  DA I  85       7.423 122.794  -7.493  1.00 56.09           O  \\nATOM   1723  C2'  DA I  85       8.175 121.661  -5.449  1.00 56.09           C  \\nATOM   1724  C1'  DA I  85       9.648 121.578  -5.805  1.00 56.09           C  \\nATOM   1725  N9   DA I  85      10.449 120.782  -4.873  1.00 47.43           N  \\nATOM   1726  C8   DA I  85      10.415 120.766  -3.500  1.00 47.43           C  \\nATOM   1727  N7   DA I  85      11.222 119.885  -2.962  1.00 47.43           N  \\nATOM   1728  C5   DA I  85      11.839 119.286  -4.054  1.00 47.43           C  \\nATOM   1729  C6   DA I  85      12.799 118.251  -4.164  1.00 47.43           C  \\nATOM   1730  N6   DA I  85      13.291 117.577  -3.123  1.00 47.43           N  \\nATOM   1731  N1   DA I  85      13.223 117.917  -5.406  1.00 47.43           N  \\nATOM   1732  C2   DA I  85      12.698 118.559  -6.459  1.00 47.43           C  \\nATOM   1733  N3   DA I  85      11.780 119.525  -6.486  1.00 47.43           N  \\nATOM   1734  C4   DA I  85      11.389 119.847  -5.236  1.00 47.43           C  \\nATOM   1735  P    DT I  86       5.944 122.273  -7.914  1.00 47.26           P  \\nATOM   1736  OP1  DT I  86       5.423 123.201  -8.958  1.00 47.26           O  \\nATOM   1737  OP2  DT I  86       5.116 121.981  -6.698  1.00 47.26           O  \\nATOM   1738  O5'  DT I  86       6.260 120.885  -8.625  1.00 52.82           O  \\nATOM   1739  C5'  DT I  86       7.319 120.786  -9.573  1.00 52.82           C  \\nATOM   1740  C4'  DT I  86       7.716 119.343  -9.771  1.00 52.82           C  \\nATOM   1741  O4'  DT I  86       8.601 118.856  -8.727  1.00 52.82           O  \\nATOM   1742  C3'  DT I  86       6.558 118.346  -9.857  1.00 52.82           C  \\nATOM   1743  O3'  DT I  86       6.804 117.512 -10.989  1.00 52.82           O  \\nATOM   1744  C2'  DT I  86       6.694 117.538  -8.569  1.00 52.82           C  \\nATOM   1745  C1'  DT I  86       8.199 117.539  -8.377  1.00 52.82           C  \\nATOM   1746  N1   DT I  86       8.735 117.217  -7.025  1.00 36.85           N  \\nATOM   1747  C2   DT I  86       9.848 116.394  -6.942  1.00 36.85           C  \\nATOM   1748  O2   DT I  86      10.412 115.910  -7.909  1.00 36.85           O  \\nATOM   1749  N3   DT I  86      10.283 116.158  -5.673  1.00 36.85           N  \\nATOM   1750  C4   DT I  86       9.757 116.639  -4.500  1.00 36.85           C  \\nATOM   1751  O4   DT I  86      10.279 116.344  -3.432  1.00 36.85           O  \\nATOM   1752  C5   DT I  86       8.600 117.477  -4.641  1.00 36.85           C  \\nATOM   1753  C7   DT I  86       7.954 118.020  -3.405  1.00 36.85           C  \\nATOM   1754  C6   DT I  86       8.149 117.727  -5.884  1.00 36.85           C  \\nATOM   1755  P    DG I  87       5.600 117.055 -11.951  1.00 25.47           P  \\nATOM   1756  OP1  DG I  87       5.516 117.916 -13.158  1.00 25.47           O  \\nATOM   1757  OP2  DG I  87       4.402 116.771 -11.119  1.00 25.47           O  \\nATOM   1758  O5'  DG I  87       6.143 115.689 -12.510  1.00 27.94           O  \\nATOM   1759  C5'  DG I  87       7.537 115.503 -12.625  1.00 27.94           C  \\nATOM   1760  C4'  DG I  87       7.921 114.193 -11.993  1.00 27.94           C  \\nATOM   1761  O4'  DG I  87       8.067 114.303 -10.559  1.00 27.94           O  \\nATOM   1762  C3'  DG I  87       6.908 113.075 -12.239  1.00 27.94           C  \\nATOM   1763  O3'  DG I  87       7.600 112.044 -12.914  1.00 27.94           O  \\nATOM   1764  C2'  DG I  87       6.423 112.684 -10.842  1.00 27.94           C  \\nATOM   1765  C1'  DG I  87       7.589 113.107  -9.973  1.00 27.94           C  \\nATOM   1766  N9   DG I  87       7.380 113.365  -8.550  1.00 54.83           N  \\nATOM   1767  C8   DG I  87       6.409 114.140  -7.963  1.00 54.83           C  \\nATOM   1768  N7   DG I  87       6.552 114.253  -6.666  1.00 54.83           N  \\nATOM   1769  C5   DG I  87       7.673 113.487  -6.375  1.00 54.83           C  \\nATOM   1770  C6   DG I  87       8.336 113.245  -5.132  1.00 54.83           C  \\nATOM   1771  O6   DG I  87       8.057 113.687  -4.005  1.00 54.83           O  \\nATOM   1772  N1   DG I  87       9.443 112.404  -5.293  1.00 54.83           N  \\nATOM   1773  C2   DG I  87       9.871 111.877  -6.491  1.00 54.83           C  \\nATOM   1774  N2   DG I  87      10.959 111.097  -6.442  1.00 54.83           N  \\nATOM   1775  N3   DG I  87       9.271 112.103  -7.655  1.00 54.83           N  \\nATOM   1776  C4   DG I  87       8.185 112.911  -7.523  1.00 54.83           C  \\nATOM   1777  P    DC I  88       6.862 110.680 -13.240  1.00 36.08           P  \\nATOM   1778  OP1  DC I  88       6.302 110.745 -14.617  1.00 36.08           O  \\nATOM   1779  OP2  DC I  88       5.982 110.400 -12.084  1.00 36.08           O  \\nATOM   1780  O5'  DC I  88       8.065 109.637 -13.195  1.00 50.77           O  \\nATOM   1781  C5'  DC I  88       9.417 110.094 -13.260  1.00 50.77           C  \\nATOM   1782  C4'  DC I  88      10.287 109.303 -12.315  1.00 50.77           C  \\nATOM   1783  O4'  DC I  88       9.882 109.536 -10.952  1.00 50.77           O  \\nATOM   1784  C3'  DC I  88      10.247 107.787 -12.492  1.00 50.77           C  \\nATOM   1785  O3'  DC I  88      11.541 107.268 -12.190  1.00 50.77           O  \\nATOM   1786  C2'  DC I  88       9.276 107.337 -11.418  1.00 50.77           C  \\nATOM   1787  C1'  DC I  88       9.647 108.292 -10.313  1.00 50.77           C  \\nATOM   1788  N1   DC I  88       8.630 108.518  -9.292  1.00 56.98           N  \\nATOM   1789  C2   DC I  88       9.041 108.625  -7.959  1.00 56.98           C  \\nATOM   1790  O2   DC I  88      10.244 108.434  -7.675  1.00 56.98           O  \\nATOM   1791  N3   DC I  88       8.127 108.937  -7.018  1.00 56.98           N  \\nATOM   1792  C4   DC I  88       6.855 109.146  -7.367  1.00 56.98           C  \\nATOM   1793  N4   DC I  88       6.009 109.542  -6.419  1.00 56.98           N  \\nATOM   1794  C5   DC I  88       6.401 108.981  -8.709  1.00 56.98           C  \\nATOM   1795  C6   DC I  88       7.314 108.666  -9.629  1.00 56.98           C  \\nATOM   1796  P    DC I  89      11.998 105.872 -12.818  1.00 74.09           P  \\nATOM   1797  OP1  DC I  89      12.918 106.182 -13.947  1.00 74.09           O  \\nATOM   1798  OP2  DC I  89      10.778 105.054 -13.050  1.00 74.09           O  \\nATOM   1799  O5'  DC I  89      12.837 105.183 -11.659  1.00 42.03           O  \\nATOM   1800  C5'  DC I  89      13.052 105.844 -10.429  1.00 42.03           C  \\nATOM   1801  C4'  DC I  89      12.900 104.865  -9.296  1.00 42.03           C  \\nATOM   1802  O4'  DC I  89      11.641 105.106  -8.636  1.00 42.03           O  \\nATOM   1803  C3'  DC I  89      12.878 103.390  -9.702  1.00 42.03           C  \\nATOM   1804  O3'  DC I  89      13.338 102.646  -8.574  1.00 42.03           O  \\nATOM   1805  C2'  DC I  89      11.393 103.124  -9.839  1.00 42.03           C  \\nATOM   1806  C1'  DC I  89      10.890 103.908  -8.647  1.00 42.03           C  \\nATOM   1807  N1   DC I  89       9.475 104.274  -8.633  1.00 38.14           N  \\nATOM   1808  C2   DC I  89       8.880 104.493  -7.402  1.00 38.14           C  \\nATOM   1809  O2   DC I  89       9.563 104.354  -6.382  1.00 38.14           O  \\nATOM   1810  N3   DC I  89       7.585 104.852  -7.346  1.00 38.14           N  \\nATOM   1811  C4   DC I  89       6.881 104.983  -8.476  1.00 38.14           C  \\nATOM   1812  N4   DC I  89       5.598 105.347  -8.369  1.00 38.14           N  \\nATOM   1813  C5   DC I  89       7.462 104.754  -9.755  1.00 38.14           C  \\nATOM   1814  C6   DC I  89       8.753 104.404  -9.788  1.00 38.14           C  \\nATOM   1815  P    DT I  90      14.474 101.521  -8.731  1.00 25.78           P  \\nATOM   1816  OP1  DT I  90      15.704 102.142  -9.285  1.00 25.78           O  \\nATOM   1817  OP2  DT I  90      13.867 100.331  -9.398  1.00 25.78           O  \\nATOM   1818  O5'  DT I  90      14.738 101.184  -7.205  1.00 20.65           O  \\nATOM   1819  C5'  DT I  90      15.061 102.242  -6.313  1.00 20.65           C  \\nATOM   1820  C4'  DT I  90      14.230 102.176  -5.051  1.00 20.65           C  \\nATOM   1821  O4'  DT I  90      12.838 102.478  -5.326  1.00 20.65           O  \\nATOM   1822  C3'  DT I  90      14.246 100.857  -4.285  1.00 20.65           C  \\nATOM   1823  O3'  DT I  90      14.519 101.095  -2.918  1.00 20.65           O  \\nATOM   1824  C2'  DT I  90      12.832 100.322  -4.431  1.00 20.65           C  \\nATOM   1825  C1'  DT I  90      12.002 101.581  -4.608  1.00 20.65           C  \\nATOM   1826  N1   DT I  90      10.757 101.410  -5.401  1.00 50.17           N  \\nATOM   1827  C2   DT I  90       9.536 101.698  -4.812  1.00 50.17           C  \\nATOM   1828  O2   DT I  90       9.413 102.023  -3.631  1.00 50.17           O  \\nATOM   1829  N3   DT I  90       8.457 101.581  -5.662  1.00 50.17           N  \\nATOM   1830  C4   DT I  90       8.473 101.193  -6.990  1.00 50.17           C  \\nATOM   1831  O4   DT I  90       7.428 101.151  -7.630  1.00 50.17           O  \\nATOM   1832  C5   DT I  90       9.765 100.871  -7.520  1.00 50.17           C  \\nATOM   1833  C7   DT I  90       9.867 100.419  -8.942  1.00 50.17           C  \\nATOM   1834  C6   DT I  90      10.830 100.993  -6.715  1.00 50.17           C  \\nATOM   1835  P    DT I  91      14.640  99.852  -1.927  1.00 26.11           P  \\nATOM   1836  OP1  DT I  91      15.635 100.164  -0.866  1.00 26.11           O  \\nATOM   1837  OP2  DT I  91      14.809  98.647  -2.786  1.00 26.11           O  \\nATOM   1838  O5'  DT I  91      13.203  99.772  -1.264  1.00 34.41           O  \\nATOM   1839  C5'  DT I  91      12.710 100.852  -0.488  1.00 34.41           C  \\nATOM   1840  C4'  DT I  91      11.361 100.501   0.081  1.00 34.41           C  \\nATOM   1841  O4'  DT I  91      10.384 100.481  -0.993  1.00 34.41           O  \\nATOM   1842  C3'  DT I  91      11.323  99.119   0.729  1.00 34.41           C  \\nATOM   1843  O3'  DT I  91      10.624  99.193   1.970  1.00 34.41           O  \\nATOM   1844  C2'  DT I  91      10.590  98.252  -0.287  1.00 34.41           C  \\nATOM   1845  C1'  DT I  91       9.672  99.249  -0.982  1.00 34.41           C  \\nATOM   1846  N1   DT I  91       9.283  98.926  -2.382  1.00 39.57           N  \\nATOM   1847  C2   DT I  91       8.001  99.261  -2.789  1.00 39.57           C  \\nATOM   1848  O2   DT I  91       7.190  99.807  -2.058  1.00 39.57           O  \\nATOM   1849  N3   DT I  91       7.703  98.938  -4.095  1.00 39.57           N  \\nATOM   1850  C4   DT I  91       8.546  98.345  -5.024  1.00 39.57           C  \\nATOM   1851  O4   DT I  91       8.149  98.140  -6.173  1.00 39.57           O  \\nATOM   1852  C5   DT I  91       9.872  98.016  -4.532  1.00 39.57           C  \\nATOM   1853  C7   DT I  91      10.847  97.367  -5.464  1.00 39.57           C  \\nATOM   1854  C6   DT I  91      10.168  98.316  -3.251  1.00 39.57           C  \\nATOM   1855  P    DT I  92      10.435  97.870   2.867  1.00 56.01           P  \\nATOM   1856  OP1  DT I  92      10.436  98.293   4.289  1.00 56.01           O  \\nATOM   1857  OP2  DT I  92      11.402  96.843   2.412  1.00 56.01           O  \\nATOM   1858  O5'  DT I  92       8.969  97.396   2.466  1.00 51.56           O  \\nATOM   1859  C5'  DT I  92       7.902  98.350   2.415  1.00 51.56           C  \\nATOM   1860  C4'  DT I  92       6.579  97.668   2.152  1.00 51.56           C  \\nATOM   1861  O4'  DT I  92       6.307  97.570   0.733  1.00 51.56           O  \\nATOM   1862  C3'  DT I  92       6.437  96.259   2.732  1.00 51.56           C  \\nATOM   1863  O3'  DT I  92       5.198  96.151   3.440  1.00 51.56           O  \\nATOM   1864  C2'  DT I  92       6.474  95.363   1.504  1.00 51.56           C  \\nATOM   1865  C1'  DT I  92       5.896  96.255   0.415  1.00 51.56           C  \\nATOM   1866  N1   DT I  92       6.369  95.956  -0.952  1.00 55.43           N  \\nATOM   1867  C2   DT I  92       5.462  96.063  -1.987  1.00 55.43           C  \\nATOM   1868  O2   DT I  92       4.295  96.367  -1.818  1.00 55.43           O  \\nATOM   1869  N3   DT I  92       5.976  95.798  -3.234  1.00 55.43           N  \\nATOM   1870  C4   DT I  92       7.274  95.443  -3.540  1.00 55.43           C  \\nATOM   1871  O4   DT I  92       7.593  95.262  -4.706  1.00 55.43           O  \\nATOM   1872  C5   DT I  92       8.165  95.325  -2.410  1.00 55.43           C  \\nATOM   1873  C7   DT I  92       9.581  94.919  -2.649  1.00 55.43           C  \\nATOM   1874  C6   DT I  92       7.679  95.587  -1.188  1.00 55.43           C  \\nATOM   1875  P    DT I  93       4.876  94.836   4.313  1.00 75.42           P  \\nATOM   1876  OP1  DT I  93       4.276  95.298   5.592  1.00 75.42           O  \\nATOM   1877  OP2  DT I  93       6.035  93.898   4.338  1.00 75.42           O  \\nATOM   1878  O5'  DT I  93       3.730  94.160   3.453  1.00111.96           O  \\nATOM   1879  C5'  DT I  93       2.538  94.882   3.166  1.00111.96           C  \\nATOM   1880  C4'  DT I  93       1.575  93.998   2.418  1.00111.96           C  \\nATOM   1881  O4'  DT I  93       1.965  93.943   1.029  1.00111.96           O  \\nATOM   1882  C3'  DT I  93       1.587  92.557   2.926  1.00111.96           C  \\nATOM   1883  O3'  DT I  93       0.266  92.013   2.936  1.00111.96           O  \\nATOM   1884  C2'  DT I  93       2.492  91.843   1.939  1.00111.96           C  \\nATOM   1885  C1'  DT I  93       2.222  92.602   0.655  1.00111.96           C  \\nATOM   1886  N1   DT I  93       3.334  92.617  -0.303  1.00 75.69           N  \\nATOM   1887  C2   DT I  93       3.015  92.729  -1.633  1.00 75.69           C  \\nATOM   1888  O2   DT I  93       1.867  92.843  -2.031  1.00 75.69           O  \\nATOM   1889  N3   DT I  93       4.091  92.715  -2.488  1.00 75.69           N  \\nATOM   1890  C4   DT I  93       5.424  92.624  -2.147  1.00 75.69           C  \\nATOM   1891  O4   DT I  93       6.279  92.622  -3.033  1.00 75.69           O  \\nATOM   1892  C5   DT I  93       5.686  92.533  -0.721  1.00 75.69           C  \\nATOM   1893  C7   DT I  93       7.098  92.462  -0.242  1.00 75.69           C  \\nATOM   1894  C6   DT I  93       4.640  92.524   0.116  1.00 75.69           C  \\nATOM   1895  P    DG I  94       0.011  90.558   3.565  1.00120.46           P  \\nATOM   1896  OP1  DG I  94      -1.279  90.595   4.301  1.00120.46           O  \\nATOM   1897  OP2  DG I  94       1.244  90.119   4.267  1.00120.46           O  \\nATOM   1898  O5'  DG I  94      -0.151  89.643   2.276  1.00 81.48           O  \\nATOM   1899  C5'  DG I  94       0.326  90.080   1.008  1.00 81.48           C  \\nATOM   1900  C4'  DG I  94      -0.381  89.325  -0.088  1.00 81.48           C  \\nATOM   1901  O4'  DG I  94       0.259  89.622  -1.354  1.00 81.48           O  \\nATOM   1902  C3'  DG I  94      -0.249  87.818   0.110  1.00 81.48           C  \\nATOM   1903  O3'  DG I  94      -1.427  87.128  -0.310  1.00 81.48           O  \\nATOM   1904  C2'  DG I  94       0.941  87.447  -0.743  1.00 81.48           C  \\nATOM   1905  C1'  DG I  94       0.891  88.459  -1.873  1.00 81.48           C  \\nATOM   1906  N9   DG I  94       2.248  88.811  -2.271  1.00 71.31           N  \\nATOM   1907  C8   DG I  94       3.299  89.068  -1.424  1.00 71.31           C  \\nATOM   1908  N7   DG I  94       4.425  89.260  -2.050  1.00 71.31           N  \\nATOM   1909  C5   DG I  94       4.094  89.149  -3.396  1.00 71.31           C  \\nATOM   1910  C6   DG I  94       4.907  89.253  -4.550  1.00 71.31           C  \\nATOM   1911  O6   DG I  94       6.119  89.486  -4.620  1.00 71.31           O  \\nATOM   1912  N1   DG I  94       4.172  89.057  -5.712  1.00 71.31           N  \\nATOM   1913  C2   DG I  94       2.831  88.807  -5.763  1.00 71.31           C  \\nATOM   1914  N2   DG I  94       2.325  88.656  -6.996  1.00 71.31           N  \\nATOM   1915  N3   DG I  94       2.055  88.713  -4.694  1.00 71.31           N  \\nATOM   1916  C4   DG I  94       2.750  88.890  -3.551  1.00 71.31           C  \\nATOM   1917  P    DA I  95      -1.471  85.520  -0.247  1.00132.32           P  \\nATOM   1918  OP1  DA I  95      -2.854  85.084   0.060  1.00132.32           O  \\nATOM   1919  OP2  DA I  95      -0.345  85.042   0.602  1.00132.32           O  \\nATOM   1920  O5'  DA I  95      -1.162  85.109  -1.747  1.00 84.29           O  \\nATOM   1921  C5'  DA I  95      -1.888  85.688  -2.821  1.00 84.29           C  \\nATOM   1922  C4'  DA I  95      -1.401  85.090  -4.113  1.00 84.29           C  \\nATOM   1923  O4'  DA I  95      -0.123  85.678  -4.475  1.00 84.29           O  \\nATOM   1924  C3'  DA I  95      -1.141  83.595  -3.933  1.00 84.29           C  \\nATOM   1925  O3'  DA I  95      -1.495  82.879  -5.118  1.00 84.29           O  \\nATOM   1926  C2'  DA I  95       0.355  83.535  -3.696  1.00 84.29           C  \\nATOM   1927  C1'  DA I  95       0.828  84.638  -4.619  1.00 84.29           C  \\nATOM   1928  N9   DA I  95       2.172  85.149  -4.326  1.00 77.14           N  \\nATOM   1929  C8   DA I  95       2.740  85.475  -3.111  1.00 77.14           C  \\nATOM   1930  N7   DA I  95       4.011  85.799  -3.191  1.00 77.14           N  \\nATOM   1931  C5   DA I  95       4.294  85.701  -4.551  1.00 77.14           C  \\nATOM   1932  C6   DA I  95       5.476  85.896  -5.290  1.00 77.14           C  \\nATOM   1933  N6   DA I  95       6.644  86.229  -4.736  1.00 77.14           N  \\nATOM   1934  N1   DA I  95       5.414  85.725  -6.633  1.00 77.14           N  \\nATOM   1935  C2   DA I  95       4.243  85.373  -7.184  1.00 77.14           C  \\nATOM   1936  N3   DA I  95       3.071  85.151  -6.597  1.00 77.14           N  \\nATOM   1937  C4   DA I  95       3.164  85.331  -5.264  1.00 77.14           C  \\nATOM   1938  P    DT I  96      -1.428  81.272  -5.135  1.00104.59           P  \\nATOM   1939  OP1  DT I  96      -2.802  80.760  -5.371  1.00104.59           O  \\nATOM   1940  OP2  DT I  96      -0.661  80.788  -3.951  1.00104.59           O  \\nATOM   1941  O5'  DT I  96      -0.562  80.998  -6.438  1.00132.20           O  \\nATOM   1942  C5'  DT I  96      -0.799  81.741  -7.634  1.00132.20           C  \\nATOM   1943  C4'  DT I  96       0.211  81.349  -8.682  1.00132.20           C  \\nATOM   1944  O4'  DT I  96       1.471  82.028  -8.431  1.00132.20           O  \\nATOM   1945  C3'  DT I  96       0.510  79.849  -8.638  1.00132.20           C  \\nATOM   1946  O3'  DT I  96       0.606  79.284  -9.943  1.00132.20           O  \\nATOM   1947  C2'  DT I  96       1.856  79.776  -7.947  1.00132.20           C  \\nATOM   1948  C1'  DT I  96       2.511  81.066  -8.405  1.00132.20           C  \\nATOM   1949  N1   DT I  96       3.579  81.524  -7.495  1.00 58.49           N  \\nATOM   1950  C2   DT I  96       4.736  82.044  -8.049  1.00 58.49           C  \\nATOM   1951  O2   DT I  96       4.869  82.274  -9.243  1.00 58.49           O  \\nATOM   1952  N3   DT I  96       5.734  82.295  -7.141  1.00 58.49           N  \\nATOM   1953  C4   DT I  96       5.684  82.121  -5.766  1.00 58.49           C  \\nATOM   1954  O4   DT I  96       6.680  82.362  -5.088  1.00 58.49           O  \\nATOM   1955  C5   DT I  96       4.415  81.644  -5.245  1.00 58.49           C  \\nATOM   1956  C7   DT I  96       4.250  81.469  -3.765  1.00 58.49           C  \\nATOM   1957  C6   DT I  96       3.440  81.377  -6.126  1.00 58.49           C  \\nATOM   1958  P    DG I  97       0.627  77.685 -10.114  1.00104.02           P  \\nATOM   1959  OP1  DG I  97      -0.664  77.258 -10.708  1.00104.02           O  \\nATOM   1960  OP2  DG I  97       1.076  77.086  -8.827  1.00104.02           O  \\nATOM   1961  O5'  DG I  97       1.763  77.454 -11.202  1.00104.90           O  \\nATOM   1962  C5'  DG I  97       2.036  78.445 -12.192  1.00104.90           C  \\nATOM   1963  C4'  DG I  97       3.504  78.429 -12.544  1.00104.90           C  \\nATOM   1964  O4'  DG I  97       4.300  78.965 -11.458  1.00104.90           O  \\nATOM   1965  C3'  DG I  97       4.045  77.026 -12.807  1.00104.90           C  \\nATOM   1966  O3'  DG I  97       5.007  77.085 -13.857  1.00104.90           O  \\nATOM   1967  C2'  DG I  97       4.716  76.662 -11.497  1.00104.90           C  \\nATOM   1968  C1'  DG I  97       5.267  78.004 -11.057  1.00104.90           C  \\nATOM   1969  N9   DG I  97       5.474  78.137  -9.619  1.00 65.16           N  \\nATOM   1970  C8   DG I  97       4.666  77.661  -8.613  1.00 65.16           C  \\nATOM   1971  N7   DG I  97       5.116  77.940  -7.419  1.00 65.16           N  \\nATOM   1972  C5   DG I  97       6.292  78.643  -7.652  1.00 65.16           C  \\nATOM   1973  C6   DG I  97       7.220  79.211  -6.743  1.00 65.16           C  \\nATOM   1974  O6   DG I  97       7.184  79.222  -5.516  1.00 65.16           O  \\nATOM   1975  N1   DG I  97       8.276  79.818  -7.401  1.00 65.16           N  \\nATOM   1976  C2   DG I  97       8.422  79.884  -8.756  1.00 65.16           C  \\nATOM   1977  N2   DG I  97       9.532  80.505  -9.183  1.00 65.16           N  \\nATOM   1978  N3   DG I  97       7.560  79.378  -9.621  1.00 65.16           N  \\nATOM   1979  C4   DG I  97       6.527  78.770  -9.003  1.00 65.16           C  \\nATOM   1980  P    DG I  98       5.498  75.729 -14.566  1.00 71.67           P  \\nATOM   1981  OP1  DG I  98       5.522  75.981 -16.036  1.00 71.67           O  \\nATOM   1982  OP2  DG I  98       4.702  74.591 -14.008  1.00 71.67           O  \\nATOM   1983  O5'  DG I  98       6.997  75.553 -14.050  1.00 69.98           O  \\nATOM   1984  C5'  DG I  98       7.989  76.567 -14.265  1.00 69.98           C  \\nATOM   1985  C4'  DG I  98       9.208  76.299 -13.410  1.00 69.98           C  \\nATOM   1986  O4'  DG I  98       8.964  76.633 -12.021  1.00 69.98           O  \\nATOM   1987  C3'  DG I  98       9.674  74.845 -13.412  1.00 69.98           C  \\nATOM   1988  O3'  DG I  98      11.090  74.813 -13.412  1.00 69.98           O  \\nATOM   1989  C2'  DG I  98       9.165  74.311 -12.086  1.00 69.98           C  \\nATOM   1990  C1'  DG I  98       9.316  75.529 -11.207  1.00 69.98           C  \\nATOM   1991  N9   DG I  98       8.459  75.544 -10.031  1.00 84.48           N  \\nATOM   1992  C8   DG I  98       7.140  75.169  -9.946  1.00 84.48           C  \\nATOM   1993  N7   DG I  98       6.643  75.310  -8.747  1.00 84.48           N  \\nATOM   1994  C5   DG I  98       7.701  75.805  -7.997  1.00 84.48           C  \\nATOM   1995  C6   DG I  98       7.769  76.163  -6.621  1.00 84.48           C  \\nATOM   1996  O6   DG I  98       6.872  76.110  -5.760  1.00 84.48           O  \\nATOM   1997  N1   DG I  98       9.039  76.625  -6.280  1.00 84.48           N  \\nATOM   1998  C2   DG I  98      10.098  76.727  -7.147  1.00 84.48           C  \\nATOM   1999  N2   DG I  98      11.225  77.183  -6.622  1.00 84.48           N  \\nATOM   2000  N3   DG I  98      10.049  76.400  -8.424  1.00 84.48           N  \\nATOM   2001  C4   DG I  98       8.829  75.951  -8.778  1.00 84.48           C  \\nATOM   2002  P    DA I  99      11.852  73.888 -14.462  1.00 84.90           P  \\nATOM   2003  OP1  DA I  99      11.268  74.125 -15.802  1.00 84.90           O  \\nATOM   2004  OP2  DA I  99      11.886  72.511 -13.896  1.00 84.90           O  \\nATOM   2005  O5'  DA I  99      13.313  74.503 -14.470  1.00108.09           O  \\nATOM   2006  C5'  DA I  99      13.494  75.908 -14.583  1.00108.09           C  \\nATOM   2007  C4'  DA I  99      14.323  76.412 -13.428  1.00108.09           C  \\nATOM   2008  O4'  DA I  99      13.586  76.232 -12.193  1.00108.09           O  \\nATOM   2009  C3'  DA I  99      15.648  75.673 -13.247  1.00108.09           C  \\nATOM   2010  O3'  DA I  99      16.674  76.613 -12.912  1.00108.09           O  \\nATOM   2011  C2'  DA I  99      15.362  74.700 -12.115  1.00108.09           C  \\nATOM   2012  C1'  DA I  99      14.331  75.441 -11.280  1.00108.09           C  \\nATOM   2013  N9   DA I  99      13.389  74.573 -10.573  1.00 48.72           N  \\nATOM   2014  C8   DA I  99      12.630  73.551 -11.096  1.00 48.72           C  \\nATOM   2015  N7   DA I  99      11.866  72.948 -10.210  1.00 48.72           N  \\nATOM   2016  C5   DA I  99      12.142  73.620  -9.022  1.00 48.72           C  \\nATOM   2017  C6   DA I  99      11.662  73.461  -7.703  1.00 48.72           C  \\nATOM   2018  N6   DA I  99      10.750  72.556  -7.347  1.00 48.72           N  \\nATOM   2019  N1   DA I  99      12.160  74.281  -6.750  1.00 48.72           N  \\nATOM   2020  C2   DA I  99      13.057  75.200  -7.104  1.00 48.72           C  \\nATOM   2021  N3   DA I  99      13.576  75.458  -8.302  1.00 48.72           N  \\nATOM   2022  C4   DA I  99      13.078  74.621  -9.231  1.00 48.72           C  \\nATOM   2023  P    DG I 100      18.215  76.157 -12.906  1.00100.05           P  \\nATOM   2024  OP1  DG I 100      19.036  77.313 -13.366  1.00100.05           O  \\nATOM   2025  OP2  DG I 100      18.316  74.855 -13.616  1.00100.05           O  \\nATOM   2026  O5'  DG I 100      18.492  75.903 -11.359  1.00 37.80           O  \\nATOM   2027  C5'  DG I 100      17.420  75.524 -10.513  1.00 37.80           C  \\nATOM   2028  C4'  DG I 100      17.928  75.184  -9.140  1.00 37.80           C  \\nATOM   2029  O4'  DG I 100      16.938  74.312  -8.557  1.00 37.80           O  \\nATOM   2030  C3'  DG I 100      19.217  74.370  -9.151  1.00 37.80           C  \\nATOM   2031  O3'  DG I 100      19.807  74.498  -7.857  1.00 37.80           O  \\nATOM   2032  C2'  DG I 100      18.708  72.956  -9.345  1.00 37.80           C  \\nATOM   2033  C1'  DG I 100      17.449  72.979  -8.491  1.00 37.80           C  \\nATOM   2034  N9   DG I 100      16.384  72.056  -8.891  1.00 72.12           N  \\nATOM   2035  C8   DG I 100      16.226  71.402 -10.096  1.00 72.12           C  \\nATOM   2036  N7   DG I 100      15.165  70.638 -10.129  1.00 72.12           N  \\nATOM   2037  C5   DG I 100      14.592  70.799  -8.874  1.00 72.12           C  \\nATOM   2038  C6   DG I 100      13.421  70.232  -8.317  1.00 72.12           C  \\nATOM   2039  O6   DG I 100      12.617  69.443  -8.838  1.00 72.12           O  \\nATOM   2040  N1   DG I 100      13.214  70.677  -7.014  1.00 72.12           N  \\nATOM   2041  C2   DG I 100      14.027  71.557  -6.340  1.00 72.12           C  \\nATOM   2042  N2   DG I 100      13.651  71.878  -5.100  1.00 72.12           N  \\nATOM   2043  N3   DG I 100      15.113  72.084  -6.845  1.00 72.12           N  \\nATOM   2044  C4   DG I 100      15.335  71.670  -8.104  1.00 72.12           C  \\nATOM   2045  P    DC I 101      21.396  74.603  -7.693  1.00 34.39           P  \\nATOM   2046  OP1  DC I 101      21.913  75.752  -8.455  1.00 34.39           O  \\nATOM   2047  OP2  DC I 101      21.976  73.265  -7.899  1.00 34.39           O  \\nATOM   2048  O5'  DC I 101      21.574  74.952  -6.165  1.00 47.73           O  \\nATOM   2049  C5'  DC I 101      21.884  73.926  -5.264  1.00 47.73           C  \\nATOM   2050  C4'  DC I 101      20.850  73.871  -4.173  1.00 47.73           C  \\nATOM   2051  O4'  DC I 101      19.600  73.361  -4.697  1.00 47.73           O  \\nATOM   2052  C3'  DC I 101      21.281  72.914  -3.076  1.00 47.73           C  \\nATOM   2053  O3'  DC I 101      21.055  73.516  -1.812  1.00 47.73           O  \\nATOM   2054  C2'  DC I 101      20.479  71.647  -3.336  1.00 47.73           C  \\nATOM   2055  C1'  DC I 101      19.242  72.138  -4.072  1.00 47.73           C  \\nATOM   2056  N1   DC I 101      18.733  71.222  -5.123  1.00 41.45           N  \\nATOM   2057  C2   DC I 101      17.621  70.418  -4.827  1.00 41.45           C  \\nATOM   2058  O2   DC I 101      17.124  70.474  -3.690  1.00 41.45           O  \\nATOM   2059  N3   DC I 101      17.115  69.595  -5.787  1.00 41.45           N  \\nATOM   2060  C4   DC I 101      17.678  69.554  -6.997  1.00 41.45           C  \\nATOM   2061  N4   DC I 101      17.120  68.748  -7.917  1.00 41.45           N  \\nATOM   2062  C5   DC I 101      18.829  70.342  -7.320  1.00 41.45           C  \\nATOM   2063  C6   DC I 101      19.317  71.157  -6.361  1.00 41.45           C  \\nATOM   2064  P    DA I 102      21.849  72.970  -0.540  1.00 96.48           P  \\nATOM   2065  OP1  DA I 102      21.695  73.955   0.564  1.00 96.48           O  \\nATOM   2066  OP2  DA I 102      23.206  72.541  -0.977  1.00 96.48           O  \\nATOM   2067  O5'  DA I 102      21.013  71.673  -0.179  1.00 92.71           O  \\nATOM   2068  C5'  DA I 102      19.636  71.794   0.150  1.00 92.71           C  \\nATOM   2069  C4'  DA I 102      19.036  70.432   0.384  1.00 92.71           C  \\nATOM   2070  O4'  DA I 102      18.707  69.807  -0.874  1.00 92.71           O  \\nATOM   2071  C3'  DA I 102      19.960  69.463   1.122  1.00 92.71           C  \\nATOM   2072  O3'  DA I 102      19.194  68.767   2.104  1.00 92.71           O  \\nATOM   2073  C2'  DA I 102      20.441  68.536   0.018  1.00 92.71           C  \\nATOM   2074  C1'  DA I 102      19.224  68.498  -0.878  1.00 92.71           C  \\nATOM   2075  N9   DA I 102      19.469  68.128  -2.262  1.00 56.56           N  \\nATOM   2076  C8   DA I 102      20.529  68.442  -3.073  1.00 56.56           C  \\nATOM   2077  N7   DA I 102      20.433  67.946  -4.288  1.00 56.56           N  \\nATOM   2078  C5   DA I 102      19.221  67.260  -4.271  1.00 56.56           C  \\nATOM   2079  C6   DA I 102      18.527  66.506  -5.256  1.00 56.56           C  \\nATOM   2080  N6   DA I 102      18.967  66.319  -6.509  1.00 56.56           N  \\nATOM   2081  N1   DA I 102      17.348  65.947  -4.897  1.00 56.56           N  \\nATOM   2082  C2   DA I 102      16.897  66.138  -3.644  1.00 56.56           C  \\nATOM   2083  N3   DA I 102      17.448  66.823  -2.643  1.00 56.56           N  \\nATOM   2084  C4   DA I 102      18.621  67.363  -3.025  1.00 56.56           C  \\nATOM   2085  P    DG I 103      19.907  67.736   3.108  1.00 65.02           P  \\nATOM   2086  OP1  DG I 103      20.317  68.428   4.360  1.00 65.02           O  \\nATOM   2087  OP2  DG I 103      20.908  66.935   2.335  1.00 65.02           O  \\nATOM   2088  O5'  DG I 103      18.690  66.794   3.494  1.00 82.77           O  \\nATOM   2089  C5'  DG I 103      18.903  65.420   3.693  1.00 82.77           C  \\nATOM   2090  C4'  DG I 103      17.812  64.618   3.035  1.00 82.77           C  \\nATOM   2091  O4'  DG I 103      17.777  64.854   1.604  1.00 82.77           O  \\nATOM   2092  C3'  DG I 103      18.108  63.139   3.211  1.00 82.77           C  \\nATOM   2093  O3'  DG I 103      16.956  62.448   3.641  1.00 82.77           O  \\nATOM   2094  C2'  DG I 103      18.577  62.675   1.847  1.00 82.77           C  \\nATOM   2095  C1'  DG I 103      17.867  63.620   0.909  1.00 82.77           C  \\nATOM   2096  N9   DG I 103      18.614  63.835  -0.326  1.00 67.50           N  \\nATOM   2097  C8   DG I 103      19.733  64.609  -0.502  1.00 67.50           C  \\nATOM   2098  N7   DG I 103      20.198  64.569  -1.723  1.00 67.50           N  \\nATOM   2099  C5   DG I 103      19.327  63.726  -2.394  1.00 67.50           C  \\nATOM   2100  C6   DG I 103      19.315  63.301  -3.753  1.00 67.50           C  \\nATOM   2101  O6   DG I 103      20.093  63.596  -4.667  1.00 67.50           O  \\nATOM   2102  N1   DG I 103      18.253  62.446  -4.009  1.00 67.50           N  \\nATOM   2103  C2   DG I 103      17.318  62.049  -3.081  1.00 67.50           C  \\nATOM   2104  N2   DG I 103      16.370  61.213  -3.531  1.00 67.50           N  \\nATOM   2105  N3   DG I 103      17.314  62.439  -1.816  1.00 67.50           N  \\nATOM   2106  C4   DG I 103      18.340  63.270  -1.545  1.00 67.50           C  \\nATOM   2107  P    DT I 104      17.141  61.102   4.473  1.00 88.97           P  \\nATOM   2108  OP1  DT I 104      15.887  60.843   5.230  1.00 88.97           O  \\nATOM   2109  OP2  DT I 104      18.431  61.246   5.201  1.00 88.97           O  \\nATOM   2110  O5'  DT I 104      17.321  60.021   3.323  1.00 95.25           O  \\nATOM   2111  C5'  DT I 104      16.308  59.851   2.336  1.00 95.25           C  \\nATOM   2112  C4'  DT I 104      16.630  58.669   1.455  1.00 95.25           C  \\nATOM   2113  O4'  DT I 104      17.213  59.083   0.197  1.00 95.25           O  \\nATOM   2114  C3'  DT I 104      17.612  57.682   2.083  1.00 95.25           C  \\nATOM   2115  O3'  DT I 104      17.169  56.350   1.829  1.00 95.25           O  \\nATOM   2116  C2'  DT I 104      18.910  57.976   1.351  1.00 95.25           C  \\nATOM   2117  C1'  DT I 104      18.401  58.352  -0.026  1.00 95.25           C  \\nATOM   2118  N1   DT I 104      19.306  59.186  -0.829  1.00 71.00           N  \\nATOM   2119  C2   DT I 104      19.269  59.020  -2.191  1.00 71.00           C  \\nATOM   2120  O2   DT I 104      18.508  58.246  -2.742  1.00 71.00           O  \\nATOM   2121  N3   DT I 104      20.155  59.805  -2.893  1.00 71.00           N  \\nATOM   2122  C4   DT I 104      21.040  60.734  -2.376  1.00 71.00           C  \\nATOM   2123  O4   DT I 104      21.769  61.369  -3.135  1.00 71.00           O  \\nATOM   2124  C5   DT I 104      21.013  60.871  -0.936  1.00 71.00           C  \\nATOM   2125  C7   DT I 104      21.921  61.864  -0.286  1.00 71.00           C  \\nATOM   2126  C6   DT I 104      20.162  60.095  -0.242  1.00 71.00           C  \\nATOM   2127  P    DT I 105      17.884  55.115   2.560  1.00104.52           P  \\nATOM   2128  OP1  DT I 105      16.904  54.585   3.536  1.00104.52           O  \\nATOM   2129  OP2  DT I 105      19.236  55.516   3.028  1.00104.52           O  \\nATOM   2130  O5'  DT I 105      18.053  54.094   1.354  1.00104.76           O  \\nATOM   2131  C5'  DT I 105      17.147  54.141   0.257  1.00104.76           C  \\nATOM   2132  C4'  DT I 105      17.816  53.662  -1.009  1.00104.76           C  \\nATOM   2133  O4'  DT I 105      18.655  54.686  -1.599  1.00104.76           O  \\nATOM   2134  C3'  DT I 105      18.694  52.421  -0.853  1.00104.76           C  \\nATOM   2135  O3'  DT I 105      18.391  51.501  -1.907  1.00104.76           O  \\nATOM   2136  C2'  DT I 105      20.109  52.969  -0.975  1.00104.76           C  \\nATOM   2137  C1'  DT I 105      19.912  54.120  -1.945  1.00104.76           C  \\nATOM   2138  N1   DT I 105      20.932  55.199  -1.915  1.00 78.32           N  \\nATOM   2139  C2   DT I 105      21.529  55.555  -3.110  1.00 78.32           C  \\nATOM   2140  O2   DT I 105      21.303  54.985  -4.165  1.00 78.32           O  \\nATOM   2141  N3   DT I 105      22.414  56.607  -3.021  1.00 78.32           N  \\nATOM   2142  C4   DT I 105      22.764  57.314  -1.882  1.00 78.32           C  \\nATOM   2143  O4   DT I 105      23.558  58.251  -1.961  1.00 78.32           O  \\nATOM   2144  C5   DT I 105      22.128  56.868  -0.662  1.00 78.32           C  \\nATOM   2145  C7   DT I 105      22.462  57.564   0.620  1.00 78.32           C  \\nATOM   2146  C6   DT I 105      21.257  55.845  -0.737  1.00 78.32           C  \\nATOM   2147  P    DT I 106      19.158  50.095  -1.983  1.00113.89           P  \\nATOM   2148  OP1  DT I 106      18.239  49.091  -2.584  1.00113.89           O  \\nATOM   2149  OP2  DT I 106      19.786  49.825  -0.663  1.00113.89           O  \\nATOM   2150  O5'  DT I 106      20.317  50.401  -3.021  1.00133.78           O  \\nATOM   2151  C5'  DT I 106      20.032  51.030  -4.264  1.00133.78           C  \\nATOM   2152  C4'  DT I 106      21.288  51.073  -5.093  1.00133.78           C  \\nATOM   2153  O4'  DT I 106      22.066  52.256  -4.775  1.00133.78           O  \\nATOM   2154  C3'  DT I 106      22.177  49.872  -4.777  1.00133.78           C  \\nATOM   2155  O3'  DT I 106      22.701  49.292  -5.963  1.00133.78           O  \\nATOM   2156  C2'  DT I 106      23.283  50.456  -3.914  1.00133.78           C  \\nATOM   2157  C1'  DT I 106      23.394  51.869  -4.457  1.00133.78           C  \\nATOM   2158  N1   DT I 106      23.983  52.875  -3.528  1.00 93.55           N  \\nATOM   2159  C2   DT I 106      24.672  53.937  -4.084  1.00 93.55           C  \\nATOM   2160  O2   DT I 106      24.773  54.115  -5.287  1.00 93.55           O  \\nATOM   2161  N3   DT I 106      25.236  54.795  -3.175  1.00 93.55           N  \\nATOM   2162  C4   DT I 106      25.170  54.721  -1.797  1.00 93.55           C  \\nATOM   2163  O4   DT I 106      25.732  55.577  -1.114  1.00 93.55           O  \\nATOM   2164  C5   DT I 106      24.414  53.597  -1.276  1.00 93.55           C  \\nATOM   2165  C7   DT I 106      24.280  53.438   0.205  1.00 93.55           C  \\nATOM   2166  C6   DT I 106      23.865  52.743  -2.155  1.00 93.55           C  \\nATOM   2167  P    DC I 107      22.762  47.696  -6.095  1.00101.03           P  \\nATOM   2168  OP1  DC I 107      21.557  47.238  -6.823  1.00101.03           O  \\nATOM   2169  OP2  DC I 107      23.064  47.143  -4.747  1.00101.03           O  \\nATOM   2170  O5'  DC I 107      24.029  47.472  -7.022  1.00 84.59           O  \\nATOM   2171  C5'  DC I 107      25.324  47.817  -6.550  1.00 84.59           C  \\nATOM   2172  C4'  DC I 107      26.021  48.713  -7.545  1.00 84.59           C  \\nATOM   2173  O4'  DC I 107      26.041  50.055  -7.009  1.00 84.59           O  \\nATOM   2174  C3'  DC I 107      27.478  48.314  -7.760  1.00 84.59           C  \\nATOM   2175  O3'  DC I 107      27.883  48.464  -9.119  1.00 84.59           O  \\nATOM   2176  C2'  DC I 107      28.259  49.213  -6.822  1.00 84.59           C  \\nATOM   2177  C1'  DC I 107      27.352  50.414  -6.582  1.00 84.59           C  \\nATOM   2178  N1   DC I 107      27.277  50.766  -5.152  1.00 73.55           N  \\nATOM   2179  C2   DC I 107      27.837  51.967  -4.728  1.00 73.55           C  \\nATOM   2180  O2   DC I 107      28.382  52.698  -5.567  1.00 73.55           O  \\nATOM   2181  N3   DC I 107      27.779  52.303  -3.414  1.00 73.55           N  \\nATOM   2182  C4   DC I 107      27.190  51.482  -2.541  1.00 73.55           C  \\nATOM   2183  N4   DC I 107      27.150  51.856  -1.255  1.00 73.55           N  \\nATOM   2184  C5   DC I 107      26.613  50.242  -2.946  1.00 73.55           C  \\nATOM   2185  C6   DC I 107      26.675  49.928  -4.249  1.00 73.55           C  \\nATOM   2186  P    DC I 108      28.822  47.343  -9.783  1.00115.61           P  \\nATOM   2187  OP1  DC I 108      28.146  46.795 -10.987  1.00115.61           O  \\nATOM   2188  OP2  DC I 108      29.251  46.425  -8.693  1.00115.61           O  \\nATOM   2189  O5'  DC I 108      30.097  48.157 -10.267  1.00 79.75           O  \\nATOM   2190  C5'  DC I 108      29.945  49.365 -11.009  1.00 79.75           C  \\nATOM   2191  C4'  DC I 108      31.107  50.291 -10.739  1.00 79.75           C  \\nATOM   2192  O4'  DC I 108      31.072  50.761  -9.372  1.00 79.75           O  \\nATOM   2193  C3'  DC I 108      32.483  49.657 -10.916  1.00 79.75           C  \\nATOM   2194  O3'  DC I 108      33.354  50.686 -11.348  1.00 79.75           O  \\nATOM   2195  C2'  DC I 108      32.865  49.271  -9.500  1.00 79.75           C  \\nATOM   2196  C1'  DC I 108      32.303  50.453  -8.742  1.00 79.75           C  \\nATOM   2197  N1   DC I 108      32.038  50.245  -7.317  1.00 69.94           N  \\nATOM   2198  C2   DC I 108      31.990  51.364  -6.484  1.00 69.94           C  \\nATOM   2199  O2   DC I 108      32.179  52.492  -6.975  1.00 69.94           O  \\nATOM   2200  N3   DC I 108      31.745  51.199  -5.169  1.00 69.94           N  \\nATOM   2201  C4   DC I 108      31.553  49.978  -4.677  1.00 69.94           C  \\nATOM   2202  N4   DC I 108      31.315  49.869  -3.369  1.00 69.94           N  \\nATOM   2203  C5   DC I 108      31.599  48.817  -5.502  1.00 69.94           C  \\nATOM   2204  C6   DC I 108      31.839  48.996  -6.807  1.00 69.94           C  \\nATOM   2205  P    DA I 109      34.309  50.451 -12.604  1.00 87.07           P  \\nATOM   2206  OP1  DA I 109      33.495  50.490 -13.849  1.00 87.07           O  \\nATOM   2207  OP2  DA I 109      35.125  49.252 -12.290  1.00 87.07           O  \\nATOM   2208  O5'  DA I 109      35.250  51.735 -12.556  1.00 74.61           O  \\nATOM   2209  C5'  DA I 109      34.689  53.051 -12.502  1.00 74.61           C  \\nATOM   2210  C4'  DA I 109      35.498  53.943 -11.585  1.00 74.61           C  \\nATOM   2211  O4'  DA I 109      35.234  53.636 -10.198  1.00 74.61           O  \\nATOM   2212  C3'  DA I 109      37.014  53.862 -11.759  1.00 74.61           C  \\nATOM   2213  O3'  DA I 109      37.601  55.161 -11.661  1.00 74.61           O  \\nATOM   2214  C2'  DA I 109      37.456  52.989 -10.602  1.00 74.61           C  \\nATOM   2215  C1'  DA I 109      36.437  53.305  -9.528  1.00 74.61           C  \\nATOM   2216  N9   DA I 109      36.151  52.143  -8.707  1.00 61.81           N  \\nATOM   2217  C8   DA I 109      36.103  50.838  -9.122  1.00 61.81           C  \\nATOM   2218  N7   DA I 109      35.786  49.996  -8.173  1.00 61.81           N  \\nATOM   2219  C5   DA I 109      35.621  50.803  -7.054  1.00 61.81           C  \\nATOM   2220  C6   DA I 109      35.268  50.514  -5.722  1.00 61.81           C  \\nATOM   2221  N6   DA I 109      35.001  49.279  -5.282  1.00 61.81           N  \\nATOM   2222  N1   DA I 109      35.193  51.548  -4.855  1.00 61.81           N  \\nATOM   2223  C2   DA I 109      35.451  52.783  -5.306  1.00 61.81           C  \\nATOM   2224  N3   DA I 109      35.786  53.181  -6.535  1.00 61.81           N  \\nATOM   2225  C4   DA I 109      35.853  52.129  -7.369  1.00 61.81           C  \\nATOM   2226  P    DA I 110      39.196  55.321 -11.732  1.00101.93           P  \\nATOM   2227  OP1  DA I 110      39.543  56.377 -12.721  1.00101.93           O  \\nATOM   2228  OP2  DA I 110      39.784  53.966 -11.863  1.00101.93           O  \\nATOM   2229  O5'  DA I 110      39.554  55.835 -10.279  1.00 70.56           O  \\nATOM   2230  C5'  DA I 110      38.589  56.536  -9.518  1.00 70.56           C  \\nATOM   2231  C4'  DA I 110      38.999  56.552  -8.070  1.00 70.56           C  \\nATOM   2232  O4'  DA I 110      38.638  55.324  -7.398  1.00 70.56           O  \\nATOM   2233  C3'  DA I 110      40.503  56.708  -7.892  1.00 70.56           C  \\nATOM   2234  O3'  DA I 110      40.732  57.620  -6.833  1.00 70.56           O  \\nATOM   2235  C2'  DA I 110      40.963  55.307  -7.526  1.00 70.56           C  \\nATOM   2236  C1'  DA I 110      39.773  54.784  -6.750  1.00 70.56           C  \\nATOM   2237  N9   DA I 110      39.627  53.333  -6.754  1.00 69.21           N  \\nATOM   2238  C8   DA I 110      39.861  52.466  -7.789  1.00 69.21           C  \\nATOM   2239  N7   DA I 110      39.598  51.214  -7.497  1.00 69.21           N  \\nATOM   2240  C5   DA I 110      39.168  51.263  -6.177  1.00 69.21           C  \\nATOM   2241  C6   DA I 110      38.724  50.267  -5.284  1.00 69.21           C  \\nATOM   2242  N6   DA I 110      38.606  48.977  -5.609  1.00 69.21           N  \\nATOM   2243  N1   DA I 110      38.387  50.650  -4.034  1.00 69.21           N  \\nATOM   2244  C2   DA I 110      38.470  51.942  -3.717  1.00 69.21           C  \\nATOM   2245  N3   DA I 110      38.853  52.971  -4.470  1.00 69.21           N  \\nATOM   2246  C4   DA I 110      39.195  52.559  -5.704  1.00 69.21           C  \\nATOM   2247  P    DA I 111      42.223  58.060  -6.480  1.00 78.14           P  \\nATOM   2248  OP1  DA I 111      42.243  59.532  -6.623  1.00 78.14           O  \\nATOM   2249  OP2  DA I 111      43.176  57.229  -7.267  1.00 78.14           O  \\nATOM   2250  O5'  DA I 111      42.313  57.657  -4.945  1.00 70.74           O  \\nATOM   2251  C5'  DA I 111      41.204  57.889  -4.073  1.00 70.74           C  \\nATOM   2252  C4'  DA I 111      41.396  57.150  -2.769  1.00 70.74           C  \\nATOM   2253  O4'  DA I 111      40.974  55.766  -2.901  1.00 70.74           O  \\nATOM   2254  C3'  DA I 111      42.854  57.121  -2.312  1.00 70.74           C  \\nATOM   2255  O3'  DA I 111      42.979  57.364  -0.916  1.00 70.74           O  \\nATOM   2256  C2'  DA I 111      43.297  55.708  -2.629  1.00 70.74           C  \\nATOM   2257  C1'  DA I 111      42.016  54.904  -2.462  1.00 70.74           C  \\nATOM   2258  N9   DA I 111      41.998  53.673  -3.270  1.00 72.28           N  \\nATOM   2259  C8   DA I 111      42.241  53.540  -4.620  1.00 72.28           C  \\nATOM   2260  N7   DA I 111      42.237  52.296  -5.040  1.00 72.28           N  \\nATOM   2261  C5   DA I 111      41.953  51.559  -3.898  1.00 72.28           C  \\nATOM   2262  C6   DA I 111      41.815  50.174  -3.671  1.00 72.28           C  \\nATOM   2263  N6   DA I 111      41.980  49.248  -4.615  1.00 72.28           N  \\nATOM   2264  N1   DA I 111      41.509  49.767  -2.420  1.00 72.28           N  \\nATOM   2265  C2   DA I 111      41.369  50.691  -1.465  1.00 72.28           C  \\nATOM   2266  N3   DA I 111      41.486  52.018  -1.548  1.00 72.28           N  \\nATOM   2267  C4   DA I 111      41.782  52.393  -2.805  1.00 72.28           C  \\nATOM   2268  P    DT I 112      44.444  57.527  -0.271  1.00 42.86           P  \\nATOM   2269  OP1  DT I 112      44.581  58.853   0.371  1.00 42.86           O  \\nATOM   2270  OP2  DT I 112      45.430  57.122  -1.305  1.00 42.86           O  \\nATOM   2271  O5'  DT I 112      44.415  56.480   0.920  1.00 50.49           O  \\nATOM   2272  C5'  DT I 112      43.391  56.559   1.897  1.00 50.49           C  \\nATOM   2273  C4'  DT I 112      43.267  55.248   2.628  1.00 50.49           C  \\nATOM   2274  O4'  DT I 112      43.030  54.170   1.682  1.00 50.49           O  \\nATOM   2275  C3'  DT I 112      44.511  54.855   3.418  1.00 50.49           C  \\nATOM   2276  O3'  DT I 112      44.093  54.353   4.682  1.00 50.49           O  \\nATOM   2277  C2'  DT I 112      45.151  53.760   2.576  1.00 50.49           C  \\nATOM   2278  C1'  DT I 112      43.946  53.108   1.926  1.00 50.49           C  \\nATOM   2279  N1   DT I 112      44.218  52.424   0.637  1.00 56.91           N  \\nATOM   2280  C2   DT I 112      44.020  51.058   0.570  1.00 56.91           C  \\nATOM   2281  O2   DT I 112      43.673  50.386   1.528  1.00 56.91           O  \\nATOM   2282  N3   DT I 112      44.255  50.506  -0.670  1.00 56.91           N  \\nATOM   2283  C4   DT I 112      44.665  51.165  -1.812  1.00 56.91           C  \\nATOM   2284  O4   DT I 112      44.805  50.544  -2.857  1.00 56.91           O  \\nATOM   2285  C5   DT I 112      44.891  52.577  -1.662  1.00 56.91           C  \\nATOM   2286  C7   DT I 112      45.392  53.352  -2.839  1.00 56.91           C  \\nATOM   2287  C6   DT I 112      44.650  53.134  -0.465  1.00 56.91           C  \\nATOM   2288  P    DA I 113      45.145  53.617   5.632  1.00 70.99           P  \\nATOM   2289  OP1  DA I 113      44.510  53.477   6.972  1.00 70.99           O  \\nATOM   2290  OP2  DA I 113      46.451  54.323   5.495  1.00 70.99           O  \\nATOM   2291  O5'  DA I 113      45.263  52.174   4.972  1.00105.55           O  \\nATOM   2292  C5'  DA I 113      44.312  51.157   5.277  1.00105.55           C  \\nATOM   2293  C4'  DA I 113      45.025  49.841   5.465  1.00105.55           C  \\nATOM   2294  O4'  DA I 113      45.362  49.293   4.169  1.00105.55           O  \\nATOM   2295  C3'  DA I 113      46.341  49.990   6.230  1.00105.55           C  \\nATOM   2296  O3'  DA I 113      46.525  48.905   7.147  1.00105.55           O  \\nATOM   2297  C2'  DA I 113      47.388  50.018   5.128  1.00105.55           C  \\nATOM   2298  C1'  DA I 113      46.771  49.159   4.032  1.00105.55           C  \\nATOM   2299  N9   DA I 113      47.127  49.558   2.665  1.00 70.52           N  \\nATOM   2300  C8   DA I 113      47.392  50.822   2.196  1.00 70.52           C  \\nATOM   2301  N7   DA I 113      47.663  50.867   0.912  1.00 70.52           N  \\nATOM   2302  C5   DA I 113      47.577  49.546   0.507  1.00 70.52           C  \\nATOM   2303  C6   DA I 113      47.749  48.932  -0.740  1.00 70.52           C  \\nATOM   2304  N6   DA I 113      48.048  49.593  -1.860  1.00 70.52           N  \\nATOM   2305  N1   DA I 113      47.598  47.594  -0.803  1.00 70.52           N  \\nATOM   2306  C2   DA I 113      47.289  46.927   0.319  1.00 70.52           C  \\nATOM   2307  N3   DA I 113      47.096  47.391   1.549  1.00 70.52           N  \\nATOM   2308  C4   DA I 113      47.254  48.725   1.577  1.00 70.52           C  \\nATOM   2309  P    DC I 114      47.860  48.829   8.041  1.00105.53           P  \\nATOM   2310  OP1  DC I 114      47.775  47.576   8.832  1.00105.53           O  \\nATOM   2311  OP2  DC I 114      48.051  50.128   8.744  1.00105.53           O  \\nATOM   2312  O5'  DC I 114      49.002  48.669   6.938  1.00 92.52           O  \\nATOM   2313  C5'  DC I 114      50.216  47.978   7.213  1.00 92.52           C  \\nATOM   2314  C4'  DC I 114      50.149  46.562   6.684  1.00 92.52           C  \\nATOM   2315  O4'  DC I 114      49.610  46.517   5.340  1.00 92.52           O  \\nATOM   2316  C3'  DC I 114      51.513  45.890   6.614  1.00 92.52           C  \\nATOM   2317  O3'  DC I 114      51.422  44.535   7.041  1.00 92.52           O  \\nATOM   2318  C2'  DC I 114      51.904  45.989   5.153  1.00 92.52           C  \\nATOM   2319  C1'  DC I 114      50.578  46.035   4.414  1.00 92.52           C  \\nATOM   2320  N1   DC I 114      50.624  46.987   3.292  1.00 63.64           N  \\nATOM   2321  C2   DC I 114      50.478  46.517   1.972  1.00 63.64           C  \\nATOM   2322  O2   DC I 114      50.314  45.303   1.774  1.00 63.64           O  \\nATOM   2323  N3   DC I 114      50.530  47.408   0.946  1.00 63.64           N  \\nATOM   2324  C4   DC I 114      50.732  48.708   1.196  1.00 63.64           C  \\nATOM   2325  N4   DC I 114      50.798  49.548   0.160  1.00 63.64           N  \\nATOM   2326  C5   DC I 114      50.882  49.206   2.524  1.00 63.64           C  \\nATOM   2327  C6   DC I 114      50.820  48.321   3.530  1.00 63.64           C  \\nATOM   2328  P    DA I 115      52.764  43.732   7.375  1.00 86.86           P  \\nATOM   2329  OP1  DA I 115      52.404  42.445   8.033  1.00 86.86           O  \\nATOM   2330  OP2  DA I 115      53.677  44.683   8.061  1.00 86.86           O  \\nATOM   2331  O5'  DA I 115      53.341  43.420   5.929  1.00154.94           O  \\nATOM   2332  C5'  DA I 115      52.705  42.455   5.100  1.00154.94           C  \\nATOM   2333  C4'  DA I 115      53.546  42.194   3.876  1.00154.94           C  \\nATOM   2334  O4'  DA I 115      53.291  43.211   2.878  1.00154.94           O  \\nATOM   2335  C3'  DA I 115      55.048  42.226   4.163  1.00154.94           C  \\nATOM   2336  O3'  DA I 115      55.703  41.162   3.472  1.00154.94           O  \\nATOM   2337  C2'  DA I 115      55.477  43.582   3.628  1.00154.94           C  \\nATOM   2338  C1'  DA I 115      54.516  43.795   2.470  1.00154.94           C  \\nATOM   2339  N9   DA I 115      54.267  45.201   2.139  1.00 93.27           N  \\nATOM   2340  C8   DA I 115      54.022  46.239   3.004  1.00 93.27           C  \\nATOM   2341  N7   DA I 115      53.881  47.400   2.410  1.00 93.27           N  \\nATOM   2342  C5   DA I 115      54.035  47.107   1.061  1.00 93.27           C  \\nATOM   2343  C6   DA I 115      54.003  47.913  -0.099  1.00 93.27           C  \\nATOM   2344  N6   DA I 115      53.805  49.239  -0.085  1.00 93.27           N  \\nATOM   2345  N1   DA I 115      54.187  47.303  -1.289  1.00 93.27           N  \\nATOM   2346  C2   DA I 115      54.390  45.982  -1.309  1.00 93.27           C  \\nATOM   2347  N3   DA I 115      54.445  45.122  -0.294  1.00 93.27           N  \\nATOM   2348  C4   DA I 115      54.259  45.754   0.879  1.00 93.27           C  \\nATOM   2349  P    DC I 116      57.244  40.822   3.790  1.00106.13           P  \\nATOM   2350  OP1  DC I 116      57.301  39.569   4.585  1.00106.13           O  \\nATOM   2351  OP2  DC I 116      57.907  42.050   4.307  1.00106.13           O  \\nATOM   2352  O5'  DC I 116      57.817  40.534   2.335  1.00158.95           O  \\nATOM   2353  C5'  DC I 116      57.048  40.887   1.183  1.00158.95           C  \\nATOM   2354  C4'  DC I 116      57.953  41.298   0.045  1.00158.95           C  \\nATOM   2355  O4'  DC I 116      57.598  42.630  -0.407  1.00158.95           O  \\nATOM   2356  C3'  DC I 116      59.443  41.352   0.391  1.00158.95           C  \\nATOM   2357  O3'  DC I 116      60.206  40.807  -0.690  1.00158.95           O  \\nATOM   2358  C2'  DC I 116      59.715  42.836   0.555  1.00158.95           C  \\nATOM   2359  C1'  DC I 116      58.761  43.446  -0.452  1.00158.95           C  \\nATOM   2360  N1   DC I 116      58.375  44.833  -0.137  1.00116.12           N  \\nATOM   2361  C2   DC I 116      57.827  45.644  -1.150  1.00116.12           C  \\nATOM   2362  O2   DC I 116      57.656  45.166  -2.290  1.00116.12           O  \\nATOM   2363  N3   DC I 116      57.500  46.926  -0.856  1.00116.12           N  \\nATOM   2364  C4   DC I 116      57.695  47.403   0.380  1.00116.12           C  \\nATOM   2365  N4   DC I 116      57.362  48.668   0.624  1.00116.12           N  \\nATOM   2366  C5   DC I 116      58.240  46.599   1.421  1.00116.12           C  \\nATOM   2367  C6   DC I 116      58.560  45.334   1.123  1.00116.12           C  \\nATOM   2368  P    DT I 117      61.774  41.138  -0.812  1.00120.60           P  \\nATOM   2369  OP1  DT I 117      62.445  39.942  -1.381  1.00120.60           O  \\nATOM   2370  OP2  DT I 117      62.242  41.693   0.488  1.00120.60           O  \\nATOM   2371  O5'  DT I 117      61.812  42.303  -1.898  1.00135.17           O  \\nATOM   2372  C5'  DT I 117      61.129  42.155  -3.144  1.00135.17           C  \\nATOM   2373  C4'  DT I 117      61.633  43.167  -4.146  1.00135.17           C  \\nATOM   2374  O4'  DT I 117      61.104  44.481  -3.842  1.00135.17           O  \\nATOM   2375  C3'  DT I 117      63.154  43.308  -4.187  1.00135.17           C  \\nATOM   2376  O3'  DT I 117      63.617  43.380  -5.536  1.00135.17           O  \\nATOM   2377  C2'  DT I 117      63.422  44.596  -3.429  1.00135.17           C  \\nATOM   2378  C1'  DT I 117      62.158  45.415  -3.644  1.00135.17           C  \\nATOM   2379  N1   DT I 117      61.805  46.249  -2.474  1.00 83.79           N  \\nATOM   2380  C2   DT I 117      61.443  47.559  -2.683  1.00 83.79           C  \\nATOM   2381  O2   DT I 117      61.365  48.057  -3.793  1.00 83.79           O  \\nATOM   2382  N3   DT I 117      61.166  48.266  -1.533  1.00 83.79           N  \\nATOM   2383  C4   DT I 117      61.197  47.793  -0.229  1.00 83.79           C  \\nATOM   2384  O4   DT I 117      60.926  48.548   0.702  1.00 83.79           O  \\nATOM   2385  C5   DT I 117      61.562  46.402  -0.086  1.00 83.79           C  \\nATOM   2386  C7   DT I 117      61.599  45.794   1.282  1.00 83.79           C  \\nATOM   2387  C6   DT I 117      61.850  45.712  -1.199  1.00 83.79           C  \\nATOM   2388  P    DT I 118      65.154  43.737  -5.836  1.00120.38           P  \\nATOM   2389  OP1  DT I 118      65.542  43.011  -7.075  1.00120.38           O  \\nATOM   2390  OP2  DT I 118      65.971  43.578  -4.602  1.00120.38           O  \\nATOM   2391  O5'  DT I 118      65.076  45.283  -6.183  1.00 90.80           O  \\nATOM   2392  C5'  DT I 118      64.069  45.752  -7.068  1.00 90.80           C  \\nATOM   2393  C4'  DT I 118      64.163  47.248  -7.225  1.00 90.80           C  \\nATOM   2394  O4'  DT I 118      63.832  47.873  -5.965  1.00 90.80           O  \\nATOM   2395  C3'  DT I 118      65.548  47.775  -7.607  1.00 90.80           C  \\nATOM   2396  O3'  DT I 118      65.394  48.833  -8.566  1.00 90.80           O  \\nATOM   2397  C2'  DT I 118      66.104  48.277  -6.286  1.00 90.80           C  \\nATOM   2398  C1'  DT I 118      64.850  48.793  -5.622  1.00 90.80           C  \\nATOM   2399  N1   DT I 118      64.886  48.888  -4.166  1.00 77.56           N  \\nATOM   2400  C2   DT I 118      64.614  50.113  -3.607  1.00 77.56           C  \\nATOM   2401  O2   DT I 118      64.437  51.126  -4.268  1.00 77.56           O  \\nATOM   2402  N3   DT I 118      64.567  50.115  -2.240  1.00 77.56           N  \\nATOM   2403  C4   DT I 118      64.794  49.050  -1.397  1.00 77.56           C  \\nATOM   2404  O4   DT I 118      64.691  49.206  -0.188  1.00 77.56           O  \\nATOM   2405  C5   DT I 118      65.134  47.804  -2.053  1.00 77.56           C  \\nATOM   2406  C7   DT I 118      65.452  46.603  -1.219  1.00 77.56           C  \\nATOM   2407  C6   DT I 118      65.153  47.786  -3.391  1.00 77.56           C  \\nATOM   2408  P    DT I 119      66.613  49.838  -8.865  1.00 87.10           P  \\nATOM   2409  OP1  DT I 119      66.486  50.279 -10.281  1.00 87.10           O  \\nATOM   2410  OP2  DT I 119      67.890  49.231  -8.397  1.00 87.10           O  \\nATOM   2411  O5'  DT I 119      66.309  51.069  -7.899  1.00 88.48           O  \\nATOM   2412  C5'  DT I 119      65.320  52.037  -8.236  1.00 88.48           C  \\nATOM   2413  C4'  DT I 119      65.819  53.424  -7.909  1.00 88.48           C  \\nATOM   2414  O4'  DT I 119      65.733  53.594  -6.475  1.00 88.48           O  \\nATOM   2415  C3'  DT I 119      67.282  53.669  -8.292  1.00 88.48           C  \\nATOM   2416  O3'  DT I 119      67.510  54.774  -9.190  1.00 88.48           O  \\nATOM   2417  C2'  DT I 119      68.047  53.728  -6.982  1.00 88.48           C  \\nATOM   2418  C1'  DT I 119      66.991  53.934  -5.907  1.00 88.48           C  \\nATOM   2419  N1   DT I 119      67.205  53.053  -4.741  1.00 89.04           N  \\nATOM   2420  C2   DT I 119      67.051  53.571  -3.474  1.00 89.04           C  \\nATOM   2421  O2   DT I 119      66.748  54.733  -3.258  1.00 89.04           O  \\nATOM   2422  N3   DT I 119      67.272  52.671  -2.460  1.00 89.04           N  \\nATOM   2423  C4   DT I 119      67.629  51.343  -2.585  1.00 89.04           C  \\nATOM   2424  O4   DT I 119      67.791  50.658  -1.584  1.00 89.04           O  \\nATOM   2425  C5   DT I 119      67.777  50.873  -3.936  1.00 89.04           C  \\nATOM   2426  C7   DT I 119      68.166  49.450  -4.166  1.00 89.04           C  \\nATOM   2427  C6   DT I 119      67.559  51.736  -4.933  1.00 89.04           C  \\nATOM   2428  P    DT I 120      66.619  56.107  -9.103  1.00 75.71           P  \\nATOM   2429  OP1  DT I 120      65.225  55.757  -9.496  1.00 75.71           O  \\nATOM   2430  OP2  DT I 120      67.346  57.162  -9.856  1.00 75.71           O  \\nATOM   2431  O5'  DT I 120      66.646  56.503  -7.563  1.00 67.52           O  \\nATOM   2432  C5'  DT I 120      65.537  57.171  -6.975  1.00 67.52           C  \\nATOM   2433  C4'  DT I 120      66.016  58.185  -5.970  1.00 67.52           C  \\nATOM   2434  O4'  DT I 120      66.621  57.500  -4.849  1.00 67.52           O  \\nATOM   2435  C3'  DT I 120      67.066  59.162  -6.495  1.00 67.52           C  \\nATOM   2436  O3'  DT I 120      66.821  60.421  -5.886  1.00 67.52           O  \\nATOM   2437  C2'  DT I 120      68.368  58.582  -5.971  1.00 67.52           C  \\nATOM   2438  C1'  DT I 120      67.935  57.982  -4.640  1.00 67.52           C  \\nATOM   2439  N1   DT I 120      68.748  56.852  -4.154  1.00 89.08           N  \\nATOM   2440  C2   DT I 120      68.808  56.635  -2.792  1.00 89.08           C  \\nATOM   2441  O2   DT I 120      68.248  57.346  -1.978  1.00 89.08           O  \\nATOM   2442  N3   DT I 120      69.559  55.552  -2.416  1.00 89.08           N  \\nATOM   2443  C4   DT I 120      70.248  54.686  -3.241  1.00 89.08           C  \\nATOM   2444  O4   DT I 120      70.864  53.743  -2.747  1.00 89.08           O  \\nATOM   2445  C5   DT I 120      70.162  54.990  -4.666  1.00 89.08           C  \\nATOM   2446  C7   DT I 120      70.901  54.134  -5.648  1.00 89.08           C  \\nATOM   2447  C6   DT I 120      69.421  56.039  -5.040  1.00 89.08           C  \\nATOM   2448  P    DG I 121      66.998  61.776  -6.722  1.00 63.18           P  \\nATOM   2449  OP1  DG I 121      65.909  61.914  -7.731  1.00 63.18           O  \\nATOM   2450  OP2  DG I 121      68.424  61.848  -7.150  1.00 63.18           O  \\nATOM   2451  O5'  DG I 121      66.749  62.879  -5.600  1.00 58.04           O  \\nATOM   2452  C5'  DG I 121      65.685  62.722  -4.654  1.00 58.04           C  \\nATOM   2453  C4'  DG I 121      66.200  62.896  -3.243  1.00 58.04           C  \\nATOM   2454  O4'  DG I 121      67.114  61.830  -2.900  1.00 58.04           O  \\nATOM   2455  C3'  DG I 121      66.971  64.189  -3.007  1.00 58.04           C  \\nATOM   2456  O3'  DG I 121      66.756  64.628  -1.672  1.00 58.04           O  \\nATOM   2457  C2'  DG I 121      68.418  63.766  -3.166  1.00 58.04           C  \\nATOM   2458  C1'  DG I 121      68.398  62.367  -2.586  1.00 58.04           C  \\nATOM   2459  N9   DG I 121      69.402  61.491  -3.177  1.00 74.45           N  \\nATOM   2460  C8   DG I 121      69.836  61.488  -4.483  1.00 74.45           C  \\nATOM   2461  N7   DG I 121      70.732  60.573  -4.721  1.00 74.45           N  \\nATOM   2462  C5   DG I 121      70.902  59.940  -3.501  1.00 74.45           C  \\nATOM   2463  C6   DG I 121      71.738  58.869  -3.147  1.00 74.45           C  \\nATOM   2464  O6   DG I 121      72.512  58.233  -3.873  1.00 74.45           O  \\nATOM   2465  N1   DG I 121      71.612  58.547  -1.794  1.00 74.45           N  \\nATOM   2466  C2   DG I 121      70.773  59.177  -0.906  1.00 74.45           C  \\nATOM   2467  N2   DG I 121      70.806  58.736   0.359  1.00 74.45           N  \\nATOM   2468  N3   DG I 121      69.970  60.169  -1.235  1.00 74.45           N  \\nATOM   2469  C4   DG I 121      70.091  60.500  -2.537  1.00 74.45           C  \\nATOM   2470  P    DG I 122      67.134  66.127  -1.261  1.00 45.73           P  \\nATOM   2471  OP1  DG I 122      65.899  66.708  -0.714  1.00 45.73           O  \\nATOM   2472  OP2  DG I 122      67.829  66.807  -2.384  1.00 45.73           O  \\nATOM   2473  O5'  DG I 122      68.136  65.926  -0.050  1.00 41.47           O  \\nATOM   2474  C5'  DG I 122      67.659  65.344   1.153  1.00 41.47           C  \\nATOM   2475  C4'  DG I 122      68.804  64.880   2.019  1.00 41.47           C  \\nATOM   2476  O4'  DG I 122      69.479  63.766   1.395  1.00 41.47           O  \\nATOM   2477  C3'  DG I 122      69.878  65.923   2.324  1.00 41.47           C  \\nATOM   2478  O3'  DG I 122      70.139  65.914   3.724  1.00 41.47           O  \\nATOM   2479  C2'  DG I 122      71.090  65.451   1.537  1.00 41.47           C  \\nATOM   2480  C1'  DG I 122      70.875  63.954   1.487  1.00 41.47           C  \\nATOM   2481  N9   DG I 122      71.498  63.265   0.363  1.00 80.72           N  \\nATOM   2482  C8   DG I 122      71.443  63.589  -0.973  1.00 80.72           C  \\nATOM   2483  N7   DG I 122      72.141  62.780  -1.725  1.00 80.72           N  \\nATOM   2484  C5   DG I 122      72.684  61.865  -0.830  1.00 80.72           C  \\nATOM   2485  C6   DG I 122      73.539  60.751  -1.048  1.00 80.72           C  \\nATOM   2486  O6   DG I 122      74.018  60.338  -2.114  1.00 80.72           O  \\nATOM   2487  N1   DG I 122      73.831  60.092   0.145  1.00 80.72           N  \\nATOM   2488  C2   DG I 122      73.358  60.452   1.388  1.00 80.72           C  \\nATOM   2489  N2   DG I 122      73.727  59.683   2.418  1.00 80.72           N  \\nATOM   2490  N3   DG I 122      72.577  61.489   1.604  1.00 80.72           N  \\nATOM   2491  C4   DG I 122      72.282  62.147   0.459  1.00 80.72           C  \\nATOM   2492  P    DT I 123      71.235  66.911   4.336  1.00 63.59           P  \\nATOM   2493  OP1  DT I 123      70.810  67.322   5.706  1.00 63.59           O  \\nATOM   2494  OP2  DT I 123      71.544  67.951   3.315  1.00 63.59           O  \\nATOM   2495  O5'  DT I 123      72.488  65.947   4.461  1.00 96.42           O  \\nATOM   2496  C5'  DT I 123      72.366  64.691   5.119  1.00 96.42           C  \\nATOM   2497  C4'  DT I 123      73.736  64.107   5.344  1.00 96.42           C  \\nATOM   2498  O4'  DT I 123      74.198  63.475   4.124  1.00 96.42           O  \\nATOM   2499  C3'  DT I 123      74.763  65.187   5.694  1.00 96.42           C  \\nATOM   2500  O3'  DT I 123      75.593  64.775   6.791  1.00 96.42           O  \\nATOM   2501  C2'  DT I 123      75.539  65.380   4.399  1.00 96.42           C  \\nATOM   2502  C1'  DT I 123      75.468  63.998   3.774  1.00 96.42           C  \\nATOM   2503  N1   DT I 123      75.617  63.943   2.298  1.00 65.23           N  \\nATOM   2504  C2   DT I 123      76.111  62.771   1.751  1.00 65.23           C  \\nATOM   2505  O2   DT I 123      76.341  61.772   2.413  1.00 65.23           O  \\nATOM   2506  N3   DT I 123      76.317  62.811   0.390  1.00 65.23           N  \\nATOM   2507  C4   DT I 123      76.053  63.868  -0.466  1.00 65.23           C  \\nATOM   2508  O4   DT I 123      76.299  63.763  -1.668  1.00 65.23           O  \\nATOM   2509  C5   DT I 123      75.498  65.046   0.161  1.00 65.23           C  \\nATOM   2510  C7   DT I 123      75.171  66.225  -0.697  1.00 65.23           C  \\nATOM   2511  C6   DT I 123      75.308  65.028   1.495  1.00 65.23           C  \\nATOM   2512  P    DA I 124      76.714  65.778   7.375  1.00 96.30           P  \\nATOM   2513  OP1  DA I 124      76.651  65.804   8.868  1.00 96.30           O  \\nATOM   2514  OP2  DA I 124      76.668  67.054   6.609  1.00 96.30           O  \\nATOM   2515  O5'  DA I 124      78.066  65.059   6.959  1.00117.14           O  \\nATOM   2516  C5'  DA I 124      78.314  63.703   7.320  1.00117.14           C  \\nATOM   2517  C4'  DA I 124      79.695  63.317   6.857  1.00117.14           C  \\nATOM   2518  O4'  DA I 124      79.671  63.203   5.415  1.00117.14           O  \\nATOM   2519  C3'  DA I 124      80.687  64.432   7.179  1.00117.14           C  \\nATOM   2520  O3'  DA I 124      81.953  63.934   7.594  1.00117.14           O  \\nATOM   2521  C2'  DA I 124      80.787  65.214   5.884  1.00117.14           C  \\nATOM   2522  C1'  DA I 124      80.556  64.146   4.837  1.00117.14           C  \\nATOM   2523  N9   DA I 124      79.947  64.657   3.612  1.00 80.33           N  \\nATOM   2524  C8   DA I 124      79.258  65.837   3.444  1.00 80.33           C  \\nATOM   2525  N7   DA I 124      78.909  66.073   2.201  1.00 80.33           N  \\nATOM   2526  C5   DA I 124      79.381  64.963   1.506  1.00 80.33           C  \\nATOM   2527  C6   DA I 124      79.347  64.610   0.138  1.00 80.33           C  \\nATOM   2528  N6   DA I 124      78.812  65.387  -0.816  1.00 80.33           N  \\nATOM   2529  N1   DA I 124      79.900  63.421  -0.219  1.00 80.33           N  \\nATOM   2530  C2   DA I 124      80.451  62.655   0.735  1.00 80.33           C  \\nATOM   2531  N3   DA I 124      80.554  62.884   2.044  1.00 80.33           N  \\nATOM   2532  C4   DA I 124      79.997  64.069   2.369  1.00 80.33           C  \\nATOM   2533  P    DG I 125      82.956  64.921   8.356  1.00133.47           P  \\nATOM   2534  OP1  DG I 125      84.273  64.247   8.450  1.00133.47           O  \\nATOM   2535  OP2  DG I 125      82.279  65.392   9.594  1.00133.47           O  \\nATOM   2536  O5'  DG I 125      83.069  66.152   7.351  1.00103.83           O  \\nATOM   2537  C5'  DG I 125      84.320  66.512   6.782  1.00103.83           C  \\nATOM   2538  C4'  DG I 125      84.902  65.339   6.030  1.00103.83           C  \\nATOM   2539  O4'  DG I 125      84.003  64.943   4.969  1.00103.83           O  \\nATOM   2540  C3'  DG I 125      86.239  65.640   5.361  1.00103.83           C  \\nATOM   2541  O3'  DG I 125      87.092  64.493   5.422  1.00103.83           O  \\nATOM   2542  C2'  DG I 125      85.851  65.960   3.932  1.00103.83           C  \\nATOM   2543  C1'  DG I 125      84.635  65.082   3.704  1.00103.83           C  \\nATOM   2544  N9   DG I 125      83.681  65.716   2.804  1.00119.69           N  \\nATOM   2545  C8   DG I 125      82.875  66.792   3.096  1.00119.69           C  \\nATOM   2546  N7   DG I 125      82.145  67.176   2.084  1.00119.69           N  \\nATOM   2547  C5   DG I 125      82.480  66.297   1.060  1.00119.69           C  \\nATOM   2548  C6   DG I 125      82.011  66.226  -0.282  1.00119.69           C  \\nATOM   2549  O6   DG I 125      81.173  66.948  -0.845  1.00119.69           O  \\nATOM   2550  N1   DG I 125      82.618  65.184  -0.981  1.00119.69           N  \\nATOM   2551  C2   DG I 125      83.537  64.307  -0.454  1.00119.69           C  \\nATOM   2552  N2   DG I 125      83.971  63.353  -1.288  1.00119.69           N  \\nATOM   2553  N3   DG I 125      83.987  64.362   0.794  1.00119.69           N  \\nATOM   2554  C4   DG I 125      83.421  65.379   1.490  1.00119.69           C  \\nATOM   2555  P    DA I 126      88.491  64.506   4.637  1.00114.28           P  \\nATOM   2556  OP1  DA I 126      89.195  63.221   4.882  1.00114.28           O  \\nATOM   2557  OP2  DA I 126      89.170  65.790   4.950  1.00114.28           O  \\nATOM   2558  O5'  DA I 126      88.040  64.545   3.114  1.00151.17           O  \\nATOM   2559  C5'  DA I 126      88.438  63.525   2.211  1.00151.17           C  \\nATOM   2560  C4'  DA I 126      89.018  64.150   0.967  1.00151.17           C  \\nATOM   2561  O4'  DA I 126      87.953  64.722   0.162  1.00151.17           O  \\nATOM   2562  C3'  DA I 126      89.990  65.294   1.271  1.00151.17           C  \\nATOM   2563  O3'  DA I 126      91.123  65.220   0.398  1.00151.17           O  \\nATOM   2564  C2'  DA I 126      89.157  66.536   1.011  1.00151.17           C  \\nATOM   2565  C1'  DA I 126      88.249  66.081  -0.116  1.00151.17           C  \\nATOM   2566  N9   DA I 126      86.992  66.831  -0.209  1.00138.40           N  \\nATOM   2567  C8   DA I 126      86.439  67.650   0.749  1.00138.40           C  \\nATOM   2568  N7   DA I 126      85.336  68.246   0.362  1.00138.40           N  \\nATOM   2569  C5   DA I 126      85.139  67.779  -0.931  1.00138.40           C  \\nATOM   2570  C6   DA I 126      84.145  68.044  -1.891  1.00138.40           C  \\nATOM   2571  N6   DA I 126      83.125  68.881  -1.689  1.00138.40           N  \\nATOM   2572  N1   DA I 126      84.238  67.413  -3.081  1.00138.40           N  \\nATOM   2573  C2   DA I 126      85.264  66.577  -3.284  1.00138.40           C  \\nATOM   2574  N3   DA I 126      86.262  66.249  -2.465  1.00138.40           N  \\nATOM   2575  C4   DA I 126      86.142  66.893  -1.290  1.00138.40           C  \\nATOM   2576  P    DA I 127      92.055  66.513   0.165  1.00165.61           P  \\nATOM   2577  OP1  DA I 127      93.475  66.094   0.282  1.00165.61           O  \\nATOM   2578  OP2  DA I 127      91.550  67.616   1.022  1.00165.61           O  \\nATOM   2579  O5'  DA I 127      91.763  66.883  -1.361  1.00174.46           O  \\nATOM   2580  C5'  DA I 127      91.477  65.851  -2.312  1.00174.46           C  \\nATOM   2581  C4'  DA I 127      91.145  66.437  -3.666  1.00174.46           C  \\nATOM   2582  O4'  DA I 127      89.849  67.087  -3.637  1.00174.46           O  \\nATOM   2583  C3'  DA I 127      92.136  67.473  -4.196  1.00174.46           C  \\nATOM   2584  O3'  DA I 127      92.402  67.226  -5.583  1.00174.46           O  \\nATOM   2585  C2'  DA I 127      91.423  68.798  -3.971  1.00174.46           C  \\nATOM   2586  C1'  DA I 127      89.953  68.429  -4.103  1.00174.46           C  \\nATOM   2587  N9   DA I 127      89.039  69.258  -3.304  1.00130.98           N  \\nATOM   2588  C8   DA I 127      89.261  69.783  -2.050  1.00130.98           C  \\nATOM   2589  N7   DA I 127      88.247  70.466  -1.573  1.00130.98           N  \\nATOM   2590  C5   DA I 127      87.293  70.393  -2.579  1.00130.98           C  \\nATOM   2591  C6   DA I 127      85.990  70.908  -2.682  1.00130.98           C  \\nATOM   2592  N6   DA I 127      85.399  71.630  -1.725  1.00130.98           N  \\nATOM   2593  N1   DA I 127      85.304  70.651  -3.817  1.00130.98           N  \\nATOM   2594  C2   DA I 127      85.897  69.932  -4.780  1.00130.98           C  \\nATOM   2595  N3   DA I 127      87.113  69.395  -4.802  1.00130.98           N  \\nATOM   2596  C4   DA I 127      87.769  69.660  -3.657  1.00130.98           C  \\nATOM   2597  P    DT I 128      93.154  68.338  -6.470  1.00175.78           P  \\nATOM   2598  OP1  DT I 128      93.865  67.626  -7.565  1.00175.78           O  \\nATOM   2599  OP2  DT I 128      93.922  69.238  -5.570  1.00175.78           O  \\nATOM   2600  O5'  DT I 128      91.939  69.156  -7.102  1.00146.66           O  \\nATOM   2601  C5'  DT I 128      90.905  68.480  -7.827  1.00146.66           C  \\nATOM   2602  C4'  DT I 128      90.127  69.464  -8.668  1.00146.66           C  \\nATOM   2603  O4'  DT I 128      88.994  69.998  -7.938  1.00146.66           O  \\nATOM   2604  C3'  DT I 128      90.962  70.666  -9.110  1.00146.66           C  \\nATOM   2605  O3'  DT I 128      90.718  70.976 -10.480  1.00146.66           O  \\nATOM   2606  C2'  DT I 128      90.471  71.786  -8.214  1.00146.66           C  \\nATOM   2607  C1'  DT I 128      89.014  71.413  -8.016  1.00146.66           C  \\nATOM   2608  N1   DT I 128      88.417  71.963  -6.782  1.00109.45           N  \\nATOM   2609  C2   DT I 128      87.085  72.327  -6.803  1.00109.45           C  \\nATOM   2610  O2   DT I 128      86.357  72.152  -7.774  1.00109.45           O  \\nATOM   2611  N3   DT I 128      86.634  72.907  -5.632  1.00109.45           N  \\nATOM   2612  C4   DT I 128      87.357  73.123  -4.465  1.00109.45           C  \\nATOM   2613  O4   DT I 128      86.815  73.658  -3.493  1.00109.45           O  \\nATOM   2614  C5   DT I 128      88.736  72.686  -4.508  1.00109.45           C  \\nATOM   2615  C7   DT I 128      89.593  72.869  -3.295  1.00109.45           C  \\nATOM   2616  C6   DT I 128      89.189  72.135  -5.646  1.00109.45           C  \\nATOM   2617  P    DC I 129      91.267  72.356 -11.088  1.00107.64           P  \\nATOM   2618  OP1  DC I 129      91.479  72.189 -12.555  1.00107.64           O  \\nATOM   2619  OP2  DC I 129      92.398  72.802 -10.222  1.00107.64           O  \\nATOM   2620  O5'  DC I 129      90.036  73.346 -10.871  1.00101.14           O  \\nATOM   2621  C5'  DC I 129      88.709  72.949 -11.231  1.00101.14           C  \\nATOM   2622  C4'  DC I 129      87.882  74.149 -11.632  1.00101.14           C  \\nATOM   2623  O4'  DC I 129      87.173  74.566 -10.442  1.00101.14           O  \\nATOM   2624  C3'  DC I 129      88.668  75.373 -12.120  1.00101.14           C  \\nATOM   2625  O3'  DC I 129      88.316  75.867 -13.431  1.00101.14           O  \\nATOM   2626  C2'  DC I 129      88.559  76.403 -11.014  1.00101.14           C  \\nATOM   2627  C1'  DC I 129      87.402  75.940 -10.147  1.00101.14           C  \\nATOM   2628  N1   DC I 129      87.731  76.050  -8.713  1.00 95.28           N  \\nATOM   2629  C2   DC I 129      86.726  76.408  -7.795  1.00 95.28           C  \\nATOM   2630  O2   DC I 129      85.564  76.576  -8.200  1.00 95.28           O  \\nATOM   2631  N3   DC I 129      87.050  76.560  -6.489  1.00 95.28           N  \\nATOM   2632  C4   DC I 129      88.309  76.362  -6.086  1.00 95.28           C  \\nATOM   2633  N4   DC I 129      88.586  76.545  -4.789  1.00 95.28           N  \\nATOM   2634  C5   DC I 129      89.341  75.974  -6.992  1.00 95.28           C  \\nATOM   2635  C6   DC I 129      89.010  75.828  -8.281  1.00 95.28           C  \\nATOM   2636  P    DT I 130      86.779  76.010 -13.890  1.00 83.96           P  \\nATOM   2637  OP1  DT I 130      86.086  74.707 -13.661  1.00 83.96           O  \\nATOM   2638  OP2  DT I 130      86.814  76.594 -15.259  1.00 83.96           O  \\nATOM   2639  O5'  DT I 130      86.133  77.125 -12.949  1.00 71.24           O  \\nATOM   2640  C5'  DT I 130      84.704  77.268 -12.879  1.00 71.24           C  \\nATOM   2641  C4'  DT I 130      84.315  78.633 -12.359  1.00 71.24           C  \\nATOM   2642  O4'  DT I 130      84.863  78.869 -11.043  1.00 71.24           O  \\nATOM   2643  C3'  DT I 130      84.762  79.822 -13.197  1.00 71.24           C  \\nATOM   2644  O3'  DT I 130      83.782  80.825 -13.014  1.00 71.24           O  \\nATOM   2645  C2'  DT I 130      86.013  80.287 -12.481  1.00 71.24           C  \\nATOM   2646  C1'  DT I 130      85.575  80.097 -11.046  1.00 71.24           C  \\nATOM   2647  N1   DT I 130      86.652  79.985 -10.060  1.00 91.95           N  \\nATOM   2648  C2   DT I 130      86.447  80.513  -8.804  1.00 91.95           C  \\nATOM   2649  O2   DT I 130      85.438  81.120  -8.483  1.00 91.95           O  \\nATOM   2650  N3   DT I 130      87.475  80.302  -7.928  1.00 91.95           N  \\nATOM   2651  C4   DT I 130      88.666  79.649  -8.173  1.00 91.95           C  \\nATOM   2652  O4   DT I 130      89.483  79.518  -7.267  1.00 91.95           O  \\nATOM   2653  C5   DT I 130      88.827  79.156  -9.524  1.00 91.95           C  \\nATOM   2654  C7   DT I 130      90.093  78.459  -9.900  1.00 91.95           C  \\nATOM   2655  C6   DT I 130      87.826  79.347 -10.386  1.00 91.95           C  \\nATOM   2656  P    DG I 131      82.843  81.247 -14.227  1.00 52.84           P  \\nATOM   2657  OP1  DG I 131      82.040  80.068 -14.636  1.00 52.84           O  \\nATOM   2658  OP2  DG I 131      83.707  81.939 -15.216  1.00 52.84           O  \\nATOM   2659  O5'  DG I 131      81.870  82.321 -13.570  1.00 44.44           O  \\nATOM   2660  C5'  DG I 131      80.932  81.943 -12.560  1.00 44.44           C  \\nATOM   2661  C4'  DG I 131      80.717  83.073 -11.578  1.00 44.44           C  \\nATOM   2662  O4'  DG I 131      81.837  83.228 -10.677  1.00 44.44           O  \\nATOM   2663  C3'  DG I 131      80.442  84.460 -12.147  1.00 44.44           C  \\nATOM   2664  O3'  DG I 131      79.424  85.037 -11.319  1.00 44.44           O  \\nATOM   2665  C2'  DG I 131      81.797  85.154 -12.035  1.00 44.44           C  \\nATOM   2666  C1'  DG I 131      82.462  84.500 -10.826  1.00 44.44           C  \\nATOM   2667  N9   DG I 131      83.898  84.238 -10.952  1.00 54.66           N  \\nATOM   2668  C8   DG I 131      84.568  83.842 -12.088  1.00 54.66           C  \\nATOM   2669  N7   DG I 131      85.812  83.507 -11.862  1.00 54.66           N  \\nATOM   2670  C5   DG I 131      85.990  83.731 -10.502  1.00 54.66           C  \\nATOM   2671  C6   DG I 131      87.125  83.505  -9.670  1.00 54.66           C  \\nATOM   2672  O6   DG I 131      88.218  83.015  -9.970  1.00 54.66           O  \\nATOM   2673  N1   DG I 131      86.881  83.889  -8.361  1.00 54.66           N  \\nATOM   2674  C2   DG I 131      85.698  84.395  -7.897  1.00 54.66           C  \\nATOM   2675  N2   DG I 131      85.681  84.692  -6.594  1.00 54.66           N  \\nATOM   2676  N3   DG I 131      84.622  84.588  -8.647  1.00 54.66           N  \\nATOM   2677  C4   DG I 131      84.836  84.235  -9.933  1.00 54.66           C  \\nATOM   2678  P    DC I 132      78.863  86.515 -11.601  1.00 51.60           P  \\nATOM   2679  OP1  DC I 132      77.475  86.504 -11.074  1.00 51.60           O  \\nATOM   2680  OP2  DC I 132      79.104  86.880 -13.017  1.00 51.60           O  \\nATOM   2681  O5'  DC I 132      79.732  87.408 -10.611  1.00 42.51           O  \\nATOM   2682  C5'  DC I 132      80.189  86.851  -9.379  1.00 42.51           C  \\nATOM   2683  C4'  DC I 132      81.082  87.825  -8.652  1.00 42.51           C  \\nATOM   2684  O4'  DC I 132      82.471  87.439  -8.795  1.00 42.51           O  \\nATOM   2685  C3'  DC I 132      80.997  89.261  -9.159  1.00 42.51           C  \\nATOM   2686  O3'  DC I 132      81.233  90.143  -8.058  1.00 42.51           O  \\nATOM   2687  C2'  DC I 132      82.176  89.344 -10.108  1.00 42.51           C  \\nATOM   2688  C1'  DC I 132      83.201  88.521  -9.349  1.00 42.51           C  \\nATOM   2689  N1   DC I 132      84.289  87.964 -10.168  1.00 51.98           N  \\nATOM   2690  C2   DC I 132      85.429  87.489  -9.519  1.00 51.98           C  \\nATOM   2691  O2   DC I 132      85.501  87.594  -8.288  1.00 51.98           O  \\nATOM   2692  N3   DC I 132      86.423  86.936 -10.254  1.00 51.98           N  \\nATOM   2693  C4   DC I 132      86.313  86.872 -11.593  1.00 51.98           C  \\nATOM   2694  N4   DC I 132      87.319  86.323 -12.283  1.00 51.98           N  \\nATOM   2695  C5   DC I 132      85.167  87.370 -12.280  1.00 51.98           C  \\nATOM   2696  C6   DC I 132      84.189  87.901 -11.536  1.00 51.98           C  \\nATOM   2697  P    DA I 133      80.090  91.167  -7.580  1.00 53.13           P  \\nATOM   2698  OP1  DA I 133      78.852  90.350  -7.428  1.00 53.13           O  \\nATOM   2699  OP2  DA I 133      80.077  92.373  -8.459  1.00 53.13           O  \\nATOM   2700  O5'  DA I 133      80.622  91.604  -6.146  1.00 68.57           O  \\nATOM   2701  C5'  DA I 133      80.997  90.618  -5.182  1.00 68.57           C  \\nATOM   2702  C4'  DA I 133      82.263  91.026  -4.462  1.00 68.57           C  \\nATOM   2703  O4'  DA I 133      83.414  90.883  -5.327  1.00 68.57           O  \\nATOM   2704  C3'  DA I 133      82.287  92.466  -3.961  1.00 68.57           C  \\nATOM   2705  O3'  DA I 133      83.004  92.523  -2.730  1.00 68.57           O  \\nATOM   2706  C2'  DA I 133      83.024  93.204  -5.064  1.00 68.57           C  \\nATOM   2707  C1'  DA I 133      83.992  92.152  -5.604  1.00 68.57           C  \\nATOM   2708  N9   DA I 133      84.208  92.210  -7.047  1.00 67.29           N  \\nATOM   2709  C8   DA I 133      83.419  92.769  -8.036  1.00 67.29           C  \\nATOM   2710  N7   DA I 133      83.876  92.570  -9.248  1.00 67.29           N  \\nATOM   2711  C5   DA I 133      85.049  91.847  -9.041  1.00 67.29           C  \\nATOM   2712  C6   DA I 133      85.994  91.312  -9.921  1.00 67.29           C  \\nATOM   2713  N6   DA I 133      85.906  91.412 -11.244  1.00 67.29           N  \\nATOM   2714  N1   DA I 133      87.047  90.654  -9.390  1.00 67.29           N  \\nATOM   2715  C2   DA I 133      87.137  90.550  -8.063  1.00 67.29           C  \\nATOM   2716  N3   DA I 133      86.313  91.004  -7.131  1.00 67.29           N  \\nATOM   2717  C4   DA I 133      85.275  91.645  -7.692  1.00 67.29           C  \\nATOM   2718  P    DG I 134      82.938  93.847  -1.832  1.00 71.31           P  \\nATOM   2719  OP1  DG I 134      82.165  93.571  -0.602  1.00 71.31           O  \\nATOM   2720  OP2  DG I 134      82.560  94.997  -2.691  1.00 71.31           O  \\nATOM   2721  O5'  DG I 134      84.450  94.035  -1.409  1.00 72.42           O  \\nATOM   2722  C5'  DG I 134      85.085  95.273  -1.619  1.00 72.42           C  \\nATOM   2723  C4'  DG I 134      86.452  95.064  -2.215  1.00 72.42           C  \\nATOM   2724  O4'  DG I 134      86.382  94.500  -3.553  1.00 72.42           O  \\nATOM   2725  C3'  DG I 134      87.161  96.399  -2.356  1.00 72.42           C  \\nATOM   2726  O3'  DG I 134      88.515  96.244  -1.986  1.00 72.42           O  \\nATOM   2727  C2'  DG I 134      87.031  96.726  -3.828  1.00 72.42           C  \\nATOM   2728  C1'  DG I 134      87.067  95.352  -4.463  1.00 72.42           C  \\nATOM   2729  N9   DG I 134      86.387  95.310  -5.757  1.00 53.77           N  \\nATOM   2730  C8   DG I 134      85.109  95.749  -6.045  1.00 53.77           C  \\nATOM   2731  N7   DG I 134      84.783  95.610  -7.306  1.00 53.77           N  \\nATOM   2732  C5   DG I 134      85.906  95.032  -7.885  1.00 53.77           C  \\nATOM   2733  C6   DG I 134      86.138  94.638  -9.220  1.00 53.77           C  \\nATOM   2734  O6   DG I 134      85.364  94.698 -10.183  1.00 53.77           O  \\nATOM   2735  N1   DG I 134      87.422  94.121  -9.382  1.00 53.77           N  \\nATOM   2736  C2   DG I 134      88.356  93.994  -8.378  1.00 53.77           C  \\nATOM   2737  N2   DG I 134      89.541  93.503  -8.751  1.00 53.77           N  \\nATOM   2738  N3   DG I 134      88.145  94.332  -7.118  1.00 53.77           N  \\nATOM   2739  C4   DG I 134      86.909  94.845  -6.943  1.00 53.77           C  \\nATOM   2740  P    DG I 135      89.323  97.505  -1.441  1.00121.64           P  \\nATOM   2741  OP1  DG I 135      89.552  97.299   0.011  1.00121.64           O  \\nATOM   2742  OP2  DG I 135      88.585  98.710  -1.912  1.00121.64           O  \\nATOM   2743  O5'  DG I 135      90.707  97.393  -2.217  1.00 79.97           O  \\nATOM   2744  C5'  DG I 135      90.749  96.792  -3.505  1.00 79.97           C  \\nATOM   2745  C4'  DG I 135      91.858  97.388  -4.336  1.00 79.97           C  \\nATOM   2746  O4'  DG I 135      91.615  96.934  -5.690  1.00 79.97           O  \\nATOM   2747  C3'  DG I 135      91.848  98.918  -4.392  1.00 79.97           C  \\nATOM   2748  O3'  DG I 135      93.179  99.452  -4.509  1.00 79.97           O  \\nATOM   2749  C2'  DG I 135      91.019  99.214  -5.621  1.00 79.97           C  \\nATOM   2750  C1'  DG I 135      91.314  98.034  -6.526  1.00 79.97           C  \\nATOM   2751  N9   DG I 135      90.146  97.695  -7.322  1.00 55.24           N  \\nATOM   2752  C8   DG I 135      88.833  97.824  -6.952  1.00 55.24           C  \\nATOM   2753  N7   DG I 135      88.004  97.554  -7.917  1.00 55.24           N  \\nATOM   2754  C5   DG I 135      88.822  97.198  -8.974  1.00 55.24           C  \\nATOM   2755  C6   DG I 135      88.497  96.816 -10.288  1.00 55.24           C  \\nATOM   2756  O6   DG I 135      87.383  96.703 -10.808  1.00 55.24           O  \\nATOM   2757  N1   DG I 135      89.637  96.549 -11.037  1.00 55.24           N  \\nATOM   2758  C2   DG I 135      90.924  96.627 -10.572  1.00 55.24           C  \\nATOM   2759  N2   DG I 135      91.884  96.320 -11.449  1.00 55.24           N  \\nATOM   2760  N3   DG I 135      91.239  96.979  -9.342  1.00 55.24           N  \\nATOM   2761  C4   DG I 135      90.146  97.255  -8.607  1.00 55.24           C  \\nATOM   2762  P    DT I 136      93.435 100.824  -5.324  1.00 85.90           P  \\nATOM   2763  OP1  DT I 136      94.750 101.374  -4.906  1.00 85.90           O  \\nATOM   2764  OP2  DT I 136      92.223 101.683  -5.257  1.00 85.90           O  \\nATOM   2765  O5'  DT I 136      93.566 100.340  -6.834  1.00 99.73           O  \\nATOM   2766  C5'  DT I 136      94.698  99.590  -7.265  1.00 99.73           C  \\nATOM   2767  C4'  DT I 136      95.167 100.108  -8.602  1.00 99.73           C  \\nATOM   2768  O4'  DT I 136      94.196  99.731  -9.609  1.00 99.73           O  \\nATOM   2769  C3'  DT I 136      95.250 101.634  -8.637  1.00 99.73           C  \\nATOM   2770  O3'  DT I 136      96.374 102.093  -9.396  1.00 99.73           O  \\nATOM   2771  C2'  DT I 136      93.949 102.044  -9.294  1.00 99.73           C  \\nATOM   2772  C1'  DT I 136      93.644 100.885 -10.227  1.00 99.73           C  \\nATOM   2773  N1   DT I 136      92.191 100.682 -10.355  1.00 66.59           N  \\nATOM   2774  C2   DT I 136      91.627 100.417 -11.591  1.00 66.59           C  \\nATOM   2775  O2   DT I 136      92.271 100.268 -12.616  1.00 66.59           O  \\nATOM   2776  N3   DT I 136      90.268 100.323 -11.578  1.00 66.59           N  \\nATOM   2777  C4   DT I 136      89.431 100.435 -10.485  1.00 66.59           C  \\nATOM   2778  O4   DT I 136      88.219 100.325 -10.643  1.00 66.59           O  \\nATOM   2779  C5   DT I 136      90.095 100.679  -9.218  1.00 66.59           C  \\nATOM   2780  C7   DT I 136      89.286 100.794  -7.966  1.00 66.59           C  \\nATOM   2781  C6   DT I 136      91.417 100.789  -9.223  1.00 66.59           C  \\nATOM   2782  P    DG I 137      96.339 103.559 -10.062  1.00111.43           P  \\nATOM   2783  OP1  DG I 137      97.722 103.971 -10.392  1.00111.43           O  \\nATOM   2784  OP2  DG I 137      95.492 104.458  -9.228  1.00111.43           O  \\nATOM   2785  O5'  DG I 137      95.577 103.276 -11.425  1.00112.14           O  \\nATOM   2786  C5'  DG I 137      96.137 102.405 -12.406  1.00112.14           C  \\nATOM   2787  C4'  DG I 137      95.875 102.969 -13.780  1.00112.14           C  \\nATOM   2788  O4'  DG I 137      94.462 102.837 -14.068  1.00112.14           O  \\nATOM   2789  C3'  DG I 137      96.178 104.465 -13.824  1.00112.14           C  \\nATOM   2790  O3'  DG I 137      96.689 104.874 -15.097  1.00112.14           O  \\nATOM   2791  C2'  DG I 137      94.840 105.106 -13.504  1.00112.14           C  \\nATOM   2792  C1'  DG I 137      93.827 104.112 -14.058  1.00112.14           C  \\nATOM   2793  N9   DG I 137      92.616 104.004 -13.246  1.00 71.97           N  \\nATOM   2794  C8   DG I 137      92.495 104.212 -11.884  1.00 71.97           C  \\nATOM   2795  N7   DG I 137      91.275 104.049 -11.447  1.00 71.97           N  \\nATOM   2796  C5   DG I 137      90.550 103.709 -12.583  1.00 71.97           C  \\nATOM   2797  C6   DG I 137      89.187 103.418 -12.736  1.00 71.97           C  \\nATOM   2798  O6   DG I 137      88.316 103.381 -11.865  1.00 71.97           O  \\nATOM   2799  N1   DG I 137      88.867 103.149 -14.064  1.00 71.97           N  \\nATOM   2800  C2   DG I 137      89.754 103.149 -15.109  1.00 71.97           C  \\nATOM   2801  N2   DG I 137      89.251 102.863 -16.309  1.00 71.97           N  \\nATOM   2802  N3   DG I 137      91.033 103.410 -14.982  1.00 71.97           N  \\nATOM   2803  C4   DG I 137      91.363 103.682 -13.700  1.00 71.97           C  \\nATOM   2804  P    DG I 138      96.674 106.432 -15.491  1.00106.48           P  \\nATOM   2805  OP1  DG I 138      97.622 106.655 -16.610  1.00106.48           O  \\nATOM   2806  OP2  DG I 138      96.781 107.256 -14.255  1.00106.48           O  \\nATOM   2807  O5'  DG I 138      95.206 106.636 -16.049  1.00108.29           O  \\nATOM   2808  C5'  DG I 138      94.733 105.843 -17.125  1.00108.29           C  \\nATOM   2809  C4'  DG I 138      93.495 106.476 -17.698  1.00108.29           C  \\nATOM   2810  O4'  DG I 138      92.394 106.312 -16.779  1.00108.29           O  \\nATOM   2811  C3'  DG I 138      93.646 107.982 -17.889  1.00108.29           C  \\nATOM   2812  O3'  DG I 138      92.822 108.340 -18.986  1.00108.29           O  \\nATOM   2813  C2'  DG I 138      93.066 108.543 -16.604  1.00108.29           C  \\nATOM   2814  C1'  DG I 138      91.909 107.592 -16.421  1.00108.29           C  \\nATOM   2815  N9   DG I 138      91.300 107.490 -15.104  1.00 47.71           N  \\nATOM   2816  C8   DG I 138      91.811 107.822 -13.868  1.00 47.71           C  \\nATOM   2817  N7   DG I 138      90.960 107.616 -12.896  1.00 47.71           N  \\nATOM   2818  C5   DG I 138      89.834 107.112 -13.537  1.00 47.71           C  \\nATOM   2819  C6   DG I 138      88.587 106.706 -13.024  1.00 47.71           C  \\nATOM   2820  O6   DG I 138      88.205 106.668 -11.838  1.00 47.71           O  \\nATOM   2821  N1   DG I 138      87.730 106.297 -14.044  1.00 47.71           N  \\nATOM   2822  C2   DG I 138      88.047 106.253 -15.377  1.00 47.71           C  \\nATOM   2823  N2   DG I 138      87.093 105.829 -16.215  1.00 47.71           N  \\nATOM   2824  N3   DG I 138      89.206 106.602 -15.857  1.00 47.71           N  \\nATOM   2825  C4   DG I 138      90.041 107.028 -14.894  1.00 47.71           C  \\nATOM   2826  P    DA I 139      93.040 109.736 -19.730  1.00 87.47           P  \\nATOM   2827  OP1  DA I 139      94.239 109.625 -20.595  1.00 87.47           O  \\nATOM   2828  OP2  DA I 139      92.946 110.826 -18.723  1.00 87.47           O  \\nATOM   2829  O5'  DA I 139      91.752 109.811 -20.651  1.00 58.85           O  \\nATOM   2830  C5'  DA I 139      91.129 108.618 -21.105  1.00 58.85           C  \\nATOM   2831  C4'  DA I 139      89.644 108.684 -20.846  1.00 58.85           C  \\nATOM   2832  O4'  DA I 139      89.343 108.430 -19.450  1.00 58.85           O  \\nATOM   2833  C3'  DA I 139      89.012 110.035 -21.184  1.00 58.85           C  \\nATOM   2834  O3'  DA I 139      87.791 109.821 -21.896  1.00 58.85           O  \\nATOM   2835  C2'  DA I 139      88.741 110.648 -19.819  1.00 58.85           C  \\nATOM   2836  C1'  DA I 139      88.441 109.418 -18.983  1.00 58.85           C  \\nATOM   2837  N9   DA I 139      88.651 109.588 -17.546  1.00 41.52           N  \\nATOM   2838  C8   DA I 139      89.836 109.847 -16.900  1.00 41.52           C  \\nATOM   2839  N7   DA I 139      89.714 109.977 -15.599  1.00 41.52           N  \\nATOM   2840  C5   DA I 139      88.359 109.779 -15.369  1.00 41.52           C  \\nATOM   2841  C6   DA I 139      87.595 109.776 -14.191  1.00 41.52           C  \\nATOM   2842  N6   DA I 139      88.117 109.966 -12.977  1.00 41.52           N  \\nATOM   2843  N1   DA I 139      86.265 109.560 -14.304  1.00 41.52           N  \\nATOM   2844  C2   DA I 139      85.753 109.339 -15.526  1.00 41.52           C  \\nATOM   2845  N3   DA I 139      86.371 109.297 -16.706  1.00 41.52           N  \\nATOM   2846  C4   DA I 139      87.689 109.533 -16.558  1.00 41.52           C  \\nATOM   2847  P    DT I 140      87.167 111.004 -22.789  1.00 84.09           P  \\nATOM   2848  OP1  DT I 140      86.761 110.435 -24.104  1.00 84.09           O  \\nATOM   2849  OP2  DT I 140      88.085 112.178 -22.736  1.00 84.09           O  \\nATOM   2850  O5'  DT I 140      85.841 111.398 -22.001  1.00 83.73           O  \\nATOM   2851  C5'  DT I 140      84.924 110.398 -21.555  1.00 83.73           C  \\nATOM   2852  C4'  DT I 140      83.999 110.977 -20.511  1.00 83.73           C  \\nATOM   2853  O4'  DT I 140      84.605 111.019 -19.192  1.00 83.73           O  \\nATOM   2854  C3'  DT I 140      83.533 112.405 -20.804  1.00 83.73           C  \\nATOM   2855  O3'  DT I 140      82.175 112.497 -20.407  1.00 83.73           O  \\nATOM   2856  C2'  DT I 140      84.351 113.233 -19.827  1.00 83.73           C  \\nATOM   2857  C1'  DT I 140      84.355 112.301 -18.635  1.00 83.73           C  \\nATOM   2858  N1   DT I 140      85.341 112.567 -17.558  1.00 60.47           N  \\nATOM   2859  C2   DT I 140      84.890 112.528 -16.242  1.00 60.47           C  \\nATOM   2860  O2   DT I 140      83.740 112.253 -15.926  1.00 60.47           O  \\nATOM   2861  N3   DT I 140      85.845 112.818 -15.298  1.00 60.47           N  \\nATOM   2862  C4   DT I 140      87.177 113.123 -15.517  1.00 60.47           C  \\nATOM   2863  O4   DT I 140      87.914 113.370 -14.563  1.00 60.47           O  \\nATOM   2864  C5   DT I 140      87.587 113.121 -16.909  1.00 60.47           C  \\nATOM   2865  C7   DT I 140      89.016 113.413 -17.239  1.00 60.47           C  \\nATOM   2866  C6   DT I 140      86.660 112.852 -17.847  1.00 60.47           C  \\nATOM   2867  P    DA I 141      81.047 112.942 -21.452  1.00 98.02           P  \\nATOM   2868  OP1  DA I 141      80.978 111.958 -22.565  1.00 98.02           O  \\nATOM   2869  OP2  DA I 141      81.254 114.385 -21.757  1.00 98.02           O  \\nATOM   2870  O5'  DA I 141      79.741 112.792 -20.552  1.00 77.28           O  \\nATOM   2871  C5'  DA I 141      79.650 111.742 -19.572  1.00 77.28           C  \\nATOM   2872  C4'  DA I 141      79.236 112.283 -18.218  1.00 77.28           C  \\nATOM   2873  O4'  DA I 141      80.339 112.651 -17.360  1.00 77.28           O  \\nATOM   2874  C3'  DA I 141      78.306 113.488 -18.224  1.00 77.28           C  \\nATOM   2875  O3'  DA I 141      77.341 113.312 -17.210  1.00 77.28           O  \\nATOM   2876  C2'  DA I 141      79.206 114.629 -17.805  1.00 77.28           C  \\nATOM   2877  C1'  DA I 141      80.067 113.923 -16.793  1.00 77.28           C  \\nATOM   2878  N9   DA I 141      81.340 114.572 -16.522  1.00 41.39           N  \\nATOM   2879  C8   DA I 141      82.301 115.006 -17.401  1.00 41.39           C  \\nATOM   2880  N7   DA I 141      83.372 115.487 -16.816  1.00 41.39           N  \\nATOM   2881  C5   DA I 141      83.086 115.373 -15.461  1.00 41.39           C  \\nATOM   2882  C6   DA I 141      83.819 115.697 -14.307  1.00 41.39           C  \\nATOM   2883  N6   DA I 141      85.057 116.199 -14.326  1.00 41.39           N  \\nATOM   2884  N1   DA I 141      83.228 115.476 -13.114  1.00 41.39           N  \\nATOM   2885  C2   DA I 141      81.993 114.958 -13.089  1.00 41.39           C  \\nATOM   2886  N3   DA I 141      81.212 114.601 -14.102  1.00 41.39           N  \\nATOM   2887  C4   DA I 141      81.827 114.836 -15.271  1.00 41.39           C  \\nATOM   2888  P    DT I 142      75.820 113.641 -17.529  1.00 89.61           P  \\nATOM   2889  OP1  DT I 142      75.130 112.405 -17.987  1.00 89.61           O  \\nATOM   2890  OP2  DT I 142      75.806 114.866 -18.379  1.00 89.61           O  \\nATOM   2891  O5'  DT I 142      75.267 114.038 -16.113  1.00 62.85           O  \\nATOM   2892  C5'  DT I 142      75.496 115.328 -15.638  1.00 62.85           C  \\nATOM   2893  C4'  DT I 142      75.937 115.261 -14.205  1.00 62.85           C  \\nATOM   2894  O4'  DT I 142      77.377 115.412 -14.135  1.00 62.85           O  \\nATOM   2895  C3'  DT I 142      75.342 116.419 -13.418  1.00 62.85           C  \\nATOM   2896  O3'  DT I 142      74.886 115.950 -12.161  1.00 62.85           O  \\nATOM   2897  C2'  DT I 142      76.478 117.421 -13.307  1.00 62.85           C  \\nATOM   2898  C1'  DT I 142      77.709 116.541 -13.334  1.00 62.85           C  \\nATOM   2899  N1   DT I 142      78.884 117.203 -13.925  1.00 53.31           N  \\nATOM   2900  C2   DT I 142      79.854 117.660 -13.058  1.00 53.31           C  \\nATOM   2901  O2   DT I 142      79.775 117.543 -11.840  1.00 53.31           O  \\nATOM   2902  N3   DT I 142      80.926 118.264 -13.668  1.00 53.31           N  \\nATOM   2903  C4   DT I 142      81.119 118.453 -15.019  1.00 53.31           C  \\nATOM   2904  O4   DT I 142      82.135 119.015 -15.408  1.00 53.31           O  \\nATOM   2905  C5   DT I 142      80.063 117.950 -15.871  1.00 53.31           C  \\nATOM   2906  C7   DT I 142      80.193 118.103 -17.351  1.00 53.31           C  \\nATOM   2907  C6   DT I 142      79.011 117.361 -15.290  1.00 53.31           C  \\nATOM   2908  P    DT I 143      73.749 116.764 -11.398  1.00 50.87           P  \\nATOM   2909  OP1  DT I 143      73.107 115.840 -10.426  1.00 50.87           O  \\nATOM   2910  OP2  DT I 143      72.931 117.423 -12.455  1.00 50.87           O  \\nATOM   2911  O5'  DT I 143      74.586 117.854 -10.595  1.00 52.75           O  \\nATOM   2912  C5'  DT I 143      75.529 117.439  -9.614  1.00 52.75           C  \\nATOM   2913  C4'  DT I 143      76.327 118.613  -9.100  1.00 52.75           C  \\nATOM   2914  O4'  DT I 143      77.414 118.975  -9.988  1.00 52.75           O  \\nATOM   2915  C3'  DT I 143      75.532 119.892  -8.844  1.00 52.75           C  \\nATOM   2916  O3'  DT I 143      75.847 120.366  -7.532  1.00 52.75           O  \\nATOM   2917  C2'  DT I 143      76.039 120.846  -9.915  1.00 52.75           C  \\nATOM   2918  C1'  DT I 143      77.474 120.385 -10.086  1.00 52.75           C  \\nATOM   2919  N1   DT I 143      78.118 120.732 -11.365  1.00 39.29           N  \\nATOM   2920  C2   DT I 143      79.389 121.262 -11.319  1.00 39.29           C  \\nATOM   2921  O2   DT I 143      80.001 121.462 -10.273  1.00 39.29           O  \\nATOM   2922  N3   DT I 143      79.926 121.551 -12.550  1.00 39.29           N  \\nATOM   2923  C4   DT I 143      79.333 121.373 -13.788  1.00 39.29           C  \\nATOM   2924  O4   DT I 143      79.949 121.679 -14.813  1.00 39.29           O  \\nATOM   2925  C5   DT I 143      78.004 120.819 -13.758  1.00 39.29           C  \\nATOM   2926  C7   DT I 143      77.288 120.593 -15.051  1.00 39.29           C  \\nATOM   2927  C6   DT I 143      77.469 120.529 -12.564  1.00 39.29           C  \\nATOM   2928  P    DG I 144      74.960 121.526  -6.861  1.00 47.55           P  \\nATOM   2929  OP1  DG I 144      74.698 121.199  -5.437  1.00 47.55           O  \\nATOM   2930  OP2  DG I 144      73.825 121.821  -7.773  1.00 47.55           O  \\nATOM   2931  O5'  DG I 144      75.965 122.750  -6.856  1.00 82.56           O  \\nATOM   2932  C5'  DG I 144      77.159 122.687  -6.089  1.00 82.56           C  \\nATOM   2933  C4'  DG I 144      77.953 123.949  -6.296  1.00 82.56           C  \\nATOM   2934  O4'  DG I 144      78.575 123.924  -7.601  1.00 82.56           O  \\nATOM   2935  C3'  DG I 144      77.083 125.205  -6.261  1.00 82.56           C  \\nATOM   2936  O3'  DG I 144      77.749 126.200  -5.487  1.00 82.56           O  \\nATOM   2937  C2'  DG I 144      76.931 125.579  -7.726  1.00 82.56           C  \\nATOM   2938  C1'  DG I 144      78.242 125.101  -8.304  1.00 82.56           C  \\nATOM   2939  N9   DG I 144      78.214 124.789  -9.725  1.00 43.55           N  \\nATOM   2940  C8   DG I 144      77.147 124.358 -10.478  1.00 43.55           C  \\nATOM   2941  N7   DG I 144      77.434 124.234 -11.751  1.00 43.55           N  \\nATOM   2942  C5   DG I 144      78.778 124.588 -11.836  1.00 43.55           C  \\nATOM   2943  C6   DG I 144      79.649 124.676 -12.970  1.00 43.55           C  \\nATOM   2944  O6   DG I 144      79.394 124.441 -14.164  1.00 43.55           O  \\nATOM   2945  N1   DG I 144      80.930 125.093 -12.599  1.00 43.55           N  \\nATOM   2946  C2   DG I 144      81.329 125.378 -11.304  1.00 43.55           C  \\nATOM   2947  N2   DG I 144      82.614 125.737 -11.143  1.00 43.55           N  \\nATOM   2948  N3   DG I 144      80.529 125.311 -10.250  1.00 43.55           N  \\nATOM   2949  C4   DG I 144      79.277 124.915 -10.588  1.00 43.55           C  \\nATOM   2950  P    DA I 145      77.299 127.736  -5.581  1.00 80.34           P  \\nATOM   2951  OP1  DA I 145      77.036 128.227  -4.199  1.00 80.34           O  \\nATOM   2952  OP2  DA I 145      76.242 127.875  -6.628  1.00 80.34           O  \\nATOM   2953  O5'  DA I 145      78.641 128.412  -6.099  1.00 66.94           O  \\nATOM   2954  C5'  DA I 145      79.915 128.027  -5.575  1.00 66.94           C  \\nATOM   2955  C4'  DA I 145      80.984 128.823  -6.279  1.00 66.94           C  \\nATOM   2956  O4'  DA I 145      81.139 128.254  -7.599  1.00 66.94           O  \\nATOM   2957  C3'  DA I 145      80.486 130.256  -6.486  1.00 66.94           C  \\nATOM   2958  O3'  DA I 145      81.434 131.297  -6.294  1.00 66.94           O  \\nATOM   2959  C2'  DA I 145      80.033 130.295  -7.922  1.00 66.94           C  \\nATOM   2960  C1'  DA I 145      80.873 129.235  -8.580  1.00 66.94           C  \\nATOM   2961  N9   DA I 145      80.030 128.648  -9.597  1.00 35.04           N  \\nATOM   2962  C8   DA I 145      78.795 128.088  -9.435  1.00 35.04           C  \\nATOM   2963  N7   DA I 145      78.194 127.806 -10.566  1.00 35.04           N  \\nATOM   2964  C5   DA I 145      79.116 128.174 -11.528  1.00 35.04           C  \\nATOM   2965  C6   DA I 145      79.076 128.151 -12.915  1.00 35.04           C  \\nATOM   2966  N6   DA I 145      78.000 127.778 -13.615  1.00 35.04           N  \\nATOM   2967  N1   DA I 145      80.185 128.555 -13.582  1.00 35.04           N  \\nATOM   2968  C2   DA I 145      81.238 128.990 -12.874  1.00 35.04           C  \\nATOM   2969  N3   DA I 145      81.379 129.087 -11.563  1.00 35.04           N  \\nATOM   2970  C4   DA I 145      80.270 128.652 -10.942  1.00 35.04           C  \\nATOM   2971  P    DT I 146      80.908 132.819  -6.318  1.00 79.53           P  \\nATOM   2972  OP1  DT I 146      80.973 133.380  -4.940  1.00 79.53           O  \\nATOM   2973  OP2  DT I 146      79.613 132.831  -7.059  1.00 79.53           O  \\nATOM   2974  O5'  DT I 146      81.967 133.557  -7.237  1.00 74.83           O  \\nATOM   2975  C5'  DT I 146      83.074 132.860  -7.785  1.00 74.83           C  \\nATOM   2976  C4'  DT I 146      83.354 133.389  -9.168  1.00 74.83           C  \\nATOM   2977  O4'  DT I 146      82.627 132.623 -10.160  1.00 74.83           O  \\nATOM   2978  C3'  DT I 146      82.906 134.845  -9.336  1.00 74.83           C  \\nATOM   2979  O3'  DT I 146      83.686 135.572 -10.277  1.00 74.83           O  \\nATOM   2980  C2'  DT I 146      81.571 134.698 -10.036  1.00 74.83           C  \\nATOM   2981  C1'  DT I 146      81.855 133.512 -10.943  1.00 74.83           C  \\nATOM   2982  N1   DT I 146      80.646 132.808 -11.374  1.00 54.79           N  \\nATOM   2983  C2   DT I 146      80.514 132.436 -12.701  1.00 54.79           C  \\nATOM   2984  O2   DT I 146      81.383 132.604 -13.545  1.00 54.79           O  \\nATOM   2985  N3   DT I 146      79.317 131.852 -13.004  1.00 54.79           N  \\nATOM   2986  C4   DT I 146      78.270 131.586 -12.142  1.00 54.79           C  \\nATOM   2987  O4   DT I 146      77.247 131.053 -12.576  1.00 54.79           O  \\nATOM   2988  C5   DT I 146      78.492 131.980 -10.758  1.00 54.79           C  \\nATOM   2989  C7   DT I 146      77.426 131.738  -9.738  1.00 54.79           C  \\nATOM   2990  C6   DT I 146      79.654 132.556 -10.453  1.00 54.79           C  \\nTER    2991       DT I 146                                                      \\nATOM   2992  O5'  DA J 147      76.848 129.368 -22.671  1.00202.00           O  \\nATOM   2993  C5'  DA J 147      77.522 130.162 -23.648  1.00202.00           C  \\nATOM   2994  C4'  DA J 147      78.764 130.836 -23.109  1.00202.00           C  \\nATOM   2995  O4'  DA J 147      78.414 131.513 -21.877  1.00202.00           O  \\nATOM   2996  C3'  DA J 147      79.913 129.883 -22.767  1.00202.00           C  \\nATOM   2997  O3'  DA J 147      81.187 130.417 -23.150  1.00202.00           O  \\nATOM   2998  C2'  DA J 147      79.844 129.760 -21.259  1.00202.00           C  \\nATOM   2999  C1'  DA J 147      79.251 131.085 -20.815  1.00202.00           C  \\nATOM   3000  N9   DA J 147      78.423 130.903 -19.624  1.00 42.19           N  \\nATOM   3001  C8   DA J 147      77.192 130.281 -19.553  1.00 42.19           C  \\nATOM   3002  N7   DA J 147      76.737 130.142 -18.323  1.00 42.19           N  \\nATOM   3003  C5   DA J 147      77.720 130.730 -17.533  1.00 42.19           C  \\nATOM   3004  C6   DA J 147      77.848 130.885 -16.129  1.00 42.19           C  \\nATOM   3005  N6   DA J 147      76.962 130.413 -15.239  1.00 42.19           N  \\nATOM   3006  N1   DA J 147      78.937 131.539 -15.669  1.00 42.19           N  \\nATOM   3007  C2   DA J 147      79.835 131.999 -16.558  1.00 42.19           C  \\nATOM   3008  N3   DA J 147      79.835 131.902 -17.897  1.00 42.19           N  \\nATOM   3009  C4   DA J 147      78.743 131.244 -18.325  1.00 42.19           C  \\nATOM   3010  P    DT J 148      82.495 129.470 -23.114  1.00128.18           P  \\nATOM   3011  OP1  DT J 148      83.399 129.898 -24.212  1.00128.18           O  \\nATOM   3012  OP2  DT J 148      82.045 128.054 -23.052  1.00128.18           O  \\nATOM   3013  O5'  DT J 148      83.193 129.827 -21.726  1.00106.82           O  \\nATOM   3014  C5'  DT J 148      83.880 131.065 -21.547  1.00106.82           C  \\nATOM   3015  C4'  DT J 148      84.714 131.023 -20.287  1.00106.82           C  \\nATOM   3016  O4'  DT J 148      83.843 130.994 -19.131  1.00106.82           O  \\nATOM   3017  C3'  DT J 148      85.606 129.786 -20.168  1.00106.82           C  \\nATOM   3018  O3'  DT J 148      86.813 130.112 -19.470  1.00106.82           O  \\nATOM   3019  C2'  DT J 148      84.775 128.851 -19.316  1.00106.82           C  \\nATOM   3020  C1'  DT J 148      84.115 129.829 -18.362  1.00106.82           C  \\nATOM   3021  N1   DT J 148      82.844 129.339 -17.800  1.00 74.82           N  \\nATOM   3022  C2   DT J 148      82.644 129.447 -16.437  1.00 74.82           C  \\nATOM   3023  O2   DT J 148      83.472 129.937 -15.669  1.00 74.82           O  \\nATOM   3024  N3   DT J 148      81.431 128.953 -16.004  1.00 74.82           N  \\nATOM   3025  C4   DT J 148      80.432 128.378 -16.775  1.00 74.82           C  \\nATOM   3026  O4   DT J 148      79.396 127.983 -16.244  1.00 74.82           O  \\nATOM   3027  C5   DT J 148      80.712 128.296 -18.184  1.00 74.82           C  \\nATOM   3028  C7   DT J 148      79.691 127.679 -19.086  1.00 74.82           C  \\nATOM   3029  C6   DT J 148      81.884 128.777 -18.623  1.00 74.82           C  \\nATOM   3030  P    DC J 149      87.956 128.993 -19.286  1.00124.16           P  \\nATOM   3031  OP1  DC J 149      89.001 129.524 -18.366  1.00124.16           O  \\nATOM   3032  OP2  DC J 149      88.336 128.524 -20.646  1.00124.16           O  \\nATOM   3033  O5'  DC J 149      87.219 127.792 -18.544  1.00112.14           O  \\nATOM   3034  C5'  DC J 149      87.955 126.665 -18.078  1.00112.14           C  \\nATOM   3035  C4'  DC J 149      88.475 126.937 -16.687  1.00112.14           C  \\nATOM   3036  O4'  DC J 149      87.390 127.474 -15.893  1.00112.14           O  \\nATOM   3037  C3'  DC J 149      88.982 125.707 -15.943  1.00112.14           C  \\nATOM   3038  O3'  DC J 149      90.151 126.024 -15.185  1.00112.14           O  \\nATOM   3039  C2'  DC J 149      87.804 125.275 -15.093  1.00112.14           C  \\nATOM   3040  C1'  DC J 149      86.921 126.517 -14.949  1.00112.14           C  \\nATOM   3041  N1   DC J 149      85.514 126.201 -15.286  1.00 67.30           N  \\nATOM   3042  C2   DC J 149      84.517 126.304 -14.298  1.00 67.30           C  \\nATOM   3043  O2   DC J 149      84.821 126.731 -13.174  1.00 67.30           O  \\nATOM   3044  N3   DC J 149      83.249 125.933 -14.604  1.00 67.30           N  \\nATOM   3045  C4   DC J 149      82.960 125.487 -15.837  1.00 67.30           C  \\nATOM   3046  N4   DC J 149      81.702 125.097 -16.100  1.00 67.30           N  \\nATOM   3047  C5   DC J 149      83.946 125.410 -16.862  1.00 67.30           C  \\nATOM   3048  C6   DC J 149      85.193 125.776 -16.548  1.00 67.30           C  \\nATOM   3049  P    DA J 150      90.045 127.017 -13.928  1.00106.86           P  \\nATOM   3050  OP1  DA J 150      89.491 128.320 -14.395  1.00106.86           O  \\nATOM   3051  OP2  DA J 150      91.339 126.982 -13.198  1.00106.86           O  \\nATOM   3052  O5'  DA J 150      88.964 126.355 -12.978  1.00 87.06           O  \\nATOM   3053  C5'  DA J 150      88.553 127.028 -11.802  1.00 87.06           C  \\nATOM   3054  C4'  DA J 150      88.199 126.024 -10.735  1.00 87.06           C  \\nATOM   3055  O4'  DA J 150      87.025 125.296 -11.160  1.00 87.06           O  \\nATOM   3056  C3'  DA J 150      89.271 124.975 -10.453  1.00 87.06           C  \\nATOM   3057  O3'  DA J 150      89.286 124.723  -9.041  1.00 87.06           O  \\nATOM   3058  C2'  DA J 150      88.813 123.781 -11.279  1.00 87.06           C  \\nATOM   3059  C1'  DA J 150      87.299 123.908 -11.243  1.00 87.06           C  \\nATOM   3060  N9   DA J 150      86.575 123.398 -12.408  1.00 53.74           N  \\nATOM   3061  C8   DA J 150      87.037 123.107 -13.669  1.00 53.74           C  \\nATOM   3062  N7   DA J 150      86.094 122.727 -14.501  1.00 53.74           N  \\nATOM   3063  C5   DA J 150      84.937 122.755 -13.729  1.00 53.74           C  \\nATOM   3064  C6   DA J 150      83.590 122.468 -14.020  1.00 53.74           C  \\nATOM   3065  N6   DA J 150      83.143 122.125 -15.231  1.00 53.74           N  \\nATOM   3066  N1   DA J 150      82.697 122.564 -13.013  1.00 53.74           N  \\nATOM   3067  C2   DA J 150      83.126 122.948 -11.808  1.00 53.74           C  \\nATOM   3068  N3   DA J 150      84.351 123.266 -11.417  1.00 53.74           N  \\nATOM   3069  C4   DA J 150      85.222 123.146 -12.436  1.00 53.74           C  \\nATOM   3070  P    DA J 151      89.918 123.361  -8.463  1.00 67.15           P  \\nATOM   3071  OP1  DA J 151      90.679 123.681  -7.226  1.00 67.15           O  \\nATOM   3072  OP2  DA J 151      90.589 122.647  -9.577  1.00 67.15           O  \\nATOM   3073  O5'  DA J 151      88.649 122.507  -8.007  1.00 94.04           O  \\nATOM   3074  C5'  DA J 151      87.723 123.052  -7.063  1.00 94.04           C  \\nATOM   3075  C4'  DA J 151      86.667 122.041  -6.674  1.00 94.04           C  \\nATOM   3076  O4'  DA J 151      85.841 121.672  -7.806  1.00 94.04           O  \\nATOM   3077  C3'  DA J 151      87.150 120.736  -6.047  1.00 94.04           C  \\nATOM   3078  O3'  DA J 151      86.273 120.446  -4.938  1.00 94.04           O  \\nATOM   3079  C2'  DA J 151      87.046 119.742  -7.200  1.00 94.04           C  \\nATOM   3080  C1'  DA J 151      85.861 120.267  -8.006  1.00 94.04           C  \\nATOM   3081  N9   DA J 151      85.890 120.047  -9.456  1.00 41.12           N  \\nATOM   3082  C8   DA J 151      86.934 120.244 -10.333  1.00 41.12           C  \\nATOM   3083  N7   DA J 151      86.608 120.068 -11.597  1.00 41.12           N  \\nATOM   3084  C5   DA J 151      85.268 119.708 -11.547  1.00 41.12           C  \\nATOM   3085  C6   DA J 151      84.334 119.417 -12.550  1.00 41.12           C  \\nATOM   3086  N6   DA J 151      84.613 119.455 -13.851  1.00 41.12           N  \\nATOM   3087  N1   DA J 151      83.080 119.090 -12.166  1.00 41.12           N  \\nATOM   3088  C2   DA J 151      82.792 119.068 -10.856  1.00 41.12           C  \\nATOM   3089  N3   DA J 151      83.578 119.333  -9.816  1.00 41.12           N  \\nATOM   3090  C4   DA J 151      84.820 119.656 -10.233  1.00 41.12           C  \\nATOM   3091  P    DT J 152      86.773 119.521  -3.711  1.00 80.90           P  \\nATOM   3092  OP1  DT J 152      86.184 119.982  -2.422  1.00 80.90           O  \\nATOM   3093  OP2  DT J 152      88.237 119.333  -3.829  1.00 80.90           O  \\nATOM   3094  O5'  DT J 152      86.125 118.127  -4.082  1.00 57.87           O  \\nATOM   3095  C5'  DT J 152      85.792 117.873  -5.433  1.00 57.87           C  \\nATOM   3096  C4'  DT J 152      84.463 117.180  -5.507  1.00 57.87           C  \\nATOM   3097  O4'  DT J 152      83.980 117.291  -6.858  1.00 57.87           O  \\nATOM   3098  C3'  DT J 152      84.574 115.698  -5.188  1.00 57.87           C  \\nATOM   3099  O3'  DT J 152      83.448 115.292  -4.409  1.00 57.87           O  \\nATOM   3100  C2'  DT J 152      84.672 115.046  -6.552  1.00 57.87           C  \\nATOM   3101  C1'  DT J 152      83.988 116.031  -7.490  1.00 57.87           C  \\nATOM   3102  N1   DT J 152      84.699 116.188  -8.767  1.00 43.58           N  \\nATOM   3103  C2   DT J 152      83.974 116.078  -9.935  1.00 43.58           C  \\nATOM   3104  O2   DT J 152      82.765 115.879  -9.969  1.00 43.58           O  \\nATOM   3105  N3   DT J 152      84.718 116.192 -11.074  1.00 43.58           N  \\nATOM   3106  C4   DT J 152      86.073 116.387 -11.175  1.00 43.58           C  \\nATOM   3107  O4   DT J 152      86.594 116.447 -12.283  1.00 43.58           O  \\nATOM   3108  C5   DT J 152      86.775 116.495  -9.917  1.00 43.58           C  \\nATOM   3109  C7   DT J 152      88.262 116.678  -9.931  1.00 43.58           C  \\nATOM   3110  C6   DT J 152      86.060 116.410  -8.788  1.00 43.58           C  \\nATOM   3111  P    DA J 153      83.233 113.744  -4.039  1.00 54.44           P  \\nATOM   3112  OP1  DA J 153      82.469 113.744  -2.765  1.00 54.44           O  \\nATOM   3113  OP2  DA J 153      84.512 112.995  -4.124  1.00 54.44           O  \\nATOM   3114  O5'  DA J 153      82.297 113.257  -5.229  1.00 51.97           O  \\nATOM   3115  C5'  DA J 153      81.209 114.076  -5.647  1.00 51.97           C  \\nATOM   3116  C4'  DA J 153      80.481 113.436  -6.799  1.00 51.97           C  \\nATOM   3117  O4'  DA J 153      81.236 113.571  -8.022  1.00 51.97           O  \\nATOM   3118  C3'  DA J 153      80.218 111.948  -6.627  1.00 51.97           C  \\nATOM   3119  O3'  DA J 153      78.914 111.675  -7.152  1.00 51.97           O  \\nATOM   3120  C2'  DA J 153      81.341 111.301  -7.426  1.00 51.97           C  \\nATOM   3121  C1'  DA J 153      81.558 112.294  -8.555  1.00 51.97           C  \\nATOM   3122  N9   DA J 153      82.922 112.376  -9.093  1.00 47.69           N  \\nATOM   3123  C8   DA J 153      84.102 112.499  -8.395  1.00 47.69           C  \\nATOM   3124  N7   DA J 153      85.162 112.617  -9.165  1.00 47.69           N  \\nATOM   3125  C5   DA J 153      84.650 112.560 -10.457  1.00 47.69           C  \\nATOM   3126  C6   DA J 153      85.262 112.646 -11.734  1.00 47.69           C  \\nATOM   3127  N6   DA J 153      86.575 112.835 -11.921  1.00 47.69           N  \\nATOM   3128  N1   DA J 153      84.464 112.537 -12.824  1.00 47.69           N  \\nATOM   3129  C2   DA J 153      83.150 112.362 -12.637  1.00 47.69           C  \\nATOM   3130  N3   DA J 153      82.457 112.279 -11.497  1.00 47.69           N  \\nATOM   3131  C4   DA J 153      83.274 112.388 -10.430  1.00 47.69           C  \\nATOM   3132  P    DT J 154      78.319 110.186  -7.101  1.00 62.64           P  \\nATOM   3133  OP1  DT J 154      76.848 110.349  -7.047  1.00 62.64           O  \\nATOM   3134  OP2  DT J 154      79.018 109.388  -6.049  1.00 62.64           O  \\nATOM   3135  O5'  DT J 154      78.679 109.623  -8.542  1.00 53.68           O  \\nATOM   3136  C5'  DT J 154      78.215 110.310  -9.695  1.00 53.68           C  \\nATOM   3137  C4'  DT J 154      78.607 109.561 -10.942  1.00 53.68           C  \\nATOM   3138  O4'  DT J 154      79.967 109.847 -11.351  1.00 53.68           O  \\nATOM   3139  C3'  DT J 154      78.521 108.048 -10.798  1.00 53.68           C  \\nATOM   3140  O3'  DT J 154      78.037 107.508 -12.024  1.00 53.68           O  \\nATOM   3141  C2'  DT J 154      79.969 107.647 -10.606  1.00 53.68           C  \\nATOM   3142  C1'  DT J 154      80.639 108.620 -11.555  1.00 53.68           C  \\nATOM   3143  N1   DT J 154      82.071 108.831 -11.309  1.00 44.79           N  \\nATOM   3144  C2   DT J 154      82.891 109.029 -12.392  1.00 44.79           C  \\nATOM   3145  O2   DT J 154      82.483 109.045 -13.542  1.00 44.79           O  \\nATOM   3146  N3   DT J 154      84.210 109.207 -12.078  1.00 44.79           N  \\nATOM   3147  C4   DT J 154      84.772 109.215 -10.811  1.00 44.79           C  \\nATOM   3148  O4   DT J 154      85.985 109.408 -10.677  1.00 44.79           O  \\nATOM   3149  C5   DT J 154      83.845 108.997  -9.726  1.00 44.79           C  \\nATOM   3150  C7   DT J 154      84.355 108.984  -8.323  1.00 44.79           C  \\nATOM   3151  C6   DT J 154      82.562 108.818 -10.025  1.00 44.79           C  \\nATOM   3152  P    DC J 155      77.617 105.968 -12.101  1.00 83.45           P  \\nATOM   3153  OP1  DC J 155      76.135 105.902 -12.128  1.00 83.45           O  \\nATOM   3154  OP2  DC J 155      78.378 105.245 -11.041  1.00 83.45           O  \\nATOM   3155  O5'  DC J 155      78.172 105.537 -13.521  1.00 90.12           O  \\nATOM   3156  C5'  DC J 155      79.501 105.863 -13.869  1.00 90.12           C  \\nATOM   3157  C4'  DC J 155      79.700 105.752 -15.358  1.00 90.12           C  \\nATOM   3158  O4'  DC J 155      80.940 106.429 -15.645  1.00 90.12           O  \\nATOM   3159  C3'  DC J 155      79.886 104.313 -15.826  1.00 90.12           C  \\nATOM   3160  O3'  DC J 155      79.364 104.118 -17.145  1.00 90.12           O  \\nATOM   3161  C2'  DC J 155      81.385 104.096 -15.736  1.00 90.12           C  \\nATOM   3162  C1'  DC J 155      82.005 105.496 -15.723  1.00 90.12           C  \\nATOM   3163  N1   DC J 155      82.857 105.697 -14.531  1.00 43.59           N  \\nATOM   3164  C2   DC J 155      84.224 105.950 -14.705  1.00 43.59           C  \\nATOM   3165  O2   DC J 155      84.674 106.071 -15.869  1.00 43.59           O  \\nATOM   3166  N3   DC J 155      85.017 106.052 -13.605  1.00 43.59           N  \\nATOM   3167  C4   DC J 155      84.492 105.915 -12.379  1.00 43.59           C  \\nATOM   3168  N4   DC J 155      85.322 105.971 -11.318  1.00 43.59           N  \\nATOM   3169  C5   DC J 155      83.100 105.701 -12.180  1.00 43.59           C  \\nATOM   3170  C6   DC J 155      82.328 105.604 -13.271  1.00 43.59           C  \\nATOM   3171  P    DC J 156      79.074 102.625 -17.677  1.00 62.07           P  \\nATOM   3172  OP1  DC J 156      77.970 102.683 -18.672  1.00 62.07           O  \\nATOM   3173  OP2  DC J 156      78.958 101.725 -16.492  1.00 62.07           O  \\nATOM   3174  O5'  DC J 156      80.411 102.256 -18.459  1.00 75.04           O  \\nATOM   3175  C5'  DC J 156      81.370 103.276 -18.767  1.00 75.04           C  \\nATOM   3176  C4'  DC J 156      82.596 102.677 -19.415  1.00 75.04           C  \\nATOM   3177  O4'  DC J 156      83.759 103.035 -18.642  1.00 75.04           O  \\nATOM   3178  C3'  DC J 156      82.611 101.154 -19.514  1.00 75.04           C  \\nATOM   3179  O3'  DC J 156      83.274 100.768 -20.715  1.00 75.04           O  \\nATOM   3180  C2'  DC J 156      83.424 100.729 -18.311  1.00 75.04           C  \\nATOM   3181  C1'  DC J 156      84.414 101.867 -18.179  1.00 75.04           C  \\nATOM   3182  N1   DC J 156      84.783 102.101 -16.790  1.00 50.44           N  \\nATOM   3183  C2   DC J 156      86.050 102.570 -16.503  1.00 50.44           C  \\nATOM   3184  O2   DC J 156      86.822 102.827 -17.449  1.00 50.44           O  \\nATOM   3185  N3   DC J 156      86.404 102.742 -15.207  1.00 50.44           N  \\nATOM   3186  C4   DC J 156      85.528 102.484 -14.234  1.00 50.44           C  \\nATOM   3187  N4   DC J 156      85.912 102.652 -12.975  1.00 50.44           N  \\nATOM   3188  C5   DC J 156      84.219 102.035 -14.510  1.00 50.44           C  \\nATOM   3189  C6   DC J 156      83.891 101.854 -15.790  1.00 50.44           C  \\nATOM   3190  P    DA J 157      83.537  99.214 -21.017  1.00 54.11           P  \\nATOM   3191  OP1  DA J 157      83.307  99.032 -22.480  1.00 54.11           O  \\nATOM   3192  OP2  DA J 157      82.803  98.367 -20.023  1.00 54.11           O  \\nATOM   3193  O5'  DA J 157      85.085  99.026 -20.698  1.00 50.89           O  \\nATOM   3194  C5'  DA J 157      86.069  99.691 -21.470  1.00 50.89           C  \\nATOM   3195  C4'  DA J 157      87.433  99.176 -21.093  1.00 50.89           C  \\nATOM   3196  O4'  DA J 157      87.735  99.623 -19.750  1.00 50.89           O  \\nATOM   3197  C3'  DA J 157      87.519  97.651 -21.072  1.00 50.89           C  \\nATOM   3198  O3'  DA J 157      88.737  97.207 -21.695  1.00 50.89           O  \\nATOM   3199  C2'  DA J 157      87.465  97.316 -19.591  1.00 50.89           C  \\nATOM   3200  C1'  DA J 157      88.085  98.531 -18.936  1.00 50.89           C  \\nATOM   3201  N9   DA J 157      87.552  98.795 -17.608  1.00 48.77           N  \\nATOM   3202  C8   DA J 157      86.253  98.627 -17.202  1.00 48.77           C  \\nATOM   3203  N7   DA J 157      86.059  98.885 -15.929  1.00 48.77           N  \\nATOM   3204  C5   DA J 157      87.314  99.262 -15.468  1.00 48.77           C  \\nATOM   3205  C6   DA J 157      87.781  99.639 -14.194  1.00 48.77           C  \\nATOM   3206  N6   DA J 157      87.009  99.679 -13.110  1.00 48.77           N  \\nATOM   3207  N1   DA J 157      89.084  99.966 -14.072  1.00 48.77           N  \\nATOM   3208  C2   DA J 157      89.859  99.907 -15.156  1.00 48.77           C  \\nATOM   3209  N3   DA J 157      89.543  99.555 -16.408  1.00 48.77           N  \\nATOM   3210  C4   DA J 157      88.239  99.235 -16.498  1.00 48.77           C  \\nATOM   3211  P    DC J 158      88.836  95.712 -22.299  1.00 68.14           P  \\nATOM   3212  OP1  DC J 158      89.593  95.758 -23.577  1.00 68.14           O  \\nATOM   3213  OP2  DC J 158      87.491  95.088 -22.278  1.00 68.14           O  \\nATOM   3214  O5'  DC J 158      89.732  94.979 -21.213  1.00 64.73           O  \\nATOM   3215  C5'  DC J 158      89.604  95.323 -19.842  1.00 64.73           C  \\nATOM   3216  C4'  DC J 158      90.959  95.593 -19.237  1.00 64.73           C  \\nATOM   3217  O4'  DC J 158      90.758  96.483 -18.113  1.00 64.73           O  \\nATOM   3218  C3'  DC J 158      91.569  94.319 -18.664  1.00 64.73           C  \\nATOM   3219  O3'  DC J 158      92.983  94.236 -18.794  1.00 64.73           O  \\nATOM   3220  C2'  DC J 158      91.201  94.356 -17.197  1.00 64.73           C  \\nATOM   3221  C1'  DC J 158      91.040  95.827 -16.883  1.00 64.73           C  \\nATOM   3222  N1   DC J 158      89.874  95.969 -16.011  1.00 38.98           N  \\nATOM   3223  C2   DC J 158      90.070  96.256 -14.657  1.00 38.98           C  \\nATOM   3224  O2   DC J 158      91.211  96.528 -14.257  1.00 38.98           O  \\nATOM   3225  N3   DC J 158      89.008  96.238 -13.819  1.00 38.98           N  \\nATOM   3226  C4   DC J 158      87.791  95.978 -14.293  1.00 38.98           C  \\nATOM   3227  N4   DC J 158      86.781  95.923 -13.427  1.00 38.98           N  \\nATOM   3228  C5   DC J 158      87.554  95.752 -15.681  1.00 38.98           C  \\nATOM   3229  C6   DC J 158      88.616  95.760 -16.498  1.00 38.98           C  \\nATOM   3230  P    DC J 159      93.725  92.903 -18.291  1.00 74.22           P  \\nATOM   3231  OP1  DC J 159      95.146  92.957 -18.699  1.00 74.22           O  \\nATOM   3232  OP2  DC J 159      92.878  91.757 -18.711  1.00 74.22           O  \\nATOM   3233  O5'  DC J 159      93.643  92.986 -16.705  1.00 68.71           O  \\nATOM   3234  C5'  DC J 159      94.325  94.011 -15.990  1.00 68.71           C  \\nATOM   3235  C4'  DC J 159      94.639  93.529 -14.594  1.00 68.71           C  \\nATOM   3236  O4'  DC J 159      93.514  93.799 -13.725  1.00 68.71           O  \\nATOM   3237  C3'  DC J 159      94.881  92.024 -14.493  1.00 68.71           C  \\nATOM   3238  O3'  DC J 159      95.792  91.781 -13.416  1.00 68.71           O  \\nATOM   3239  C2'  DC J 159      93.503  91.488 -14.155  1.00 68.71           C  \\nATOM   3240  C1'  DC J 159      92.968  92.579 -13.237  1.00 68.71           C  \\nATOM   3241  N1   DC J 159      91.501  92.715 -13.232  1.00 58.46           N  \\nATOM   3242  C2   DC J 159      90.843  92.990 -12.013  1.00 58.46           C  \\nATOM   3243  O2   DC J 159      91.513  93.056 -10.955  1.00 58.46           O  \\nATOM   3244  N3   DC J 159      89.495  93.169 -12.024  1.00 58.46           N  \\nATOM   3245  C4   DC J 159      88.814  93.071 -13.173  1.00 58.46           C  \\nATOM   3246  N4   DC J 159      87.497  93.285 -13.141  1.00 58.46           N  \\nATOM   3247  C5   DC J 159      89.455  92.758 -14.407  1.00 58.46           C  \\nATOM   3248  C6   DC J 159      90.783  92.592 -14.392  1.00 58.46           C  \\nATOM   3249  P    DT J 160      96.561  90.371 -13.306  1.00 70.67           P  \\nATOM   3250  OP1  DT J 160      98.019  90.661 -13.281  1.00 70.67           O  \\nATOM   3251  OP2  DT J 160      96.014  89.440 -14.329  1.00 70.67           O  \\nATOM   3252  O5'  DT J 160      96.137  89.843 -11.865  1.00 98.25           O  \\nATOM   3253  C5'  DT J 160      96.211  90.699 -10.726  1.00 98.25           C  \\nATOM   3254  C4'  DT J 160      95.385  90.132  -9.596  1.00 98.25           C  \\nATOM   3255  O4'  DT J 160      93.973  90.426  -9.770  1.00 98.25           O  \\nATOM   3256  C3'  DT J 160      95.491  88.610  -9.451  1.00 98.25           C  \\nATOM   3257  O3'  DT J 160      95.541  88.268  -8.070  1.00 98.25           O  \\nATOM   3258  C2'  DT J 160      94.177  88.116 -10.028  1.00 98.25           C  \\nATOM   3259  C1'  DT J 160      93.247  89.222  -9.569  1.00 98.25           C  \\nATOM   3260  N1   DT J 160      91.939  89.321 -10.259  1.00 65.27           N  \\nATOM   3261  C2   DT J 160      90.903  89.894  -9.557  1.00 65.27           C  \\nATOM   3262  O2   DT J 160      91.035  90.370  -8.438  1.00 65.27           O  \\nATOM   3263  N3   DT J 160      89.702  89.899 -10.219  1.00 65.27           N  \\nATOM   3264  C4   DT J 160      89.445  89.426 -11.487  1.00 65.27           C  \\nATOM   3265  O4   DT J 160      88.316  89.497 -11.943  1.00 65.27           O  \\nATOM   3266  C5   DT J 160      90.575  88.874 -12.183  1.00 65.27           C  \\nATOM   3267  C7   DT J 160      90.382  88.375 -13.580  1.00 65.27           C  \\nATOM   3268  C6   DT J 160      91.755  88.840 -11.542  1.00 65.27           C  \\nATOM   3269  P    DG J 161      96.525  87.106  -7.570  1.00124.73           P  \\nATOM   3270  OP1  DG J 161      97.891  87.685  -7.480  1.00124.73           O  \\nATOM   3271  OP2  DG J 161      96.288  85.894  -8.399  1.00124.73           O  \\nATOM   3272  O5'  DG J 161      96.006  86.822  -6.095  1.00118.51           O  \\nATOM   3273  C5'  DG J 161      95.751  87.909  -5.213  1.00118.51           C  \\nATOM   3274  C4'  DG J 161      94.431  87.721  -4.502  1.00118.51           C  \\nATOM   3275  O4'  DG J 161      93.323  87.823  -5.433  1.00118.51           O  \\nATOM   3276  C3'  DG J 161      94.279  86.380  -3.790  1.00118.51           C  \\nATOM   3277  O3'  DG J 161      93.716  86.600  -2.498  1.00118.51           O  \\nATOM   3278  C2'  DG J 161      93.328  85.603  -4.684  1.00118.51           C  \\nATOM   3279  C1'  DG J 161      92.470  86.694  -5.307  1.00118.51           C  \\nATOM   3280  N9   DG J 161      91.957  86.361  -6.637  1.00 77.99           N  \\nATOM   3281  C8   DG J 161      92.616  85.670  -7.625  1.00 77.99           C  \\nATOM   3282  N7   DG J 161      91.904  85.514  -8.708  1.00 77.99           N  \\nATOM   3283  C5   DG J 161      90.703  86.141  -8.422  1.00 77.99           C  \\nATOM   3284  C6   DG J 161      89.550  86.292  -9.213  1.00 77.99           C  \\nATOM   3285  O6   DG J 161      89.349  85.902 -10.368  1.00 77.99           O  \\nATOM   3286  N1   DG J 161      88.557  86.981  -8.535  1.00 77.99           N  \\nATOM   3287  C2   DG J 161      88.666  87.472  -7.259  1.00 77.99           C  \\nATOM   3288  N2   DG J 161      87.593  88.105  -6.780  1.00 77.99           N  \\nATOM   3289  N3   DG J 161      89.744  87.348  -6.510  1.00 77.99           N  \\nATOM   3290  C4   DG J 161      90.717  86.672  -7.147  1.00 77.99           C  \\nATOM   3291  P    DC J 162      93.891  85.493  -1.344  1.00104.81           P  \\nATOM   3292  OP1  DC J 162      94.455  86.163  -0.136  1.00104.81           O  \\nATOM   3293  OP2  DC J 162      94.552  84.282  -1.902  1.00104.81           O  \\nATOM   3294  O5'  DC J 162      92.388  85.121  -1.019  1.00 96.09           O  \\nATOM   3295  C5'  DC J 162      91.425  86.153  -0.881  1.00 96.09           C  \\nATOM   3296  C4'  DC J 162      90.120  85.567  -0.419  1.00 96.09           C  \\nATOM   3297  O4'  DC J 162      89.313  85.363  -1.599  1.00 96.09           O  \\nATOM   3298  C3'  DC J 162      90.287  84.202   0.243  1.00 96.09           C  \\nATOM   3299  O3'  DC J 162      89.615  84.153   1.524  1.00 96.09           O  \\nATOM   3300  C2'  DC J 162      89.941  83.194  -0.846  1.00 96.09           C  \\nATOM   3301  C1'  DC J 162      89.106  83.984  -1.858  1.00 96.09           C  \\nATOM   3302  N1   DC J 162      89.410  83.749  -3.290  1.00 83.72           N  \\nATOM   3303  C2   DC J 162      88.652  84.434  -4.260  1.00 83.72           C  \\nATOM   3304  O2   DC J 162      87.785  85.244  -3.885  1.00 83.72           O  \\nATOM   3305  N3   DC J 162      88.889  84.198  -5.578  1.00 83.72           N  \\nATOM   3306  C4   DC J 162      89.841  83.335  -5.943  1.00 83.72           C  \\nATOM   3307  N4   DC J 162      90.034  83.135  -7.250  1.00 83.72           N  \\nATOM   3308  C5   DC J 162      90.637  82.642  -4.982  1.00 83.72           C  \\nATOM   3309  C6   DC J 162      90.392  82.877  -3.678  1.00 83.72           C  \\nATOM   3310  P    DA J 163      88.086  83.674   1.643  1.00137.94           P  \\nATOM   3311  OP1  DA J 163      87.487  84.428   2.777  1.00137.94           O  \\nATOM   3312  OP2  DA J 163      88.068  82.186   1.666  1.00137.94           O  \\nATOM   3313  O5'  DA J 163      87.423  84.184   0.285  1.00106.21           O  \\nATOM   3314  C5'  DA J 163      86.616  85.367   0.229  1.00106.21           C  \\nATOM   3315  C4'  DA J 163      85.192  84.980  -0.083  1.00106.21           C  \\nATOM   3316  O4'  DA J 163      85.230  84.129  -1.254  1.00106.21           O  \\nATOM   3317  C3'  DA J 163      84.598  84.116   1.026  1.00106.21           C  \\nATOM   3318  O3'  DA J 163      83.178  84.255   1.079  1.00106.21           O  \\nATOM   3319  C2'  DA J 163      84.988  82.712   0.621  1.00106.21           C  \\nATOM   3320  C1'  DA J 163      84.965  82.776  -0.891  1.00106.21           C  \\nATOM   3321  N9   DA J 163      86.005  81.933  -1.475  1.00 87.75           N  \\nATOM   3322  C8   DA J 163      87.003  81.260  -0.814  1.00 87.75           C  \\nATOM   3323  N7   DA J 163      87.792  80.577  -1.601  1.00 87.75           N  \\nATOM   3324  C5   DA J 163      87.282  80.817  -2.869  1.00 87.75           C  \\nATOM   3325  C6   DA J 163      87.677  80.384  -4.146  1.00 87.75           C  \\nATOM   3326  N6   DA J 163      88.724  79.582  -4.369  1.00 87.75           N  \\nATOM   3327  N1   DA J 163      86.947  80.805  -5.203  1.00 87.75           N  \\nATOM   3328  C2   DA J 163      85.896  81.603  -4.982  1.00 87.75           C  \\nATOM   3329  N3   DA J 163      85.430  82.081  -3.831  1.00 87.75           N  \\nATOM   3330  C4   DA J 163      86.178  81.647  -2.803  1.00 87.75           C  \\nATOM   3331  P    DG J 164      82.315  83.322   2.073  1.00 96.36           P  \\nATOM   3332  OP1  DG J 164      81.667  84.187   3.091  1.00 96.36           O  \\nATOM   3333  OP2  DG J 164      83.150  82.170   2.511  1.00 96.36           O  \\nATOM   3334  O5'  DG J 164      81.185  82.759   1.110  1.00 68.80           O  \\nATOM   3335  C5'  DG J 164      80.937  83.398  -0.128  1.00 68.80           C  \\nATOM   3336  C4'  DG J 164      80.863  82.377  -1.236  1.00 68.80           C  \\nATOM   3337  O4'  DG J 164      82.129  81.716  -1.488  1.00 68.80           O  \\nATOM   3338  C3'  DG J 164      79.850  81.253  -1.044  1.00 68.80           C  \\nATOM   3339  O3'  DG J 164      79.301  81.046  -2.333  1.00 68.80           O  \\nATOM   3340  C2'  DG J 164      80.721  80.058  -0.695  1.00 68.80           C  \\nATOM   3341  C1'  DG J 164      81.870  80.328  -1.638  1.00 68.80           C  \\nATOM   3342  N9   DG J 164      83.113  79.592  -1.427  1.00 84.97           N  \\nATOM   3343  C8   DG J 164      83.724  79.291  -0.234  1.00 84.97           C  \\nATOM   3344  N7   DG J 164      84.845  78.636  -0.383  1.00 84.97           N  \\nATOM   3345  C5   DG J 164      84.979  78.493  -1.758  1.00 84.97           C  \\nATOM   3346  C6   DG J 164      86.008  77.879  -2.526  1.00 84.97           C  \\nATOM   3347  O6   DG J 164      87.053  77.331  -2.128  1.00 84.97           O  \\nATOM   3348  N1   DG J 164      85.735  77.955  -3.891  1.00 84.97           N  \\nATOM   3349  C2   DG J 164      84.638  78.564  -4.445  1.00 84.97           C  \\nATOM   3350  N2   DG J 164      84.580  78.544  -5.779  1.00 84.97           N  \\nATOM   3351  N3   DG J 164      83.683  79.147  -3.745  1.00 84.97           N  \\nATOM   3352  C4   DG J 164      83.915  79.071  -2.416  1.00 84.97           C  \\nATOM   3353  P    DA J 165      77.967  80.206  -2.506  1.00 66.14           P  \\nATOM   3354  OP1  DA J 165      76.807  81.107  -2.331  1.00 66.14           O  \\nATOM   3355  OP2  DA J 165      78.088  78.987  -1.671  1.00 66.14           O  \\nATOM   3356  O5'  DA J 165      78.027  79.785  -4.030  1.00 59.08           O  \\nATOM   3357  C5'  DA J 165      77.608  78.499  -4.411  1.00 59.08           C  \\nATOM   3358  C4'  DA J 165      77.871  78.296  -5.878  1.00 59.08           C  \\nATOM   3359  O4'  DA J 165      79.299  78.408  -6.069  1.00 59.08           O  \\nATOM   3360  C3'  DA J 165      77.472  76.901  -6.341  1.00 59.08           C  \\nATOM   3361  O3'  DA J 165      76.660  76.922  -7.529  1.00 59.08           O  \\nATOM   3362  C2'  DA J 165      78.766  76.106  -6.354  1.00 59.08           C  \\nATOM   3363  C1'  DA J 165      79.889  77.137  -6.308  1.00 59.08           C  \\nATOM   3364  N9   DA J 165      80.834  76.876  -5.215  1.00 69.83           N  \\nATOM   3365  C8   DA J 165      80.685  77.199  -3.885  1.00 69.83           C  \\nATOM   3366  N7   DA J 165      81.698  76.829  -3.133  1.00 69.83           N  \\nATOM   3367  C5   DA J 165      82.576  76.223  -4.025  1.00 69.83           C  \\nATOM   3368  C6   DA J 165      83.842  75.621  -3.857  1.00 69.83           C  \\nATOM   3369  N6   DA J 165      84.469  75.517  -2.683  1.00 69.83           N  \\nATOM   3370  N1   DA J 165      84.450  75.120  -4.954  1.00 69.83           N  \\nATOM   3371  C2   DA J 165      83.825  75.210  -6.133  1.00 69.83           C  \\nATOM   3372  N3   DA J 165      82.639  75.741  -6.420  1.00 69.83           N  \\nATOM   3373  C4   DA J 165      82.057  76.242  -5.312  1.00 69.83           C  \\nATOM   3374  P    DT J 166      77.331  76.890  -8.978  1.00 95.43           P  \\nATOM   3375  OP1  DT J 166      77.716  78.283  -9.316  1.00 95.43           O  \\nATOM   3376  OP2  DT J 166      76.370  76.156  -9.848  1.00 95.43           O  \\nATOM   3377  O5'  DT J 166      78.656  76.027  -8.820  1.00 75.61           O  \\nATOM   3378  C5'  DT J 166      78.583  74.614  -8.782  1.00 75.61           C  \\nATOM   3379  C4'  DT J 166      79.862  74.004  -9.302  1.00 75.61           C  \\nATOM   3380  O4'  DT J 166      80.906  74.132  -8.300  1.00 75.61           O  \\nATOM   3381  C3'  DT J 166      79.694  72.508  -9.552  1.00 75.61           C  \\nATOM   3382  O3'  DT J 166      80.205  72.117 -10.817  1.00 75.61           O  \\nATOM   3383  C2'  DT J 166      80.433  71.837  -8.413  1.00 75.61           C  \\nATOM   3384  C1'  DT J 166      81.470  72.860  -8.015  1.00 75.61           C  \\nATOM   3385  N1   DT J 166      81.766  72.789  -6.574  1.00115.63           N  \\nATOM   3386  C2   DT J 166      82.903  72.117  -6.189  1.00115.63           C  \\nATOM   3387  O2   DT J 166      83.693  71.622  -6.984  1.00115.63           O  \\nATOM   3388  N3   DT J 166      83.087  72.044  -4.831  1.00115.63           N  \\nATOM   3389  C4   DT J 166      82.280  72.576  -3.844  1.00115.63           C  \\nATOM   3390  O4   DT J 166      82.579  72.419  -2.662  1.00115.63           O  \\nATOM   3391  C5   DT J 166      81.121  73.290  -4.319  1.00115.63           C  \\nATOM   3392  C7   DT J 166      80.202  73.924  -3.323  1.00115.63           C  \\nATOM   3393  C6   DT J 166      80.922  73.357  -5.644  1.00115.63           C  \\nATOM   3394  P    DT J 167      79.287  71.214 -11.773  1.00117.46           P  \\nATOM   3395  OP1  DT J 167      79.328  71.807 -13.130  1.00117.46           O  \\nATOM   3396  OP2  DT J 167      77.976  71.021 -11.095  1.00117.46           O  \\nATOM   3397  O5'  DT J 167      80.054  69.825 -11.816  1.00112.13           O  \\nATOM   3398  C5'  DT J 167      81.319  69.746 -12.447  1.00112.13           C  \\nATOM   3399  C4'  DT J 167      82.192  68.722 -11.763  1.00112.13           C  \\nATOM   3400  O4'  DT J 167      82.476  69.115 -10.392  1.00112.13           O  \\nATOM   3401  C3'  DT J 167      81.603  67.312 -11.691  1.00112.13           C  \\nATOM   3402  O3'  DT J 167      82.628  66.374 -12.036  1.00112.13           O  \\nATOM   3403  C2'  DT J 167      81.211  67.176 -10.230  1.00112.13           C  \\nATOM   3404  C1'  DT J 167      82.316  67.973  -9.568  1.00112.13           C  \\nATOM   3405  N1   DT J 167      82.042  68.409  -8.183  1.00103.01           N  \\nATOM   3406  C2   DT J 167      83.117  68.573  -7.325  1.00103.01           C  \\nATOM   3407  O2   DT J 167      84.281  68.417  -7.665  1.00103.01           O  \\nATOM   3408  N3   DT J 167      82.772  68.929  -6.042  1.00103.01           N  \\nATOM   3409  C4   DT J 167      81.497  69.135  -5.543  1.00103.01           C  \\nATOM   3410  O4   DT J 167      81.345  69.433  -4.363  1.00103.01           O  \\nATOM   3411  C5   DT J 167      80.427  68.967  -6.499  1.00103.01           C  \\nATOM   3412  C7   DT J 167      79.018  69.183  -6.052  1.00103.01           C  \\nATOM   3413  C6   DT J 167      80.747  68.621  -7.755  1.00103.01           C  \\nATOM   3414  P    DC J 168      82.711  64.963 -11.278  1.00125.07           P  \\nATOM   3415  OP1  DC J 168      83.681  64.123 -12.022  1.00125.07           O  \\nATOM   3416  OP2  DC J 168      81.327  64.469 -11.059  1.00125.07           O  \\nATOM   3417  O5'  DC J 168      83.340  65.329  -9.860  1.00169.04           O  \\nATOM   3418  C5'  DC J 168      84.743  65.212  -9.624  1.00169.04           C  \\nATOM   3419  C4'  DC J 168      85.031  63.915  -8.906  1.00169.04           C  \\nATOM   3420  O4'  DC J 168      84.826  64.115  -7.486  1.00169.04           O  \\nATOM   3421  C3'  DC J 168      84.085  62.784  -9.312  1.00169.04           C  \\nATOM   3422  O3'  DC J 168      84.764  61.524  -9.356  1.00169.04           O  \\nATOM   3423  C2'  DC J 168      83.027  62.798  -8.228  1.00169.04           C  \\nATOM   3424  C1'  DC J 168      83.809  63.245  -7.007  1.00169.04           C  \\nATOM   3425  N1   DC J 168      82.982  63.992  -6.047  1.00110.48           N  \\nATOM   3426  C2   DC J 168      83.545  64.399  -4.833  1.00110.48           C  \\nATOM   3427  O2   DC J 168      84.738  64.131  -4.602  1.00110.48           O  \\nATOM   3428  N3   DC J 168      82.775  65.075  -3.946  1.00110.48           N  \\nATOM   3429  C4   DC J 168      81.501  65.350  -4.238  1.00110.48           C  \\nATOM   3430  N4   DC J 168      80.784  66.026  -3.342  1.00110.48           N  \\nATOM   3431  C5   DC J 168      80.905  64.947  -5.467  1.00110.48           C  \\nATOM   3432  C6   DC J 168      81.674  64.278  -6.334  1.00110.48           C  \\nATOM   3433  P    DT J 169      83.924  60.159  -9.216  1.00121.12           P  \\nATOM   3434  OP1  DT J 169      84.690  59.072  -9.875  1.00121.12           O  \\nATOM   3435  OP2  DT J 169      82.515  60.418  -9.628  1.00121.12           O  \\nATOM   3436  O5'  DT J 169      83.966  59.889  -7.651  1.00150.72           O  \\nATOM   3437  C5'  DT J 169      85.217  59.757  -6.983  1.00150.72           C  \\nATOM   3438  C4'  DT J 169      85.050  58.923  -5.737  1.00150.72           C  \\nATOM   3439  O4'  DT J 169      84.383  59.720  -4.727  1.00150.72           O  \\nATOM   3440  C3'  DT J 169      84.198  57.666  -5.944  1.00150.72           C  \\nATOM   3441  O3'  DT J 169      84.800  56.519  -5.317  1.00150.72           O  \\nATOM   3442  C2'  DT J 169      82.857  58.034  -5.330  1.00150.72           C  \\nATOM   3443  C1'  DT J 169      83.215  59.061  -4.263  1.00150.72           C  \\nATOM   3444  N1   DT J 169      82.164  60.085  -4.039  1.00138.36           N  \\nATOM   3445  C2   DT J 169      82.188  60.830  -2.873  1.00138.36           C  \\nATOM   3446  O2   DT J 169      83.056  60.720  -2.021  1.00138.36           O  \\nATOM   3447  N3   DT J 169      81.147  61.722  -2.744  1.00138.36           N  \\nATOM   3448  C4   DT J 169      80.125  61.952  -3.647  1.00138.36           C  \\nATOM   3449  O4   DT J 169      79.262  62.790  -3.392  1.00138.36           O  \\nATOM   3450  C5   DT J 169      80.170  61.150  -4.849  1.00138.36           C  \\nATOM   3451  C7   DT J 169      79.103  61.330  -5.883  1.00138.36           C  \\nATOM   3452  C6   DT J 169      81.173  60.272  -4.983  1.00138.36           C  \\nATOM   3453  P    DA J 170      84.064  55.080  -5.376  1.00140.46           P  \\nATOM   3454  OP1  DA J 170      85.105  54.021  -5.462  1.00140.46           O  \\nATOM   3455  OP2  DA J 170      82.969  55.109  -6.382  1.00140.46           O  \\nATOM   3456  O5'  DA J 170      83.402  54.996  -3.935  1.00126.15           O  \\nATOM   3457  C5'  DA J 170      84.144  55.396  -2.788  1.00126.15           C  \\nATOM   3458  C4'  DA J 170      83.251  55.411  -1.573  1.00126.15           C  \\nATOM   3459  O4'  DA J 170      82.447  56.618  -1.533  1.00126.15           O  \\nATOM   3460  C3'  DA J 170      82.272  54.237  -1.519  1.00126.15           C  \\nATOM   3461  O3'  DA J 170      82.262  53.677  -0.204  1.00126.15           O  \\nATOM   3462  C2'  DA J 170      80.934  54.877  -1.853  1.00126.15           C  \\nATOM   3463  C1'  DA J 170      81.096  56.270  -1.273  1.00126.15           C  \\nATOM   3464  N9   DA J 170      80.229  57.290  -1.869  1.00111.14           N  \\nATOM   3465  C8   DA J 170      79.755  57.330  -3.159  1.00111.14           C  \\nATOM   3466  N7   DA J 170      78.984  58.362  -3.411  1.00111.14           N  \\nATOM   3467  C5   DA J 170      78.948  59.052  -2.209  1.00111.14           C  \\nATOM   3468  C6   DA J 170      78.303  60.237  -1.825  1.00111.14           C  \\nATOM   3469  N6   DA J 170      77.543  60.966  -2.652  1.00111.14           N  \\nATOM   3470  N1   DA J 170      78.467  60.655  -0.550  1.00111.14           N  \\nATOM   3471  C2   DA J 170      79.234  59.924   0.273  1.00111.14           C  \\nATOM   3472  N3   DA J 170      79.895  58.795   0.028  1.00111.14           N  \\nATOM   3473  C4   DA J 170      79.710  58.405  -1.246  1.00111.14           C  \\nATOM   3474  P    DC J 171      81.172  52.564   0.182  1.00146.06           P  \\nATOM   3475  OP1  DC J 171      81.870  51.480   0.910  1.00146.06           O  \\nATOM   3476  OP2  DC J 171      80.382  52.241  -1.038  1.00146.06           O  \\nATOM   3477  O5'  DC J 171      80.231  53.332   1.211  1.00102.70           O  \\nATOM   3478  C5'  DC J 171      80.783  54.237   2.177  1.00102.70           C  \\nATOM   3479  C4'  DC J 171      79.759  54.541   3.246  1.00102.70           C  \\nATOM   3480  O4'  DC J 171      78.961  55.677   2.833  1.00102.70           O  \\nATOM   3481  C3'  DC J 171      78.777  53.395   3.454  1.00102.70           C  \\nATOM   3482  O3'  DC J 171      78.413  53.248   4.822  1.00102.70           O  \\nATOM   3483  C2'  DC J 171      77.582  53.775   2.601  1.00102.70           C  \\nATOM   3484  C1'  DC J 171      77.607  55.294   2.603  1.00102.70           C  \\nATOM   3485  N1   DC J 171      77.193  55.870   1.310  1.00103.61           N  \\nATOM   3486  C2   DC J 171      76.563  57.117   1.292  1.00103.61           C  \\nATOM   3487  O2   DC J 171      76.386  57.714   2.364  1.00103.61           O  \\nATOM   3488  N3   DC J 171      76.167  57.639   0.103  1.00103.61           N  \\nATOM   3489  C4   DC J 171      76.388  56.965  -1.033  1.00103.61           C  \\nATOM   3490  N4   DC J 171      75.980  57.512  -2.182  1.00103.61           N  \\nATOM   3491  C5   DC J 171      77.036  55.698  -1.042  1.00103.61           C  \\nATOM   3492  C6   DC J 171      77.417  55.192   0.140  1.00103.61           C  \\nATOM   3493  P    DC J 172      77.467  52.027   5.243  1.00104.62           P  \\nATOM   3494  OP1  DC J 172      77.166  52.126   6.691  1.00104.62           O  \\nATOM   3495  OP2  DC J 172      78.051  50.773   4.698  1.00104.62           O  \\nATOM   3496  O5'  DC J 172      76.142  52.327   4.417  1.00 98.24           O  \\nATOM   3497  C5'  DC J 172      74.897  51.752   4.791  1.00 98.24           C  \\nATOM   3498  C4'  DC J 172      74.025  52.795   5.449  1.00 98.24           C  \\nATOM   3499  O4'  DC J 172      74.009  54.001   4.654  1.00 98.24           O  \\nATOM   3500  C3'  DC J 172      72.572  52.374   5.604  1.00 98.24           C  \\nATOM   3501  O3'  DC J 172      72.055  52.906   6.818  1.00 98.24           O  \\nATOM   3502  C2'  DC J 172      71.895  52.997   4.399  1.00 98.24           C  \\nATOM   3503  C1'  DC J 172      72.709  54.253   4.147  1.00 98.24           C  \\nATOM   3504  N1   DC J 172      72.857  54.560   2.721  1.00 99.46           N  \\nATOM   3505  C2   DC J 172      73.074  55.882   2.330  1.00 99.46           C  \\nATOM   3506  O2   DC J 172      73.099  56.773   3.200  1.00 99.46           O  \\nATOM   3507  N3   DC J 172      73.245  56.159   1.014  1.00 99.46           N  \\nATOM   3508  C4   DC J 172      73.189  55.175   0.111  1.00 99.46           C  \\nATOM   3509  N4   DC J 172      73.367  55.490  -1.176  1.00 99.46           N  \\nATOM   3510  C5   DC J 172      72.950  53.826   0.487  1.00 99.46           C  \\nATOM   3511  C6   DC J 172      72.794  53.565   1.788  1.00 99.46           C  \\nATOM   3512  P    DA J 173      71.116  51.999   7.751  1.00138.20           P  \\nATOM   3513  OP1  DA J 173      71.910  51.554   8.925  1.00138.20           O  \\nATOM   3514  OP2  DA J 173      70.438  50.985   6.897  1.00138.20           O  \\nATOM   3515  O5'  DA J 173      70.031  53.048   8.253  1.00 80.00           O  \\nATOM   3516  C5'  DA J 173      70.400  54.410   8.483  1.00 80.00           C  \\nATOM   3517  C4'  DA J 173      69.457  55.338   7.754  1.00 80.00           C  \\nATOM   3518  O4'  DA J 173      69.713  55.294   6.325  1.00 80.00           O  \\nATOM   3519  C3'  DA J 173      67.985  54.978   7.939  1.00 80.00           C  \\nATOM   3520  O3'  DA J 173      67.207  56.149   8.169  1.00 80.00           O  \\nATOM   3521  C2'  DA J 173      67.602  54.341   6.615  1.00 80.00           C  \\nATOM   3522  C1'  DA J 173      68.505  55.050   5.625  1.00 80.00           C  \\nATOM   3523  N9   DA J 173      68.815  54.242   4.443  1.00 81.91           N  \\nATOM   3524  C8   DA J 173      68.714  52.878   4.330  1.00 81.91           C  \\nATOM   3525  N7   DA J 173      69.046  52.416   3.146  1.00 81.91           N  \\nATOM   3526  C5   DA J 173      69.393  53.553   2.430  1.00 81.91           C  \\nATOM   3527  C6   DA J 173      69.841  53.740   1.104  1.00 81.91           C  \\nATOM   3528  N6   DA J 173      70.026  52.746   0.229  1.00 81.91           N  \\nATOM   3529  N1   DA J 173      70.097  55.000   0.703  1.00 81.91           N  \\nATOM   3530  C2   DA J 173      69.919  55.997   1.579  1.00 81.91           C  \\nATOM   3531  N3   DA J 173      69.508  55.950   2.848  1.00 81.91           N  \\nATOM   3532  C4   DA J 173      69.257  54.686   3.217  1.00 81.91           C  \\nATOM   3533  P    DA J 174      65.692  56.011   8.692  1.00126.78           P  \\nATOM   3534  OP1  DA J 174      65.648  56.471  10.105  1.00126.78           O  \\nATOM   3535  OP2  DA J 174      65.191  54.658   8.342  1.00126.78           O  \\nATOM   3536  O5'  DA J 174      64.893  57.045   7.786  1.00 83.96           O  \\nATOM   3537  C5'  DA J 174      65.579  58.106   7.127  1.00 83.96           C  \\nATOM   3538  C4'  DA J 174      65.105  58.227   5.698  1.00 83.96           C  \\nATOM   3539  O4'  DA J 174      65.700  57.224   4.834  1.00 83.96           O  \\nATOM   3540  C3'  DA J 174      63.591  58.105   5.522  1.00 83.96           C  \\nATOM   3541  O3'  DA J 174      63.146  59.119   4.627  1.00 83.96           O  \\nATOM   3542  C2'  DA J 174      63.417  56.742   4.873  1.00 83.96           C  \\nATOM   3543  C1'  DA J 174      64.677  56.648   4.034  1.00 83.96           C  \\nATOM   3544  N9   DA J 174      65.078  55.287   3.678  1.00 86.48           N  \\nATOM   3545  C8   DA J 174      64.953  54.152   4.434  1.00 86.48           C  \\nATOM   3546  N7   DA J 174      65.365  53.065   3.826  1.00 86.48           N  \\nATOM   3547  C5   DA J 174      65.796  53.518   2.587  1.00 86.48           C  \\nATOM   3548  C6   DA J 174      66.329  52.852   1.465  1.00 86.48           C  \\nATOM   3549  N6   DA J 174      66.515  51.533   1.401  1.00 86.48           N  \\nATOM   3550  N1   DA J 174      66.660  53.598   0.394  1.00 86.48           N  \\nATOM   3551  C2   DA J 174      66.459  54.914   0.450  1.00 86.48           C  \\nATOM   3552  N3   DA J 174      65.957  55.652   1.437  1.00 86.48           N  \\nATOM   3553  C4   DA J 174      65.640  54.885   2.489  1.00 86.48           C  \\nATOM   3554  P    DA J 175      62.123  60.238   5.145  1.00117.29           P  \\nATOM   3555  OP1  DA J 175      62.815  61.557   5.183  1.00117.29           O  \\nATOM   3556  OP2  DA J 175      61.481  59.709   6.372  1.00117.29           O  \\nATOM   3557  O5'  DA J 175      61.025  60.265   3.999  1.00 81.99           O  \\nATOM   3558  C5'  DA J 175      60.698  59.079   3.291  1.00 81.99           C  \\nATOM   3559  C4'  DA J 175      61.258  59.153   1.892  1.00 81.99           C  \\nATOM   3560  O4'  DA J 175      62.195  58.073   1.717  1.00 81.99           O  \\nATOM   3561  C3'  DA J 175      60.213  58.992   0.790  1.00 81.99           C  \\nATOM   3562  O3'  DA J 175      60.566  59.777  -0.354  1.00 81.99           O  \\nATOM   3563  C2'  DA J 175      60.282  57.515   0.466  1.00 81.99           C  \\nATOM   3564  C1'  DA J 175      61.747  57.202   0.693  1.00 81.99           C  \\nATOM   3565  N9   DA J 175      61.997  55.832   1.130  1.00 86.90           N  \\nATOM   3566  C8   DA J 175      61.809  55.272   2.371  1.00 86.90           C  \\nATOM   3567  N7   DA J 175      62.159  54.012   2.437  1.00 86.90           N  \\nATOM   3568  C5   DA J 175      62.604  53.723   1.152  1.00 86.90           C  \\nATOM   3569  C6   DA J 175      63.120  52.553   0.566  1.00 86.90           C  \\nATOM   3570  N6   DA J 175      63.293  51.409   1.230  1.00 86.90           N  \\nATOM   3571  N1   DA J 175      63.461  52.602  -0.744  1.00 86.90           N  \\nATOM   3572  C2   DA J 175      63.298  53.754  -1.407  1.00 86.90           C  \\nATOM   3573  N3   DA J 175      62.834  54.917  -0.966  1.00 86.90           N  \\nATOM   3574  C4   DA J 175      62.501  54.833   0.337  1.00 86.90           C  \\nATOM   3575  P    DA J 176      59.413  60.449  -1.252  1.00 79.70           P  \\nATOM   3576  OP1  DA J 176      59.973  61.726  -1.777  1.00 79.70           O  \\nATOM   3577  OP2  DA J 176      58.124  60.442  -0.503  1.00 79.70           O  \\nATOM   3578  O5'  DA J 176      59.237  59.445  -2.465  1.00 61.35           O  \\nATOM   3579  C5'  DA J 176      60.304  59.214  -3.362  1.00 61.35           C  \\nATOM   3580  C4'  DA J 176      60.094  57.896  -4.063  1.00 61.35           C  \\nATOM   3581  O4'  DA J 176      60.399  56.772  -3.200  1.00 61.35           O  \\nATOM   3582  C3'  DA J 176      58.665  57.673  -4.552  1.00 61.35           C  \\nATOM   3583  O3'  DA J 176      58.742  57.072  -5.827  1.00 61.35           O  \\nATOM   3584  C2'  DA J 176      58.107  56.662  -3.564  1.00 61.35           C  \\nATOM   3585  C1'  DA J 176      59.343  55.831  -3.302  1.00 61.35           C  \\nATOM   3586  N9   DA J 176      59.344  55.007  -2.093  1.00 72.02           N  \\nATOM   3587  C8   DA J 176      58.939  55.328  -0.822  1.00 72.02           C  \\nATOM   3588  N7   DA J 176      59.093  54.355   0.045  1.00 72.02           N  \\nATOM   3589  C5   DA J 176      59.630  53.319  -0.710  1.00 72.02           C  \\nATOM   3590  C6   DA J 176      60.023  52.005  -0.383  1.00 72.02           C  \\nATOM   3591  N6   DA J 176      59.936  51.487   0.846  1.00 72.02           N  \\nATOM   3592  N1   DA J 176      60.517  51.231  -1.377  1.00 72.02           N  \\nATOM   3593  C2   DA J 176      60.610  51.748  -2.605  1.00 72.02           C  \\nATOM   3594  N3   DA J 176      60.277  52.960  -3.035  1.00 72.02           N  \\nATOM   3595  C4   DA J 176      59.787  53.707  -2.028  1.00 72.02           C  \\nATOM   3596  P    DG J 177      57.528  57.225  -6.847  1.00 78.59           P  \\nATOM   3597  OP1  DG J 177      57.802  58.347  -7.789  1.00 78.59           O  \\nATOM   3598  OP2  DG J 177      56.282  57.233  -6.034  1.00 78.59           O  \\nATOM   3599  O5'  DG J 177      57.608  55.866  -7.670  1.00 79.54           O  \\nATOM   3600  C5'  DG J 177      58.866  55.378  -8.137  1.00 79.54           C  \\nATOM   3601  C4'  DG J 177      58.877  53.868  -8.134  1.00 79.54           C  \\nATOM   3602  O4'  DG J 177      59.099  53.337  -6.798  1.00 79.54           O  \\nATOM   3603  C3'  DG J 177      57.580  53.242  -8.640  1.00 79.54           C  \\nATOM   3604  O3'  DG J 177      57.862  52.259  -9.631  1.00 79.54           O  \\nATOM   3605  C2'  DG J 177      56.975  52.602  -7.400  1.00 79.54           C  \\nATOM   3606  C1'  DG J 177      58.189  52.282  -6.548  1.00 79.54           C  \\nATOM   3607  N9   DG J 177      57.886  52.268  -5.122  1.00 74.30           N  \\nATOM   3608  C8   DG J 177      57.604  53.354  -4.339  1.00 74.30           C  \\nATOM   3609  N7   DG J 177      57.290  53.036  -3.114  1.00 74.30           N  \\nATOM   3610  C5   DG J 177      57.388  51.655  -3.081  1.00 74.30           C  \\nATOM   3611  C6   DG J 177      57.142  50.742  -2.019  1.00 74.30           C  \\nATOM   3612  O6   DG J 177      56.746  50.984  -0.874  1.00 74.30           O  \\nATOM   3613  N1   DG J 177      57.383  49.427  -2.405  1.00 74.30           N  \\nATOM   3614  C2   DG J 177      57.785  49.035  -3.654  1.00 74.30           C  \\nATOM   3615  N2   DG J 177      57.966  47.708  -3.808  1.00 74.30           N  \\nATOM   3616  N3   DG J 177      57.994  49.876  -4.666  1.00 74.30           N  \\nATOM   3617  C4   DG J 177      57.780  51.164  -4.306  1.00 74.30           C  \\nATOM   3618  P    DT J 178      56.656  51.604 -10.466  1.00114.94           P  \\nATOM   3619  OP1  DT J 178      57.228  51.287 -11.799  1.00114.94           O  \\nATOM   3620  OP2  DT J 178      55.438  52.451 -10.382  1.00114.94           O  \\nATOM   3621  O5'  DT J 178      56.384  50.247  -9.679  1.00105.86           O  \\nATOM   3622  C5'  DT J 178      57.435  49.302  -9.500  1.00105.86           C  \\nATOM   3623  C4'  DT J 178      56.899  48.008  -8.935  1.00105.86           C  \\nATOM   3624  O4'  DT J 178      56.708  48.117  -7.505  1.00105.86           O  \\nATOM   3625  C3'  DT J 178      55.571  47.521  -9.522  1.00105.86           C  \\nATOM   3626  O3'  DT J 178      55.668  46.119  -9.828  1.00105.86           O  \\nATOM   3627  C2'  DT J 178      54.570  47.804  -8.409  1.00105.86           C  \\nATOM   3628  C1'  DT J 178      55.416  47.653  -7.155  1.00105.86           C  \\nATOM   3629  N1   DT J 178      54.966  48.436  -5.990  1.00111.58           N  \\nATOM   3630  C2   DT J 178      54.948  47.817  -4.752  1.00111.58           C  \\nATOM   3631  O2   DT J 178      55.241  46.642  -4.579  1.00111.58           O  \\nATOM   3632  N3   DT J 178      54.567  48.628  -3.716  1.00111.58           N  \\nATOM   3633  C4   DT J 178      54.205  49.961  -3.781  1.00111.58           C  \\nATOM   3634  O4   DT J 178      53.910  50.564  -2.745  1.00111.58           O  \\nATOM   3635  C5   DT J 178      54.215  50.537  -5.114  1.00111.58           C  \\nATOM   3636  C7   DT J 178      53.805  51.964  -5.293  1.00111.58           C  \\nATOM   3637  C6   DT J 178      54.592  49.755  -6.136  1.00111.58           C  \\nATOM   3638  P    DG J 179      54.516  45.384 -10.687  1.00 98.21           P  \\nATOM   3639  OP1  DG J 179      55.164  44.590 -11.763  1.00 98.21           O  \\nATOM   3640  OP2  DG J 179      53.439  46.352 -11.039  1.00 98.21           O  \\nATOM   3641  O5'  DG J 179      53.926  44.374  -9.615  1.00108.05           O  \\nATOM   3642  C5'  DG J 179      54.796  43.714  -8.695  1.00108.05           C  \\nATOM   3643  C4'  DG J 179      53.985  43.047  -7.615  1.00108.05           C  \\nATOM   3644  O4'  DG J 179      53.813  43.920  -6.471  1.00108.05           O  \\nATOM   3645  C3'  DG J 179      52.581  42.697  -8.103  1.00108.05           C  \\nATOM   3646  O3'  DG J 179      52.189  41.408  -7.653  1.00108.05           O  \\nATOM   3647  C2'  DG J 179      51.708  43.756  -7.458  1.00108.05           C  \\nATOM   3648  C1'  DG J 179      52.434  43.982  -6.150  1.00108.05           C  \\nATOM   3649  N9   DG J 179      52.154  45.278  -5.550  1.00 80.42           N  \\nATOM   3650  C8   DG J 179      52.028  46.481  -6.199  1.00 80.42           C  \\nATOM   3651  N7   DG J 179      51.713  47.461  -5.401  1.00 80.42           N  \\nATOM   3652  C5   DG J 179      51.638  46.871  -4.145  1.00 80.42           C  \\nATOM   3653  C6   DG J 179      51.314  47.434  -2.872  1.00 80.42           C  \\nATOM   3654  O6   DG J 179      51.018  48.604  -2.589  1.00 80.42           O  \\nATOM   3655  N1   DG J 179      51.352  46.476  -1.866  1.00 80.42           N  \\nATOM   3656  C2   DG J 179      51.664  45.155  -2.047  1.00 80.42           C  \\nATOM   3657  N2   DG J 179      51.647  44.408  -0.935  1.00 80.42           N  \\nATOM   3658  N3   DG J 179      51.966  44.615  -3.222  1.00 80.42           N  \\nATOM   3659  C4   DG J 179      51.927  45.527  -4.220  1.00 80.42           C  \\nATOM   3660  P    DT J 180      50.949  40.677  -8.354  1.00136.92           P  \\nATOM   3661  OP1  DT J 180      51.477  39.597  -9.220  1.00136.92           O  \\nATOM   3662  OP2  DT J 180      50.064  41.716  -8.943  1.00136.92           O  \\nATOM   3663  O5'  DT J 180      50.196  40.022  -7.120  1.00101.12           O  \\nATOM   3664  C5'  DT J 180      48.937  40.510  -6.692  1.00101.12           C  \\nATOM   3665  C4'  DT J 180      48.822  40.378  -5.194  1.00101.12           C  \\nATOM   3666  O4'  DT J 180      49.304  41.596  -4.567  1.00101.12           O  \\nATOM   3667  C3'  DT J 180      47.377  40.205  -4.740  1.00101.12           C  \\nATOM   3668  O3'  DT J 180      47.268  39.211  -3.724  1.00101.12           O  \\nATOM   3669  C2'  DT J 180      46.983  41.570  -4.218  1.00101.12           C  \\nATOM   3670  C1'  DT J 180      48.295  42.149  -3.727  1.00101.12           C  \\nATOM   3671  N1   DT J 180      48.314  43.629  -3.854  1.00 87.11           N  \\nATOM   3672  C2   DT J 180      48.075  44.380  -2.721  1.00 87.11           C  \\nATOM   3673  O2   DT J 180      47.954  43.895  -1.610  1.00 87.11           O  \\nATOM   3674  N3   DT J 180      47.992  45.727  -2.937  1.00 87.11           N  \\nATOM   3675  C4   DT J 180      48.144  46.394  -4.129  1.00 87.11           C  \\nATOM   3676  O4   DT J 180      48.004  47.612  -4.158  1.00 87.11           O  \\nATOM   3677  C5   DT J 180      48.457  45.555  -5.268  1.00 87.11           C  \\nATOM   3678  C7   DT J 180      48.700  46.189  -6.599  1.00 87.11           C  \\nATOM   3679  C6   DT J 180      48.523  44.233  -5.075  1.00 87.11           C  \\nATOM   3680  P    DA J 181      45.813  38.715  -3.264  1.00141.70           P  \\nATOM   3681  OP1  DA J 181      45.957  37.481  -2.451  1.00141.70           O  \\nATOM   3682  OP2  DA J 181      44.936  38.708  -4.464  1.00141.70           O  \\nATOM   3683  O5'  DA J 181      45.336  39.888  -2.306  1.00123.98           O  \\nATOM   3684  C5'  DA J 181      46.029  40.144  -1.092  1.00123.98           C  \\nATOM   3685  C4'  DA J 181      45.119  40.861  -0.127  1.00123.98           C  \\nATOM   3686  O4'  DA J 181      45.132  42.285  -0.387  1.00123.98           O  \\nATOM   3687  C3'  DA J 181      43.662  40.414  -0.206  1.00123.98           C  \\nATOM   3688  O3'  DA J 181      43.141  40.269   1.119  1.00123.98           O  \\nATOM   3689  C2'  DA J 181      42.994  41.515  -1.019  1.00123.98           C  \\nATOM   3690  C1'  DA J 181      43.826  42.756  -0.694  1.00123.98           C  \\nATOM   3691  N9   DA J 181      43.960  43.740  -1.777  1.00 91.38           N  \\nATOM   3692  C8   DA J 181      43.901  43.529  -3.138  1.00 91.38           C  \\nATOM   3693  N7   DA J 181      44.109  44.612  -3.852  1.00 91.38           N  \\nATOM   3694  C5   DA J 181      44.308  45.604  -2.901  1.00 91.38           C  \\nATOM   3695  C6   DA J 181      44.580  46.976  -3.014  1.00 91.38           C  \\nATOM   3696  N6   DA J 181      44.725  47.610  -4.179  1.00 91.38           N  \\nATOM   3697  N1   DA J 181      44.706  47.688  -1.871  1.00 91.38           N  \\nATOM   3698  C2   DA J 181      44.576  47.052  -0.702  1.00 91.38           C  \\nATOM   3699  N3   DA J 181      44.332  45.765  -0.465  1.00 91.38           N  \\nATOM   3700  C4   DA J 181      44.204  45.086  -1.620  1.00 91.38           C  \\nATOM   3701  P    DT J 182      41.557  40.167   1.357  1.00 90.97           P  \\nATOM   3702  OP1  DT J 182      41.327  39.348   2.584  1.00 90.97           O  \\nATOM   3703  OP2  DT J 182      40.902  39.784   0.073  1.00 90.97           O  \\nATOM   3704  O5'  DT J 182      41.179  41.673   1.689  1.00154.72           O  \\nATOM   3705  C5'  DT J 182      41.832  42.352   2.760  1.00154.72           C  \\nATOM   3706  C4'  DT J 182      41.053  43.587   3.134  1.00154.72           C  \\nATOM   3707  O4'  DT J 182      41.334  44.640   2.180  1.00154.72           O  \\nATOM   3708  C3'  DT J 182      39.542  43.359   3.101  1.00154.72           C  \\nATOM   3709  O3'  DT J 182      38.906  43.958   4.237  1.00154.72           O  \\nATOM   3710  C2'  DT J 182      39.118  43.981   1.781  1.00154.72           C  \\nATOM   3711  C1'  DT J 182      40.127  45.102   1.597  1.00154.72           C  \\nATOM   3712  N1   DT J 182      40.396  45.441   0.184  1.00 78.21           N  \\nATOM   3713  C2   DT J 182      40.851  46.717  -0.125  1.00 78.21           C  \\nATOM   3714  O2   DT J 182      41.064  47.584   0.716  1.00 78.21           O  \\nATOM   3715  N3   DT J 182      41.047  46.942  -1.470  1.00 78.21           N  \\nATOM   3716  C4   DT J 182      40.852  46.046  -2.509  1.00 78.21           C  \\nATOM   3717  O4   DT J 182      41.093  46.392  -3.668  1.00 78.21           O  \\nATOM   3718  C5   DT J 182      40.369  44.734  -2.109  1.00 78.21           C  \\nATOM   3719  C7   DT J 182      40.095  43.707  -3.161  1.00 78.21           C  \\nATOM   3720  C6   DT J 182      40.178  44.501  -0.801  1.00 78.21           C  \\nATOM   3721  P    DT J 183      37.380  44.454   4.132  1.00 66.93           P  \\nATOM   3722  OP1  DT J 183      36.753  44.437   5.483  1.00 66.93           O  \\nATOM   3723  OP2  DT J 183      36.731  43.720   3.004  1.00 66.93           O  \\nATOM   3724  O5'  DT J 183      37.566  45.977   3.705  1.00 77.51           O  \\nATOM   3725  C5'  DT J 183      38.719  46.711   4.142  1.00 77.51           C  \\nATOM   3726  C4'  DT J 183      38.562  48.181   3.828  1.00 77.51           C  \\nATOM   3727  O4'  DT J 183      38.916  48.478   2.454  1.00 77.51           O  \\nATOM   3728  C3'  DT J 183      37.144  48.703   4.034  1.00 77.51           C  \\nATOM   3729  O3'  DT J 183      37.192  49.951   4.716  1.00 77.51           O  \\nATOM   3730  C2'  DT J 183      36.603  48.848   2.621  1.00 77.51           C  \\nATOM   3731  C1'  DT J 183      37.852  49.169   1.818  1.00 77.51           C  \\nATOM   3732  N1   DT J 183      37.804  48.730   0.411  1.00 83.98           N  \\nATOM   3733  C2   DT J 183      38.280  49.586  -0.556  1.00 83.98           C  \\nATOM   3734  O2   DT J 183      38.737  50.684  -0.312  1.00 83.98           O  \\nATOM   3735  N3   DT J 183      38.205  49.105  -1.831  1.00 83.98           N  \\nATOM   3736  C4   DT J 183      37.730  47.879  -2.234  1.00 83.98           C  \\nATOM   3737  O4   DT J 183      37.749  47.583  -3.422  1.00 83.98           O  \\nATOM   3738  C5   DT J 183      37.243  47.029  -1.175  1.00 83.98           C  \\nATOM   3739  C7   DT J 183      36.705  45.677  -1.522  1.00 83.98           C  \\nATOM   3740  C6   DT J 183      37.298  47.493   0.080  1.00 83.98           C  \\nATOM   3741  P    DT J 184      35.831  50.645   5.195  1.00 65.25           P  \\nATOM   3742  OP1  DT J 184      36.127  51.329   6.483  1.00 65.25           O  \\nATOM   3743  OP2  DT J 184      34.728  49.651   5.126  1.00 65.25           O  \\nATOM   3744  O5'  DT J 184      35.566  51.730   4.055  1.00 61.23           O  \\nATOM   3745  C5'  DT J 184      36.546  52.730   3.756  1.00 61.23           C  \\nATOM   3746  C4'  DT J 184      36.065  53.631   2.642  1.00 61.23           C  \\nATOM   3747  O4'  DT J 184      36.157  52.979   1.352  1.00 61.23           O  \\nATOM   3748  C3'  DT J 184      34.615  54.096   2.781  1.00 61.23           C  \\nATOM   3749  O3'  DT J 184      34.515  55.450   2.337  1.00 61.23           O  \\nATOM   3750  C2'  DT J 184      33.883  53.199   1.803  1.00 61.23           C  \\nATOM   3751  C1'  DT J 184      34.910  53.090   0.700  1.00 61.23           C  \\nATOM   3752  N1   DT J 184      34.758  51.931  -0.167  1.00 51.98           N  \\nATOM   3753  C2   DT J 184      35.157  52.070  -1.469  1.00 51.98           C  \\nATOM   3754  O2   DT J 184      35.660  53.088  -1.913  1.00 51.98           O  \\nATOM   3755  N3   DT J 184      34.956  50.971  -2.242  1.00 51.98           N  \\nATOM   3756  C4   DT J 184      34.428  49.766  -1.852  1.00 51.98           C  \\nATOM   3757  O4   DT J 184      34.304  48.875  -2.669  1.00 51.98           O  \\nATOM   3758  C5   DT J 184      34.055  49.674  -0.466  1.00 51.98           C  \\nATOM   3759  C7   DT J 184      33.502  48.385   0.047  1.00 51.98           C  \\nATOM   3760  C6   DT J 184      34.229  50.753   0.302  1.00 51.98           C  \\nATOM   3761  P    DG J 185      34.470  56.647   3.410  1.00 67.28           P  \\nATOM   3762  OP1  DG J 185      35.608  56.507   4.363  1.00 67.28           O  \\nATOM   3763  OP2  DG J 185      33.081  56.720   3.930  1.00 67.28           O  \\nATOM   3764  O5'  DG J 185      34.726  57.937   2.510  1.00 58.47           O  \\nATOM   3765  C5'  DG J 185      36.005  58.181   1.925  1.00 58.47           C  \\nATOM   3766  C4'  DG J 185      35.846  58.614   0.486  1.00 58.47           C  \\nATOM   3767  O4'  DG J 185      35.335  57.523  -0.313  1.00 58.47           O  \\nATOM   3768  C3'  DG J 185      34.866  59.762   0.288  1.00 58.47           C  \\nATOM   3769  O3'  DG J 185      35.316  60.557  -0.806  1.00 58.47           O  \\nATOM   3770  C2'  DG J 185      33.572  59.049  -0.055  1.00 58.47           C  \\nATOM   3771  C1'  DG J 185      34.052  57.841  -0.836  1.00 58.47           C  \\nATOM   3772  N9   DG J 185      33.220  56.653  -0.676  1.00 60.29           N  \\nATOM   3773  C8   DG J 185      32.647  56.191   0.489  1.00 60.29           C  \\nATOM   3774  N7   DG J 185      32.037  55.045   0.343  1.00 60.29           N  \\nATOM   3775  C5   DG J 185      32.205  54.738  -1.004  1.00 60.29           C  \\nATOM   3776  C6   DG J 185      31.796  53.602  -1.747  1.00 60.29           C  \\nATOM   3777  O6   DG J 185      31.217  52.590  -1.344  1.00 60.29           O  \\nATOM   3778  N1   DG J 185      32.145  53.710  -3.090  1.00 60.29           N  \\nATOM   3779  C2   DG J 185      32.801  54.773  -3.649  1.00 60.29           C  \\nATOM   3780  N2   DG J 185      32.984  54.710  -4.978  1.00 60.29           N  \\nATOM   3781  N3   DG J 185      33.229  55.822  -2.963  1.00 60.29           N  \\nATOM   3782  C4   DG J 185      32.899  55.739  -1.655  1.00 60.29           C  \\nATOM   3783  P    DG J 186      34.758  62.042  -0.994  1.00 35.38           P  \\nATOM   3784  OP1  DG J 186      35.885  62.874  -1.482  1.00 35.38           O  \\nATOM   3785  OP2  DG J 186      34.065  62.399   0.270  1.00 35.38           O  \\nATOM   3786  O5'  DG J 186      33.736  61.890  -2.196  1.00 53.97           O  \\nATOM   3787  C5'  DG J 186      34.171  61.347  -3.431  1.00 53.97           C  \\nATOM   3788  C4'  DG J 186      32.978  60.881  -4.226  1.00 53.97           C  \\nATOM   3789  O4'  DG J 186      32.419  59.671  -3.648  1.00 53.97           O  \\nATOM   3790  C3'  DG J 186      31.842  61.908  -4.230  1.00 53.97           C  \\nATOM   3791  O3'  DG J 186      31.200  61.919  -5.508  1.00 53.97           O  \\nATOM   3792  C2'  DG J 186      30.877  61.353  -3.198  1.00 53.97           C  \\nATOM   3793  C1'  DG J 186      31.027  59.876  -3.475  1.00 53.97           C  \\nATOM   3794  N9   DG J 186      30.526  58.951  -2.462  1.00 62.85           N  \\nATOM   3795  C8   DG J 186      30.332  59.165  -1.115  1.00 62.85           C  \\nATOM   3796  N7   DG J 186      29.857  58.119  -0.493  1.00 62.85           N  \\nATOM   3797  C5   DG J 186      29.741  57.157  -1.489  1.00 62.85           C  \\nATOM   3798  C6   DG J 186      29.297  55.802  -1.427  1.00 62.85           C  \\nATOM   3799  O6   DG J 186      28.947  55.140  -0.425  1.00 62.85           O  \\nATOM   3800  N1   DG J 186      29.304  55.210  -2.697  1.00 62.85           N  \\nATOM   3801  C2   DG J 186      29.727  55.830  -3.863  1.00 62.85           C  \\nATOM   3802  N2   DG J 186      29.666  55.115  -4.997  1.00 62.85           N  \\nATOM   3803  N3   DG J 186      30.175  57.065  -3.917  1.00 62.85           N  \\nATOM   3804  C4   DG J 186      30.145  57.667  -2.709  1.00 62.85           C  \\nATOM   3805  P    DA J 187      31.310  63.217  -6.443  1.00 64.00           P  \\nATOM   3806  OP1  DA J 187      32.739  63.638  -6.433  1.00 64.00           O  \\nATOM   3807  OP2  DA J 187      30.245  64.174  -6.026  1.00 64.00           O  \\nATOM   3808  O5'  DA J 187      30.946  62.657  -7.886  1.00 77.10           O  \\nATOM   3809  C5'  DA J 187      31.682  61.575  -8.459  1.00 77.10           C  \\nATOM   3810  C4'  DA J 187      30.740  60.614  -9.151  1.00 77.10           C  \\nATOM   3811  O4'  DA J 187      30.155  59.695  -8.196  1.00 77.10           O  \\nATOM   3812  C3'  DA J 187      29.574  61.294  -9.869  1.00 77.10           C  \\nATOM   3813  O3'  DA J 187      29.327  60.668 -11.134  1.00 77.10           O  \\nATOM   3814  C2'  DA J 187      28.411  61.100  -8.914  1.00 77.10           C  \\nATOM   3815  C1'  DA J 187      28.738  59.780  -8.234  1.00 77.10           C  \\nATOM   3816  N9   DA J 187      28.257  59.696  -6.858  1.00 72.73           N  \\nATOM   3817  C8   DA J 187      28.174  60.707  -5.930  1.00 72.73           C  \\nATOM   3818  N7   DA J 187      27.713  60.322  -4.767  1.00 72.73           N  \\nATOM   3819  C5   DA J 187      27.468  58.963  -4.940  1.00 72.73           C  \\nATOM   3820  C6   DA J 187      26.966  57.960  -4.067  1.00 72.73           C  \\nATOM   3821  N6   DA J 187      26.607  58.190  -2.794  1.00 72.73           N  \\nATOM   3822  N1   DA J 187      26.846  56.701  -4.558  1.00 72.73           N  \\nATOM   3823  C2   DA J 187      27.205  56.474  -5.828  1.00 72.73           C  \\nATOM   3824  N3   DA J 187      27.687  57.328  -6.741  1.00 72.73           N  \\nATOM   3825  C4   DA J 187      27.796  58.567  -6.226  1.00 72.73           C  \\nATOM   3826  P    DA J 188      28.331  61.364 -12.193  1.00128.75           P  \\nATOM   3827  OP1  DA J 188      28.974  61.358 -13.533  1.00128.75           O  \\nATOM   3828  OP2  DA J 188      27.848  62.646 -11.616  1.00128.75           O  \\nATOM   3829  O5'  DA J 188      27.103  60.356 -12.235  1.00 96.02           O  \\nATOM   3830  C5'  DA J 188      27.323  58.968 -12.472  1.00 96.02           C  \\nATOM   3831  C4'  DA J 188      26.005  58.243 -12.603  1.00 96.02           C  \\nATOM   3832  O4'  DA J 188      25.568  57.774 -11.306  1.00 96.02           O  \\nATOM   3833  C3'  DA J 188      24.886  59.106 -13.177  1.00 96.02           C  \\nATOM   3834  O3'  DA J 188      24.423  58.586 -14.437  1.00 96.02           O  \\nATOM   3835  C2'  DA J 188      23.914  59.329 -12.027  1.00 96.02           C  \\nATOM   3836  C1'  DA J 188      24.324  58.343 -10.926  1.00 96.02           C  \\nATOM   3837  N9   DA J 188      24.508  58.981  -9.611  1.00 96.48           N  \\nATOM   3838  C8   DA J 188      24.919  60.274  -9.381  1.00 96.48           C  \\nATOM   3839  N7   DA J 188      24.947  60.606  -8.111  1.00 96.48           N  \\nATOM   3840  C5   DA J 188      24.538  59.454  -7.454  1.00 96.48           C  \\nATOM   3841  C6   DA J 188      24.340  59.160  -6.084  1.00 96.48           C  \\nATOM   3842  N6   DA J 188      24.535  60.039  -5.097  1.00 96.48           N  \\nATOM   3843  N1   DA J 188      23.926  57.916  -5.761  1.00 96.48           N  \\nATOM   3844  C2   DA J 188      23.728  57.036  -6.746  1.00 96.48           C  \\nATOM   3845  N3   DA J 188      23.874  57.191  -8.066  1.00 96.48           N  \\nATOM   3846  C4   DA J 188      24.282  58.438  -8.361  1.00 96.48           C  \\nATOM   3847  P    DA J 189      23.043  57.778 -14.567  1.00 87.94           P  \\nATOM   3848  OP1  DA J 189      23.442  56.523 -15.247  1.00 87.94           O  \\nATOM   3849  OP2  DA J 189      22.030  58.665 -15.197  1.00 87.94           O  \\nATOM   3850  O5'  DA J 189      22.568  57.422 -13.087  1.00110.01           O  \\nATOM   3851  C5'  DA J 189      21.977  56.151 -12.809  1.00110.01           C  \\nATOM   3852  C4'  DA J 189      20.580  56.312 -12.252  1.00110.01           C  \\nATOM   3853  O4'  DA J 189      20.655  56.871 -10.918  1.00110.01           O  \\nATOM   3854  C3'  DA J 189      19.600  57.194 -13.042  1.00110.01           C  \\nATOM   3855  O3'  DA J 189      18.315  56.530 -13.164  1.00110.01           O  \\nATOM   3856  C2'  DA J 189      19.520  58.459 -12.204  1.00110.01           C  \\nATOM   3857  C1'  DA J 189      19.741  57.944 -10.790  1.00110.01           C  \\nATOM   3858  N9   DA J 189      20.321  58.932  -9.877  1.00 55.04           N  \\nATOM   3859  C8   DA J 189      21.006  60.070 -10.224  1.00 55.04           C  \\nATOM   3860  N7   DA J 189      21.387  60.794  -9.198  1.00 55.04           N  \\nATOM   3861  C5   DA J 189      20.930  60.086  -8.098  1.00 55.04           C  \\nATOM   3862  C6   DA J 189      21.009  60.334  -6.716  1.00 55.04           C  \\nATOM   3863  N6   DA J 189      21.570  61.422  -6.194  1.00 55.04           N  \\nATOM   3864  N1   DA J 189      20.473  59.423  -5.880  1.00 55.04           N  \\nATOM   3865  C2   DA J 189      19.877  58.347  -6.407  1.00 55.04           C  \\nATOM   3866  N3   DA J 189      19.718  58.010  -7.690  1.00 55.04           N  \\nATOM   3867  C4   DA J 189      20.278  58.930  -8.497  1.00 55.04           C  \\nATOM   3868  P    DC J 190      17.009  57.338 -13.689  1.00 94.27           P  \\nATOM   3869  OP1  DC J 190      15.903  56.361 -13.873  1.00 94.27           O  \\nATOM   3870  OP2  DC J 190      17.399  58.216 -14.830  1.00 94.27           O  \\nATOM   3871  O5'  DC J 190      16.643  58.243 -12.428  1.00104.70           O  \\nATOM   3872  C5'  DC J 190      15.297  58.588 -12.133  1.00104.70           C  \\nATOM   3873  C4'  DC J 190      14.937  58.163 -10.727  1.00104.70           C  \\nATOM   3874  O4'  DC J 190      16.023  58.419  -9.802  1.00104.70           O  \\nATOM   3875  C3'  DC J 190      13.729  58.918 -10.178  1.00104.70           C  \\nATOM   3876  O3'  DC J 190      12.847  58.042  -9.492  1.00104.70           O  \\nATOM   3877  C2'  DC J 190      14.322  59.930  -9.218  1.00104.70           C  \\nATOM   3878  C1'  DC J 190      15.573  59.234  -8.725  1.00104.70           C  \\nATOM   3879  N1   DC J 190      16.641  60.188  -8.399  1.00 60.46           N  \\nATOM   3880  C2   DC J 190      16.854  60.528  -7.057  1.00 60.46           C  \\nATOM   3881  O2   DC J 190      16.139  60.015  -6.187  1.00 60.46           O  \\nATOM   3882  N3   DC J 190      17.829  61.417  -6.744  1.00 60.46           N  \\nATOM   3883  C4   DC J 190      18.568  61.969  -7.715  1.00 60.46           C  \\nATOM   3884  N4   DC J 190      19.513  62.856  -7.365  1.00 60.46           N  \\nATOM   3885  C5   DC J 190      18.371  61.639  -9.092  1.00 60.46           C  \\nATOM   3886  C6   DC J 190      17.409  60.748  -9.384  1.00 60.46           C  \\nATOM   3887  P    DT J 191      11.332  58.495  -9.261  1.00111.31           P  \\nATOM   3888  OP1  DT J 191      10.571  57.346  -8.708  1.00111.31           O  \\nATOM   3889  OP2  DT J 191      10.880  59.140 -10.518  1.00111.31           O  \\nATOM   3890  O5'  DT J 191      11.465  59.616  -8.141  1.00103.30           O  \\nATOM   3891  C5'  DT J 191      11.838  59.259  -6.815  1.00103.30           C  \\nATOM   3892  C4'  DT J 191      11.827  60.473  -5.918  1.00103.30           C  \\nATOM   3893  O4'  DT J 191      13.034  61.248  -6.096  1.00103.30           O  \\nATOM   3894  C3'  DT J 191      10.662  61.437  -6.147  1.00103.30           C  \\nATOM   3895  O3'  DT J 191      10.177  61.896  -4.886  1.00103.30           O  \\nATOM   3896  C2'  DT J 191      11.316  62.591  -6.885  1.00103.30           C  \\nATOM   3897  C1'  DT J 191      12.667  62.605  -6.207  1.00103.30           C  \\nATOM   3898  N1   DT J 191      13.748  63.317  -6.897  1.00 61.88           N  \\nATOM   3899  C2   DT J 191      14.745  63.858  -6.109  1.00 61.88           C  \\nATOM   3900  O2   DT J 191      14.745  63.790  -4.882  1.00 61.88           O  \\nATOM   3901  N3   DT J 191      15.741  64.492  -6.811  1.00 61.88           N  \\nATOM   3902  C4   DT J 191      15.839  64.633  -8.184  1.00 61.88           C  \\nATOM   3903  O4   DT J 191      16.810  65.200  -8.671  1.00 61.88           O  \\nATOM   3904  C5   DT J 191      14.745  64.069  -8.938  1.00 61.88           C  \\nATOM   3905  C7   DT J 191      14.740  64.216 -10.423  1.00 61.88           C  \\nATOM   3906  C6   DT J 191      13.771  63.439  -8.267  1.00 61.88           C  \\nATOM   3907  P    DG J 192       8.599  62.019  -4.639  1.00 89.02           P  \\nATOM   3908  OP1  DG J 192       8.003  60.670  -4.800  1.00 89.02           O  \\nATOM   3909  OP2  DG J 192       8.120  63.152  -5.477  1.00 89.02           O  \\nATOM   3910  O5'  DG J 192       8.475  62.440  -3.112  1.00 84.27           O  \\nATOM   3911  C5'  DG J 192       9.464  62.051  -2.167  1.00 84.27           C  \\nATOM   3912  C4'  DG J 192      10.089  63.275  -1.537  1.00 84.27           C  \\nATOM   3913  O4'  DG J 192      11.064  63.901  -2.411  1.00 84.27           O  \\nATOM   3914  C3'  DG J 192       9.103  64.376  -1.154  1.00 84.27           C  \\nATOM   3915  O3'  DG J 192       9.474  64.877   0.130  1.00 84.27           O  \\nATOM   3916  C2'  DG J 192       9.312  65.431  -2.233  1.00 84.27           C  \\nATOM   3917  C1'  DG J 192      10.804  65.298  -2.491  1.00 84.27           C  \\nATOM   3918  N9   DG J 192      11.324  65.783  -3.774  1.00 66.15           N  \\nATOM   3919  C8   DG J 192      10.878  65.457  -5.035  1.00 66.15           C  \\nATOM   3920  N7   DG J 192      11.617  65.964  -5.991  1.00 66.15           N  \\nATOM   3921  C5   DG J 192      12.597  66.689  -5.325  1.00 66.15           C  \\nATOM   3922  C6   DG J 192      13.706  67.437  -5.833  1.00 66.15           C  \\nATOM   3923  O6   DG J 192      14.077  67.592  -7.012  1.00 66.15           O  \\nATOM   3924  N1   DG J 192      14.430  68.024  -4.806  1.00 66.15           N  \\nATOM   3925  C2   DG J 192      14.142  67.904  -3.464  1.00 66.15           C  \\nATOM   3926  N2   DG J 192      14.958  68.564  -2.630  1.00 66.15           N  \\nATOM   3927  N3   DG J 192      13.134  67.197  -2.978  1.00 66.15           N  \\nATOM   3928  C4   DG J 192      12.409  66.619  -3.955  1.00 66.15           C  \\nATOM   3929  P    DC J 193       8.409  65.695   1.009  1.00106.91           P  \\nATOM   3930  OP1  DC J 193       8.360  65.105   2.377  1.00106.91           O  \\nATOM   3931  OP2  DC J 193       7.166  65.808   0.199  1.00106.91           O  \\nATOM   3932  O5'  DC J 193       9.063  67.142   1.115  1.00 88.46           O  \\nATOM   3933  C5'  DC J 193      10.481  67.313   1.027  1.00 88.46           C  \\nATOM   3934  C4'  DC J 193      10.824  68.747   0.696  1.00 88.46           C  \\nATOM   3935  O4'  DC J 193      11.170  68.864  -0.703  1.00 88.46           O  \\nATOM   3936  C3'  DC J 193       9.716  69.779   0.940  1.00 88.46           C  \\nATOM   3937  O3'  DC J 193      10.318  70.990   1.400  1.00 88.46           O  \\nATOM   3938  C2'  DC J 193       9.161  70.013  -0.452  1.00 88.46           C  \\nATOM   3939  C1'  DC J 193      10.436  69.939  -1.257  1.00 88.46           C  \\nATOM   3940  N1   DC J 193      10.289  69.700  -2.693  1.00 88.37           N  \\nATOM   3941  C2   DC J 193      11.168  70.353  -3.560  1.00 88.37           C  \\nATOM   3942  O2   DC J 193      12.047  71.093  -3.079  1.00 88.37           O  \\nATOM   3943  N3   DC J 193      11.048  70.163  -4.895  1.00 88.37           N  \\nATOM   3944  C4   DC J 193      10.097  69.355  -5.370  1.00 88.37           C  \\nATOM   3945  N4   DC J 193      10.012  69.208  -6.702  1.00 88.37           N  \\nATOM   3946  C5   DC J 193       9.192  68.667  -4.504  1.00 88.37           C  \\nATOM   3947  C6   DC J 193       9.322  68.869  -3.184  1.00 88.37           C  \\nATOM   3948  P    DT J 194       9.946  71.584   2.850  1.00 87.58           P  \\nATOM   3949  OP1  DT J 194       9.948  70.532   3.914  1.00 87.58           O  \\nATOM   3950  OP2  DT J 194       8.744  72.433   2.644  1.00 87.58           O  \\nATOM   3951  O5'  DT J 194      11.158  72.562   3.160  1.00 77.34           O  \\nATOM   3952  C5'  DT J 194      11.190  73.870   2.605  1.00 77.34           C  \\nATOM   3953  C4'  DT J 194      12.567  74.177   2.068  1.00 77.34           C  \\nATOM   3954  O4'  DT J 194      12.699  73.700   0.707  1.00 77.34           O  \\nATOM   3955  C3'  DT J 194      12.838  75.672   2.010  1.00 77.34           C  \\nATOM   3956  O3'  DT J 194      14.194  75.901   2.390  1.00 77.34           O  \\nATOM   3957  C2'  DT J 194      12.554  76.035   0.565  1.00 77.34           C  \\nATOM   3958  C1'  DT J 194      12.966  74.782  -0.176  1.00 77.34           C  \\nATOM   3959  N1   DT J 194      12.198  74.548  -1.408  1.00 72.36           N  \\nATOM   3960  C2   DT J 194      12.812  74.682  -2.646  1.00 72.36           C  \\nATOM   3961  O2   DT J 194      13.967  75.068  -2.798  1.00 72.36           O  \\nATOM   3962  N3   DT J 194      12.008  74.353  -3.712  1.00 72.36           N  \\nATOM   3963  C4   DT J 194      10.691  73.937  -3.669  1.00 72.36           C  \\nATOM   3964  O4   DT J 194      10.117  73.624  -4.708  1.00 72.36           O  \\nATOM   3965  C5   DT J 194      10.103  73.889  -2.352  1.00 72.36           C  \\nATOM   3966  C7   DT J 194       8.659  73.526  -2.213  1.00 72.36           C  \\nATOM   3967  C6   DT J 194      10.879  74.181  -1.304  1.00 72.36           C  \\nATOM   3968  P    DC J 195      14.708  77.397   2.642  1.00 57.79           P  \\nATOM   3969  OP1  DC J 195      16.090  77.285   3.167  1.00 57.79           O  \\nATOM   3970  OP2  DC J 195      13.686  78.156   3.411  1.00 57.79           O  \\nATOM   3971  O5'  DC J 195      14.746  77.974   1.165  1.00 40.36           O  \\nATOM   3972  C5'  DC J 195      15.057  77.118   0.082  1.00 40.36           C  \\nATOM   3973  C4'  DC J 195      15.375  77.946  -1.129  1.00 40.36           C  \\nATOM   3974  O4'  DC J 195      14.389  77.712  -2.153  1.00 40.36           O  \\nATOM   3975  C3'  DC J 195      15.349  79.443  -0.854  1.00 40.36           C  \\nATOM   3976  O3'  DC J 195      16.374  80.011  -1.682  1.00 40.36           O  \\nATOM   3977  C2'  DC J 195      13.924  79.836  -1.214  1.00 40.36           C  \\nATOM   3978  C1'  DC J 195      13.593  78.874  -2.356  1.00 40.36           C  \\nATOM   3979  N1   DC J 195      12.187  78.422  -2.463  1.00 64.42           N  \\nATOM   3980  C2   DC J 195      11.680  78.090  -3.733  1.00 64.42           C  \\nATOM   3981  O2   DC J 195      12.400  78.252  -4.725  1.00 64.42           O  \\nATOM   3982  N3   DC J 195      10.423  77.606  -3.841  1.00 64.42           N  \\nATOM   3983  C4   DC J 195       9.672  77.456  -2.752  1.00 64.42           C  \\nATOM   3984  N4   DC J 195       8.457  76.948  -2.905  1.00 64.42           N  \\nATOM   3985  C5   DC J 195      10.142  77.816  -1.454  1.00 64.42           C  \\nATOM   3986  C6   DC J 195      11.394  78.294  -1.355  1.00 64.42           C  \\nATOM   3987  P    DC J 196      16.532  81.594  -1.816  1.00 47.94           P  \\nATOM   3988  OP1  DC J 196      17.946  81.831  -1.512  1.00 47.94           O  \\nATOM   3989  OP2  DC J 196      15.481  82.313  -1.052  1.00 47.94           O  \\nATOM   3990  O5'  DC J 196      16.337  81.811  -3.372  1.00 40.61           O  \\nATOM   3991  C5'  DC J 196      17.039  80.980  -4.284  1.00 40.61           C  \\nATOM   3992  C4'  DC J 196      16.639  81.297  -5.706  1.00 40.61           C  \\nATOM   3993  O4'  DC J 196      15.333  80.724  -5.955  1.00 40.61           O  \\nATOM   3994  C3'  DC J 196      16.534  82.783  -6.051  1.00 40.61           C  \\nATOM   3995  O3'  DC J 196      17.150  83.058  -7.300  1.00 40.61           O  \\nATOM   3996  C2'  DC J 196      15.042  83.049  -6.120  1.00 40.61           C  \\nATOM   3997  C1'  DC J 196      14.442  81.700  -6.477  1.00 40.61           C  \\nATOM   3998  N1   DC J 196      13.121  81.471  -5.861  1.00 49.17           N  \\nATOM   3999  C2   DC J 196      12.047  81.051  -6.668  1.00 49.17           C  \\nATOM   4000  O2   DC J 196      12.241  80.857  -7.879  1.00 49.17           O  \\nATOM   4001  N3   DC J 196      10.832  80.866  -6.096  1.00 49.17           N  \\nATOM   4002  C4   DC J 196      10.665  81.081  -4.779  1.00 49.17           C  \\nATOM   4003  N4   DC J 196       9.450  80.899  -4.257  1.00 49.17           N  \\nATOM   4004  C5   DC J 196      11.738  81.495  -3.941  1.00 49.17           C  \\nATOM   4005  C6   DC J 196      12.938  81.674  -4.516  1.00 49.17           C  \\nATOM   4006  P    DA J 197      16.976  84.503  -7.961  1.00 27.94           P  \\nATOM   4007  OP1  DA J 197      18.153  84.723  -8.849  1.00 27.94           O  \\nATOM   4008  OP2  DA J 197      16.619  85.524  -6.924  1.00 27.94           O  \\nATOM   4009  O5'  DA J 197      15.712  84.299  -8.894  1.00 38.92           O  \\nATOM   4010  C5'  DA J 197      15.731  83.280  -9.881  1.00 38.92           C  \\nATOM   4011  C4'  DA J 197      14.692  83.556 -10.937  1.00 38.92           C  \\nATOM   4012  O4'  DA J 197      13.380  83.317 -10.390  1.00 38.92           O  \\nATOM   4013  C3'  DA J 197      14.678  84.987 -11.458  1.00 38.92           C  \\nATOM   4014  O3'  DA J 197      14.424  84.958 -12.865  1.00 38.92           O  \\nATOM   4015  C2'  DA J 197      13.550  85.636 -10.672  1.00 38.92           C  \\nATOM   4016  C1'  DA J 197      12.591  84.491 -10.435  1.00 38.92           C  \\nATOM   4017  N9   DA J 197      11.875  84.547  -9.169  1.00 37.21           N  \\nATOM   4018  C8   DA J 197      12.317  85.045  -7.976  1.00 37.21           C  \\nATOM   4019  N7   DA J 197      11.471  84.884  -6.989  1.00 37.21           N  \\nATOM   4020  C5   DA J 197      10.393  84.249  -7.579  1.00 37.21           C  \\nATOM   4021  C6   DA J 197       9.181  83.799  -7.065  1.00 37.21           C  \\nATOM   4022  N6   DA J 197       8.854  83.904  -5.780  1.00 37.21           N  \\nATOM   4023  N1   DA J 197       8.305  83.224  -7.920  1.00 37.21           N  \\nATOM   4024  C2   DA J 197       8.651  83.109  -9.209  1.00 37.21           C  \\nATOM   4025  N3   DA J 197       9.777  83.481  -9.813  1.00 37.21           N  \\nATOM   4026  C4   DA J 197      10.617  84.054  -8.928  1.00 37.21           C  \\nATOM   4027  P    DT J 198      13.841  86.258 -13.598  1.00 61.91           P  \\nATOM   4028  OP1  DT J 198      13.822  85.980 -15.058  1.00 61.91           O  \\nATOM   4029  OP2  DT J 198      14.564  87.461 -13.069  1.00 61.91           O  \\nATOM   4030  O5'  DT J 198      12.332  86.278 -13.105  1.00 74.61           O  \\nATOM   4031  C5'  DT J 198      11.447  85.246 -13.512  1.00 74.61           C  \\nATOM   4032  C4'  DT J 198      10.031  85.759 -13.532  1.00 74.61           C  \\nATOM   4033  O4'  DT J 198       9.438  85.619 -12.222  1.00 74.61           O  \\nATOM   4034  C3'  DT J 198       9.917  87.238 -13.904  1.00 74.61           C  \\nATOM   4035  O3'  DT J 198       8.817  87.432 -14.798  1.00 74.61           O  \\nATOM   4036  C2'  DT J 198       9.655  87.911 -12.569  1.00 74.61           C  \\nATOM   4037  C1'  DT J 198       8.851  86.849 -11.857  1.00 74.61           C  \\nATOM   4038  N1   DT J 198       8.868  86.938 -10.402  1.00 47.31           N  \\nATOM   4039  C2   DT J 198       7.798  86.399  -9.718  1.00 47.31           C  \\nATOM   4040  O2   DT J 198       6.889  85.795 -10.260  1.00 47.31           O  \\nATOM   4041  N3   DT J 198       7.839  86.581  -8.365  1.00 47.31           N  \\nATOM   4042  C4   DT J 198       8.830  87.203  -7.638  1.00 47.31           C  \\nATOM   4043  O4   DT J 198       8.715  87.289  -6.424  1.00 47.31           O  \\nATOM   4044  C5   DT J 198       9.947  87.711  -8.414  1.00 47.31           C  \\nATOM   4045  C7   DT J 198      11.080  88.376  -7.705  1.00 47.31           C  \\nATOM   4046  C6   DT J 198       9.909  87.556  -9.741  1.00 47.31           C  \\nATOM   4047  P    DC J 199       8.392  88.920 -15.243  1.00100.93           P  \\nATOM   4048  OP1  DC J 199       8.261  88.917 -16.719  1.00100.93           O  \\nATOM   4049  OP2  DC J 199       9.280  89.921 -14.588  1.00100.93           O  \\nATOM   4050  O5'  DC J 199       6.936  89.060 -14.619  1.00 70.94           O  \\nATOM   4051  C5'  DC J 199       6.075  87.924 -14.534  1.00 70.94           C  \\nATOM   4052  C4'  DC J 199       4.676  88.352 -14.159  1.00 70.94           C  \\nATOM   4053  O4'  DC J 199       4.501  88.075 -12.746  1.00 70.94           O  \\nATOM   4054  C3'  DC J 199       4.398  89.847 -14.355  1.00 70.94           C  \\nATOM   4055  O3'  DC J 199       3.114  90.102 -14.952  1.00 70.94           O  \\nATOM   4056  C2'  DC J 199       4.501  90.428 -12.956  1.00 70.94           C  \\nATOM   4057  C1'  DC J 199       4.166  89.259 -12.037  1.00 70.94           C  \\nATOM   4058  N1   DC J 199       4.974  89.303 -10.803  1.00 66.89           N  \\nATOM   4059  C2   DC J 199       4.380  88.972  -9.569  1.00 66.89           C  \\nATOM   4060  O2   DC J 199       3.205  88.551  -9.547  1.00 66.89           O  \\nATOM   4061  N3   DC J 199       5.107  89.121  -8.435  1.00 66.89           N  \\nATOM   4062  C4   DC J 199       6.367  89.565  -8.501  1.00 66.89           C  \\nATOM   4063  N4   DC J 199       7.027  89.745  -7.359  1.00 66.89           N  \\nATOM   4064  C5   DC J 199       7.002  89.854  -9.740  1.00 66.89           C  \\nATOM   4065  C6   DC J 199       6.281  89.706 -10.853  1.00 66.89           C  \\nATOM   4066  P    DA J 200       2.493  91.591 -14.908  1.00107.67           P  \\nATOM   4067  OP1  DA J 200       1.297  91.659 -15.787  1.00107.67           O  \\nATOM   4068  OP2  DA J 200       3.592  92.580 -15.091  1.00107.67           O  \\nATOM   4069  O5'  DA J 200       1.973  91.693 -13.409  1.00 74.03           O  \\nATOM   4070  C5'  DA J 200       0.957  90.816 -12.925  1.00 74.03           C  \\nATOM   4071  C4'  DA J 200       0.175  91.511 -11.840  1.00 74.03           C  \\nATOM   4072  O4'  DA J 200       0.850  91.414 -10.565  1.00 74.03           O  \\nATOM   4073  C3'  DA J 200       0.024  93.001 -12.124  1.00 74.03           C  \\nATOM   4074  O3'  DA J 200      -1.255  93.440 -11.698  1.00 74.03           O  \\nATOM   4075  C2'  DA J 200       1.109  93.630 -11.270  1.00 74.03           C  \\nATOM   4076  C1'  DA J 200       1.125  92.714 -10.066  1.00 74.03           C  \\nATOM   4077  N9   DA J 200       2.416  92.672  -9.383  1.00 50.04           N  \\nATOM   4078  C8   DA J 200       3.670  92.716  -9.940  1.00 50.04           C  \\nATOM   4079  N7   DA J 200       4.639  92.670  -9.058  1.00 50.04           N  \\nATOM   4080  C5   DA J 200       3.980  92.590  -7.837  1.00 50.04           C  \\nATOM   4081  C6   DA J 200       4.446  92.523  -6.500  1.00 50.04           C  \\nATOM   4082  N6   DA J 200       5.740  92.505  -6.154  1.00 50.04           N  \\nATOM   4083  N1   DA J 200       3.518  92.468  -5.515  1.00 50.04           N  \\nATOM   4084  C2   DA J 200       2.219  92.473  -5.858  1.00 50.04           C  \\nATOM   4085  N3   DA J 200       1.664  92.529  -7.071  1.00 50.04           N  \\nATOM   4086  C4   DA J 200       2.610  92.589  -8.024  1.00 50.04           C  \\nATOM   4087  P    DA J 201      -1.729  94.937 -12.019  1.00 89.49           P  \\nATOM   4088  OP1  DA J 201      -2.374  94.939 -13.361  1.00 89.49           O  \\nATOM   4089  OP2  DA J 201      -0.601  95.873 -11.741  1.00 89.49           O  \\nATOM   4090  O5'  DA J 201      -2.828  95.159 -10.895  1.00 80.35           O  \\nATOM   4091  C5'  DA J 201      -2.679  94.554  -9.609  1.00 80.35           C  \\nATOM   4092  C4'  DA J 201      -2.261  95.596  -8.599  1.00 80.35           C  \\nATOM   4093  O4'  DA J 201      -0.880  95.428  -8.188  1.00 80.35           O  \\nATOM   4094  C3'  DA J 201      -2.384  97.036  -9.107  1.00 80.35           C  \\nATOM   4095  O3'  DA J 201      -2.970  97.853  -8.096  1.00 80.35           O  \\nATOM   4096  C2'  DA J 201      -0.940  97.452  -9.335  1.00 80.35           C  \\nATOM   4097  C1'  DA J 201      -0.255  96.702  -8.209  1.00 80.35           C  \\nATOM   4098  N9   DA J 201       1.198  96.526  -8.330  1.00 66.94           N  \\nATOM   4099  C8   DA J 201       1.980  96.576  -9.466  1.00 66.94           C  \\nATOM   4100  N7   DA J 201       3.265  96.416  -9.231  1.00 66.94           N  \\nATOM   4101  C5   DA J 201       3.335  96.242  -7.851  1.00 66.94           C  \\nATOM   4102  C6   DA J 201       4.421  96.026  -6.968  1.00 66.94           C  \\nATOM   4103  N6   DA J 201       5.693  95.954  -7.363  1.00 66.94           N  \\nATOM   4104  N1   DA J 201       4.146  95.887  -5.650  1.00 66.94           N  \\nATOM   4105  C2   DA J 201       2.872  95.961  -5.253  1.00 66.94           C  \\nATOM   4106  N3   DA J 201       1.769  96.164  -5.978  1.00 66.94           N  \\nATOM   4107  C4   DA J 201       2.070  96.298  -7.284  1.00 66.94           C  \\nATOM   4108  P    DA J 202      -3.686  99.237  -8.498  1.00103.61           P  \\nATOM   4109  OP1  DA J 202      -5.095  98.938  -8.861  1.00103.61           O  \\nATOM   4110  OP2  DA J 202      -2.813  99.978  -9.460  1.00103.61           O  \\nATOM   4111  O5'  DA J 202      -3.674 100.033  -7.120  1.00 98.69           O  \\nATOM   4112  C5'  DA J 202      -3.851  99.343  -5.883  1.00 98.69           C  \\nATOM   4113  C4'  DA J 202      -2.998  99.968  -4.802  1.00 98.69           C  \\nATOM   4114  O4'  DA J 202      -1.614  99.542  -4.892  1.00 98.69           O  \\nATOM   4115  C3'  DA J 202      -2.978 101.496  -4.791  1.00 98.69           C  \\nATOM   4116  O3'  DA J 202      -3.180 101.962  -3.455  1.00 98.69           O  \\nATOM   4117  C2'  DA J 202      -1.592 101.842  -5.315  1.00 98.69           C  \\nATOM   4118  C1'  DA J 202      -0.747 100.667  -4.844  1.00 98.69           C  \\nATOM   4119  N9   DA J 202       0.420 100.376  -5.687  1.00 70.27           N  \\nATOM   4120  C8   DA J 202       0.464 100.394  -7.063  1.00 70.27           C  \\nATOM   4121  N7   DA J 202       1.636 100.075  -7.564  1.00 70.27           N  \\nATOM   4122  C5   DA J 202       2.423  99.833  -6.447  1.00 70.27           C  \\nATOM   4123  C6   DA J 202       3.769  99.446  -6.309  1.00 70.27           C  \\nATOM   4124  N6   DA J 202       4.580  99.217  -7.347  1.00 70.27           N  \\nATOM   4125  N1   DA J 202       4.258  99.297  -5.056  1.00 70.27           N  \\nATOM   4126  C2   DA J 202       3.440  99.522  -4.020  1.00 70.27           C  \\nATOM   4127  N3   DA J 202       2.151  99.884  -4.020  1.00 70.27           N  \\nATOM   4128  C4   DA J 202       1.693 100.024  -5.281  1.00 70.27           C  \\nATOM   4129  P    DA J 203      -3.082 103.531  -3.129  1.00 91.72           P  \\nATOM   4130  OP1  DA J 203      -3.944 103.818  -1.950  1.00 91.72           O  \\nATOM   4131  OP2  DA J 203      -3.262 104.308  -4.387  1.00 91.72           O  \\nATOM   4132  O5'  DA J 203      -1.574 103.681  -2.663  1.00140.54           O  \\nATOM   4133  C5'  DA J 203      -1.097 102.918  -1.563  1.00140.54           C  \\nATOM   4134  C4'  DA J 203       0.034 103.650  -0.888  1.00140.54           C  \\nATOM   4135  O4'  DA J 203       1.260 103.456  -1.629  1.00140.54           O  \\nATOM   4136  C3'  DA J 203      -0.186 105.157  -0.795  1.00140.54           C  \\nATOM   4137  O3'  DA J 203       0.218 105.591   0.506  1.00140.54           O  \\nATOM   4138  C2'  DA J 203       0.638 105.711  -1.949  1.00140.54           C  \\nATOM   4139  C1'  DA J 203       1.764 104.695  -2.109  1.00140.54           C  \\nATOM   4140  N9   DA J 203       2.242 104.472  -3.481  1.00 56.43           N  \\nATOM   4141  C8   DA J 203       1.659 104.831  -4.679  1.00 56.43           C  \\nATOM   4142  N7   DA J 203       2.337 104.442  -5.737  1.00 56.43           N  \\nATOM   4143  C5   DA J 203       3.448 103.792  -5.204  1.00 56.43           C  \\nATOM   4144  C6   DA J 203       4.556 103.136  -5.802  1.00 56.43           C  \\nATOM   4145  N6   DA J 203       4.739 103.019  -7.117  1.00 56.43           N  \\nATOM   4146  N1   DA J 203       5.479 102.594  -4.982  1.00 56.43           N  \\nATOM   4147  C2   DA J 203       5.304 102.698  -3.658  1.00 56.43           C  \\nATOM   4148  N3   DA J 203       4.316 103.282  -2.976  1.00 56.43           N  \\nATOM   4149  C4   DA J 203       3.408 103.814  -3.816  1.00 56.43           C  \\nATOM   4150  P    DG J 204       0.676 107.106   0.756  1.00 81.30           P  \\nATOM   4151  OP1  DG J 204       0.096 107.547   2.043  1.00 81.30           O  \\nATOM   4152  OP2  DG J 204       0.466 107.925  -0.471  1.00 81.30           O  \\nATOM   4153  O5'  DG J 204       2.228 106.928   0.997  1.00110.04           O  \\nATOM   4154  C5'  DG J 204       2.722 105.738   1.601  1.00110.04           C  \\nATOM   4155  C4'  DG J 204       4.217 105.837   1.739  1.00110.04           C  \\nATOM   4156  O4'  DG J 204       4.817 105.848   0.423  1.00110.04           O  \\nATOM   4157  C3'  DG J 204       4.622 107.152   2.386  1.00110.04           C  \\nATOM   4158  O3'  DG J 204       5.796 106.940   3.145  1.00110.04           O  \\nATOM   4159  C2'  DG J 204       4.868 108.073   1.203  1.00110.04           C  \\nATOM   4160  C1'  DG J 204       5.388 107.123   0.138  1.00110.04           C  \\nATOM   4161  N9   DG J 204       4.997 107.484  -1.222  1.00 73.48           N  \\nATOM   4162  C8   DG J 204       4.005 108.360  -1.591  1.00 73.48           C  \\nATOM   4163  N7   DG J 204       3.854 108.450  -2.886  1.00 73.48           N  \\nATOM   4164  C5   DG J 204       4.808 107.585  -3.406  1.00 73.48           C  \\nATOM   4165  C6   DG J 204       5.113 107.246  -4.763  1.00 73.48           C  \\nATOM   4166  O6   DG J 204       4.559 107.629  -5.801  1.00 73.48           O  \\nATOM   4167  N1   DG J 204       6.175 106.346  -4.840  1.00 73.48           N  \\nATOM   4168  C2   DG J 204       6.844 105.822  -3.761  1.00 73.48           C  \\nATOM   4169  N2   DG J 204       7.843 104.976  -4.062  1.00 73.48           N  \\nATOM   4170  N3   DG J 204       6.556 106.107  -2.493  1.00 73.48           N  \\nATOM   4171  C4   DG J 204       5.535 106.993  -2.393  1.00 73.48           C  \\nATOM   4172  P    DG J 205       6.511 108.178   3.857  1.00 64.48           P  \\nATOM   4173  OP1  DG J 205       6.135 108.158   5.294  1.00 64.48           O  \\nATOM   4174  OP2  DG J 205       6.244 109.389   3.023  1.00 64.48           O  \\nATOM   4175  O5'  DG J 205       8.050 107.777   3.778  1.00 48.62           O  \\nATOM   4176  C5'  DG J 205       8.434 106.436   3.449  1.00 48.62           C  \\nATOM   4177  C4'  DG J 205       9.508 106.450   2.390  1.00 48.62           C  \\nATOM   4178  O4'  DG J 205       9.012 106.861   1.094  1.00 48.62           O  \\nATOM   4179  C3'  DG J 205      10.643 107.411   2.711  1.00 48.62           C  \\nATOM   4180  O3'  DG J 205      11.819 106.810   2.248  1.00 48.62           O  \\nATOM   4181  C2'  DG J 205      10.360 108.607   1.825  1.00 48.62           C  \\nATOM   4182  C1'  DG J 205       9.845 107.904   0.600  1.00 48.62           C  \\nATOM   4183  N9   DG J 205       9.063 108.736  -0.305  1.00 61.32           N  \\nATOM   4184  C8   DG J 205       8.176 109.729   0.028  1.00 61.32           C  \\nATOM   4185  N7   DG J 205       7.615 110.282  -1.012  1.00 61.32           N  \\nATOM   4186  C5   DG J 205       8.169 109.616  -2.098  1.00 61.32           C  \\nATOM   4187  C6   DG J 205       7.934 109.769  -3.486  1.00 61.32           C  \\nATOM   4188  O6   DG J 205       7.160 110.541  -4.054  1.00 61.32           O  \\nATOM   4189  N1   DG J 205       8.710 108.894  -4.238  1.00 61.32           N  \\nATOM   4190  C2   DG J 205       9.602 107.988  -3.724  1.00 61.32           C  \\nATOM   4191  N2   DG J 205      10.277 107.253  -4.624  1.00 61.32           N  \\nATOM   4192  N3   DG J 205       9.819 107.822  -2.428  1.00 61.32           N  \\nATOM   4193  C4   DG J 205       9.072 108.667  -1.678  1.00 61.32           C  \\nATOM   4194  P    DC J 206      13.137 106.891   3.120  1.00 46.58           P  \\nATOM   4195  OP1  DC J 206      13.342 105.607   3.838  1.00 46.58           O  \\nATOM   4196  OP2  DC J 206      13.110 108.171   3.874  1.00 46.58           O  \\nATOM   4197  O5'  DC J 206      14.217 107.073   1.990  1.00 34.79           O  \\nATOM   4198  C5'  DC J 206      14.118 108.202   1.174  1.00 34.79           C  \\nATOM   4199  C4'  DC J 206      14.244 107.807  -0.267  1.00 34.79           C  \\nATOM   4200  O4'  DC J 206      13.061 108.266  -0.959  1.00 34.79           O  \\nATOM   4201  C3'  DC J 206      15.409 108.587  -0.841  1.00 34.79           C  \\nATOM   4202  O3'  DC J 206      16.149 107.808  -1.761  1.00 34.79           O  \\nATOM   4203  C2'  DC J 206      14.767 109.819  -1.448  1.00 34.79           C  \\nATOM   4204  C1'  DC J 206      13.374 109.351  -1.819  1.00 34.79           C  \\nATOM   4205  N1   DC J 206      12.356 110.395  -1.636  1.00 35.23           N  \\nATOM   4206  C2   DC J 206      11.755 110.941  -2.769  1.00 35.23           C  \\nATOM   4207  O2   DC J 206      12.082 110.522  -3.875  1.00 35.23           O  \\nATOM   4208  N3   DC J 206      10.828 111.911  -2.635  1.00 35.23           N  \\nATOM   4209  C4   DC J 206      10.476 112.337  -1.421  1.00 35.23           C  \\nATOM   4210  N4   DC J 206       9.525 113.283  -1.348  1.00 35.23           N  \\nATOM   4211  C5   DC J 206      11.077 111.804  -0.231  1.00 35.23           C  \\nATOM   4212  C6   DC J 206      12.005 110.838  -0.387  1.00 35.23           C  \\nATOM   4213  P    DA J 207      17.651 108.220  -2.080  1.00 32.96           P  \\nATOM   4214  OP1  DA J 207      18.466 106.987  -2.118  1.00 32.96           O  \\nATOM   4215  OP2  DA J 207      18.048 109.345  -1.191  1.00 32.96           O  \\nATOM   4216  O5'  DA J 207      17.540 108.775  -3.551  1.00 23.75           O  \\nATOM   4217  C5'  DA J 207      17.063 107.926  -4.569  1.00 23.75           C  \\nATOM   4218  C4'  DA J 207      16.820 108.704  -5.839  1.00 23.75           C  \\nATOM   4219  O4'  DA J 207      15.702 109.595  -5.639  1.00 23.75           O  \\nATOM   4220  C3'  DA J 207      17.982 109.562  -6.339  1.00 23.75           C  \\nATOM   4221  O3'  DA J 207      18.177 109.274  -7.723  1.00 23.75           O  \\nATOM   4222  C2'  DA J 207      17.558 110.997  -6.026  1.00 23.75           C  \\nATOM   4223  C1'  DA J 207      16.032 110.925  -5.986  1.00 23.75           C  \\nATOM   4224  N9   DA J 207      15.355 111.783  -5.014  1.00 28.89           N  \\nATOM   4225  C8   DA J 207      15.577 111.862  -3.673  1.00 28.89           C  \\nATOM   4226  N7   DA J 207      14.777 112.691  -3.052  1.00 28.89           N  \\nATOM   4227  C5   DA J 207      13.981 113.204  -4.061  1.00 28.89           C  \\nATOM   4228  C6   DA J 207      12.920 114.145  -4.059  1.00 28.89           C  \\nATOM   4229  N6   DA J 207      12.487 114.786  -2.959  1.00 28.89           N  \\nATOM   4230  N1   DA J 207      12.320 114.411  -5.241  1.00 28.89           N  \\nATOM   4231  C2   DA J 207      12.769 113.791  -6.340  1.00 28.89           C  \\nATOM   4232  N3   DA J 207      13.761 112.908  -6.468  1.00 28.89           N  \\nATOM   4233  C4   DA J 207      14.328 112.653  -5.277  1.00 28.89           C  \\nATOM   4234  P    DT J 208      19.314 110.028  -8.548  1.00 21.74           P  \\nATOM   4235  OP1  DT J 208      19.685 109.176  -9.712  1.00 21.74           O  \\nATOM   4236  OP2  DT J 208      20.360 110.575  -7.660  1.00 21.74           O  \\nATOM   4237  O5'  DT J 208      18.547 111.295  -9.089  1.00 28.53           O  \\nATOM   4238  C5'  DT J 208      17.431 111.129  -9.917  1.00 28.53           C  \\nATOM   4239  C4'  DT J 208      16.987 112.470 -10.428  1.00 28.53           C  \\nATOM   4240  O4'  DT J 208      16.269 113.223  -9.430  1.00 28.53           O  \\nATOM   4241  C3'  DT J 208      18.101 113.375 -10.934  1.00 28.53           C  \\nATOM   4242  O3'  DT J 208      17.608 113.851 -12.177  1.00 28.53           O  \\nATOM   4243  C2'  DT J 208      18.179 114.472  -9.878  1.00 28.53           C  \\nATOM   4244  C1'  DT J 208      16.746 114.554  -9.390  1.00 28.53           C  \\nATOM   4245  N1   DT J 208      16.531 115.025  -8.017  1.00 36.35           N  \\nATOM   4246  C2   DT J 208      15.433 115.837  -7.755  1.00 36.35           C  \\nATOM   4247  O2   DT J 208      14.679 116.265  -8.614  1.00 36.35           O  \\nATOM   4248  N3   DT J 208      15.246 116.127  -6.435  1.00 36.35           N  \\nATOM   4249  C4   DT J 208      16.014 115.708  -5.372  1.00 36.35           C  \\nATOM   4250  O4   DT J 208      15.667 116.005  -4.227  1.00 36.35           O  \\nATOM   4251  C5   DT J 208      17.185 114.913  -5.726  1.00 36.35           C  \\nATOM   4252  C7   DT J 208      18.120 114.464  -4.647  1.00 36.35           C  \\nATOM   4253  C6   DT J 208      17.379 114.620  -7.013  1.00 36.35           C  \\nATOM   4254  P    DG J 209      18.596 114.477 -13.260  1.00 46.23           P  \\nATOM   4255  OP1  DG J 209      18.109 114.026 -14.591  1.00 46.23           O  \\nATOM   4256  OP2  DG J 209      20.022 114.257 -12.875  1.00 46.23           O  \\nATOM   4257  O5'  DG J 209      18.217 116.009 -13.085  1.00 34.77           O  \\nATOM   4258  C5'  DG J 209      16.843 116.399 -12.994  1.00 34.77           C  \\nATOM   4259  C4'  DG J 209      16.741 117.863 -12.650  1.00 34.77           C  \\nATOM   4260  O4'  DG J 209      16.580 118.048 -11.230  1.00 34.77           O  \\nATOM   4261  C3'  DG J 209      17.959 118.683 -13.059  1.00 34.77           C  \\nATOM   4262  O3'  DG J 209      17.510 119.843 -13.752  1.00 34.77           O  \\nATOM   4263  C2'  DG J 209      18.647 118.995 -11.738  1.00 34.77           C  \\nATOM   4264  C1'  DG J 209      17.485 119.030 -10.768  1.00 34.77           C  \\nATOM   4265  N9   DG J 209      17.805 118.716  -9.377  1.00 42.96           N  \\nATOM   4266  C8   DG J 209      18.800 117.882  -8.915  1.00 42.96           C  \\nATOM   4267  N7   DG J 209      18.838 117.800  -7.609  1.00 42.96           N  \\nATOM   4268  C5   DG J 209      17.804 118.629  -7.178  1.00 42.96           C  \\nATOM   4269  C6   DG J 209      17.358 118.951  -5.857  1.00 42.96           C  \\nATOM   4270  O6   DG J 209      17.799 118.559  -4.771  1.00 42.96           O  \\nATOM   4271  N1   DG J 209      16.281 119.833  -5.881  1.00 42.96           N  \\nATOM   4272  C2   DG J 209      15.697 120.340  -7.015  1.00 42.96           C  \\nATOM   4273  N2   DG J 209      14.665 121.162  -6.804  1.00 42.96           N  \\nATOM   4274  N3   DG J 209      16.098 120.058  -8.250  1.00 42.96           N  \\nATOM   4275  C4   DG J 209      17.152 119.201  -8.256  1.00 42.96           C  \\nATOM   4276  P    DT J 210      18.561 120.961 -14.219  1.00 40.57           P  \\nATOM   4277  OP1  DT J 210      18.254 121.367 -15.623  1.00 40.57           O  \\nATOM   4278  OP2  DT J 210      19.938 120.516 -13.863  1.00 40.57           O  \\nATOM   4279  O5'  DT J 210      18.166 122.162 -13.261  1.00 65.84           O  \\nATOM   4280  C5'  DT J 210      16.798 122.395 -12.939  1.00 65.84           C  \\nATOM   4281  C4'  DT J 210      16.693 123.501 -11.921  1.00 65.84           C  \\nATOM   4282  O4'  DT J 210      16.844 122.964 -10.584  1.00 65.84           O  \\nATOM   4283  C3'  DT J 210      17.777 124.564 -12.094  1.00 65.84           C  \\nATOM   4284  O3'  DT J 210      17.216 125.866 -12.099  1.00 65.84           O  \\nATOM   4285  C2'  DT J 210      18.678 124.371 -10.888  1.00 65.84           C  \\nATOM   4286  C1'  DT J 210      17.736 123.782  -9.856  1.00 65.84           C  \\nATOM   4287  N1   DT J 210      18.402 122.951  -8.827  1.00 43.10           N  \\nATOM   4288  C2   DT J 210      17.978 123.076  -7.517  1.00 43.10           C  \\nATOM   4289  O2   DT J 210      17.032 123.781  -7.171  1.00 43.10           O  \\nATOM   4290  N3   DT J 210      18.703 122.335  -6.614  1.00 43.10           N  \\nATOM   4291  C4   DT J 210      19.758 121.488  -6.877  1.00 43.10           C  \\nATOM   4292  O4   DT J 210      20.304 120.899  -5.956  1.00 43.10           O  \\nATOM   4293  C5   DT J 210      20.124 121.376  -8.267  1.00 43.10           C  \\nATOM   4294  C7   DT J 210      21.252 120.467  -8.645  1.00 43.10           C  \\nATOM   4295  C6   DT J 210      19.435 122.099  -9.163  1.00 43.10           C  \\nATOM   4296  P    DT J 211      18.158 127.128 -12.403  1.00 74.60           P  \\nATOM   4297  OP1  DT J 211      17.500 127.932 -13.468  1.00 74.60           O  \\nATOM   4298  OP2  DT J 211      19.559 126.670 -12.583  1.00 74.60           O  \\nATOM   4299  O5'  DT J 211      18.089 127.921 -11.031  1.00 50.10           O  \\nATOM   4300  C5'  DT J 211      16.837 128.085 -10.380  1.00 50.10           C  \\nATOM   4301  C4'  DT J 211      17.042 128.674  -9.010  1.00 50.10           C  \\nATOM   4302  O4'  DT J 211      17.584 127.673  -8.123  1.00 50.10           O  \\nATOM   4303  C3'  DT J 211      18.018 129.847  -8.977  1.00 50.10           C  \\nATOM   4304  O3'  DT J 211      17.536 130.774  -8.023  1.00 50.10           O  \\nATOM   4305  C2'  DT J 211      19.296 129.227  -8.457  1.00 50.10           C  \\nATOM   4306  C1'  DT J 211      18.752 128.184  -7.504  1.00 50.10           C  \\nATOM   4307  N1   DT J 211      19.661 127.057  -7.261  1.00 37.44           N  \\nATOM   4308  C2   DT J 211      19.767 126.580  -5.978  1.00 37.44           C  \\nATOM   4309  O2   DT J 211      19.134 127.037  -5.052  1.00 37.44           O  \\nATOM   4310  N3   DT J 211      20.645 125.549  -5.818  1.00 37.44           N  \\nATOM   4311  C4   DT J 211      21.415 124.956  -6.793  1.00 37.44           C  \\nATOM   4312  O4   DT J 211      22.162 124.025  -6.490  1.00 37.44           O  \\nATOM   4313  C5   DT J 211      21.257 125.518  -8.132  1.00 37.44           C  \\nATOM   4314  C7   DT J 211      22.074 124.977  -9.262  1.00 37.44           C  \\nATOM   4315  C6   DT J 211      20.389 126.516  -8.292  1.00 37.44           C  \\nATOM   4316  P    DC J 212      18.023 132.300  -8.066  1.00 41.91           P  \\nATOM   4317  OP1  DC J 212      16.783 133.041  -7.730  1.00 41.91           O  \\nATOM   4318  OP2  DC J 212      18.768 132.615  -9.323  1.00 41.91           O  \\nATOM   4319  O5'  DC J 212      18.987 132.380  -6.803  1.00 48.54           O  \\nATOM   4320  C5'  DC J 212      18.517 131.899  -5.546  1.00 48.54           C  \\nATOM   4321  C4'  DC J 212      19.610 131.948  -4.507  1.00 48.54           C  \\nATOM   4322  O4'  DC J 212      20.329 130.692  -4.474  1.00 48.54           O  \\nATOM   4323  C3'  DC J 212      20.664 133.038  -4.680  1.00 48.54           C  \\nATOM   4324  O3'  DC J 212      20.925 133.619  -3.401  1.00 48.54           O  \\nATOM   4325  C2'  DC J 212      21.880 132.277  -5.187  1.00 48.54           C  \\nATOM   4326  C1'  DC J 212      21.722 130.936  -4.497  1.00 48.54           C  \\nATOM   4327  N1   DC J 212      22.354 129.814  -5.194  1.00 31.23           N  \\nATOM   4328  C2   DC J 212      22.712 128.656  -4.461  1.00 31.23           C  \\nATOM   4329  O2   DC J 212      22.477 128.605  -3.239  1.00 31.23           O  \\nATOM   4330  N3   DC J 212      23.308 127.623  -5.112  1.00 31.23           N  \\nATOM   4331  C4   DC J 212      23.547 127.711  -6.428  1.00 31.23           C  \\nATOM   4332  N4   DC J 212      24.144 126.671  -7.029  1.00 31.23           N  \\nATOM   4333  C5   DC J 212      23.187 128.868  -7.188  1.00 31.23           C  \\nATOM   4334  C6   DC J 212      22.599 129.883  -6.537  1.00 31.23           C  \\nATOM   4335  P    DA J 213      21.702 135.017  -3.305  1.00 38.14           P  \\nATOM   4336  OP1  DA J 213      20.853 135.990  -2.560  1.00 38.14           O  \\nATOM   4337  OP2  DA J 213      22.207 135.349  -4.665  1.00 38.14           O  \\nATOM   4338  O5'  DA J 213      22.956 134.674  -2.395  1.00 34.50           O  \\nATOM   4339  C5'  DA J 213      22.776 133.976  -1.172  1.00 34.50           C  \\nATOM   4340  C4'  DA J 213      24.077 133.356  -0.729  1.00 34.50           C  \\nATOM   4341  O4'  DA J 213      24.400 132.228  -1.566  1.00 34.50           O  \\nATOM   4342  C3'  DA J 213      25.283 134.292  -0.800  1.00 34.50           C  \\nATOM   4343  O3'  DA J 213      26.133 134.006   0.302  1.00 34.50           O  \\nATOM   4344  C2'  DA J 213      25.962 133.875  -2.086  1.00 34.50           C  \\nATOM   4345  C1'  DA J 213      25.717 132.387  -2.035  1.00 34.50           C  \\nATOM   4346  N9   DA J 213      25.819 131.707  -3.313  1.00 29.74           N  \\nATOM   4347  C8   DA J 213      25.643 132.193  -4.586  1.00 29.74           C  \\nATOM   4348  N7   DA J 213      25.877 131.305  -5.524  1.00 29.74           N  \\nATOM   4349  C5   DA J 213      26.219 130.158  -4.817  1.00 29.74           C  \\nATOM   4350  C6   DA J 213      26.590 128.878  -5.224  1.00 29.74           C  \\nATOM   4351  N6   DA J 213      26.739 128.526  -6.502  1.00 29.74           N  \\nATOM   4352  N1   DA J 213      26.825 127.958  -4.260  1.00 29.74           N  \\nATOM   4353  C2   DA J 213      26.723 128.325  -2.975  1.00 29.74           C  \\nATOM   4354  N3   DA J 213      26.410 129.503  -2.467  1.00 29.74           N  \\nATOM   4355  C4   DA J 213      26.164 130.386  -3.454  1.00 29.74           C  \\nATOM   4356  P    DG J 214      25.869 134.741   1.693  1.00 35.57           P  \\nATOM   4357  OP1  DG J 214      24.407 134.680   1.939  1.00 35.57           O  \\nATOM   4358  OP2  DG J 214      26.576 136.060   1.639  1.00 35.57           O  \\nATOM   4359  O5'  DG J 214      26.579 133.810   2.772  1.00 27.59           O  \\nATOM   4360  C5'  DG J 214      25.902 132.679   3.320  1.00 27.59           C  \\nATOM   4361  C4'  DG J 214      26.883 131.573   3.634  1.00 27.59           C  \\nATOM   4362  O4'  DG J 214      27.420 130.976   2.428  1.00 27.59           O  \\nATOM   4363  C3'  DG J 214      28.086 131.977   4.477  1.00 27.59           C  \\nATOM   4364  O3'  DG J 214      28.319 130.900   5.387  1.00 27.59           O  \\nATOM   4365  C2'  DG J 214      29.193 132.162   3.447  1.00 27.59           C  \\nATOM   4366  C1'  DG J 214      28.835 131.132   2.382  1.00 27.59           C  \\nATOM   4367  N9   DG J 214      29.161 131.481   1.008  1.00 33.74           N  \\nATOM   4368  C8   DG J 214      29.088 132.716   0.420  1.00 33.74           C  \\nATOM   4369  N7   DG J 214      29.286 132.681  -0.871  1.00 33.74           N  \\nATOM   4370  C5   DG J 214      29.544 131.348  -1.140  1.00 33.74           C  \\nATOM   4371  C6   DG J 214      29.804 130.697  -2.366  1.00 33.74           C  \\nATOM   4372  O6   DG J 214      29.824 131.178  -3.503  1.00 33.74           O  \\nATOM   4373  N1   DG J 214      30.029 129.333  -2.187  1.00 33.74           N  \\nATOM   4374  C2   DG J 214      29.972 128.674  -0.980  1.00 33.74           C  \\nATOM   4375  N2   DG J 214      30.189 127.342  -1.005  1.00 33.74           N  \\nATOM   4376  N3   DG J 214      29.713 129.274   0.170  1.00 33.74           N  \\nATOM   4377  C4   DG J 214      29.510 130.601   0.016  1.00 33.74           C  \\nATOM   4378  P    DC J 215      29.552 130.951   6.409  1.00 38.45           P  \\nATOM   4379  OP1  DC J 215      29.159 130.048   7.520  1.00 38.45           O  \\nATOM   4380  OP2  DC J 215      29.892 132.362   6.704  1.00 38.45           O  \\nATOM   4381  O5'  DC J 215      30.724 130.272   5.560  1.00 32.65           O  \\nATOM   4382  C5'  DC J 215      30.552 128.944   5.025  1.00 32.65           C  \\nATOM   4383  C4'  DC J 215      31.785 128.495   4.275  1.00 32.65           C  \\nATOM   4384  O4'  DC J 215      31.831 129.136   2.988  1.00 32.65           O  \\nATOM   4385  C3'  DC J 215      33.112 128.848   4.942  1.00 32.65           C  \\nATOM   4386  O3'  DC J 215      34.076 127.838   4.626  1.00 32.65           O  \\nATOM   4387  C2'  DC J 215      33.492 130.147   4.261  1.00 32.65           C  \\nATOM   4388  C1'  DC J 215      33.062 129.819   2.862  1.00 32.65           C  \\nATOM   4389  N1   DC J 215      32.842 130.968   2.011  1.00 30.55           N  \\nATOM   4390  C2   DC J 215      33.022 130.805   0.652  1.00 30.55           C  \\nATOM   4391  O2   DC J 215      33.336 129.679   0.228  1.00 30.55           O  \\nATOM   4392  N3   DC J 215      32.845 131.856  -0.169  1.00 30.55           N  \\nATOM   4393  C4   DC J 215      32.483 133.035   0.335  1.00 30.55           C  \\nATOM   4394  N4   DC J 215      32.317 134.053  -0.516  1.00 30.55           N  \\nATOM   4395  C5   DC J 215      32.275 133.225   1.734  1.00 30.55           C  \\nATOM   4396  C6   DC J 215      32.468 132.173   2.528  1.00 30.55           C  \\nATOM   4397  P    DT J 216      34.461 126.736   5.731  1.00 27.66           P  \\nATOM   4398  OP1  DT J 216      33.200 126.114   6.242  1.00 27.66           O  \\nATOM   4399  OP2  DT J 216      35.400 127.350   6.688  1.00 27.66           O  \\nATOM   4400  O5'  DT J 216      35.231 125.658   4.853  1.00 27.71           O  \\nATOM   4401  C5'  DT J 216      34.559 124.972   3.803  1.00 27.71           C  \\nATOM   4402  C4'  DT J 216      35.373 125.030   2.530  1.00 27.71           C  \\nATOM   4403  O4'  DT J 216      35.203 126.293   1.812  1.00 27.71           O  \\nATOM   4404  C3'  DT J 216      36.870 124.863   2.773  1.00 27.71           C  \\nATOM   4405  O3'  DT J 216      37.414 123.932   1.855  1.00 27.71           O  \\nATOM   4406  C2'  DT J 216      37.426 126.236   2.461  1.00 27.71           C  \\nATOM   4407  C1'  DT J 216      36.479 126.729   1.382  1.00 27.71           C  \\nATOM   4408  N1   DT J 216      36.466 128.206   1.213  1.00 41.33           N  \\nATOM   4409  C2   DT J 216      36.554 128.715  -0.071  1.00 41.33           C  \\nATOM   4410  O2   DT J 216      36.601 128.017  -1.070  1.00 41.33           O  \\nATOM   4411  N3   DT J 216      36.585 130.087  -0.141  1.00 41.33           N  \\nATOM   4412  C4   DT J 216      36.532 130.984   0.912  1.00 41.33           C  \\nATOM   4413  O4   DT J 216      36.559 132.194   0.687  1.00 41.33           O  \\nATOM   4414  C5   DT J 216      36.436 130.391   2.221  1.00 41.33           C  \\nATOM   4415  C7   DT J 216      36.384 131.291   3.413  1.00 41.33           C  \\nATOM   4416  C6   DT J 216      36.400 129.050   2.307  1.00 41.33           C  \\nATOM   4417  P    DG J 217      38.697 123.058   2.274  1.00 23.27           P  \\nATOM   4418  OP1  DG J 217      38.356 121.622   2.412  1.00 23.27           O  \\nATOM   4419  OP2  DG J 217      39.379 123.750   3.397  1.00 23.27           O  \\nATOM   4420  O5'  DG J 217      39.576 123.137   0.959  1.00 20.80           O  \\nATOM   4421  C5'  DG J 217      39.056 122.622  -0.255  1.00 20.80           C  \\nATOM   4422  C4'  DG J 217      39.581 123.410  -1.427  1.00 20.80           C  \\nATOM   4423  O4'  DG J 217      39.353 124.818  -1.177  1.00 20.80           O  \\nATOM   4424  C3'  DG J 217      41.076 123.256  -1.688  1.00 20.80           C  \\nATOM   4425  O3'  DG J 217      41.279 123.257  -3.097  1.00 20.80           O  \\nATOM   4426  C2'  DG J 217      41.673 124.493  -1.043  1.00 20.80           C  \\nATOM   4427  C1'  DG J 217      40.577 125.532  -1.217  1.00 20.80           C  \\nATOM   4428  N9   DG J 217      40.528 126.583  -0.197  1.00 30.27           N  \\nATOM   4429  C8   DG J 217      40.692 126.458   1.164  1.00 30.27           C  \\nATOM   4430  N7   DG J 217      40.613 127.598   1.806  1.00 30.27           N  \\nATOM   4431  C5   DG J 217      40.376 128.527   0.801  1.00 30.27           C  \\nATOM   4432  C6   DG J 217      40.209 129.943   0.872  1.00 30.27           C  \\nATOM   4433  O6   DG J 217      40.227 130.682   1.884  1.00 30.27           O  \\nATOM   4434  N1   DG J 217      40.007 130.492  -0.396  1.00 30.27           N  \\nATOM   4435  C2   DG J 217      39.975 129.773  -1.570  1.00 30.27           C  \\nATOM   4436  N2   DG J 217      39.790 130.484  -2.670  1.00 30.27           N  \\nATOM   4437  N3   DG J 217      40.119 128.466  -1.651  1.00 30.27           N  \\nATOM   4438  C4   DG J 217      40.318 127.910  -0.438  1.00 30.27           C  \\nATOM   4439  P    DA J 218      42.584 122.568  -3.725  1.00 32.10           P  \\nATOM   4440  OP1  DA J 218      42.133 121.545  -4.693  1.00 32.10           O  \\nATOM   4441  OP2  DA J 218      43.540 122.207  -2.640  1.00 32.10           O  \\nATOM   4442  O5'  DA J 218      43.225 123.751  -4.557  1.00 40.86           O  \\nATOM   4443  C5'  DA J 218      42.394 124.668  -5.246  1.00 40.86           C  \\nATOM   4444  C4'  DA J 218      43.097 125.996  -5.388  1.00 40.86           C  \\nATOM   4445  O4'  DA J 218      42.884 126.851  -4.238  1.00 40.86           O  \\nATOM   4446  C3'  DA J 218      44.612 125.878  -5.568  1.00 40.86           C  \\nATOM   4447  O3'  DA J 218      45.012 126.741  -6.627  1.00 40.86           O  \\nATOM   4448  C2'  DA J 218      45.166 126.362  -4.236  1.00 40.86           C  \\nATOM   4449  C1'  DA J 218      44.123 127.387  -3.833  1.00 40.86           C  \\nATOM   4450  N9   DA J 218      44.042 127.704  -2.410  1.00 35.93           N  \\nATOM   4451  C8   DA J 218      44.263 126.909  -1.305  1.00 35.93           C  \\nATOM   4452  N7   DA J 218      44.131 127.542  -0.160  1.00 35.93           N  \\nATOM   4453  C5   DA J 218      43.792 128.842  -0.541  1.00 35.93           C  \\nATOM   4454  C6   DA J 218      43.521 130.016   0.198  1.00 35.93           C  \\nATOM   4455  N6   DA J 218      43.549 130.076   1.535  1.00 35.93           N  \\nATOM   4456  N1   DA J 218      43.221 131.139  -0.494  1.00 35.93           N  \\nATOM   4457  C2   DA J 218      43.201 131.089  -1.831  1.00 35.93           C  \\nATOM   4458  N3   DA J 218      43.439 130.057  -2.638  1.00 35.93           N  \\nATOM   4459  C4   DA J 218      43.730 128.950  -1.922  1.00 35.93           C  \\nATOM   4460  P    DA J 219      46.307 126.390  -7.506  1.00 45.75           P  \\nATOM   4461  OP1  DA J 219      45.827 125.843  -8.811  1.00 45.75           O  \\nATOM   4462  OP2  DA J 219      47.273 125.624  -6.678  1.00 45.75           O  \\nATOM   4463  O5'  DA J 219      46.925 127.833  -7.728  1.00 50.38           O  \\nATOM   4464  C5'  DA J 219      46.053 128.933  -7.961  1.00 50.38           C  \\nATOM   4465  C4'  DA J 219      46.588 130.181  -7.303  1.00 50.38           C  \\nATOM   4466  O4'  DA J 219      46.170 130.322  -5.923  1.00 50.38           O  \\nATOM   4467  C3'  DA J 219      48.105 130.279  -7.312  1.00 50.38           C  \\nATOM   4468  O3'  DA J 219      48.469 131.460  -8.005  1.00 50.38           O  \\nATOM   4469  C2'  DA J 219      48.489 130.313  -5.839  1.00 50.38           C  \\nATOM   4470  C1'  DA J 219      47.237 130.833  -5.163  1.00 50.38           C  \\nATOM   4471  N9   DA J 219      47.069 130.351  -3.797  1.00 33.64           N  \\nATOM   4472  C8   DA J 219      47.183 129.054  -3.373  1.00 33.64           C  \\nATOM   4473  N7   DA J 219      47.059 128.908  -2.068  1.00 33.64           N  \\nATOM   4474  C5   DA J 219      46.832 130.200  -1.602  1.00 33.64           C  \\nATOM   4475  C6   DA J 219      46.634 130.738  -0.292  1.00 33.64           C  \\nATOM   4476  N6   DA J 219      46.669 130.029   0.835  1.00 33.64           N  \\nATOM   4477  N1   DA J 219      46.410 132.059  -0.188  1.00 33.64           N  \\nATOM   4478  C2   DA J 219      46.396 132.795  -1.305  1.00 33.64           C  \\nATOM   4479  N3   DA J 219      46.583 132.419  -2.578  1.00 33.64           N  \\nATOM   4480  C4   DA J 219      46.804 131.095  -2.662  1.00 33.64           C  \\nATOM   4481  P    DT J 220      49.989 131.687  -8.432  1.00 73.26           P  \\nATOM   4482  OP1  DT J 220      49.976 132.230  -9.812  1.00 73.26           O  \\nATOM   4483  OP2  DT J 220      50.790 130.471  -8.124  1.00 73.26           O  \\nATOM   4484  O5'  DT J 220      50.393 132.834  -7.416  1.00 58.76           O  \\nATOM   4485  C5'  DT J 220      49.484 133.896  -7.162  1.00 58.76           C  \\nATOM   4486  C4'  DT J 220      50.019 134.783  -6.069  1.00 58.76           C  \\nATOM   4487  O4'  DT J 220      49.607 134.291  -4.775  1.00 58.76           O  \\nATOM   4488  C3'  DT J 220      51.545 134.872  -6.035  1.00 58.76           C  \\nATOM   4489  O3'  DT J 220      51.959 136.241  -5.909  1.00 58.76           O  \\nATOM   4490  C2'  DT J 220      51.913 134.043  -4.816  1.00 58.76           C  \\nATOM   4491  C1'  DT J 220      50.722 134.287  -3.914  1.00 58.76           C  \\nATOM   4492  N1   DT J 220      50.499 133.267  -2.876  1.00 64.10           N  \\nATOM   4493  C2   DT J 220      50.165 133.696  -1.602  1.00 64.10           C  \\nATOM   4494  O2   DT J 220      50.048 134.874  -1.296  1.00 64.10           O  \\nATOM   4495  N3   DT J 220      49.976 132.683  -0.691  1.00 64.10           N  \\nATOM   4496  C4   DT J 220      50.090 131.316  -0.915  1.00 64.10           C  \\nATOM   4497  O4   DT J 220      49.876 130.524   0.009  1.00 64.10           O  \\nATOM   4498  C5   DT J 220      50.461 130.940  -2.266  1.00 64.10           C  \\nATOM   4499  C7   DT J 220      50.649 129.489  -2.590  1.00 64.10           C  \\nATOM   4500  C6   DT J 220      50.631 131.922  -3.169  1.00 64.10           C  \\nATOM   4501  P    DT J 221      53.527 136.624  -5.975  1.00 62.08           P  \\nATOM   4502  OP1  DT J 221      53.622 137.903  -6.735  1.00 62.08           O  \\nATOM   4503  OP2  DT J 221      54.350 135.453  -6.393  1.00 62.08           O  \\nATOM   4504  O5'  DT J 221      53.843 136.913  -4.447  1.00 55.20           O  \\nATOM   4505  C5'  DT J 221      52.959 137.724  -3.696  1.00 55.20           C  \\nATOM   4506  C4'  DT J 221      53.426 137.787  -2.269  1.00 55.20           C  \\nATOM   4507  O4'  DT J 221      53.044 136.590  -1.563  1.00 55.20           O  \\nATOM   4508  C3'  DT J 221      54.943 137.871  -2.148  1.00 55.20           C  \\nATOM   4509  O3'  DT J 221      55.265 138.720  -1.047  1.00 55.20           O  \\nATOM   4510  C2'  DT J 221      55.331 136.445  -1.811  1.00 55.20           C  \\nATOM   4511  C1'  DT J 221      54.184 136.094  -0.901  1.00 55.20           C  \\nATOM   4512  N1   DT J 221      53.972 134.674  -0.641  1.00 53.92           N  \\nATOM   4513  C2   DT J 221      53.690 134.309   0.657  1.00 53.92           C  \\nATOM   4514  O2   DT J 221      53.666 135.105   1.589  1.00 53.92           O  \\nATOM   4515  N3   DT J 221      53.447 132.972   0.832  1.00 53.92           N  \\nATOM   4516  C4   DT J 221      53.476 131.983  -0.130  1.00 53.92           C  \\nATOM   4517  O4   DT J 221      53.209 130.826   0.183  1.00 53.92           O  \\nATOM   4518  C5   DT J 221      53.820 132.431  -1.465  1.00 53.92           C  \\nATOM   4519  C7   DT J 221      53.920 131.425  -2.567  1.00 53.92           C  \\nATOM   4520  C6   DT J 221      54.039 133.741  -1.652  1.00 53.92           C  \\nATOM   4521  P    DC J 222      56.595 139.616  -1.093  1.00 76.40           P  \\nATOM   4522  OP1  DC J 222      56.187 141.022  -1.336  1.00 76.40           O  \\nATOM   4523  OP2  DC J 222      57.577 138.953  -2.001  1.00 76.40           O  \\nATOM   4524  O5'  DC J 222      57.122 139.538   0.399  1.00 95.23           O  \\nATOM   4525  C5'  DC J 222      56.204 139.363   1.469  1.00 95.23           C  \\nATOM   4526  C4'  DC J 222      56.850 138.571   2.579  1.00 95.23           C  \\nATOM   4527  O4'  DC J 222      56.426 137.186   2.532  1.00 95.23           O  \\nATOM   4528  C3'  DC J 222      58.379 138.539   2.520  1.00 95.23           C  \\nATOM   4529  O3'  DC J 222      58.870 138.571   3.857  1.00 95.23           O  \\nATOM   4530  C2'  DC J 222      58.667 137.176   1.923  1.00 95.23           C  \\nATOM   4531  C1'  DC J 222      57.584 136.383   2.605  1.00 95.23           C  \\nATOM   4532  N1   DC J 222      57.289 135.069   2.037  1.00 33.19           N  \\nATOM   4533  C2   DC J 222      56.807 134.090   2.895  1.00 33.19           C  \\nATOM   4534  O2   DC J 222      56.544 134.415   4.084  1.00 33.19           O  \\nATOM   4535  N3   DC J 222      56.631 132.827   2.426  1.00 33.19           N  \\nATOM   4536  C4   DC J 222      56.902 132.544   1.152  1.00 33.19           C  \\nATOM   4537  N4   DC J 222      56.766 131.274   0.747  1.00 33.19           N  \\nATOM   4538  C5   DC J 222      57.338 133.545   0.239  1.00 33.19           C  \\nATOM   4539  C6   DC J 222      57.514 134.786   0.719  1.00 33.19           C  \\nATOM   4540  P    DA J 223      60.362 139.078   4.159  1.00 77.49           P  \\nATOM   4541  OP1  DA J 223      60.371 140.561   4.087  1.00 77.49           O  \\nATOM   4542  OP2  DA J 223      61.311 138.284   3.325  1.00 77.49           O  \\nATOM   4543  O5'  DA J 223      60.555 138.659   5.677  1.00 71.91           O  \\nATOM   4544  C5'  DA J 223      59.467 138.762   6.599  1.00 71.91           C  \\nATOM   4545  C4'  DA J 223      59.547 137.650   7.616  1.00 71.91           C  \\nATOM   4546  O4'  DA J 223      59.204 136.384   6.994  1.00 71.91           O  \\nATOM   4547  C3'  DA J 223      60.957 137.488   8.167  1.00 71.91           C  \\nATOM   4548  O3'  DA J 223      60.914 137.210   9.560  1.00 71.91           O  \\nATOM   4549  C2'  DA J 223      61.524 136.331   7.361  1.00 71.91           C  \\nATOM   4550  C1'  DA J 223      60.299 135.485   7.047  1.00 71.91           C  \\nATOM   4551  N9   DA J 223      60.366 134.768   5.766  1.00 64.49           N  \\nATOM   4552  C8   DA J 223      60.904 135.204   4.573  1.00 64.49           C  \\nATOM   4553  N7   DA J 223      60.838 134.318   3.606  1.00 64.49           N  \\nATOM   4554  C5   DA J 223      60.209 133.228   4.194  1.00 64.49           C  \\nATOM   4555  C6   DA J 223      59.835 131.966   3.695  1.00 64.49           C  \\nATOM   4556  N6   DA J 223      60.052 131.570   2.439  1.00 64.49           N  \\nATOM   4557  N1   DA J 223      59.219 131.112   4.542  1.00 64.49           N  \\nATOM   4558  C2   DA J 223      58.990 131.508   5.800  1.00 64.49           C  \\nATOM   4559  N3   DA J 223      59.290 132.665   6.387  1.00 64.49           N  \\nATOM   4560  C4   DA J 223      59.906 133.492   5.521  1.00 64.49           C  \\nATOM   4561  P    DG J 224      62.121 137.692  10.503  1.00 77.45           P  \\nATOM   4562  OP1  DG J 224      61.863 139.091  10.930  1.00 77.45           O  \\nATOM   4563  OP2  DG J 224      63.395 137.361   9.797  1.00 77.45           O  \\nATOM   4564  O5'  DG J 224      61.959 136.757  11.791  1.00 44.18           O  \\nATOM   4565  C5'  DG J 224      60.743 136.035  12.028  1.00 44.18           C  \\nATOM   4566  C4'  DG J 224      60.960 134.544  11.865  1.00 44.18           C  \\nATOM   4567  O4'  DG J 224      61.163 134.137  10.489  1.00 44.18           O  \\nATOM   4568  C3'  DG J 224      62.102 133.909  12.647  1.00 44.18           C  \\nATOM   4569  O3'  DG J 224      61.602 132.685  13.120  1.00 44.18           O  \\nATOM   4570  C2'  DG J 224      63.148 133.607  11.585  1.00 44.18           C  \\nATOM   4571  C1'  DG J 224      62.284 133.257  10.391  1.00 44.18           C  \\nATOM   4572  N9   DG J 224      62.903 133.470   9.081  1.00 65.79           N  \\nATOM   4573  C8   DG J 224      63.629 134.570   8.699  1.00 65.79           C  \\nATOM   4574  N7   DG J 224      64.021 134.525   7.453  1.00 65.79           N  \\nATOM   4575  C5   DG J 224      63.532 133.317   6.980  1.00 65.79           C  \\nATOM   4576  C6   DG J 224      63.637 132.729   5.684  1.00 65.79           C  \\nATOM   4577  O6   DG J 224      64.196 133.190   4.663  1.00 65.79           O  \\nATOM   4578  N1   DG J 224      63.009 131.486   5.636  1.00 65.79           N  \\nATOM   4579  C2   DG J 224      62.371 130.890   6.693  1.00 65.79           C  \\nATOM   4580  N2   DG J 224      61.856 129.682   6.443  1.00 65.79           N  \\nATOM   4581  N3   DG J 224      62.253 131.432   7.900  1.00 65.79           N  \\nATOM   4582  C4   DG J 224      62.853 132.639   7.973  1.00 65.79           C  \\nATOM   4583  P    DC J 225      62.049 132.139  14.544  1.00 60.56           P  \\nATOM   4584  OP1  DC J 225      61.029 132.562  15.548  1.00 60.56           O  \\nATOM   4585  OP2  DC J 225      63.473 132.530  14.714  1.00 60.56           O  \\nATOM   4586  O5'  DC J 225      61.963 130.562  14.333  1.00 90.95           O  \\nATOM   4587  C5'  DC J 225      61.506 130.018  13.087  1.00 90.95           C  \\nATOM   4588  C4'  DC J 225      62.422 128.906  12.628  1.00 90.95           C  \\nATOM   4589  O4'  DC J 225      63.027 129.254  11.360  1.00 90.95           O  \\nATOM   4590  C3'  DC J 225      63.585 128.588  13.571  1.00 90.95           C  \\nATOM   4591  O3'  DC J 225      63.828 127.179  13.547  1.00 90.95           O  \\nATOM   4592  C2'  DC J 225      64.755 129.314  12.929  1.00 90.95           C  \\nATOM   4593  C1'  DC J 225      64.436 129.116  11.462  1.00 90.95           C  \\nATOM   4594  N1   DC J 225      65.060 130.067  10.533  1.00 88.80           N  \\nATOM   4595  C2   DC J 225      65.096 129.740   9.172  1.00 88.80           C  \\nATOM   4596  O2   DC J 225      64.601 128.666   8.802  1.00 88.80           O  \\nATOM   4597  N3   DC J 225      65.668 130.599   8.298  1.00 88.80           N  \\nATOM   4598  C4   DC J 225      66.192 131.750   8.739  1.00 88.80           C  \\nATOM   4599  N4   DC J 225      66.748 132.580   7.832  1.00 88.80           N  \\nATOM   4600  C5   DC J 225      66.169 132.106  10.126  1.00 88.80           C  \\nATOM   4601  C6   DC J 225      65.598 131.242  10.978  1.00 88.80           C  \\nATOM   4602  P    DT J 226      63.223 126.245  14.703  1.00 94.45           P  \\nATOM   4603  OP1  DT J 226      61.887 126.758  15.105  1.00 94.45           O  \\nATOM   4604  OP2  DT J 226      64.288 126.079  15.718  1.00 94.45           O  \\nATOM   4605  O5'  DT J 226      62.998 124.851  13.977  1.00 56.93           O  \\nATOM   4606  C5'  DT J 226      62.105 124.753  12.871  1.00 56.93           C  \\nATOM   4607  C4'  DT J 226      62.761 123.997  11.738  1.00 56.93           C  \\nATOM   4608  O4'  DT J 226      63.638 124.807  10.917  1.00 56.93           O  \\nATOM   4609  C3'  DT J 226      63.589 122.795  12.170  1.00 56.93           C  \\nATOM   4610  O3'  DT J 226      63.337 121.790  11.210  1.00 56.93           O  \\nATOM   4611  C2'  DT J 226      65.019 123.286  12.005  1.00 56.93           C  \\nATOM   4612  C1'  DT J 226      64.877 124.129  10.758  1.00 56.93           C  \\nATOM   4613  N1   DT J 226      65.926 125.141  10.522  1.00 56.58           N  \\nATOM   4614  C2   DT J 226      66.214 125.470   9.212  1.00 56.58           C  \\nATOM   4615  O2   DT J 226      65.702 124.912   8.249  1.00 56.58           O  \\nATOM   4616  N3   DT J 226      67.125 126.486   9.065  1.00 56.58           N  \\nATOM   4617  C4   DT J 226      67.753 127.195  10.060  1.00 56.58           C  \\nATOM   4618  O4   DT J 226      68.485 128.129   9.759  1.00 56.58           O  \\nATOM   4619  C5   DT J 226      67.450 126.763  11.408  1.00 56.58           C  \\nATOM   4620  C7   DT J 226      68.121 127.442  12.557  1.00 56.58           C  \\nATOM   4621  C6   DT J 226      66.569 125.764  11.570  1.00 56.58           C  \\nATOM   4622  P    DG J 227      63.360 120.253  11.623  1.00 40.43           P  \\nATOM   4623  OP1  DG J 227      61.987 119.841  11.997  1.00 40.43           O  \\nATOM   4624  OP2  DG J 227      64.502 119.961  12.543  1.00 40.43           O  \\nATOM   4625  O5'  DG J 227      63.693 119.617  10.221  1.00 38.42           O  \\nATOM   4626  C5'  DG J 227      64.946 119.042  10.022  1.00 38.42           C  \\nATOM   4627  C4'  DG J 227      65.549 119.519   8.729  1.00 38.42           C  \\nATOM   4628  O4'  DG J 227      66.049 120.870   8.862  1.00 38.42           O  \\nATOM   4629  C3'  DG J 227      66.768 118.653   8.469  1.00 38.42           C  \\nATOM   4630  O3'  DG J 227      66.885 118.326   7.109  1.00 38.42           O  \\nATOM   4631  C2'  DG J 227      67.933 119.480   8.955  1.00 38.42           C  \\nATOM   4632  C1'  DG J 227      67.464 120.883   8.665  1.00 38.42           C  \\nATOM   4633  N9   DG J 227      68.062 121.882   9.552  1.00 40.96           N  \\nATOM   4634  C8   DG J 227      67.912 122.009  10.918  1.00 40.96           C  \\nATOM   4635  N7   DG J 227      68.561 123.026  11.412  1.00 40.96           N  \\nATOM   4636  C5   DG J 227      69.177 123.602  10.305  1.00 40.96           C  \\nATOM   4637  C6   DG J 227      70.001 124.754  10.205  1.00 40.96           C  \\nATOM   4638  O6   DG J 227      70.350 125.538  11.101  1.00 40.96           O  \\nATOM   4639  N1   DG J 227      70.425 124.969   8.895  1.00 40.96           N  \\nATOM   4640  C2   DG J 227      70.096 124.180   7.821  1.00 40.96           C  \\nATOM   4641  N2   DG J 227      70.636 124.536   6.638  1.00 40.96           N  \\nATOM   4642  N3   DG J 227      69.308 123.119   7.898  1.00 40.96           N  \\nATOM   4643  C4   DG J 227      68.891 122.892   9.158  1.00 40.96           C  \\nATOM   4644  P    DA J 228      67.826 117.121   6.706  1.00 28.41           P  \\nATOM   4645  OP1  DA J 228      67.142 116.125   5.826  1.00 28.41           O  \\nATOM   4646  OP2  DA J 228      68.415 116.666   7.993  1.00 28.41           O  \\nATOM   4647  O5'  DA J 228      68.911 117.884   5.837  1.00 28.47           O  \\nATOM   4648  C5'  DA J 228      68.530 118.601   4.665  1.00 28.47           C  \\nATOM   4649  C4'  DA J 228      69.758 119.114   3.946  1.00 28.47           C  \\nATOM   4650  O4'  DA J 228      70.360 120.190   4.710  1.00 28.47           O  \\nATOM   4651  C3'  DA J 228      70.856 118.072   3.724  1.00 28.47           C  \\nATOM   4652  O3'  DA J 228      71.423 118.254   2.420  1.00 28.47           O  \\nATOM   4653  C2'  DA J 228      71.833 118.343   4.854  1.00 28.47           C  \\nATOM   4654  C1'  DA J 228      71.642 119.827   5.171  1.00 28.47           C  \\nATOM   4655  N9   DA J 228      71.686 120.137   6.595  1.00 30.07           N  \\nATOM   4656  C8   DA J 228      71.134 119.426   7.636  1.00 30.07           C  \\nATOM   4657  N7   DA J 228      71.369 119.946   8.826  1.00 30.07           N  \\nATOM   4658  C5   DA J 228      72.121 121.079   8.546  1.00 30.07           C  \\nATOM   4659  C6   DA J 228      72.701 122.059   9.375  1.00 30.07           C  \\nATOM   4660  N6   DA J 228      72.612 122.062  10.705  1.00 30.07           N  \\nATOM   4661  N1   DA J 228      73.394 123.050   8.776  1.00 30.07           N  \\nATOM   4662  C2   DA J 228      73.495 123.055   7.430  1.00 30.07           C  \\nATOM   4663  N3   DA J 228      72.999 122.192   6.542  1.00 30.07           N  \\nATOM   4664  C4   DA J 228      72.316 121.214   7.171  1.00 30.07           C  \\nATOM   4665  P    DA J 229      72.459 117.176   1.818  1.00 33.93           P  \\nATOM   4666  OP1  DA J 229      72.202 117.082   0.356  1.00 33.93           O  \\nATOM   4667  OP2  DA J 229      72.473 115.939   2.649  1.00 33.93           O  \\nATOM   4668  O5'  DA J 229      73.858 117.903   2.032  1.00 33.59           O  \\nATOM   4669  C5'  DA J 229      74.062 119.229   1.532  1.00 33.59           C  \\nATOM   4670  C4'  DA J 229      75.363 119.804   2.044  1.00 33.59           C  \\nATOM   4671  O4'  DA J 229      75.231 120.242   3.417  1.00 33.59           O  \\nATOM   4672  C3'  DA J 229      76.577 118.872   1.995  1.00 33.59           C  \\nATOM   4673  O3'  DA J 229      77.688 119.578   1.409  1.00 33.59           O  \\nATOM   4674  C2'  DA J 229      76.813 118.533   3.459  1.00 33.59           C  \\nATOM   4675  C1'  DA J 229      76.324 119.774   4.174  1.00 33.59           C  \\nATOM   4676  N9   DA J 229      75.853 119.559   5.536  1.00 48.40           N  \\nATOM   4677  C8   DA J 229      75.087 118.524   6.005  1.00 48.40           C  \\nATOM   4678  N7   DA J 229      74.807 118.605   7.285  1.00 48.40           N  \\nATOM   4679  C5   DA J 229      75.438 119.773   7.691  1.00 48.40           C  \\nATOM   4680  C6   DA J 229      75.529 120.424   8.945  1.00 48.40           C  \\nATOM   4681  N6   DA J 229      74.971 119.970  10.070  1.00 48.40           N  \\nATOM   4682  N1   DA J 229      76.232 121.575   9.002  1.00 48.40           N  \\nATOM   4683  C2   DA J 229      76.808 122.033   7.882  1.00 48.40           C  \\nATOM   4684  N3   DA J 229      76.800 121.514   6.651  1.00 48.40           N  \\nATOM   4685  C4   DA J 229      76.087 120.372   6.621  1.00 48.40           C  \\nATOM   4686  P    DC J 230      79.014 118.782   0.934  1.00 36.79           P  \\nATOM   4687  OP1  DC J 230      79.545 119.471  -0.271  1.00 36.79           O  \\nATOM   4688  OP2  DC J 230      78.677 117.339   0.845  1.00 36.79           O  \\nATOM   4689  O5'  DC J 230      80.022 119.061   2.146  1.00 32.06           O  \\nATOM   4690  C5'  DC J 230      80.065 120.357   2.756  1.00 32.06           C  \\nATOM   4691  C4'  DC J 230      81.101 120.424   3.858  1.00 32.06           C  \\nATOM   4692  O4'  DC J 230      80.425 120.503   5.141  1.00 32.06           O  \\nATOM   4693  C3'  DC J 230      82.112 119.271   3.963  1.00 32.06           C  \\nATOM   4694  O3'  DC J 230      83.453 119.764   4.164  1.00 32.06           O  \\nATOM   4695  C2'  DC J 230      81.669 118.524   5.207  1.00 32.06           C  \\nATOM   4696  C1'  DC J 230      81.034 119.614   6.060  1.00 32.06           C  \\nATOM   4697  N1   DC J 230      79.999 119.111   7.001  1.00 49.38           N  \\nATOM   4698  C2   DC J 230      79.786 119.789   8.218  1.00 49.38           C  \\nATOM   4699  O2   DC J 230      80.381 120.852   8.432  1.00 49.38           O  \\nATOM   4700  N3   DC J 230      78.929 119.267   9.125  1.00 49.38           N  \\nATOM   4701  C4   DC J 230      78.277 118.134   8.856  1.00 49.38           C  \\nATOM   4702  N4   DC J 230      77.473 117.641   9.803  1.00 49.38           N  \\nATOM   4703  C5   DC J 230      78.427 117.454   7.611  1.00 49.38           C  \\nATOM   4704  C6   DC J 230      79.287 117.974   6.719  1.00 49.38           C  \\nATOM   4705  P    DA J 231      84.715 118.915   3.614  1.00 72.18           P  \\nATOM   4706  OP1  DA J 231      84.891 119.184   2.161  1.00 72.18           O  \\nATOM   4707  OP2  DA J 231      84.583 117.508   4.085  1.00 72.18           O  \\nATOM   4708  O5'  DA J 231      85.948 119.562   4.381  1.00146.67           O  \\nATOM   4709  C5'  DA J 231      85.764 120.623   5.320  1.00146.67           C  \\nATOM   4710  C4'  DA J 231      86.351 120.231   6.655  1.00146.67           C  \\nATOM   4711  O4'  DA J 231      85.300 119.805   7.563  1.00146.67           O  \\nATOM   4712  C3'  DA J 231      87.339 119.062   6.557  1.00146.67           C  \\nATOM   4713  O3'  DA J 231      88.519 119.267   7.346  1.00146.67           O  \\nATOM   4714  C2'  DA J 231      86.550 117.889   7.108  1.00146.67           C  \\nATOM   4715  C1'  DA J 231      85.672 118.565   8.141  1.00146.67           C  \\nATOM   4716  N9   DA J 231      84.466 117.801   8.457  1.00119.90           N  \\nATOM   4717  C8   DA J 231      83.766 116.963   7.622  1.00119.90           C  \\nATOM   4718  N7   DA J 231      82.776 116.337   8.210  1.00119.90           N  \\nATOM   4719  C5   DA J 231      82.813 116.810   9.514  1.00119.90           C  \\nATOM   4720  C6   DA J 231      82.034 116.516  10.644  1.00119.90           C  \\nATOM   4721  N6   DA J 231      81.028 115.636  10.635  1.00119.90           N  \\nATOM   4722  N1   DA J 231      82.328 117.161  11.797  1.00119.90           N  \\nATOM   4723  C2   DA J 231      83.344 118.038  11.801  1.00119.90           C  \\nATOM   4724  N3   DA J 231      84.155 118.392  10.804  1.00119.90           N  \\nATOM   4725  C4   DA J 231      83.834 117.731   9.675  1.00119.90           C  \\nATOM   4726  P    DT J 232      89.673 118.137   7.363  1.00158.32           P  \\nATOM   4727  OP1  DT J 232      90.991 118.819   7.341  1.00158.32           O  \\nATOM   4728  OP2  DT J 232      89.362 117.116   6.328  1.00158.32           O  \\nATOM   4729  O5'  DT J 232      89.492 117.444   8.784  1.00193.87           O  \\nATOM   4730  C5'  DT J 232      90.047 116.158   9.051  1.00193.87           C  \\nATOM   4731  C4'  DT J 232      89.746 115.754  10.476  1.00193.87           C  \\nATOM   4732  O4'  DT J 232      88.310 115.746  10.686  1.00193.87           O  \\nATOM   4733  C3'  DT J 232      90.241 114.361  10.871  1.00193.87           C  \\nATOM   4734  O3'  DT J 232      90.722 114.383  12.221  1.00193.87           O  \\nATOM   4735  C2'  DT J 232      88.985 113.510  10.788  1.00193.87           C  \\nATOM   4736  C1'  DT J 232      87.917 114.494  11.231  1.00193.87           C  \\nATOM   4737  N1   DT J 232      86.544 114.185  10.765  1.00169.77           N  \\nATOM   4738  C2   DT J 232      85.539 114.123  11.709  1.00169.77           C  \\nATOM   4739  O2   DT J 232      85.716 114.350  12.896  1.00169.77           O  \\nATOM   4740  N3   DT J 232      84.308 113.789  11.206  1.00169.77           N  \\nATOM   4741  C4   DT J 232      83.979 113.536   9.888  1.00169.77           C  \\nATOM   4742  O4   DT J 232      82.826 113.245   9.596  1.00169.77           O  \\nATOM   4743  C5   DT J 232      85.068 113.642   8.949  1.00169.77           C  \\nATOM   4744  C7   DT J 232      84.799 113.402   7.495  1.00169.77           C  \\nATOM   4745  C6   DT J 232      86.283 113.954   9.428  1.00169.77           C  \\nATOM   4746  P    DG J 233      92.066 113.589  12.609  1.00169.02           P  \\nATOM   4747  OP1  DG J 233      93.235 114.394  12.168  1.00169.02           O  \\nATOM   4748  OP2  DG J 233      91.922 112.186  12.135  1.00169.02           O  \\nATOM   4749  O5'  DG J 233      92.038 113.571  14.202  1.00153.54           O  \\nATOM   4750  C5'  DG J 233      91.798 114.763  14.956  1.00153.54           C  \\nATOM   4751  C4'  DG J 233      90.940 114.447  16.160  1.00153.54           C  \\nATOM   4752  O4'  DG J 233      89.591 114.156  15.724  1.00153.54           O  \\nATOM   4753  C3'  DG J 233      91.400 113.215  16.939  1.00153.54           C  \\nATOM   4754  O3'  DG J 233      91.152 113.381  18.339  1.00153.54           O  \\nATOM   4755  C2'  DG J 233      90.551 112.099  16.359  1.00153.54           C  \\nATOM   4756  C1'  DG J 233      89.245 112.807  16.036  1.00153.54           C  \\nATOM   4757  N9   DG J 233      88.556 112.247  14.878  1.00186.84           N  \\nATOM   4758  C8   DG J 233      89.089 112.052  13.626  1.00186.84           C  \\nATOM   4759  N7   DG J 233      88.236 111.548  12.777  1.00186.84           N  \\nATOM   4760  C5   DG J 233      87.067 111.397  13.510  1.00186.84           C  \\nATOM   4761  C6   DG J 233      85.801 110.905  13.117  1.00186.84           C  \\nATOM   4762  O6   DG J 233      85.439 110.512  12.003  1.00186.84           O  \\nATOM   4763  N1   DG J 233      84.901 110.903  14.175  1.00186.84           N  \\nATOM   4764  C2   DG J 233      85.178 111.332  15.450  1.00186.84           C  \\nATOM   4765  N2   DG J 233      84.172 111.233  16.330  1.00186.84           N  \\nATOM   4766  N3   DG J 233      86.353 111.814  15.829  1.00186.84           N  \\nATOM   4767  C4   DG J 233      87.247 111.815  14.814  1.00186.84           C  \\nATOM   4768  P    DC J 234      91.317 112.126  19.336  1.00139.25           P  \\nATOM   4769  OP1  DC J 234      91.414 112.662  20.719  1.00139.25           O  \\nATOM   4770  OP2  DC J 234      92.373 111.213  18.819  1.00139.25           O  \\nATOM   4771  O5'  DC J 234      89.921 111.372  19.215  1.00158.75           O  \\nATOM   4772  C5'  DC J 234      88.696 112.080  19.384  1.00158.75           C  \\nATOM   4773  C4'  DC J 234      87.643 111.161  19.952  1.00158.75           C  \\nATOM   4774  O4'  DC J 234      87.129 110.321  18.896  1.00158.75           O  \\nATOM   4775  C3'  DC J 234      88.159 110.210  21.025  1.00158.75           C  \\nATOM   4776  O3'  DC J 234      87.127 109.987  21.982  1.00158.75           O  \\nATOM   4777  C2'  DC J 234      88.495 108.950  20.247  1.00158.75           C  \\nATOM   4778  C1'  DC J 234      87.491 108.962  19.105  1.00158.75           C  \\nATOM   4779  N1   DC J 234      88.027 108.463  17.830  1.00135.04           N  \\nATOM   4780  C2   DC J 234      87.161 108.342  16.733  1.00135.04           C  \\nATOM   4781  O2   DC J 234      85.954 108.615  16.880  1.00135.04           O  \\nATOM   4782  N3   DC J 234      87.657 107.933  15.545  1.00135.04           N  \\nATOM   4783  C4   DC J 234      88.954 107.652  15.426  1.00135.04           C  \\nATOM   4784  N4   DC J 234      89.405 107.296  14.224  1.00135.04           N  \\nATOM   4785  C5   DC J 234      89.849 107.736  16.530  1.00135.04           C  \\nATOM   4786  C6   DC J 234      89.348 108.140  17.702  1.00135.04           C  \\nATOM   4787  P    DC J 235      87.307 108.854  23.100  1.00 81.09           P  \\nATOM   4788  OP1  DC J 235      87.101 109.454  24.443  1.00 81.09           O  \\nATOM   4789  OP2  DC J 235      88.550 108.088  22.804  1.00 81.09           O  \\nATOM   4790  O5'  DC J 235      86.081 107.888  22.836  1.00113.21           O  \\nATOM   4791  C5'  DC J 235      84.767 108.407  22.714  1.00113.21           C  \\nATOM   4792  C4'  DC J 235      83.858 107.328  22.185  1.00113.21           C  \\nATOM   4793  O4'  DC J 235      84.361 106.906  20.893  1.00113.21           O  \\nATOM   4794  C3'  DC J 235      83.853 106.077  23.063  1.00113.21           C  \\nATOM   4795  O3'  DC J 235      82.540 105.517  23.095  1.00113.21           O  \\nATOM   4796  C2'  DC J 235      84.850 105.155  22.381  1.00113.21           C  \\nATOM   4797  C1'  DC J 235      84.696 105.526  20.920  1.00113.21           C  \\nATOM   4798  N1   DC J 235      85.906 105.340  20.105  1.00108.11           N  \\nATOM   4799  C2   DC J 235      85.793 105.424  18.715  1.00108.11           C  \\nATOM   4800  O2   DC J 235      84.686 105.670  18.218  1.00108.11           O  \\nATOM   4801  N3   DC J 235      86.887 105.242  17.947  1.00108.11           N  \\nATOM   4802  C4   DC J 235      88.063 104.997  18.517  1.00108.11           C  \\nATOM   4803  N4   DC J 235      89.109 104.834  17.715  1.00108.11           N  \\nATOM   4804  C5   DC J 235      88.214 104.911  19.934  1.00108.11           C  \\nATOM   4805  C6   DC J 235      87.118 105.086  20.683  1.00108.11           C  \\nATOM   4806  P    DT J 236      82.297 104.077  23.757  1.00131.18           P  \\nATOM   4807  OP1  DT J 236      81.208 104.223  24.756  1.00131.18           O  \\nATOM   4808  OP2  DT J 236      83.605 103.503  24.170  1.00131.18           O  \\nATOM   4809  O5'  DT J 236      81.752 103.230  22.527  1.00143.00           O  \\nATOM   4810  C5'  DT J 236      80.977 103.866  21.513  1.00143.00           C  \\nATOM   4811  C4'  DT J 236      80.921 103.016  20.264  1.00143.00           C  \\nATOM   4812  O4'  DT J 236      82.209 102.960  19.600  1.00143.00           O  \\nATOM   4813  C3'  DT J 236      80.472 101.568  20.453  1.00143.00           C  \\nATOM   4814  O3'  DT J 236      79.564 101.246  19.404  1.00143.00           O  \\nATOM   4815  C2'  DT J 236      81.758 100.773  20.298  1.00143.00           C  \\nATOM   4816  C1'  DT J 236      82.546 101.612  19.307  1.00143.00           C  \\nATOM   4817  N1   DT J 236      84.014 101.476  19.424  1.00104.25           N  \\nATOM   4818  C2   DT J 236      84.750 101.245  18.279  1.00104.25           C  \\nATOM   4819  O2   DT J 236      84.258 101.145  17.168  1.00104.25           O  \\nATOM   4820  N3   DT J 236      86.099 101.132  18.487  1.00104.25           N  \\nATOM   4821  C4   DT J 236      86.778 101.231  19.686  1.00104.25           C  \\nATOM   4822  O4   DT J 236      88.001 101.115  19.701  1.00104.25           O  \\nATOM   4823  C5   DT J 236      85.947 101.470  20.848  1.00104.25           C  \\nATOM   4824  C7   DT J 236      86.587 101.577  22.198  1.00104.25           C  \\nATOM   4825  C6   DT J 236      84.625 101.580  20.659  1.00104.25           C  \\nATOM   4826  P    DT J 237      78.643  99.938  19.504  1.00 52.64           P  \\nATOM   4827  OP1  DT J 237      77.236 100.385  19.606  1.00 52.64           O  \\nATOM   4828  OP2  DT J 237      79.198  99.015  20.527  1.00 52.64           O  \\nATOM   4829  O5'  DT J 237      78.859  99.289  18.075  1.00 37.64           O  \\nATOM   4830  C5'  DT J 237      79.003 100.140  16.946  1.00 37.64           C  \\nATOM   4831  C4'  DT J 237      79.780  99.447  15.855  1.00 37.64           C  \\nATOM   4832  O4'  DT J 237      81.185  99.394  16.200  1.00 37.64           O  \\nATOM   4833  C3'  DT J 237      79.343  98.008  15.581  1.00 37.64           C  \\nATOM   4834  O3'  DT J 237      79.174  97.832  14.176  1.00 37.64           O  \\nATOM   4835  C2'  DT J 237      80.496  97.178  16.116  1.00 37.64           C  \\nATOM   4836  C1'  DT J 237      81.679  98.103  15.903  1.00 37.64           C  \\nATOM   4837  N1   DT J 237      82.823  97.838  16.790  1.00 54.88           N  \\nATOM   4838  C2   DT J 237      84.085  97.652  16.243  1.00 54.88           C  \\nATOM   4839  O2   DT J 237      84.325  97.709  15.044  1.00 54.88           O  \\nATOM   4840  N3   DT J 237      85.063  97.395  17.166  1.00 54.88           N  \\nATOM   4841  C4   DT J 237      84.920  97.317  18.535  1.00 54.88           C  \\nATOM   4842  O4   DT J 237      85.897  97.089  19.236  1.00 54.88           O  \\nATOM   4843  C5   DT J 237      83.581  97.523  19.033  1.00 54.88           C  \\nATOM   4844  C7   DT J 237      83.331  97.453  20.507  1.00 54.88           C  \\nATOM   4845  C6   DT J 237      82.614  97.770  18.146  1.00 54.88           C  \\nATOM   4846  P    DT J 238      79.090  96.355  13.556  1.00 30.33           P  \\nATOM   4847  OP1  DT J 238      78.319  96.332  12.268  1.00 30.33           O  \\nATOM   4848  OP2  DT J 238      78.749  95.393  14.645  1.00 30.33           O  \\nATOM   4849  O5'  DT J 238      80.590  96.107  13.132  1.00 48.10           O  \\nATOM   4850  C5'  DT J 238      80.901  94.992  12.356  1.00 48.10           C  \\nATOM   4851  C4'  DT J 238      82.245  95.168  11.710  1.00 48.10           C  \\nATOM   4852  O4'  DT J 238      83.199  95.644  12.695  1.00 48.10           O  \\nATOM   4853  C3'  DT J 238      82.716  93.798  11.264  1.00 48.10           C  \\nATOM   4854  O3'  DT J 238      83.238  93.828   9.943  1.00 48.10           O  \\nATOM   4855  C2'  DT J 238      83.687  93.359  12.348  1.00 48.10           C  \\nATOM   4856  C1'  DT J 238      84.167  94.650  12.999  1.00 48.10           C  \\nATOM   4857  N1   DT J 238      84.265  94.546  14.477  1.00 68.29           N  \\nATOM   4858  C2   DT J 238      85.512  94.381  15.059  1.00 68.29           C  \\nATOM   4859  O2   DT J 238      86.554  94.314  14.419  1.00 68.29           O  \\nATOM   4860  N3   DT J 238      85.493  94.289  16.434  1.00 68.29           N  \\nATOM   4861  C4   DT J 238      84.388  94.341  17.262  1.00 68.29           C  \\nATOM   4862  O4   DT J 238      84.530  94.259  18.482  1.00 68.29           O  \\nATOM   4863  C5   DT J 238      83.122  94.500  16.588  1.00 68.29           C  \\nATOM   4864  C7   DT J 238      81.871  94.537  17.407  1.00 68.29           C  \\nATOM   4865  C6   DT J 238      83.124  94.601  15.250  1.00 68.29           C  \\nATOM   4866  P    DT J 239      83.331  92.458   9.106  1.00 76.19           P  \\nATOM   4867  OP1  DT J 239      83.166  92.771   7.657  1.00 76.19           O  \\nATOM   4868  OP2  DT J 239      82.436  91.464   9.755  1.00 76.19           O  \\nATOM   4869  O5'  DT J 239      84.832  92.012   9.384  1.00 70.92           O  \\nATOM   4870  C5'  DT J 239      85.481  92.456  10.567  1.00 70.92           C  \\nATOM   4871  C4'  DT J 239      86.783  91.729  10.759  1.00 70.92           C  \\nATOM   4872  O4'  DT J 239      87.098  91.843  12.160  1.00 70.92           O  \\nATOM   4873  C3'  DT J 239      86.690  90.233  10.481  1.00 70.92           C  \\nATOM   4874  O3'  DT J 239      87.967  89.754  10.032  1.00 70.92           O  \\nATOM   4875  C2'  DT J 239      86.300  89.656  11.828  1.00 70.92           C  \\nATOM   4876  C1'  DT J 239      87.024  90.575  12.786  1.00 70.92           C  \\nATOM   4877  N1   DT J 239      86.319  90.764  14.039  1.00 92.50           N  \\nATOM   4878  C2   DT J 239      87.003  90.572  15.210  1.00 92.50           C  \\nATOM   4879  O2   DT J 239      88.171  90.213  15.260  1.00 92.50           O  \\nATOM   4880  N3   DT J 239      86.267  90.812  16.333  1.00 92.50           N  \\nATOM   4881  C4   DT J 239      84.952  91.209  16.403  1.00 92.50           C  \\nATOM   4882  O4   DT J 239      84.438  91.394  17.490  1.00 92.50           O  \\nATOM   4883  C5   DT J 239      84.292  91.375  15.135  1.00 92.50           C  \\nATOM   4884  C7   DT J 239      82.858  91.796  15.110  1.00 92.50           C  \\nATOM   4885  C6   DT J 239      85.000  91.144  14.029  1.00 92.50           C  \\nATOM   4886  P    DG J 240      88.100  88.269   9.443  1.00114.93           P  \\nATOM   4887  OP1  DG J 240      89.535  87.902   9.515  1.00114.93           O  \\nATOM   4888  OP2  DG J 240      87.390  88.204   8.137  1.00114.93           O  \\nATOM   4889  O5'  DG J 240      87.296  87.398  10.510  1.00154.49           O  \\nATOM   4890  C5'  DG J 240      87.736  86.099  10.879  1.00154.49           C  \\nATOM   4891  C4'  DG J 240      88.874  86.200  11.867  1.00154.49           C  \\nATOM   4892  O4'  DG J 240      88.495  87.042  12.981  1.00154.49           O  \\nATOM   4893  C3'  DG J 240      89.285  84.859  12.471  1.00154.49           C  \\nATOM   4894  O3'  DG J 240      90.700  84.800  12.631  1.00154.49           O  \\nATOM   4895  C2'  DG J 240      88.609  84.860  13.825  1.00154.49           C  \\nATOM   4896  C1'  DG J 240      88.641  86.327  14.198  1.00154.49           C  \\nATOM   4897  N9   DG J 240      87.538  86.699  15.069  1.00108.40           N  \\nATOM   4898  C8   DG J 240      86.232  86.913  14.702  1.00108.40           C  \\nATOM   4899  N7   DG J 240      85.463  87.207  15.710  1.00108.40           N  \\nATOM   4900  C5   DG J 240      86.314  87.191  16.808  1.00108.40           C  \\nATOM   4901  C6   DG J 240      86.046  87.429  18.175  1.00108.40           C  \\nATOM   4902  O6   DG J 240      84.974  87.714  18.707  1.00108.40           O  \\nATOM   4903  N1   DG J 240      87.192  87.307  18.955  1.00108.40           N  \\nATOM   4904  C2   DG J 240      88.444  86.998  18.480  1.00108.40           C  \\nATOM   4905  N2   DG J 240      89.425  86.928  19.404  1.00108.40           N  \\nATOM   4906  N3   DG J 240      88.709  86.775  17.199  1.00108.40           N  \\nATOM   4907  C4   DG J 240      87.600  86.886  16.427  1.00108.40           C  \\nATOM   4908  P    DA J 241      91.418  83.374  12.794  1.00121.92           P  \\nATOM   4909  OP1  DA J 241      92.716  83.440  12.083  1.00121.92           O  \\nATOM   4910  OP2  DA J 241      90.439  82.318  12.428  1.00121.92           O  \\nATOM   4911  O5'  DA J 241      91.689  83.257  14.359  1.00114.59           O  \\nATOM   4912  C5'  DA J 241      91.769  81.983  14.975  1.00114.59           C  \\nATOM   4913  C4'  DA J 241      91.998  82.120  16.461  1.00114.59           C  \\nATOM   4914  O4'  DA J 241      91.033  83.064  16.994  1.00114.59           O  \\nATOM   4915  C3'  DA J 241      91.763  80.799  17.198  1.00114.59           C  \\nATOM   4916  O3'  DA J 241      92.652  80.611  18.304  1.00114.59           O  \\nATOM   4917  C2'  DA J 241      90.336  80.925  17.690  1.00114.59           C  \\nATOM   4918  C1'  DA J 241      90.211  82.415  17.956  1.00114.59           C  \\nATOM   4919  N9   DA J 241      88.840  82.884  17.785  1.00103.90           N  \\nATOM   4920  C8   DA J 241      88.147  83.124  16.623  1.00103.90           C  \\nATOM   4921  N7   DA J 241      86.904  83.486  16.818  1.00103.90           N  \\nATOM   4922  C5   DA J 241      86.778  83.496  18.199  1.00103.90           C  \\nATOM   4923  C6   DA J 241      85.707  83.793  19.036  1.00103.90           C  \\nATOM   4924  N6   DA J 241      84.509  84.152  18.585  1.00103.90           N  \\nATOM   4925  N1   DA J 241      85.905  83.708  20.369  1.00103.90           N  \\nATOM   4926  C2   DA J 241      87.114  83.348  20.814  1.00103.90           C  \\nATOM   4927  N3   DA J 241      88.201  83.046  20.124  1.00103.90           N  \\nATOM   4928  C4   DA J 241      87.963  83.140  18.805  1.00103.90           C  \\nATOM   4929  P    DT J 242      92.362  79.424  19.351  1.00135.22           P  \\nATOM   4930  OP1  DT J 242      93.547  79.246  20.222  1.00135.22           O  \\nATOM   4931  OP2  DT J 242      91.823  78.266  18.592  1.00135.22           O  \\nATOM   4932  O5'  DT J 242      91.186  80.000  20.249  1.00118.22           O  \\nATOM   4933  C5'  DT J 242      91.460  80.617  21.499  1.00118.22           C  \\nATOM   4934  C4'  DT J 242      90.583  80.007  22.563  1.00118.22           C  \\nATOM   4935  O4'  DT J 242      89.199  80.356  22.307  1.00118.22           O  \\nATOM   4936  C3'  DT J 242      90.628  78.480  22.585  1.00118.22           C  \\nATOM   4937  O3'  DT J 242      90.475  78.041  23.932  1.00118.22           O  \\nATOM   4938  C2'  DT J 242      89.411  78.087  21.767  1.00118.22           C  \\nATOM   4939  C1'  DT J 242      88.427  79.172  22.165  1.00118.22           C  \\nATOM   4940  N1   DT J 242      87.364  79.437  21.186  1.00 76.38           N  \\nATOM   4941  C2   DT J 242      86.208  80.037  21.632  1.00 76.38           C  \\nATOM   4942  O2   DT J 242      86.043  80.395  22.793  1.00 76.38           O  \\nATOM   4943  N3   DT J 242      85.248  80.215  20.663  1.00 76.38           N  \\nATOM   4944  C4   DT J 242      85.339  79.882  19.323  1.00 76.38           C  \\nATOM   4945  O4   DT J 242      84.398  80.102  18.574  1.00 76.38           O  \\nATOM   4946  C5   DT J 242      86.587  79.280  18.923  1.00 76.38           C  \\nATOM   4947  C7   DT J 242      86.782  78.907  17.488  1.00 76.38           C  \\nATOM   4948  C6   DT J 242      87.524  79.084  19.863  1.00 76.38           C  \\nATOM   4949  P    DG J 243      90.379  76.478  24.256  1.00104.97           P  \\nATOM   4950  OP1  DG J 243      91.777  75.974  24.192  1.00104.97           O  \\nATOM   4951  OP2  DG J 243      89.347  75.874  23.373  1.00104.97           O  \\nATOM   4952  O5'  DG J 243      89.862  76.467  25.769  1.00104.53           O  \\nATOM   4953  C5'  DG J 243      88.888  75.519  26.233  1.00104.53           C  \\nATOM   4954  C4'  DG J 243      87.756  76.228  26.949  1.00104.53           C  \\nATOM   4955  O4'  DG J 243      87.065  77.096  26.018  1.00104.53           O  \\nATOM   4956  C3'  DG J 243      86.673  75.320  27.538  1.00104.53           C  \\nATOM   4957  O3'  DG J 243      86.147  75.898  28.740  1.00104.53           O  \\nATOM   4958  C2'  DG J 243      85.609  75.298  26.460  1.00104.53           C  \\nATOM   4959  C1'  DG J 243      85.708  76.689  25.859  1.00104.53           C  \\nATOM   4960  N9   DG J 243      85.403  76.719  24.431  1.00105.48           N  \\nATOM   4961  C8   DG J 243      86.165  76.197  23.408  1.00105.48           C  \\nATOM   4962  N7   DG J 243      85.636  76.377  22.229  1.00105.48           N  \\nATOM   4963  C5   DG J 243      84.454  77.060  22.486  1.00105.48           C  \\nATOM   4964  C6   DG J 243      83.455  77.534  21.598  1.00105.48           C  \\nATOM   4965  O6   DG J 243      83.418  77.462  20.360  1.00105.48           O  \\nATOM   4966  N1   DG J 243      82.417  78.155  22.285  1.00105.48           N  \\nATOM   4967  C2   DG J 243      82.357  78.322  23.653  1.00105.48           C  \\nATOM   4968  N2   DG J 243      81.276  78.953  24.129  1.00105.48           N  \\nATOM   4969  N3   DG J 243      83.289  77.899  24.489  1.00105.48           N  \\nATOM   4970  C4   DG J 243      84.297  77.277  23.844  1.00105.48           C  \\nATOM   4971  P    DG J 244      85.138  75.049  29.664  1.00102.73           P  \\nATOM   4972  OP1  DG J 244      85.008  75.731  30.986  1.00102.73           O  \\nATOM   4973  OP2  DG J 244      85.551  73.617  29.613  1.00102.73           O  \\nATOM   4974  O5'  DG J 244      83.741  75.181  28.908  1.00 91.84           O  \\nATOM   4975  C5'  DG J 244      82.836  76.248  29.213  1.00 91.84           C  \\nATOM   4976  C4'  DG J 244      81.464  75.947  28.656  1.00 91.84           C  \\nATOM   4977  O4'  DG J 244      81.511  75.956  27.213  1.00 91.84           O  \\nATOM   4978  C3'  DG J 244      80.915  74.576  29.046  1.00 91.84           C  \\nATOM   4979  O3'  DG J 244      79.493  74.650  29.130  1.00 91.84           O  \\nATOM   4980  C2'  DG J 244      81.309  73.709  27.864  1.00 91.84           C  \\nATOM   4981  C1'  DG J 244      81.140  74.680  26.712  1.00 91.84           C  \\nATOM   4982  N9   DG J 244      81.966  74.412  25.541  1.00 85.05           N  \\nATOM   4983  C8   DG J 244      83.237  73.896  25.513  1.00 85.05           C  \\nATOM   4984  N7   DG J 244      83.722  73.798  24.306  1.00 85.05           N  \\nATOM   4985  C5   DG J 244      82.705  74.269  23.491  1.00 85.05           C  \\nATOM   4986  C6   DG J 244      82.649  74.404  22.095  1.00 85.05           C  \\nATOM   4987  O6   DG J 244      83.514  74.123  21.266  1.00 85.05           O  \\nATOM   4988  N1   DG J 244      81.431  74.934  21.681  1.00 85.05           N  \\nATOM   4989  C2   DG J 244      80.405  75.292  22.514  1.00 85.05           C  \\nATOM   4990  N2   DG J 244      79.323  75.806  21.922  1.00 85.05           N  \\nATOM   4991  N3   DG J 244      80.441  75.162  23.820  1.00 85.05           N  \\nATOM   4992  C4   DG J 244      81.614  74.650  24.239  1.00 85.05           C  \\nATOM   4993  P    DA J 245      78.779  74.958  30.538  1.00103.71           P  \\nATOM   4994  OP1  DA J 245      79.530  76.025  31.254  1.00103.71           O  \\nATOM   4995  OP2  DA J 245      78.506  73.658  31.217  1.00103.71           O  \\nATOM   4996  O5'  DA J 245      77.378  75.569  30.096  1.00 83.07           O  \\nATOM   4997  C5'  DA J 245      77.322  76.807  29.388  1.00 83.07           C  \\nATOM   4998  C4'  DA J 245      76.353  76.731  28.226  1.00 83.07           C  \\nATOM   4999  O4'  DA J 245      76.913  76.040  27.087  1.00 83.07           O  \\nATOM   5000  C3'  DA J 245      74.992  76.094  28.492  1.00 83.07           C  \\nATOM   5001  O3'  DA J 245      73.996  76.910  27.871  1.00 83.07           O  \\nATOM   5002  C2'  DA J 245      75.109  74.726  27.835  1.00 83.07           C  \\nATOM   5003  C1'  DA J 245      76.072  74.971  26.679  1.00 83.07           C  \\nATOM   5004  N9   DA J 245      76.954  73.851  26.340  1.00 67.02           N  \\nATOM   5005  C8   DA J 245      77.576  72.979  27.203  1.00 67.02           C  \\nATOM   5006  N7   DA J 245      78.395  72.141  26.611  1.00 67.02           N  \\nATOM   5007  C5   DA J 245      78.294  72.468  25.266  1.00 67.02           C  \\nATOM   5008  C6   DA J 245      78.931  71.967  24.124  1.00 67.02           C  \\nATOM   5009  N6   DA J 245      79.860  71.006  24.150  1.00 67.02           N  \\nATOM   5010  N1   DA J 245      78.589  72.502  22.934  1.00 67.02           N  \\nATOM   5011  C2   DA J 245      77.680  73.478  22.903  1.00 67.02           C  \\nATOM   5012  N3   DA J 245      77.028  74.049  23.904  1.00 67.02           N  \\nATOM   5013  C4   DA J 245      77.385  73.496  25.079  1.00 67.02           C  \\nATOM   5014  P    DG J 246      72.455  76.760  28.285  1.00 65.37           P  \\nATOM   5015  OP1  DG J 246      71.944  77.980  28.970  1.00 65.37           O  \\nATOM   5016  OP2  DG J 246      72.302  75.433  28.945  1.00 65.37           O  \\nATOM   5017  O5'  DG J 246      71.768  76.697  26.858  1.00 47.97           O  \\nATOM   5018  C5'  DG J 246      70.941  75.608  26.524  1.00 47.97           C  \\nATOM   5019  C4'  DG J 246      71.270  75.091  25.146  1.00 47.97           C  \\nATOM   5020  O4'  DG J 246      72.578  74.458  25.116  1.00 47.97           O  \\nATOM   5021  C3'  DG J 246      70.273  74.005  24.760  1.00 47.97           C  \\nATOM   5022  O3'  DG J 246      69.876  74.148  23.416  1.00 47.97           O  \\nATOM   5023  C2'  DG J 246      71.038  72.715  24.944  1.00 47.97           C  \\nATOM   5024  C1'  DG J 246      72.442  73.136  24.594  1.00 47.97           C  \\nATOM   5025  N9   DG J 246      73.442  72.265  25.206  1.00 75.80           N  \\nATOM   5026  C8   DG J 246      73.622  72.008  26.547  1.00 75.80           C  \\nATOM   5027  N7   DG J 246      74.593  71.167  26.783  1.00 75.80           N  \\nATOM   5028  C5   DG J 246      75.089  70.856  25.523  1.00 75.80           C  \\nATOM   5029  C6   DG J 246      76.165  70.011  25.141  1.00 75.80           C  \\nATOM   5030  O6   DG J 246      76.922  69.354  25.868  1.00 75.80           O  \\nATOM   5031  N1   DG J 246      76.324  69.981  23.755  1.00 75.80           N  \\nATOM   5032  C2   DG J 246      75.547  70.678  22.859  1.00 75.80           C  \\nATOM   5033  N2   DG J 246      75.845  70.517  21.566  1.00 75.80           N  \\nATOM   5034  N3   DG J 246      74.551  71.475  23.204  1.00 75.80           N  \\nATOM   5035  C4   DG J 246      74.381  71.519  24.540  1.00 75.80           C  \\nATOM   5036  P    DC J 247      68.324  74.235  23.082  1.00 44.36           P  \\nATOM   5037  OP1  DC J 247      67.890  75.509  23.667  1.00 44.36           O  \\nATOM   5038  OP2  DC J 247      67.651  72.979  23.486  1.00 44.36           O  \\nATOM   5039  O5'  DC J 247      68.325  74.348  21.505  1.00 61.15           O  \\nATOM   5040  C5'  DC J 247      69.513  74.731  20.834  1.00 61.15           C  \\nATOM   5041  C4'  DC J 247      69.944  73.643  19.880  1.00 61.15           C  \\nATOM   5042  O4'  DC J 247      70.872  72.735  20.521  1.00 61.15           O  \\nATOM   5043  C3'  DC J 247      68.812  72.779  19.330  1.00 61.15           C  \\nATOM   5044  O3'  DC J 247      69.039  72.597  17.931  1.00 61.15           O  \\nATOM   5045  C2'  DC J 247      68.932  71.482  20.118  1.00 61.15           C  \\nATOM   5046  C1'  DC J 247      70.428  71.391  20.371  1.00 61.15           C  \\nATOM   5047  N1   DC J 247      70.828  70.655  21.586  1.00 56.36           N  \\nATOM   5048  C2   DC J 247      72.074  69.990  21.602  1.00 56.36           C  \\nATOM   5049  O2   DC J 247      72.775  69.978  20.566  1.00 56.36           O  \\nATOM   5050  N3   DC J 247      72.478  69.377  22.740  1.00 56.36           N  \\nATOM   5051  C4   DC J 247      71.695  69.393  23.820  1.00 56.36           C  \\nATOM   5052  N4   DC J 247      72.148  68.801  24.923  1.00 56.36           N  \\nATOM   5053  C5   DC J 247      70.414  70.023  23.818  1.00 56.36           C  \\nATOM   5054  C6   DC J 247      70.024  70.635  22.692  1.00 56.36           C  \\nATOM   5055  P    DA J 248      68.050  71.680  17.066  1.00 54.49           P  \\nATOM   5056  OP1  DA J 248      67.611  72.425  15.859  1.00 54.49           O  \\nATOM   5057  OP2  DA J 248      67.034  71.053  17.978  1.00 54.49           O  \\nATOM   5058  O5'  DA J 248      69.003  70.506  16.588  1.00 82.84           O  \\nATOM   5059  C5'  DA J 248      68.464  69.227  16.347  1.00 82.84           C  \\nATOM   5060  C4'  DA J 248      69.458  68.148  16.698  1.00 82.84           C  \\nATOM   5061  O4'  DA J 248      69.913  68.252  18.071  1.00 82.84           O  \\nATOM   5062  C3'  DA J 248      68.774  66.795  16.588  1.00 82.84           C  \\nATOM   5063  O3'  DA J 248      69.618  65.874  15.946  1.00 82.84           O  \\nATOM   5064  C2'  DA J 248      68.518  66.387  18.021  1.00 82.84           C  \\nATOM   5065  C1'  DA J 248      69.682  67.018  18.735  1.00 82.84           C  \\nATOM   5066  N9   DA J 248      69.363  67.282  20.133  1.00 83.86           N  \\nATOM   5067  C8   DA J 248      68.316  68.007  20.646  1.00 83.86           C  \\nATOM   5068  N7   DA J 248      68.240  67.974  21.954  1.00 83.86           N  \\nATOM   5069  C5   DA J 248      69.324  67.191  22.329  1.00 83.86           C  \\nATOM   5070  C6   DA J 248      69.793  66.757  23.584  1.00 83.86           C  \\nATOM   5071  N6   DA J 248      69.191  67.050  24.745  1.00 83.86           N  \\nATOM   5072  N1   DA J 248      70.913  65.994  23.604  1.00 83.86           N  \\nATOM   5073  C2   DA J 248      71.507  65.688  22.438  1.00 83.86           C  \\nATOM   5074  N3   DA J 248      71.155  66.026  21.202  1.00 83.86           N  \\nATOM   5075  C4   DA J 248      70.041  66.783  21.217  1.00 83.86           C  \\nATOM   5076  P    DG J 249      69.026  64.978  14.771  1.00 73.61           P  \\nATOM   5077  OP1  DG J 249      68.577  65.873  13.672  1.00 73.61           O  \\nATOM   5078  OP2  DG J 249      68.066  64.007  15.374  1.00 73.61           O  \\nATOM   5079  O5'  DG J 249      70.304  64.175  14.300  1.00106.31           O  \\nATOM   5080  C5'  DG J 249      70.214  62.789  14.156  1.00106.31           C  \\nATOM   5081  C4'  DG J 249      70.919  62.088  15.289  1.00106.31           C  \\nATOM   5082  O4'  DG J 249      70.786  62.759  16.572  1.00106.31           O  \\nATOM   5083  C3'  DG J 249      70.289  60.716  15.459  1.00106.31           C  \\nATOM   5084  O3'  DG J 249      71.248  59.689  15.312  1.00106.31           O  \\nATOM   5085  C2'  DG J 249      69.625  60.752  16.829  1.00106.31           C  \\nATOM   5086  C1'  DG J 249      70.415  61.809  17.567  1.00106.31           C  \\nATOM   5087  N9   DG J 249      69.675  62.500  18.628  1.00 92.68           N  \\nATOM   5088  C8   DG J 249      68.736  63.493  18.477  1.00 92.68           C  \\nATOM   5089  N7   DG J 249      68.285  63.955  19.614  1.00 92.68           N  \\nATOM   5090  C5   DG J 249      68.958  63.218  20.579  1.00 92.68           C  \\nATOM   5091  C6   DG J 249      68.900  63.287  22.004  1.00 92.68           C  \\nATOM   5092  O6   DG J 249      68.244  64.053  22.719  1.00 92.68           O  \\nATOM   5093  N1   DG J 249      69.729  62.344  22.597  1.00 92.68           N  \\nATOM   5094  C2   DG J 249      70.524  61.458  21.919  1.00 92.68           C  \\nATOM   5095  N2   DG J 249      71.246  60.621  22.683  1.00 92.68           N  \\nATOM   5096  N3   DG J 249      70.605  61.394  20.595  1.00 92.68           N  \\nATOM   5097  C4   DG J 249      69.801  62.298  19.992  1.00 92.68           C  \\nATOM   5098  P    DT J 250      70.738  58.206  15.035  1.00109.16           P  \\nATOM   5099  OP1  DT J 250      71.882  57.438  14.491  1.00109.16           O  \\nATOM   5100  OP2  DT J 250      69.457  58.264  14.274  1.00109.16           O  \\nATOM   5101  O5'  DT J 250      70.448  57.722  16.515  1.00 82.94           O  \\nATOM   5102  C5'  DT J 250      71.410  57.981  17.533  1.00 82.94           C  \\nATOM   5103  C4'  DT J 250      71.049  57.225  18.783  1.00 82.94           C  \\nATOM   5104  O4'  DT J 250      70.408  58.100  19.737  1.00 82.94           O  \\nATOM   5105  C3'  DT J 250      70.076  56.076  18.525  1.00 82.94           C  \\nATOM   5106  O3'  DT J 250      70.505  54.923  19.243  1.00 82.94           O  \\nATOM   5107  C2'  DT J 250      68.753  56.607  19.052  1.00 82.94           C  \\nATOM   5108  C1'  DT J 250      69.216  57.492  20.193  1.00 82.94           C  \\nATOM   5109  N1   DT J 250      68.293  58.563  20.600  1.00 87.36           N  \\nATOM   5110  C2   DT J 250      68.176  58.825  21.947  1.00 87.36           C  \\nATOM   5111  O2   DT J 250      68.801  58.226  22.802  1.00 87.36           O  \\nATOM   5112  N3   DT J 250      67.298  59.818  22.261  1.00 87.36           N  \\nATOM   5113  C4   DT J 250      66.539  60.564  21.388  1.00 87.36           C  \\nATOM   5114  O4   DT J 250      65.783  61.421  21.825  1.00 87.36           O  \\nATOM   5115  C5   DT J 250      66.715  60.246  19.987  1.00 87.36           C  \\nATOM   5116  C7   DT J 250      65.936  61.009  18.962  1.00 87.36           C  \\nATOM   5117  C6   DT J 250      67.574  59.273  19.667  1.00 87.36           C  \\nATOM   5118  P    DT J 251      69.815  53.509  18.950  1.00130.75           P  \\nATOM   5119  OP1  DT J 251      70.874  52.542  18.566  1.00130.75           O  \\nATOM   5120  OP2  DT J 251      68.668  53.749  18.037  1.00130.75           O  \\nATOM   5121  O5'  DT J 251      69.244  53.103  20.374  1.00107.80           O  \\nATOM   5122  C5'  DT J 251      70.076  53.171  21.525  1.00107.80           C  \\nATOM   5123  C4'  DT J 251      69.264  52.891  22.764  1.00107.80           C  \\nATOM   5124  O4'  DT J 251      68.540  54.076  23.181  1.00107.80           O  \\nATOM   5125  C3'  DT J 251      68.221  51.793  22.567  1.00107.80           C  \\nATOM   5126  O3'  DT J 251      68.243  50.899  23.678  1.00107.80           O  \\nATOM   5127  C2'  DT J 251      66.909  52.557  22.466  1.00107.80           C  \\nATOM   5128  C1'  DT J 251      67.167  53.767  23.347  1.00107.80           C  \\nATOM   5129  N1   DT J 251      66.381  54.972  23.003  1.00 93.28           N  \\nATOM   5130  C2   DT J 251      66.044  55.837  24.021  1.00 93.28           C  \\nATOM   5131  O2   DT J 251      66.367  55.658  25.182  1.00 93.28           O  \\nATOM   5132  N3   DT J 251      65.310  56.927  23.626  1.00 93.28           N  \\nATOM   5133  C4   DT J 251      64.898  57.239  22.348  1.00 93.28           C  \\nATOM   5134  O4   DT J 251      64.258  58.267  22.151  1.00 93.28           O  \\nATOM   5135  C5   DT J 251      65.280  56.288  21.328  1.00 93.28           C  \\nATOM   5136  C7   DT J 251      64.863  56.534  19.913  1.00 93.28           C  \\nATOM   5137  C6   DT J 251      65.996  55.217  21.701  1.00 93.28           C  \\nATOM   5138  P    DT J 252      67.052  49.845  23.875  1.00 85.03           P  \\nATOM   5139  OP1  DT J 252      67.645  48.580  24.395  1.00 85.03           O  \\nATOM   5140  OP2  DT J 252      66.209  49.818  22.644  1.00 85.03           O  \\nATOM   5141  O5'  DT J 252      66.206  50.525  25.031  1.00 79.65           O  \\nATOM   5142  C5'  DT J 252      66.862  51.191  26.109  1.00 79.65           C  \\nATOM   5143  C4'  DT J 252      65.843  51.633  27.129  1.00 79.65           C  \\nATOM   5144  O4'  DT J 252      65.199  52.864  26.714  1.00 79.65           O  \\nATOM   5145  C3'  DT J 252      64.732  50.607  27.314  1.00 79.65           C  \\nATOM   5146  O3'  DT J 252      64.429  50.466  28.696  1.00 79.65           O  \\nATOM   5147  C2'  DT J 252      63.568  51.182  26.518  1.00 79.65           C  \\nATOM   5148  C1'  DT J 252      63.790  52.685  26.622  1.00 79.65           C  \\nATOM   5149  N1   DT J 252      63.304  53.494  25.471  1.00 78.34           N  \\nATOM   5150  C2   DT J 252      62.618  54.663  25.741  1.00 78.34           C  \\nATOM   5151  O2   DT J 252      62.345  55.034  26.872  1.00 78.34           O  \\nATOM   5152  N3   DT J 252      62.258  55.386  24.628  1.00 78.34           N  \\nATOM   5153  C4   DT J 252      62.499  55.063  23.302  1.00 78.34           C  \\nATOM   5154  O4   DT J 252      62.137  55.823  22.407  1.00 78.34           O  \\nATOM   5155  C5   DT J 252      63.187  53.813  23.090  1.00 78.34           C  \\nATOM   5156  C7   DT J 252      63.466  53.371  21.687  1.00 78.34           C  \\nATOM   5157  C6   DT J 252      63.550  53.099  24.169  1.00 78.34           C  \\nATOM   5158  P    DC J 253      63.213  49.531  29.139  1.00 85.52           P  \\nATOM   5159  OP1  DC J 253      63.518  49.051  30.510  1.00 85.52           O  \\nATOM   5160  OP2  DC J 253      62.942  48.553  28.045  1.00 85.52           O  \\nATOM   5161  O5'  DC J 253      61.985  50.538  29.211  1.00109.10           O  \\nATOM   5162  C5'  DC J 253      62.007  51.657  30.094  1.00109.10           C  \\nATOM   5163  C4'  DC J 253      60.597  52.023  30.489  1.00109.10           C  \\nATOM   5164  O4'  DC J 253      59.994  52.808  29.435  1.00109.10           O  \\nATOM   5165  C3'  DC J 253      59.691  50.810  30.667  1.00109.10           C  \\nATOM   5166  O3'  DC J 253      58.723  51.095  31.672  1.00109.10           O  \\nATOM   5167  C2'  DC J 253      59.050  50.650  29.300  1.00109.10           C  \\nATOM   5168  C1'  DC J 253      58.945  52.081  28.804  1.00109.10           C  \\nATOM   5169  N1   DC J 253      59.141  52.209  27.356  1.00 81.34           N  \\nATOM   5170  C2   DC J 253      58.574  53.299  26.693  1.00 81.34           C  \\nATOM   5171  O2   DC J 253      57.897  54.114  27.343  1.00 81.34           O  \\nATOM   5172  N3   DC J 253      58.778  53.441  25.362  1.00 81.34           N  \\nATOM   5173  C4   DC J 253      59.511  52.543  24.701  1.00 81.34           C  \\nATOM   5174  N4   DC J 253      59.694  52.722  23.391  1.00 81.34           N  \\nATOM   5175  C5   DC J 253      60.091  51.417  25.353  1.00 81.34           C  \\nATOM   5176  C6   DC J 253      59.880  51.288  26.667  1.00 81.34           C  \\nATOM   5177  P    DC J 254      57.514  50.073  31.935  1.00114.20           P  \\nATOM   5178  OP1  DC J 254      57.893  49.157  33.038  1.00114.20           O  \\nATOM   5179  OP2  DC J 254      57.058  49.508  30.633  1.00114.20           O  \\nATOM   5180  O5'  DC J 254      56.383  51.044  32.479  1.00 92.13           O  \\nATOM   5181  C5'  DC J 254      56.707  52.387  32.822  1.00 92.13           C  \\nATOM   5182  C4'  DC J 254      55.682  53.336  32.248  1.00 92.13           C  \\nATOM   5183  O4'  DC J 254      55.848  53.460  30.812  1.00 92.13           O  \\nATOM   5184  C3'  DC J 254      54.223  52.929  32.470  1.00 92.13           C  \\nATOM   5185  O3'  DC J 254      53.472  54.119  32.704  1.00 92.13           O  \\nATOM   5186  C2'  DC J 254      53.825  52.343  31.127  1.00 92.13           C  \\nATOM   5187  C1'  DC J 254      54.586  53.257  30.193  1.00 92.13           C  \\nATOM   5188  N1   DC J 254      54.802  52.756  28.826  1.00 67.33           N  \\nATOM   5189  C2   DC J 254      54.587  53.631  27.757  1.00 67.33           C  \\nATOM   5190  O2   DC J 254      54.261  54.803  27.996  1.00 67.33           O  \\nATOM   5191  N3   DC J 254      54.747  53.189  26.498  1.00 67.33           N  \\nATOM   5192  C4   DC J 254      55.120  51.935  26.276  1.00 67.33           C  \\nATOM   5193  N4   DC J 254      55.254  51.551  25.012  1.00 67.33           N  \\nATOM   5194  C5   DC J 254      55.367  51.020  27.343  1.00 67.33           C  \\nATOM   5195  C6   DC J 254      55.195  51.468  28.592  1.00 67.33           C  \\nATOM   5196  P    DA J 255      52.018  54.045  33.381  1.00 76.17           P  \\nATOM   5197  OP1  DA J 255      52.234  54.052  34.847  1.00 76.17           O  \\nATOM   5198  OP2  DA J 255      51.200  52.964  32.764  1.00 76.17           O  \\nATOM   5199  O5'  DA J 255      51.384  55.447  32.959  1.00 80.39           O  \\nATOM   5200  C5'  DA J 255      52.222  56.599  32.783  1.00 80.39           C  \\nATOM   5201  C4'  DA J 255      51.656  57.528  31.732  1.00 80.39           C  \\nATOM   5202  O4'  DA J 255      51.706  56.917  30.424  1.00 80.39           O  \\nATOM   5203  C3'  DA J 255      50.199  57.916  31.951  1.00 80.39           C  \\nATOM   5204  O3'  DA J 255      49.998  59.272  31.549  1.00 80.39           O  \\nATOM   5205  C2'  DA J 255      49.437  56.937  31.076  1.00 80.39           C  \\nATOM   5206  C1'  DA J 255      50.394  56.670  29.931  1.00 80.39           C  \\nATOM   5207  N9   DA J 255      50.372  55.284  29.492  1.00 75.08           N  \\nATOM   5208  C8   DA J 255      50.120  54.167  30.246  1.00 75.08           C  \\nATOM   5209  N7   DA J 255      50.267  53.045  29.589  1.00 75.08           N  \\nATOM   5210  C5   DA J 255      50.623  53.452  28.311  1.00 75.08           C  \\nATOM   5211  C6   DA J 255      50.948  52.740  27.143  1.00 75.08           C  \\nATOM   5212  N6   DA J 255      50.999  51.410  27.070  1.00 75.08           N  \\nATOM   5213  N1   DA J 255      51.240  53.456  26.037  1.00 75.08           N  \\nATOM   5214  C2   DA J 255      51.220  54.792  26.112  1.00 75.08           C  \\nATOM   5215  N3   DA J 255      50.950  55.572  27.153  1.00 75.08           N  \\nATOM   5216  C4   DA J 255      50.659  54.831  28.233  1.00 75.08           C  \\nATOM   5217  P    DA J 256      48.508  59.827  31.347  1.00102.07           P  \\nATOM   5218  OP1  DA J 256      48.572  61.295  31.556  1.00102.07           O  \\nATOM   5219  OP2  DA J 256      47.572  59.008  32.158  1.00102.07           O  \\nATOM   5220  O5'  DA J 256      48.224  59.524  29.811  1.00 77.02           O  \\nATOM   5221  C5'  DA J 256      49.107  60.030  28.813  1.00 77.02           C  \\nATOM   5222  C4'  DA J 256      48.566  59.732  27.438  1.00 77.02           C  \\nATOM   5223  O4'  DA J 256      48.740  58.334  27.135  1.00 77.02           O  \\nATOM   5224  C3'  DA J 256      47.072  60.008  27.263  1.00 77.02           C  \\nATOM   5225  O3'  DA J 256      46.848  60.402  25.908  1.00 77.02           O  \\nATOM   5226  C2'  DA J 256      46.463  58.640  27.483  1.00 77.02           C  \\nATOM   5227  C1'  DA J 256      47.489  57.806  26.761  1.00 77.02           C  \\nATOM   5228  N9   DA J 256      47.497  56.396  27.083  1.00 74.09           N  \\nATOM   5229  C8   DA J 256      47.218  55.761  28.260  1.00 74.09           C  \\nATOM   5230  N7   DA J 256      47.324  54.458  28.189  1.00 74.09           N  \\nATOM   5231  C5   DA J 256      47.701  54.229  26.874  1.00 74.09           C  \\nATOM   5232  C6   DA J 256      47.981  53.057  26.164  1.00 74.09           C  \\nATOM   5233  N6   DA J 256      47.916  51.836  26.704  1.00 74.09           N  \\nATOM   5234  N1   DA J 256      48.334  53.182  24.861  1.00 74.09           N  \\nATOM   5235  C2   DA J 256      48.397  54.413  24.327  1.00 74.09           C  \\nATOM   5236  N3   DA J 256      48.158  55.586  24.898  1.00 74.09           N  \\nATOM   5237  C4   DA J 256      47.811  55.417  26.185  1.00 74.09           C  \\nATOM   5238  P    DA J 257      45.461  61.087  25.488  1.00 55.44           P  \\nATOM   5239  OP1  DA J 257      45.675  62.569  25.491  1.00 55.44           O  \\nATOM   5240  OP2  DA J 257      44.370  60.482  26.296  1.00 55.44           O  \\nATOM   5241  O5'  DA J 257      45.253  60.594  23.996  1.00 45.93           O  \\nATOM   5242  C5'  DA J 257      46.361  60.516  23.116  1.00 45.93           C  \\nATOM   5243  C4'  DA J 257      46.092  59.489  22.045  1.00 45.93           C  \\nATOM   5244  O4'  DA J 257      46.323  58.139  22.519  1.00 45.93           O  \\nATOM   5245  C3'  DA J 257      44.657  59.533  21.537  1.00 45.93           C  \\nATOM   5246  O3'  DA J 257      44.649  59.502  20.125  1.00 45.93           O  \\nATOM   5247  C2'  DA J 257      44.029  58.278  22.107  1.00 45.93           C  \\nATOM   5248  C1'  DA J 257      45.203  57.326  22.238  1.00 45.93           C  \\nATOM   5249  N9   DA J 257      45.054  56.389  23.351  1.00 63.46           N  \\nATOM   5250  C8   DA J 257      44.648  56.661  24.638  1.00 63.46           C  \\nATOM   5251  N7   DA J 257      44.594  55.607  25.412  1.00 63.46           N  \\nATOM   5252  C5   DA J 257      44.997  54.569  24.584  1.00 63.46           C  \\nATOM   5253  C6   DA J 257      45.148  53.196  24.805  1.00 63.46           C  \\nATOM   5254  N6   DA J 257      44.925  52.608  25.984  1.00 63.46           N  \\nATOM   5255  N1   DA J 257      45.549  52.433  23.762  1.00 63.46           N  \\nATOM   5256  C2   DA J 257      45.794  53.026  22.584  1.00 63.46           C  \\nATOM   5257  N3   DA J 257      45.701  54.310  22.256  1.00 63.46           N  \\nATOM   5258  C4   DA J 257      45.288  55.037  23.312  1.00 63.46           C  \\nATOM   5259  P    DT J 258      43.294  59.800  19.354  1.00 49.05           P  \\nATOM   5260  OP1  DT J 258      43.511  60.827  18.317  1.00 49.05           O  \\nATOM   5261  OP2  DT J 258      42.260  60.016  20.398  1.00 49.05           O  \\nATOM   5262  O5'  DT J 258      43.031  58.408  18.656  1.00 58.61           O  \\nATOM   5263  C5'  DT J 258      43.453  57.234  19.314  1.00 58.61           C  \\nATOM   5264  C4'  DT J 258      43.772  56.158  18.311  1.00 58.61           C  \\nATOM   5265  O4'  DT J 258      44.016  54.978  19.091  1.00 58.61           O  \\nATOM   5266  C3'  DT J 258      42.574  55.821  17.437  1.00 58.61           C  \\nATOM   5267  O3'  DT J 258      43.004  55.179  16.228  1.00 58.61           O  \\nATOM   5268  C2'  DT J 258      41.773  54.908  18.336  1.00 58.61           C  \\nATOM   5269  C1'  DT J 258      42.831  54.219  19.184  1.00 58.61           C  \\nATOM   5270  N1   DT J 258      42.477  54.179  20.592  1.00 53.19           N  \\nATOM   5271  C2   DT J 258      42.628  52.988  21.247  1.00 53.19           C  \\nATOM   5272  O2   DT J 258      43.027  51.976  20.702  1.00 53.19           O  \\nATOM   5273  N3   DT J 258      42.302  53.019  22.569  1.00 53.19           N  \\nATOM   5274  C4   DT J 258      41.872  54.109  23.296  1.00 53.19           C  \\nATOM   5275  O4   DT J 258      41.658  53.983  24.496  1.00 53.19           O  \\nATOM   5276  C5   DT J 258      41.721  55.341  22.537  1.00 53.19           C  \\nATOM   5277  C7   DT J 258      41.247  56.578  23.233  1.00 53.19           C  \\nATOM   5278  C6   DT J 258      42.021  55.308  21.235  1.00 53.19           C  \\nATOM   5279  P    DA J 259      41.954  54.921  15.032  1.00119.77           P  \\nATOM   5280  OP1  DA J 259      42.730  54.661  13.786  1.00119.77           O  \\nATOM   5281  OP2  DA J 259      40.936  56.005  15.054  1.00119.77           O  \\nATOM   5282  O5'  DA J 259      41.249  53.551  15.437  1.00110.54           O  \\nATOM   5283  C5'  DA J 259      41.949  52.312  15.326  1.00110.54           C  \\nATOM   5284  C4'  DA J 259      41.051  51.166  15.728  1.00110.54           C  \\nATOM   5285  O4'  DA J 259      40.834  51.184  17.159  1.00110.54           O  \\nATOM   5286  C3'  DA J 259      39.661  51.183  15.090  1.00110.54           C  \\nATOM   5287  O3'  DA J 259      39.274  49.849  14.749  1.00110.54           O  \\nATOM   5288  C2'  DA J 259      38.775  51.725  16.198  1.00110.54           C  \\nATOM   5289  C1'  DA J 259      39.443  51.149  17.430  1.00110.54           C  \\nATOM   5290  N9   DA J 259      39.203  51.887  18.670  1.00116.92           N  \\nATOM   5291  C8   DA J 259      38.977  53.233  18.834  1.00116.92           C  \\nATOM   5292  N7   DA J 259      38.790  53.590  20.083  1.00116.92           N  \\nATOM   5293  C5   DA J 259      38.899  52.398  20.789  1.00116.92           C  \\nATOM   5294  C6   DA J 259      38.791  52.095  22.158  1.00116.92           C  \\nATOM   5295  N6   DA J 259      38.536  53.004  23.100  1.00116.92           N  \\nATOM   5296  N1   DA J 259      38.954  50.804  22.531  1.00116.92           N  \\nATOM   5297  C2   DA J 259      39.200  49.892  21.587  1.00116.92           C  \\nATOM   5298  N3   DA J 259      39.318  50.051  20.272  1.00116.92           N  \\nATOM   5299  C4   DA J 259      39.155  51.343  19.933  1.00116.92           C  \\nATOM   5300  P    DC J 260      37.956  49.595  13.864  1.00123.13           P  \\nATOM   5301  OP1  DC J 260      38.383  48.912  12.614  1.00123.13           O  \\nATOM   5302  OP2  DC J 260      37.158  50.850  13.784  1.00123.13           O  \\nATOM   5303  O5'  DC J 260      37.148  48.550  14.746  1.00102.32           O  \\nATOM   5304  C5'  DC J 260      37.800  47.820  15.783  1.00102.32           C  \\nATOM   5305  C4'  DC J 260      36.773  47.179  16.683  1.00102.32           C  \\nATOM   5306  O4'  DC J 260      36.763  47.869  17.959  1.00102.32           O  \\nATOM   5307  C3'  DC J 260      35.350  47.282  16.131  1.00102.32           C  \\nATOM   5308  O3'  DC J 260      34.618  46.076  16.383  1.00102.32           O  \\nATOM   5309  C2'  DC J 260      34.767  48.461  16.886  1.00102.32           C  \\nATOM   5310  C1'  DC J 260      35.457  48.351  18.235  1.00102.32           C  \\nATOM   5311  N1   DC J 260      35.569  49.629  18.962  1.00103.69           N  \\nATOM   5312  C2   DC J 260      35.549  49.619  20.365  1.00103.69           C  \\nATOM   5313  O2   DC J 260      35.496  48.533  20.955  1.00103.69           O  \\nATOM   5314  N3   DC J 260      35.591  50.796  21.038  1.00103.69           N  \\nATOM   5315  C4   DC J 260      35.673  51.948  20.364  1.00103.69           C  \\nATOM   5316  N4   DC J 260      35.704  53.088  21.066  1.00103.69           N  \\nATOM   5317  C5   DC J 260      35.723  51.985  18.938  1.00103.69           C  \\nATOM   5318  C6   DC J 260      35.671  50.814  18.284  1.00103.69           C  \\nATOM   5319  P    DA J 261      33.093  45.947  15.882  1.00122.34           P  \\nATOM   5320  OP1  DA J 261      32.892  44.562  15.398  1.00122.34           O  \\nATOM   5321  OP2  DA J 261      32.781  47.089  14.981  1.00122.34           O  \\nATOM   5322  O5'  DA J 261      32.246  46.124  17.219  1.00124.59           O  \\nATOM   5323  C5'  DA J 261      32.494  45.299  18.359  1.00124.59           C  \\nATOM   5324  C4'  DA J 261      31.456  45.558  19.426  1.00124.59           C  \\nATOM   5325  O4'  DA J 261      31.682  46.845  20.050  1.00124.59           O  \\nATOM   5326  C3'  DA J 261      30.027  45.593  18.890  1.00124.59           C  \\nATOM   5327  O3'  DA J 261      29.138  44.977  19.821  1.00124.59           O  \\nATOM   5328  C2'  DA J 261      29.730  47.079  18.771  1.00124.59           C  \\nATOM   5329  C1'  DA J 261      30.521  47.662  19.931  1.00124.59           C  \\nATOM   5330  N9   DA J 261      30.956  49.053  19.746  1.00123.90           N  \\nATOM   5331  C8   DA J 261      31.046  49.757  18.567  1.00123.90           C  \\nATOM   5332  N7   DA J 261      31.485  50.985  18.715  1.00123.90           N  \\nATOM   5333  C5   DA J 261      31.694  51.103  20.082  1.00123.90           C  \\nATOM   5334  C6   DA J 261      32.158  52.170  20.886  1.00123.90           C  \\nATOM   5335  N6   DA J 261      32.515  53.368  20.408  1.00123.90           N  \\nATOM   5336  N1   DA J 261      32.244  51.958  22.219  1.00123.90           N  \\nATOM   5337  C2   DA J 261      31.886  50.762  22.703  1.00123.90           C  \\nATOM   5338  N3   DA J 261      31.437  49.688  22.054  1.00123.90           N  \\nATOM   5339  C4   DA J 261      31.365  49.924  20.731  1.00123.90           C  \\nATOM   5340  P    DC J 262      27.902  44.104  19.281  1.00157.91           P  \\nATOM   5341  OP1  DC J 262      28.242  42.667  19.440  1.00157.91           O  \\nATOM   5342  OP2  DC J 262      27.514  44.625  17.942  1.00157.91           O  \\nATOM   5343  O5'  DC J 262      26.734  44.462  20.298  1.00106.91           O  \\nATOM   5344  C5'  DC J 262      26.358  45.819  20.507  1.00106.91           C  \\nATOM   5345  C4'  DC J 262      26.264  46.117  21.985  1.00106.91           C  \\nATOM   5346  O4'  DC J 262      27.243  47.136  22.316  1.00106.91           O  \\nATOM   5347  C3'  DC J 262      24.904  46.683  22.385  1.00106.91           C  \\nATOM   5348  O3'  DC J 262      24.494  46.207  23.669  1.00106.91           O  \\nATOM   5349  C2'  DC J 262      25.130  48.182  22.397  1.00106.91           C  \\nATOM   5350  C1'  DC J 262      26.599  48.320  22.771  1.00106.91           C  \\nATOM   5351  N1   DC J 262      27.237  49.475  22.110  1.00131.93           N  \\nATOM   5352  C2   DC J 262      27.926  50.416  22.887  1.00131.93           C  \\nATOM   5353  O2   DC J 262      28.026  50.231  24.108  1.00131.93           O  \\nATOM   5354  N3   DC J 262      28.461  51.503  22.284  1.00131.93           N  \\nATOM   5355  C4   DC J 262      28.332  51.667  20.965  1.00131.93           C  \\nATOM   5356  N4   DC J 262      28.846  52.771  20.416  1.00131.93           N  \\nATOM   5357  C5   DC J 262      27.664  50.712  20.149  1.00131.93           C  \\nATOM   5358  C6   DC J 262      27.139  49.640  20.756  1.00131.93           C  \\nATOM   5359  P    DT J 263      23.082  46.685  24.273  1.00109.70           P  \\nATOM   5360  OP1  DT J 263      22.660  45.757  25.360  1.00109.70           O  \\nATOM   5361  OP2  DT J 263      22.165  46.961  23.133  1.00109.70           O  \\nATOM   5362  O5'  DT J 263      23.431  48.085  24.936  1.00104.51           O  \\nATOM   5363  C5'  DT J 263      24.277  48.158  26.078  1.00104.51           C  \\nATOM   5364  C4'  DT J 263      24.020  49.447  26.817  1.00104.51           C  \\nATOM   5365  O4'  DT J 263      24.651  50.566  26.147  1.00104.51           O  \\nATOM   5366  C3'  DT J 263      22.536  49.779  26.892  1.00104.51           C  \\nATOM   5367  O3'  DT J 263      22.242  50.278  28.187  1.00104.51           O  \\nATOM   5368  C2'  DT J 263      22.337  50.813  25.792  1.00104.51           C  \\nATOM   5369  C1'  DT J 263      23.681  51.525  25.738  1.00104.51           C  \\nATOM   5370  N1   DT J 263      24.086  52.030  24.397  1.00 92.57           N  \\nATOM   5371  C2   DT J 263      24.580  53.321  24.292  1.00 92.57           C  \\nATOM   5372  O2   DT J 263      24.664  54.095  25.235  1.00 92.57           O  \\nATOM   5373  N3   DT J 263      24.974  53.678  23.024  1.00 92.57           N  \\nATOM   5374  C4   DT J 263      24.929  52.905  21.883  1.00 92.57           C  \\nATOM   5375  O4   DT J 263      25.363  53.358  20.830  1.00 92.57           O  \\nATOM   5376  C5   DT J 263      24.366  51.585  22.052  1.00 92.57           C  \\nATOM   5377  C7   DT J 263      24.227  50.696  20.856  1.00 92.57           C  \\nATOM   5378  C6   DT J 263      23.984  51.216  23.285  1.00 92.57           C  \\nATOM   5379  P    DT J 264      20.935  51.160  28.409  1.00110.00           P  \\nATOM   5380  OP1  DT J 264      20.635  51.161  29.867  1.00110.00           O  \\nATOM   5381  OP2  DT J 264      19.914  50.686  27.439  1.00110.00           O  \\nATOM   5382  O5'  DT J 264      21.421  52.612  27.976  1.00110.10           O  \\nATOM   5383  C5'  DT J 264      22.552  53.214  28.609  1.00110.10           C  \\nATOM   5384  C4'  DT J 264      22.559  54.705  28.365  1.00110.10           C  \\nATOM   5385  O4'  DT J 264      22.973  55.003  27.012  1.00110.10           O  \\nATOM   5386  C3'  DT J 264      21.198  55.371  28.546  1.00110.10           C  \\nATOM   5387  O3'  DT J 264      21.380  56.649  29.127  1.00110.10           O  \\nATOM   5388  C2'  DT J 264      20.693  55.530  27.125  1.00110.10           C  \\nATOM   5389  C1'  DT J 264      21.978  55.779  26.361  1.00110.10           C  \\nATOM   5390  N1   DT J 264      21.926  55.355  24.951  1.00 74.83           N  \\nATOM   5391  C2   DT J 264      22.336  56.247  23.986  1.00 74.83           C  \\nATOM   5392  O2   DT J 264      22.777  57.361  24.242  1.00 74.83           O  \\nATOM   5393  N3   DT J 264      22.224  55.787  22.702  1.00 74.83           N  \\nATOM   5394  C4   DT J 264      21.781  54.547  22.291  1.00 74.83           C  \\nATOM   5395  O4   DT J 264      21.747  54.280  21.098  1.00 74.83           O  \\nATOM   5396  C5   DT J 264      21.388  53.650  23.357  1.00 74.83           C  \\nATOM   5397  C7   DT J 264      20.913  52.273  23.015  1.00 74.83           C  \\nATOM   5398  C6   DT J 264      21.471  54.096  24.615  1.00 74.83           C  \\nATOM   5399  P    DT J 265      20.209  57.301  30.005  1.00106.78           P  \\nATOM   5400  OP1  DT J 265      20.247  56.690  31.360  1.00106.78           O  \\nATOM   5401  OP2  DT J 265      18.948  57.269  29.211  1.00106.78           O  \\nATOM   5402  O5'  DT J 265      20.685  58.813  30.111  1.00 95.80           O  \\nATOM   5403  C5'  DT J 265      22.063  59.145  29.935  1.00 95.80           C  \\nATOM   5404  C4'  DT J 265      22.219  60.277  28.945  1.00 95.80           C  \\nATOM   5405  O4'  DT J 265      22.088  59.825  27.573  1.00 95.80           O  \\nATOM   5406  C3'  DT J 265      21.230  61.430  29.114  1.00 95.80           C  \\nATOM   5407  O3'  DT J 265      21.951  62.660  29.137  1.00 95.80           O  \\nATOM   5408  C2'  DT J 265      20.337  61.327  27.885  1.00 95.80           C  \\nATOM   5409  C1'  DT J 265      21.287  60.750  26.859  1.00 95.80           C  \\nATOM   5410  N1   DT J 265      20.669  60.045  25.716  1.00106.48           N  \\nATOM   5411  C2   DT J 265      20.661  60.683  24.494  1.00106.48           C  \\nATOM   5412  O2   DT J 265      21.089  61.808  24.330  1.00106.48           O  \\nATOM   5413  N3   DT J 265      20.126  59.953  23.464  1.00106.48           N  \\nATOM   5414  C4   DT J 265      19.593  58.686  23.530  1.00106.48           C  \\nATOM   5415  O4   DT J 265      19.170  58.152  22.507  1.00106.48           O  \\nATOM   5416  C5   DT J 265      19.597  58.083  24.852  1.00106.48           C  \\nATOM   5417  C7   DT J 265      19.006  56.719  25.034  1.00106.48           C  \\nATOM   5418  C6   DT J 265      20.134  58.785  25.863  1.00106.48           C  \\nATOM   5419  P    DT J 266      21.183  64.036  28.856  1.00 67.86           P  \\nATOM   5420  OP1  DT J 266      22.006  65.143  29.428  1.00 67.86           O  \\nATOM   5421  OP2  DT J 266      19.761  63.871  29.264  1.00 67.86           O  \\nATOM   5422  O5'  DT J 266      21.224  64.137  27.273  1.00 63.87           O  \\nATOM   5423  C5'  DT J 266      22.471  64.170  26.589  1.00 63.87           C  \\nATOM   5424  C4'  DT J 266      22.352  65.055  25.377  1.00 63.87           C  \\nATOM   5425  O4'  DT J 266      21.437  64.448  24.435  1.00 63.87           O  \\nATOM   5426  C3'  DT J 266      21.762  66.422  25.701  1.00 63.87           C  \\nATOM   5427  O3'  DT J 266      22.284  67.359  24.783  1.00 63.87           O  \\nATOM   5428  C2'  DT J 266      20.292  66.239  25.395  1.00 63.87           C  \\nATOM   5429  C1'  DT J 266      20.356  65.328  24.186  1.00 63.87           C  \\nATOM   5430  N1   DT J 266      19.140  64.522  23.981  1.00101.50           N  \\nATOM   5431  C2   DT J 266      19.029  63.741  22.847  1.00101.50           C  \\nATOM   5432  O2   DT J 266      19.902  63.651  22.003  1.00101.50           O  \\nATOM   5433  N3   DT J 266      17.845  63.063  22.739  1.00101.50           N  \\nATOM   5434  C4   DT J 266      16.786  63.084  23.629  1.00101.50           C  \\nATOM   5435  O4   DT J 266      15.780  62.430  23.389  1.00101.50           O  \\nATOM   5436  C5   DT J 266      16.977  63.913  24.803  1.00101.50           C  \\nATOM   5437  C7   DT J 266      15.891  63.999  25.830  1.00101.50           C  \\nATOM   5438  C6   DT J 266      18.129  64.576  24.916  1.00101.50           C  \\nATOM   5439  P    DG J 267      22.216  68.918  25.114  1.00 70.98           P  \\nATOM   5440  OP1  DG J 267      23.492  69.255  25.811  1.00 70.98           O  \\nATOM   5441  OP2  DG J 267      20.905  69.223  25.751  1.00 70.98           O  \\nATOM   5442  O5'  DG J 267      22.227  69.574  23.669  1.00 56.67           O  \\nATOM   5443  C5'  DG J 267      23.064  69.036  22.654  1.00 56.67           C  \\nATOM   5444  C4'  DG J 267      22.330  68.999  21.334  1.00 56.67           C  \\nATOM   5445  O4'  DG J 267      21.183  68.123  21.418  1.00 56.67           O  \\nATOM   5446  C3'  DG J 267      21.798  70.342  20.836  1.00 56.67           C  \\nATOM   5447  O3'  DG J 267      21.983  70.401  19.423  1.00 56.67           O  \\nATOM   5448  C2'  DG J 267      20.320  70.276  21.161  1.00 56.67           C  \\nATOM   5449  C1'  DG J 267      20.028  68.804  20.964  1.00 56.67           C  \\nATOM   5450  N9   DG J 267      18.891  68.305  21.728  1.00 61.99           N  \\nATOM   5451  C8   DG J 267      18.442  68.758  22.948  1.00 61.99           C  \\nATOM   5452  N7   DG J 267      17.403  68.104  23.384  1.00 61.99           N  \\nATOM   5453  C5   DG J 267      17.153  67.163  22.394  1.00 61.99           C  \\nATOM   5454  C6   DG J 267      16.152  66.163  22.310  1.00 61.99           C  \\nATOM   5455  O6   DG J 267      15.256  65.904  23.129  1.00 61.99           O  \\nATOM   5456  N1   DG J 267      16.263  65.424  21.128  1.00 61.99           N  \\nATOM   5457  C2   DG J 267      17.218  65.624  20.164  1.00 61.99           C  \\nATOM   5458  N2   DG J 267      17.165  64.808  19.116  1.00 61.99           N  \\nATOM   5459  N3   DG J 267      18.152  66.552  20.230  1.00 61.99           N  \\nATOM   5460  C4   DG J 267      18.062  67.280  21.364  1.00 61.99           C  \\nATOM   5461  P    DG J 268      21.789  71.792  18.646  1.00 42.33           P  \\nATOM   5462  OP1  DG J 268      23.080  72.167  18.013  1.00 42.33           O  \\nATOM   5463  OP2  DG J 268      21.126  72.738  19.582  1.00 42.33           O  \\nATOM   5464  O5'  DG J 268      20.771  71.402  17.485  1.00 47.23           O  \\nATOM   5465  C5'  DG J 268      21.143  70.447  16.486  1.00 47.23           C  \\nATOM   5466  C4'  DG J 268      19.939  70.035  15.672  1.00 47.23           C  \\nATOM   5467  O4'  DG J 268      19.063  69.252  16.517  1.00 47.23           O  \\nATOM   5468  C3'  DG J 268      19.106  71.205  15.150  1.00 47.23           C  \\nATOM   5469  O3'  DG J 268      18.724  71.021  13.789  1.00 47.23           O  \\nATOM   5470  C2'  DG J 268      17.898  71.246  16.070  1.00 47.23           C  \\nATOM   5471  C1'  DG J 268      17.771  69.820  16.566  1.00 47.23           C  \\nATOM   5472  N9   DG J 268      17.314  69.747  17.945  1.00 92.18           N  \\nATOM   5473  C8   DG J 268      17.806  70.429  19.030  1.00 92.18           C  \\nATOM   5474  N7   DG J 268      17.141  70.188  20.125  1.00 92.18           N  \\nATOM   5475  C5   DG J 268      16.165  69.285  19.735  1.00 92.18           C  \\nATOM   5476  C6   DG J 268      15.130  68.673  20.479  1.00 92.18           C  \\nATOM   5477  O6   DG J 268      14.854  68.814  21.687  1.00 92.18           O  \\nATOM   5478  N1   DG J 268      14.363  67.827  19.677  1.00 92.18           N  \\nATOM   5479  C2   DG J 268      14.581  67.595  18.339  1.00 92.18           C  \\nATOM   5480  N2   DG J 268      13.761  66.739  17.728  1.00 92.18           N  \\nATOM   5481  N3   DG J 268      15.535  68.165  17.644  1.00 92.18           N  \\nATOM   5482  C4   DG J 268      16.278  68.994  18.396  1.00 92.18           C  \\nATOM   5483  P    DT J 269      17.673  72.037  13.120  1.00 65.24           P  \\nATOM   5484  OP1  DT J 269      17.927  72.091  11.654  1.00 65.24           O  \\nATOM   5485  OP2  DT J 269      17.622  73.304  13.905  1.00 65.24           O  \\nATOM   5486  O5'  DT J 269      16.285  71.307  13.385  1.00 82.97           O  \\nATOM   5487  C5'  DT J 269      16.025  70.009  12.853  1.00 82.97           C  \\nATOM   5488  C4'  DT J 269      14.537  69.780  12.810  1.00 82.97           C  \\nATOM   5489  O4'  DT J 269      14.059  69.534  14.155  1.00 82.97           O  \\nATOM   5490  C3'  DT J 269      13.790  71.018  12.306  1.00 82.97           C  \\nATOM   5491  O3'  DT J 269      12.635  70.626  11.568  1.00 82.97           O  \\nATOM   5492  C2'  DT J 269      13.353  71.695  13.592  1.00 82.97           C  \\nATOM   5493  C1'  DT J 269      13.065  70.494  14.480  1.00 82.97           C  \\nATOM   5494  N1   DT J 269      13.098  70.744  15.946  1.00 81.21           N  \\nATOM   5495  C2   DT J 269      12.552  69.785  16.784  1.00 81.21           C  \\nATOM   5496  O2   DT J 269      12.114  68.717  16.384  1.00 81.21           O  \\nATOM   5497  N3   DT J 269      12.549  70.117  18.116  1.00 81.21           N  \\nATOM   5498  C4   DT J 269      13.056  71.262  18.692  1.00 81.21           C  \\nATOM   5499  O4   DT J 269      12.989  71.409  19.910  1.00 81.21           O  \\nATOM   5500  C5   DT J 269      13.642  72.213  17.763  1.00 81.21           C  \\nATOM   5501  C7   DT J 269      14.228  73.482  18.294  1.00 81.21           C  \\nATOM   5502  C6   DT J 269      13.633  71.910  16.456  1.00 81.21           C  \\nATOM   5503  P    DA J 270      12.550  70.892   9.981  1.00111.66           P  \\nATOM   5504  OP1  DA J 270      13.517  69.997   9.282  1.00111.66           O  \\nATOM   5505  OP2  DA J 270      12.586  72.357   9.729  1.00111.66           O  \\nATOM   5506  O5'  DA J 270      11.081  70.381   9.649  1.00188.00           O  \\nATOM   5507  C5'  DA J 270      10.652  69.091  10.085  1.00188.00           C  \\nATOM   5508  C4'  DA J 270       9.410  69.193  10.946  1.00188.00           C  \\nATOM   5509  O4'  DA J 270       9.721  69.516  12.331  1.00188.00           O  \\nATOM   5510  C3'  DA J 270       8.351  70.208  10.491  1.00188.00           C  \\nATOM   5511  O3'  DA J 270       7.049  69.600  10.444  1.00188.00           O  \\nATOM   5512  C2'  DA J 270       8.378  71.257  11.590  1.00188.00           C  \\nATOM   5513  C1'  DA J 270       8.728  70.414  12.800  1.00188.00           C  \\nATOM   5514  N9   DA J 270       9.237  71.155  13.961  1.00107.08           N  \\nATOM   5515  C8   DA J 270      10.056  72.261  13.978  1.00107.08           C  \\nATOM   5516  N7   DA J 270      10.276  72.742  15.182  1.00107.08           N  \\nATOM   5517  C5   DA J 270       9.568  71.886  16.018  1.00107.08           C  \\nATOM   5518  C6   DA J 270       9.392  71.853  17.423  1.00107.08           C  \\nATOM   5519  N6   DA J 270       9.933  72.738  18.264  1.00107.08           N  \\nATOM   5520  N1   DA J 270       8.627  70.865  17.938  1.00107.08           N  \\nATOM   5521  C2   DA J 270       8.082  69.975  17.099  1.00107.08           C  \\nATOM   5522  N3   DA J 270       8.171  69.900  15.768  1.00107.08           N  \\nATOM   5523  C4   DA J 270       8.936  70.895  15.282  1.00107.08           C  \\nATOM   5524  P    DG J 271       5.808  70.408   9.802  1.00132.56           P  \\nATOM   5525  OP1  DG J 271       4.929  69.435   9.098  1.00132.56           O  \\nATOM   5526  OP2  DG J 271       6.354  71.573   9.058  1.00132.56           O  \\nATOM   5527  O5'  DG J 271       5.012  70.947  11.074  1.00135.63           O  \\nATOM   5528  C5'  DG J 271       4.185  70.067  11.834  1.00135.63           C  \\nATOM   5529  C4'  DG J 271       3.329  70.843  12.809  1.00135.63           C  \\nATOM   5530  O4'  DG J 271       4.129  71.300  13.929  1.00135.63           O  \\nATOM   5531  C3'  DG J 271       2.623  72.082  12.244  1.00135.63           C  \\nATOM   5532  O3'  DG J 271       1.239  72.078  12.639  1.00135.63           O  \\nATOM   5533  C2'  DG J 271       3.382  73.238  12.875  1.00135.63           C  \\nATOM   5534  C1'  DG J 271       3.810  72.652  14.206  1.00135.63           C  \\nATOM   5535  N9   DG J 271       4.976  73.293  14.809  1.00 98.15           N  \\nATOM   5536  C8   DG J 271       5.929  74.045  14.162  1.00 98.15           C  \\nATOM   5537  N7   DG J 271       6.842  74.523  14.968  1.00 98.15           N  \\nATOM   5538  C5   DG J 271       6.476  74.053  16.224  1.00 98.15           C  \\nATOM   5539  C6   DG J 271       7.086  74.250  17.495  1.00 98.15           C  \\nATOM   5540  O6   DG J 271       8.111  74.890  17.770  1.00 98.15           O  \\nATOM   5541  N1   DG J 271       6.377  73.606  18.506  1.00 98.15           N  \\nATOM   5542  C2   DG J 271       5.243  72.859  18.321  1.00 98.15           C  \\nATOM   5543  N2   DG J 271       4.725  72.325  19.429  1.00 98.15           N  \\nATOM   5544  N3   DG J 271       4.668  72.657  17.146  1.00 98.15           N  \\nATOM   5545  C4   DG J 271       5.330  73.285  16.146  1.00 98.15           C  \\nATOM   5546  P    DA J 272       0.313  73.381  12.400  1.00169.15           P  \\nATOM   5547  OP1  DA J 272      -0.960  72.938  11.772  1.00169.15           O  \\nATOM   5548  OP2  DA J 272       1.107  74.462  11.765  1.00169.15           O  \\nATOM   5549  O5'  DA J 272      -0.013  73.841  13.884  1.00158.59           O  \\nATOM   5550  C5'  DA J 272      -0.226  72.859  14.886  1.00158.59           C  \\nATOM   5551  C4'  DA J 272      -0.230  73.490  16.255  1.00158.59           C  \\nATOM   5552  O4'  DA J 272       1.110  73.842  16.682  1.00158.59           O  \\nATOM   5553  C3'  DA J 272      -1.073  74.757  16.368  1.00158.59           C  \\nATOM   5554  O3'  DA J 272      -1.878  74.641  17.537  1.00158.59           O  \\nATOM   5555  C2'  DA J 272      -0.037  75.866  16.496  1.00158.59           C  \\nATOM   5556  C1'  DA J 272       1.111  75.161  17.203  1.00158.59           C  \\nATOM   5557  N9   DA J 272       2.446  75.735  16.993  1.00137.45           N  \\nATOM   5558  C8   DA J 272       2.994  76.189  15.816  1.00137.45           C  \\nATOM   5559  N7   DA J 272       4.216  76.652  15.945  1.00137.45           N  \\nATOM   5560  C5   DA J 272       4.496  76.495  17.296  1.00137.45           C  \\nATOM   5561  C6   DA J 272       5.636  76.799  18.073  1.00137.45           C  \\nATOM   5562  N6   DA J 272       6.750  77.346  17.578  1.00137.45           N  \\nATOM   5563  N1   DA J 272       5.591  76.518  19.392  1.00137.45           N  \\nATOM   5564  C2   DA J 272       4.476  75.969  19.891  1.00137.45           C  \\nATOM   5565  N3   DA J 272       3.343  75.638  19.268  1.00137.45           N  \\nATOM   5566  C4   DA J 272       3.417  75.930  17.956  1.00137.45           C  \\nATOM   5567  P    DA J 273      -3.066  75.679  17.799  1.00138.61           P  \\nATOM   5568  OP1  DA J 273      -4.324  74.914  18.018  1.00138.61           O  \\nATOM   5569  OP2  DA J 273      -3.015  76.725  16.745  1.00138.61           O  \\nATOM   5570  O5'  DA J 273      -2.616  76.326  19.177  1.00174.73           O  \\nATOM   5571  C5'  DA J 273      -1.976  75.525  20.172  1.00174.73           C  \\nATOM   5572  C4'  DA J 273      -1.333  76.410  21.210  1.00174.73           C  \\nATOM   5573  O4'  DA J 273       0.042  76.722  20.862  1.00174.73           O  \\nATOM   5574  C3'  DA J 273      -2.061  77.744  21.350  1.00174.73           C  \\nATOM   5575  O3'  DA J 273      -2.281  78.068  22.719  1.00174.73           O  \\nATOM   5576  C2'  DA J 273      -1.124  78.740  20.687  1.00174.73           C  \\nATOM   5577  C1'  DA J 273       0.243  78.127  20.935  1.00174.73           C  \\nATOM   5578  N9   DA J 273       1.261  78.512  19.948  1.00168.57           N  \\nATOM   5579  C8   DA J 273       1.115  78.614  18.584  1.00168.57           C  \\nATOM   5580  N7   DA J 273       2.197  79.019  17.963  1.00168.57           N  \\nATOM   5581  C5   DA J 273       3.124  79.190  18.983  1.00168.57           C  \\nATOM   5582  C6   DA J 273       4.472  79.610  18.981  1.00168.57           C  \\nATOM   5583  N6   DA J 273       5.145  79.948  17.880  1.00168.57           N  \\nATOM   5584  N1   DA J 273       5.112  79.673  20.169  1.00168.57           N  \\nATOM   5585  C2   DA J 273       4.439  79.335  21.276  1.00168.57           C  \\nATOM   5586  N3   DA J 273       3.175  78.927  21.408  1.00168.57           N  \\nATOM   5587  C4   DA J 273       2.565  78.874  20.211  1.00168.57           C  \\nATOM   5588  P    DT J 274      -3.119  79.385  23.096  1.00154.52           P  \\nATOM   5589  OP1  DT J 274      -4.100  78.999  24.143  1.00154.52           O  \\nATOM   5590  OP2  DT J 274      -3.598  80.027  21.840  1.00154.52           O  \\nATOM   5591  O5'  DT J 274      -2.010  80.312  23.763  1.00157.35           O  \\nATOM   5592  C5'  DT J 274      -1.106  79.769  24.727  1.00157.35           C  \\nATOM   5593  C4'  DT J 274      -0.081  80.802  25.130  1.00157.35           C  \\nATOM   5594  O4'  DT J 274       0.953  80.923  24.120  1.00157.35           O  \\nATOM   5595  C3'  DT J 274      -0.666  82.202  25.320  1.00157.35           C  \\nATOM   5596  O3'  DT J 274      -0.101  82.821  26.474  1.00157.35           O  \\nATOM   5597  C2'  DT J 274      -0.220  82.938  24.070  1.00157.35           C  \\nATOM   5598  C1'  DT J 274       1.130  82.296  23.815  1.00157.35           C  \\nATOM   5599  N1   DT J 274       1.637  82.418  22.429  1.00114.06           N  \\nATOM   5600  C2   DT J 274       3.005  82.485  22.246  1.00114.06           C  \\nATOM   5601  O2   DT J 274       3.811  82.386  23.165  1.00114.06           O  \\nATOM   5602  N3   DT J 274       3.398  82.671  20.937  1.00114.06           N  \\nATOM   5603  C4   DT J 274       2.581  82.773  19.822  1.00114.06           C  \\nATOM   5604  O4   DT J 274       3.084  82.943  18.711  1.00114.06           O  \\nATOM   5605  C5   DT J 274       1.159  82.667  20.088  1.00114.06           C  \\nATOM   5606  C7   DT J 274       0.196  82.756  18.946  1.00114.06           C  \\nATOM   5607  C6   DT J 274       0.766  82.495  21.358  1.00114.06           C  \\nATOM   5608  P    DC J 275      -0.907  83.993  27.222  1.00145.29           P  \\nATOM   5609  OP1  DC J 275      -1.769  83.360  28.251  1.00145.29           O  \\nATOM   5610  OP2  DC J 275      -1.522  84.867  26.187  1.00145.29           O  \\nATOM   5611  O5'  DC J 275       0.244  84.808  27.966  1.00117.02           O  \\nATOM   5612  C5'  DC J 275       1.101  85.685  27.234  1.00117.02           C  \\nATOM   5613  C4'  DC J 275       2.530  85.191  27.268  1.00117.02           C  \\nATOM   5614  O4'  DC J 275       2.871  84.632  25.974  1.00117.02           O  \\nATOM   5615  C3'  DC J 275       3.532  86.315  27.514  1.00117.02           C  \\nATOM   5616  O3'  DC J 275       4.639  85.877  28.300  1.00117.02           O  \\nATOM   5617  C2'  DC J 275       3.979  86.709  26.122  1.00117.02           C  \\nATOM   5618  C1'  DC J 275       3.858  85.422  25.325  1.00117.02           C  \\nATOM   5619  N1   DC J 275       3.400  85.685  23.954  1.00 96.21           N  \\nATOM   5620  C2   DC J 275       4.278  86.316  23.064  1.00 96.21           C  \\nATOM   5621  O2   DC J 275       5.435  86.578  23.442  1.00 96.21           O  \\nATOM   5622  N3   DC J 275       3.849  86.619  21.813  1.00 96.21           N  \\nATOM   5623  C4   DC J 275       2.612  86.298  21.434  1.00 96.21           C  \\nATOM   5624  N4   DC J 275       2.244  86.615  20.194  1.00 96.21           N  \\nATOM   5625  C5   DC J 275       1.705  85.636  22.311  1.00 96.21           C  \\nATOM   5626  C6   DC J 275       2.138  85.350  23.552  1.00 96.21           C  \\nATOM   5627  P    DT J 276       5.422  86.948  29.204  1.00104.64           P  \\nATOM   5628  OP1  DT J 276       6.595  86.291  29.846  1.00104.64           O  \\nATOM   5629  OP2  DT J 276       4.412  87.640  30.045  1.00104.64           O  \\nATOM   5630  O5'  DT J 276       5.962  88.006  28.145  1.00 55.96           O  \\nATOM   5631  C5'  DT J 276       7.217  87.820  27.500  1.00 55.96           C  \\nATOM   5632  C4'  DT J 276       7.497  88.967  26.558  1.00 55.96           C  \\nATOM   5633  O4'  DT J 276       6.733  88.822  25.333  1.00 55.96           O  \\nATOM   5634  C3'  DT J 276       7.195  90.373  27.097  1.00 55.96           C  \\nATOM   5635  O3'  DT J 276       8.293  91.252  26.827  1.00 55.96           O  \\nATOM   5636  C2'  DT J 276       6.021  90.822  26.234  1.00 55.96           C  \\nATOM   5637  C1'  DT J 276       6.347  90.119  24.933  1.00 55.96           C  \\nATOM   5638  N1   DT J 276       5.300  90.020  23.878  1.00 85.97           N  \\nATOM   5639  C2   DT J 276       5.589  90.566  22.635  1.00 85.97           C  \\nATOM   5640  O2   DT J 276       6.661  91.077  22.359  1.00 85.97           O  \\nATOM   5641  N3   DT J 276       4.572  90.477  21.718  1.00 85.97           N  \\nATOM   5642  C4   DT J 276       3.338  89.894  21.894  1.00 85.97           C  \\nATOM   5643  O4   DT J 276       2.531  89.894  20.975  1.00 85.97           O  \\nATOM   5644  C5   DT J 276       3.107  89.317  23.198  1.00 85.97           C  \\nATOM   5645  C7   DT J 276       1.802  88.632  23.461  1.00 85.97           C  \\nATOM   5646  C6   DT J 276       4.083  89.416  24.119  1.00 85.97           C  \\nATOM   5647  P    DG J 277       9.377  91.592  27.973  1.00 50.99           P  \\nATOM   5648  OP1  DG J 277       9.464  90.532  29.006  1.00 50.99           O  \\nATOM   5649  OP2  DG J 277       9.136  92.990  28.388  1.00 50.99           O  \\nATOM   5650  O5'  DG J 277      10.752  91.551  27.174  1.00 40.72           O  \\nATOM   5651  C5'  DG J 277      11.489  92.742  26.933  1.00 40.72           C  \\nATOM   5652  C4'  DG J 277      11.895  92.834  25.479  1.00 40.72           C  \\nATOM   5653  O4'  DG J 277      10.778  92.511  24.617  1.00 40.72           O  \\nATOM   5654  C3'  DG J 277      12.277  94.267  25.142  1.00 40.72           C  \\nATOM   5655  O3'  DG J 277      13.310  94.345  24.190  1.00 40.72           O  \\nATOM   5656  C2'  DG J 277      11.009  94.847  24.562  1.00 40.72           C  \\nATOM   5657  C1'  DG J 277      10.388  93.658  23.872  1.00 40.72           C  \\nATOM   5658  N9   DG J 277       8.938  93.745  23.917  1.00 61.53           N  \\nATOM   5659  C8   DG J 277       8.156  93.851  25.039  1.00 61.53           C  \\nATOM   5660  N7   DG J 277       6.883  93.912  24.770  1.00 61.53           N  \\nATOM   5661  C5   DG J 277       6.823  93.841  23.387  1.00 61.53           C  \\nATOM   5662  C6   DG J 277       5.705  93.843  22.518  1.00 61.53           C  \\nATOM   5663  O6   DG J 277       4.503  93.892  22.808  1.00 61.53           O  \\nATOM   5664  N1   DG J 277       6.090  93.761  21.183  1.00 61.53           N  \\nATOM   5665  C2   DG J 277       7.390  93.678  20.740  1.00 61.53           C  \\nATOM   5666  N2   DG J 277       7.558  93.618  19.402  1.00 61.53           N  \\nATOM   5667  N3   DG J 277       8.445  93.658  21.546  1.00 61.53           N  \\nATOM   5668  C4   DG J 277       8.086  93.743  22.847  1.00 61.53           C  \\nATOM   5669  P    DC J 278      14.012  95.755  23.939  1.00 49.82           P  \\nATOM   5670  OP1  DC J 278      15.449  95.467  23.742  1.00 49.82           O  \\nATOM   5671  OP2  DC J 278      13.583  96.697  25.010  1.00 49.82           O  \\nATOM   5672  O5'  DC J 278      13.383  96.253  22.568  1.00 46.57           O  \\nATOM   5673  C5'  DC J 278      12.496  95.419  21.828  1.00 46.57           C  \\nATOM   5674  C4'  DC J 278      11.752  96.231  20.794  1.00 46.57           C  \\nATOM   5675  O4'  DC J 278      10.337  96.142  21.066  1.00 46.57           O  \\nATOM   5676  C3'  DC J 278      12.072  97.727  20.772  1.00 46.57           C  \\nATOM   5677  O3'  DC J 278      11.946  98.219  19.433  1.00 46.57           O  \\nATOM   5678  C2'  DC J 278      10.984  98.328  21.645  1.00 46.57           C  \\nATOM   5679  C1'  DC J 278       9.804  97.442  21.298  1.00 46.57           C  \\nATOM   5680  N1   DC J 278       8.775  97.320  22.339  1.00 53.85           N  \\nATOM   5681  C2   DC J 278       7.459  97.145  21.935  1.00 53.85           C  \\nATOM   5682  O2   DC J 278       7.202  97.159  20.727  1.00 53.85           O  \\nATOM   5683  N3   DC J 278       6.500  96.970  22.862  1.00 53.85           N  \\nATOM   5684  C4   DC J 278       6.815  96.986  24.160  1.00 53.85           C  \\nATOM   5685  N4   DC J 278       5.829  96.799  25.040  1.00 53.85           N  \\nATOM   5686  C5   DC J 278       8.155  97.194  24.608  1.00 53.85           C  \\nATOM   5687  C6   DC J 278       9.094  97.356  23.671  1.00 53.85           C  \\nATOM   5688  P    DA J 279      13.039  99.243  18.847  1.00 51.99           P  \\nATOM   5689  OP1  DA J 279      14.359  98.583  18.985  1.00 51.99           O  \\nATOM   5690  OP2  DA J 279      12.836 100.604  19.415  1.00 51.99           O  \\nATOM   5691  O5'  DA J 279      12.672  99.307  17.306  1.00 71.89           O  \\nATOM   5692  C5'  DA J 279      12.176  98.159  16.632  1.00 71.89           C  \\nATOM   5693  C4'  DA J 279      10.942  98.533  15.850  1.00 71.89           C  \\nATOM   5694  O4'  DA J 279       9.779  98.598  16.713  1.00 71.89           O  \\nATOM   5695  C3'  DA J 279      11.067  99.906  15.204  1.00 71.89           C  \\nATOM   5696  O3'  DA J 279      10.452  99.888  13.923  1.00 71.89           O  \\nATOM   5697  C2'  DA J 279      10.333 100.822  16.167  1.00 71.89           C  \\nATOM   5698  C1'  DA J 279       9.258  99.921  16.753  1.00 71.89           C  \\nATOM   5699  N9   DA J 279       8.940 100.219  18.148  1.00 58.53           N  \\nATOM   5700  C8   DA J 279       9.783 100.703  19.116  1.00 58.53           C  \\nATOM   5701  N7   DA J 279       9.216 100.847  20.287  1.00 58.53           N  \\nATOM   5702  C5   DA J 279       7.908 100.444  20.071  1.00 58.53           C  \\nATOM   5703  C6   DA J 279       6.790 100.383  20.915  1.00 58.53           C  \\nATOM   5704  N6   DA J 279       6.807 100.749  22.196  1.00 58.53           N  \\nATOM   5705  N1   DA J 279       5.635  99.938  20.390  1.00 58.53           N  \\nATOM   5706  C2   DA J 279       5.610  99.590  19.098  1.00 58.53           C  \\nATOM   5707  N3   DA J 279       6.590  99.611  18.202  1.00 58.53           N  \\nATOM   5708  C4   DA J 279       7.726 100.054  18.759  1.00 58.53           C  \\nATOM   5709  P    DG J 280      10.617 101.144  12.953  1.00 63.68           P  \\nATOM   5710  OP1  DG J 280      11.405 100.748  11.759  1.00 63.68           O  \\nATOM   5711  OP2  DG J 280      11.054 102.314  13.778  1.00 63.68           O  \\nATOM   5712  O5'  DG J 280       9.124 101.389  12.494  1.00 82.78           O  \\nATOM   5713  C5'  DG J 280       8.644 102.701  12.385  1.00 82.78           C  \\nATOM   5714  C4'  DG J 280       7.270 102.806  12.991  1.00 82.78           C  \\nATOM   5715  O4'  DG J 280       7.303 102.411  14.391  1.00 82.78           O  \\nATOM   5716  C3'  DG J 280       6.814 104.259  12.955  1.00 82.78           C  \\nATOM   5717  O3'  DG J 280       5.521 104.394  12.377  1.00 82.78           O  \\nATOM   5718  C2'  DG J 280       6.874 104.718  14.400  1.00 82.78           C  \\nATOM   5719  C1'  DG J 280       6.771 103.442  15.214  1.00 82.78           C  \\nATOM   5720  N9   DG J 280       7.558 103.528  16.448  1.00 69.68           N  \\nATOM   5721  C8   DG J 280       8.924 103.655  16.562  1.00 69.68           C  \\nATOM   5722  N7   DG J 280       9.327 103.808  17.795  1.00 69.68           N  \\nATOM   5723  C5   DG J 280       8.164 103.758  18.539  1.00 69.68           C  \\nATOM   5724  C6   DG J 280       7.976 103.873  19.924  1.00 69.68           C  \\nATOM   5725  O6   DG J 280       8.832 104.071  20.800  1.00 69.68           O  \\nATOM   5726  N1   DG J 280       6.626 103.742  20.267  1.00 69.68           N  \\nATOM   5727  C2   DG J 280       5.600 103.536  19.371  1.00 69.68           C  \\nATOM   5728  N2   DG J 280       4.377 103.419  19.888  1.00 69.68           N  \\nATOM   5729  N3   DG J 280       5.768 103.447  18.071  1.00 69.68           N  \\nATOM   5730  C4   DG J 280       7.065 103.563  17.725  1.00 69.68           C  \\nATOM   5731  P    DG J 281       5.117 105.778  11.678  1.00 94.51           P  \\nATOM   5732  OP1  DG J 281       4.474 105.452  10.381  1.00 94.51           O  \\nATOM   5733  OP2  DG J 281       6.303 106.677  11.699  1.00 94.51           O  \\nATOM   5734  O5'  DG J 281       4.027 106.360  12.683  1.00135.91           O  \\nATOM   5735  C5'  DG J 281       3.013 105.518  13.241  1.00135.91           C  \\nATOM   5736  C4'  DG J 281       2.247 106.274  14.301  1.00135.91           C  \\nATOM   5737  O4'  DG J 281       2.790 106.013  15.623  1.00135.91           O  \\nATOM   5738  C3'  DG J 281       2.319 107.784  14.083  1.00135.91           C  \\nATOM   5739  O3'  DG J 281       1.034 108.404  14.087  1.00135.91           O  \\nATOM   5740  C2'  DG J 281       3.212 108.287  15.206  1.00135.91           C  \\nATOM   5741  C1'  DG J 281       3.109 107.228  16.296  1.00135.91           C  \\nATOM   5742  N9   DG J 281       4.392 107.043  16.978  1.00 63.55           N  \\nATOM   5743  C8   DG J 281       5.597 106.841  16.356  1.00 63.55           C  \\nATOM   5744  N7   DG J 281       6.603 106.757  17.184  1.00 63.55           N  \\nATOM   5745  C5   DG J 281       6.035 106.902  18.435  1.00 63.55           C  \\nATOM   5746  C6   DG J 281       6.647 106.905  19.706  1.00 63.55           C  \\nATOM   5747  O6   DG J 281       7.854 106.786  19.974  1.00 63.55           O  \\nATOM   5748  N1   DG J 281       5.711 107.070  20.726  1.00 63.55           N  \\nATOM   5749  C2   DG J 281       4.358 107.215  20.536  1.00 63.55           C  \\nATOM   5750  N2   DG J 281       3.631 107.347  21.659  1.00 63.55           N  \\nATOM   5751  N3   DG J 281       3.768 107.227  19.341  1.00 63.55           N  \\nATOM   5752  C4   DG J 281       4.664 107.066  18.338  1.00 63.55           C  \\nATOM   5753  P    DT J 282       0.865 109.875  13.455  1.00128.78           P  \\nATOM   5754  OP1  DT J 282      -0.492 109.962  12.853  1.00128.78           O  \\nATOM   5755  OP2  DT J 282       2.055 110.170  12.615  1.00128.78           O  \\nATOM   5756  O5'  DT J 282       0.938 110.813  14.738  1.00138.13           O  \\nATOM   5757  C5'  DT J 282       1.600 110.370  15.924  1.00138.13           C  \\nATOM   5758  C4'  DT J 282       0.890 110.899  17.147  1.00138.13           C  \\nATOM   5759  O4'  DT J 282       1.519 110.357  18.333  1.00138.13           O  \\nATOM   5760  C3'  DT J 282       0.967 112.417  17.275  1.00138.13           C  \\nATOM   5761  O3'  DT J 282      -0.278 112.969  17.707  1.00138.13           O  \\nATOM   5762  C2'  DT J 282       2.080 112.653  18.280  1.00138.13           C  \\nATOM   5763  C1'  DT J 282       2.111 111.385  19.119  1.00138.13           C  \\nATOM   5764  N1   DT J 282       3.495 110.971  19.430  1.00 69.49           N  \\nATOM   5765  C2   DT J 282       3.850 110.760  20.742  1.00 69.49           C  \\nATOM   5766  O2   DT J 282       3.076 110.896  21.672  1.00 69.49           O  \\nATOM   5767  N3   DT J 282       5.161 110.386  20.924  1.00 69.49           N  \\nATOM   5768  C4   DT J 282       6.126 110.209  19.939  1.00 69.49           C  \\nATOM   5769  O4   DT J 282       7.263 109.861  20.247  1.00 69.49           O  \\nATOM   5770  C5   DT J 282       5.684 110.459  18.591  1.00 69.49           C  \\nATOM   5771  C7   DT J 282       6.665 110.322  17.471  1.00 69.49           C  \\nATOM   5772  C6   DT J 282       4.409 110.814  18.406  1.00 69.49           C  \\nATOM   5773  P    DG J 283      -0.450 114.564  17.794  1.00130.65           P  \\nATOM   5774  OP1  DG J 283      -1.902 114.883  17.771  1.00130.65           O  \\nATOM   5775  OP2  DG J 283       0.454 115.188  16.791  1.00130.65           O  \\nATOM   5776  O5'  DG J 283       0.134 114.890  19.236  1.00125.50           O  \\nATOM   5777  C5'  DG J 283      -0.338 114.200  20.395  1.00125.50           C  \\nATOM   5778  C4'  DG J 283       0.315 114.788  21.619  1.00125.50           C  \\nATOM   5779  O4'  DG J 283       1.686 114.328  21.669  1.00125.50           O  \\nATOM   5780  C3'  DG J 283       0.380 116.309  21.498  1.00125.50           C  \\nATOM   5781  O3'  DG J 283       0.227 116.968  22.750  1.00125.50           O  \\nATOM   5782  C2'  DG J 283       1.761 116.562  20.937  1.00125.50           C  \\nATOM   5783  C1'  DG J 283       2.570 115.427  21.528  1.00125.50           C  \\nATOM   5784  N9   DG J 283       3.660 115.026  20.647  1.00113.99           N  \\nATOM   5785  C8   DG J 283       3.700 115.131  19.273  1.00113.99           C  \\nATOM   5786  N7   DG J 283       4.845 114.767  18.764  1.00113.99           N  \\nATOM   5787  C5   DG J 283       5.601 114.379  19.865  1.00113.99           C  \\nATOM   5788  C6   DG J 283       6.937 113.903  19.944  1.00113.99           C  \\nATOM   5789  O6   DG J 283       7.751 113.730  19.024  1.00113.99           O  \\nATOM   5790  N1   DG J 283       7.305 113.628  21.265  1.00113.99           N  \\nATOM   5791  C2   DG J 283       6.498 113.797  22.366  1.00113.99           C  \\nATOM   5792  N2   DG J 283       7.051 113.480  23.552  1.00113.99           N  \\nATOM   5793  N3   DG J 283       5.252 114.243  22.306  1.00113.99           N  \\nATOM   5794  C4   DG J 283       4.873 114.515  21.034  1.00113.99           C  \\nATOM   5795  P    DG J 284       0.057 118.566  22.782  1.00150.25           P  \\nATOM   5796  OP1  DG J 284      -1.338 118.895  23.184  1.00150.25           O  \\nATOM   5797  OP2  DG J 284       0.603 119.101  21.507  1.00150.25           O  \\nATOM   5798  O5'  DG J 284       1.040 119.009  23.946  1.00125.01           O  \\nATOM   5799  C5'  DG J 284       1.343 118.117  25.007  1.00125.01           C  \\nATOM   5800  C4'  DG J 284       2.799 118.243  25.368  1.00125.01           C  \\nATOM   5801  O4'  DG J 284       3.636 117.572  24.391  1.00125.01           O  \\nATOM   5802  C3'  DG J 284       3.260 119.700  25.387  1.00125.01           C  \\nATOM   5803  O3'  DG J 284       4.145 119.895  26.478  1.00125.01           O  \\nATOM   5804  C2'  DG J 284       4.037 119.838  24.092  1.00125.01           C  \\nATOM   5805  C1'  DG J 284       4.674 118.467  24.029  1.00125.01           C  \\nATOM   5806  N9   DG J 284       5.250 118.061  22.745  1.00 92.97           N  \\nATOM   5807  C8   DG J 284       4.740 118.268  21.479  1.00 92.97           C  \\nATOM   5808  N7   DG J 284       5.536 117.844  20.529  1.00 92.97           N  \\nATOM   5809  C5   DG J 284       6.634 117.313  21.206  1.00 92.97           C  \\nATOM   5810  C6   DG J 284       7.847 116.712  20.708  1.00 92.97           C  \\nATOM   5811  O6   DG J 284       8.202 116.524  19.530  1.00 92.97           O  \\nATOM   5812  N1   DG J 284       8.682 116.314  21.753  1.00 92.97           N  \\nATOM   5813  C2   DG J 284       8.399 116.455  23.092  1.00 92.97           C  \\nATOM   5814  N2   DG J 284       9.326 115.978  23.930  1.00 92.97           N  \\nATOM   5815  N3   DG J 284       7.294 117.012  23.566  1.00 92.97           N  \\nATOM   5816  C4   DG J 284       6.463 117.420  22.575  1.00 92.97           C  \\nATOM   5817  P    DA J 285       4.140 121.293  27.246  1.00165.61           P  \\nATOM   5818  OP1  DA J 285       2.930 121.324  28.104  1.00165.61           O  \\nATOM   5819  OP2  DA J 285       4.332 122.339  26.209  1.00165.61           O  \\nATOM   5820  O5'  DA J 285       5.432 121.213  28.174  1.00125.20           O  \\nATOM   5821  C5'  DA J 285       5.655 120.081  29.012  1.00125.20           C  \\nATOM   5822  C4'  DA J 285       7.093 119.630  28.911  1.00125.20           C  \\nATOM   5823  O4'  DA J 285       7.369 119.191  27.552  1.00125.20           O  \\nATOM   5824  C3'  DA J 285       8.133 120.714  29.224  1.00125.20           C  \\nATOM   5825  O3'  DA J 285       9.224 120.160  29.975  1.00125.20           O  \\nATOM   5826  C2'  DA J 285       8.627 121.126  27.850  1.00125.20           C  \\nATOM   5827  C1'  DA J 285       8.581 119.799  27.123  1.00125.20           C  \\nATOM   5828  N9   DA J 285       8.592 119.884  25.659  1.00104.16           N  \\nATOM   5829  C8   DA J 285       7.606 120.328  24.812  1.00104.16           C  \\nATOM   5830  N7   DA J 285       7.949 120.309  23.543  1.00104.16           N  \\nATOM   5831  C5   DA J 285       9.249 119.811  23.551  1.00104.16           C  \\nATOM   5832  C6   DA J 285      10.187 119.550  22.513  1.00104.16           C  \\nATOM   5833  N6   DA J 285       9.956 119.774  21.213  1.00104.16           N  \\nATOM   5834  N1   DA J 285      11.389 119.044  22.868  1.00104.16           N  \\nATOM   5835  C2   DA J 285      11.633 118.825  24.168  1.00104.16           C  \\nATOM   5836  N3   DA J 285      10.847 119.036  25.226  1.00104.16           N  \\nATOM   5837  C4   DA J 285       9.654 119.535  24.847  1.00104.16           C  \\nATOM   5838  P    DT J 286      10.556 121.036  30.221  1.00153.15           P  \\nATOM   5839  OP1  DT J 286      11.292 120.449  31.371  1.00153.15           O  \\nATOM   5840  OP2  DT J 286      10.180 122.476  30.245  1.00153.15           O  \\nATOM   5841  O5'  DT J 286      11.445 120.768  28.927  1.00170.64           O  \\nATOM   5842  C5'  DT J 286      12.171 119.548  28.788  1.00170.64           C  \\nATOM   5843  C4'  DT J 286      13.501 119.790  28.111  1.00170.64           C  \\nATOM   5844  O4'  DT J 286      13.337 119.989  26.684  1.00170.64           O  \\nATOM   5845  C3'  DT J 286      14.316 120.981  28.619  1.00170.64           C  \\nATOM   5846  O3'  DT J 286      15.677 120.558  28.802  1.00170.64           O  \\nATOM   5847  C2'  DT J 286      14.153 122.022  27.517  1.00170.64           C  \\nATOM   5848  C1'  DT J 286      14.026 121.163  26.269  1.00170.64           C  \\nATOM   5849  N1   DT J 286      13.286 121.744  25.113  1.00 55.99           N  \\nATOM   5850  C2   DT J 286      13.802 121.520  23.843  1.00 55.99           C  \\nATOM   5851  O2   DT J 286      14.852 120.923  23.640  1.00 55.99           O  \\nATOM   5852  N3   DT J 286      13.037 122.017  22.814  1.00 55.99           N  \\nATOM   5853  C4   DT J 286      11.844 122.694  22.914  1.00 55.99           C  \\nATOM   5854  O4   DT J 286      11.261 123.053  21.893  1.00 55.99           O  \\nATOM   5855  C5   DT J 286      11.371 122.916  24.265  1.00 55.99           C  \\nATOM   5856  C7   DT J 286      10.078 123.645  24.459  1.00 55.99           C  \\nATOM   5857  C6   DT J 286      12.111 122.448  25.287  1.00 55.99           C  \\nATOM   5858  P    DA J 287      16.874 121.631  28.784  1.00122.19           P  \\nATOM   5859  OP1  DA J 287      18.080 121.011  29.395  1.00122.19           O  \\nATOM   5860  OP2  DA J 287      16.391 122.945  29.283  1.00122.19           O  \\nATOM   5861  O5'  DA J 287      17.164 121.801  27.234  1.00 91.86           O  \\nATOM   5862  C5'  DA J 287      18.398 122.325  26.787  1.00 91.86           C  \\nATOM   5863  C4'  DA J 287      18.842 121.598  25.543  1.00 91.86           C  \\nATOM   5864  O4'  DA J 287      17.774 121.592  24.565  1.00 91.86           O  \\nATOM   5865  C3'  DA J 287      20.013 122.302  24.886  1.00 91.86           C  \\nATOM   5866  O3'  DA J 287      20.930 121.360  24.351  1.00 91.86           O  \\nATOM   5867  C2'  DA J 287      19.366 123.176  23.824  1.00 91.86           C  \\nATOM   5868  C1'  DA J 287      18.080 122.443  23.462  1.00 91.86           C  \\nATOM   5869  N9   DA J 287      16.931 123.338  23.254  1.00 62.59           N  \\nATOM   5870  C8   DA J 287      16.216 123.995  24.227  1.00 62.59           C  \\nATOM   5871  N7   DA J 287      15.218 124.710  23.764  1.00 62.59           N  \\nATOM   5872  C5   DA J 287      15.279 124.521  22.393  1.00 62.59           C  \\nATOM   5873  C6   DA J 287      14.488 125.006  21.339  1.00 62.59           C  \\nATOM   5874  N6   DA J 287      13.440 125.808  21.504  1.00 62.59           N  \\nATOM   5875  N1   DA J 287      14.815 124.633  20.090  1.00 62.59           N  \\nATOM   5876  C2   DA J 287      15.861 123.825  19.916  1.00 62.59           C  \\nATOM   5877  N3   DA J 287      16.680 123.297  20.821  1.00 62.59           N  \\nATOM   5878  C4   DA J 287      16.333 123.687  22.059  1.00 62.59           C  \\nATOM   5879  P    DT J 288      22.325 121.884  23.766  1.00131.99           P  \\nATOM   5880  OP1  DT J 288      23.242 120.727  23.592  1.00131.99           O  \\nATOM   5881  OP2  DT J 288      22.748 123.038  24.602  1.00131.99           O  \\nATOM   5882  O5'  DT J 288      21.907 122.434  22.332  1.00 62.74           O  \\nATOM   5883  C5'  DT J 288      21.388 121.552  21.343  1.00 62.74           C  \\nATOM   5884  C4'  DT J 288      21.367 122.249  20.010  1.00 62.74           C  \\nATOM   5885  O4'  DT J 288      20.197 123.080  19.874  1.00 62.74           O  \\nATOM   5886  C3'  DT J 288      22.556 123.180  19.815  1.00 62.74           C  \\nATOM   5887  O3'  DT J 288      22.864 123.181  18.431  1.00 62.74           O  \\nATOM   5888  C2'  DT J 288      21.988 124.533  20.202  1.00 62.74           C  \\nATOM   5889  C1'  DT J 288      20.601 124.416  19.613  1.00 62.74           C  \\nATOM   5890  N1   DT J 288      19.562 125.313  20.150  1.00 56.26           N  \\nATOM   5891  C2   DT J 288      18.540 125.654  19.293  1.00 56.26           C  \\nATOM   5892  O2   DT J 288      18.504 125.309  18.125  1.00 56.26           O  \\nATOM   5893  N3   DT J 288      17.559 126.416  19.850  1.00 56.26           N  \\nATOM   5894  C4   DT J 288      17.485 126.868  21.139  1.00 56.26           C  \\nATOM   5895  O4   DT J 288      16.499 127.516  21.483  1.00 56.26           O  \\nATOM   5896  C5   DT J 288      18.617 126.509  21.986  1.00 56.26           C  \\nATOM   5897  C7   DT J 288      18.649 126.973  23.403  1.00 56.26           C  \\nATOM   5898  C6   DT J 288      19.588 125.766  21.451  1.00 56.26           C  \\nATOM   5899  P    DT J 289      24.382 123.317  17.949  1.00 56.91           P  \\nATOM   5900  OP1  DT J 289      24.966 121.970  17.665  1.00 56.91           O  \\nATOM   5901  OP2  DT J 289      25.073 124.248  18.877  1.00 56.91           O  \\nATOM   5902  O5'  DT J 289      24.200 124.109  16.597  1.00 41.19           O  \\nATOM   5903  C5'  DT J 289      23.774 125.448  16.659  1.00 41.19           C  \\nATOM   5904  C4'  DT J 289      22.742 125.713  15.597  1.00 41.19           C  \\nATOM   5905  O4'  DT J 289      21.487 126.041  16.242  1.00 41.19           O  \\nATOM   5906  C3'  DT J 289      23.151 126.940  14.798  1.00 41.19           C  \\nATOM   5907  O3'  DT J 289      22.995 126.755  13.397  1.00 41.19           O  \\nATOM   5908  C2'  DT J 289      22.322 128.072  15.375  1.00 41.19           C  \\nATOM   5909  C1'  DT J 289      21.105 127.385  15.956  1.00 41.19           C  \\nATOM   5910  N1   DT J 289      20.627 128.011  17.212  1.00 33.86           N  \\nATOM   5911  C2   DT J 289      19.453 128.741  17.167  1.00 33.86           C  \\nATOM   5912  O2   DT J 289      18.793 128.893  16.147  1.00 33.86           O  \\nATOM   5913  N3   DT J 289      19.076 129.288  18.367  1.00 33.86           N  \\nATOM   5914  C4   DT J 289      19.723 129.169  19.587  1.00 33.86           C  \\nATOM   5915  O4   DT J 289      19.235 129.705  20.588  1.00 33.86           O  \\nATOM   5916  C5   DT J 289      20.952 128.388  19.563  1.00 33.86           C  \\nATOM   5917  C7   DT J 289      21.723 128.197  20.829  1.00 33.86           C  \\nATOM   5918  C6   DT J 289      21.337 127.864  18.392  1.00 33.86           C  \\nATOM   5919  P    DG J 290      23.937 127.587  12.406  1.00 41.87           P  \\nATOM   5920  OP1  DG J 290      24.003 126.934  11.087  1.00 41.87           O  \\nATOM   5921  OP2  DG J 290      25.186 127.891  13.142  1.00 41.87           O  \\nATOM   5922  O5'  DG J 290      23.164 128.971  12.251  1.00 47.43           O  \\nATOM   5923  C5'  DG J 290      21.866 129.018  11.657  1.00 47.43           C  \\nATOM   5924  C4'  DG J 290      21.292 130.410  11.767  1.00 47.43           C  \\nATOM   5925  O4'  DG J 290      20.840 130.665  13.118  1.00 47.43           O  \\nATOM   5926  C3'  DG J 290      22.280 131.526  11.427  1.00 47.43           C  \\nATOM   5927  O3'  DG J 290      21.622 132.527  10.649  1.00 47.43           O  \\nATOM   5928  C2'  DG J 290      22.664 132.072  12.789  1.00 47.43           C  \\nATOM   5929  C1'  DG J 290      21.390 131.878  13.575  1.00 47.43           C  \\nATOM   5930  N9   DG J 290      21.599 131.747  15.001  1.00 39.78           N  \\nATOM   5931  C8   DG J 290      22.684 131.205  15.632  1.00 39.78           C  \\nATOM   5932  N7   DG J 290      22.594 131.244  16.934  1.00 39.78           N  \\nATOM   5933  C5   DG J 290      21.366 131.841  17.170  1.00 39.78           C  \\nATOM   5934  C6   DG J 290      20.715 132.157  18.397  1.00 39.78           C  \\nATOM   5935  O6   DG J 290      21.103 131.930  19.560  1.00 39.78           O  \\nATOM   5936  N1   DG J 290      19.497 132.794  18.177  1.00 39.78           N  \\nATOM   5937  C2   DG J 290      18.971 133.074  16.939  1.00 39.78           C  \\nATOM   5938  N2   DG J 290      17.806 133.724  16.936  1.00 39.78           N  \\nATOM   5939  N3   DG J 290      19.549 132.756  15.791  1.00 39.78           N  \\nATOM   5940  C4   DG J 290      20.741 132.155  15.983  1.00 39.78           C  \\nATOM   5941  P    DA J 291      22.482 133.644   9.886  1.00 59.35           P  \\nATOM   5942  OP1  DA J 291      22.549 133.260   8.454  1.00 59.35           O  \\nATOM   5943  OP2  DA J 291      23.748 133.881  10.646  1.00 59.35           O  \\nATOM   5944  O5'  DA J 291      21.520 134.908   9.976  1.00 75.17           O  \\nATOM   5945  C5'  DA J 291      20.131 134.771   9.672  1.00 75.17           C  \\nATOM   5946  C4'  DA J 291      19.311 135.754  10.477  1.00 75.17           C  \\nATOM   5947  O4'  DA J 291      19.312 135.389  11.882  1.00 75.17           O  \\nATOM   5948  C3'  DA J 291      19.804 137.198  10.406  1.00 75.17           C  \\nATOM   5949  O3'  DA J 291      18.700 138.101  10.224  1.00 75.17           O  \\nATOM   5950  C2'  DA J 291      20.480 137.410  11.748  1.00 75.17           C  \\nATOM   5951  C1'  DA J 291      19.705 136.494  12.677  1.00 75.17           C  \\nATOM   5952  N9   DA J 291      20.548 135.999  13.764  1.00 43.24           N  \\nATOM   5953  C8   DA J 291      21.725 135.305  13.625  1.00 43.24           C  \\nATOM   5954  N7   DA J 291      22.344 135.069  14.764  1.00 43.24           N  \\nATOM   5955  C5   DA J 291      21.511 135.629  15.719  1.00 43.24           C  \\nATOM   5956  C6   DA J 291      21.617 135.732  17.113  1.00 43.24           C  \\nATOM   5957  N6   DA J 291      22.652 135.271  17.815  1.00 43.24           N  \\nATOM   5958  N1   DA J 291      20.610 136.341  17.776  1.00 43.24           N  \\nATOM   5959  C2   DA J 291      19.575 136.811  17.079  1.00 43.24           C  \\nATOM   5960  N3   DA J 291      19.360 136.784  15.763  1.00 43.24           N  \\nATOM   5961  C4   DA J 291      20.382 136.177  15.125  1.00 43.24           C  \\nATOM   5962  P    DT J 292      18.974 139.663   9.900  1.00 56.82           P  \\nATOM   5963  OP1  DT J 292      17.736 140.208   9.261  1.00 56.82           O  \\nATOM   5964  OP2  DT J 292      20.293 139.806   9.214  1.00 56.82           O  \\nATOM   5965  O5'  DT J 292      19.103 140.302  11.349  1.00 53.78           O  \\nATOM   5966  C5'  DT J 292      18.017 140.236  12.268  1.00 53.78           C  \\nATOM   5967  C4'  DT J 292      18.365 141.010  13.514  1.00 53.78           C  \\nATOM   5968  O4'  DT J 292      19.230 140.233  14.382  1.00 53.78           O  \\nATOM   5969  C3'  DT J 292      19.120 142.312  13.224  1.00 53.78           C  \\nATOM   5970  O3'  DT J 292      18.687 143.321  14.148  1.00 53.78           O  \\nATOM   5971  C2'  DT J 292      20.564 141.936  13.521  1.00 53.78           C  \\nATOM   5972  C1'  DT J 292      20.365 141.014  14.708  1.00 53.78           C  \\nATOM   5973  N1   DT J 292      21.484 140.113  15.065  1.00 57.75           N  \\nATOM   5974  C2   DT J 292      21.561 139.712  16.382  1.00 57.75           C  \\nATOM   5975  O2   DT J 292      20.740 140.037  17.223  1.00 57.75           O  \\nATOM   5976  N3   DT J 292      22.638 138.918  16.683  1.00 57.75           N  \\nATOM   5977  C4   DT J 292      23.630 138.482  15.815  1.00 57.75           C  \\nATOM   5978  O4   DT J 292      24.554 137.785  16.235  1.00 57.75           O  \\nATOM   5979  C5   DT J 292      23.480 138.918  14.436  1.00 57.75           C  \\nATOM   5980  C7   DT J 292      24.497 138.483  13.423  1.00 57.75           C  \\nATOM   5981  C6   DT J 292      22.425 139.702  14.134  1.00 57.75           C  \\nTER    5982       DT J 292                                                      \\nATOM   5983  N   PRO A  38      85.595 127.850  -1.418  1.00106.36           N  \\nATOM   5984  CA  PRO A  38      85.568 126.379  -1.251  1.00106.36           C  \\nATOM   5985  C   PRO A  38      84.377 125.749  -1.958  1.00106.36           C  \\nATOM   5986  O   PRO A  38      83.423 126.432  -2.347  1.00106.36           O  \\nATOM   5987  CB  PRO A  38      85.480 126.088   0.245  1.00 84.25           C  \\nATOM   5988  CG  PRO A  38      86.020 127.374   0.845  1.00 84.25           C  \\nATOM   5989  CD  PRO A  38      85.506 128.487  -0.093  1.00 84.25           C  \\nATOM   5990  N   HIS A  39      84.440 124.431  -2.107  1.00129.33           N  \\nATOM   5991  CA  HIS A  39      83.372 123.689  -2.750  1.00129.33           C  \\nATOM   5992  C   HIS A  39      82.356 123.251  -1.727  1.00129.33           C  \\nATOM   5993  O   HIS A  39      82.700 122.844  -0.616  1.00129.33           O  \\nATOM   5994  CB  HIS A  39      83.901 122.454  -3.458  1.00 81.91           C  \\nATOM   5995  CG  HIS A  39      82.864 121.746  -4.270  1.00 81.91           C  \\nATOM   5996  ND1 HIS A  39      82.075 120.740  -3.755  1.00 81.91           N  \\nATOM   5997  CD2 HIS A  39      82.497 121.892  -5.566  1.00 81.91           C  \\nATOM   5998  CE1 HIS A  39      81.271 120.293  -4.703  1.00 81.91           C  \\nATOM   5999  NE2 HIS A  39      81.507 120.975  -5.810  1.00 81.91           N  \\nATOM   6000  N   ARG A  40      81.103 123.249  -2.148  1.00 69.13           N  \\nATOM   6001  CA  ARG A  40      80.028 122.874  -1.257  1.00 69.13           C  \\nATOM   6002  C   ARG A  40      78.762 122.563  -2.063  1.00 69.13           C  \\nATOM   6003  O   ARG A  40      78.324 123.360  -2.894  1.00 69.13           O  \\nATOM   6004  CB  ARG A  40      79.796 124.027  -0.270  1.00 55.90           C  \\nATOM   6005  CG  ARG A  40      79.092 123.647   1.003  1.00 55.90           C  \\nATOM   6006  CD  ARG A  40      78.797 124.873   1.812  1.00 55.90           C  \\nATOM   6007  NE  ARG A  40      77.690 124.648   2.730  1.00 55.90           N  \\nATOM   6008  CZ  ARG A  40      77.779 123.935   3.843  1.00 55.90           C  \\nATOM   6009  NH1 ARG A  40      78.924 123.369   4.186  1.00 55.90           N  \\nATOM   6010  NH2 ARG A  40      76.726 123.825   4.635  1.00 55.90           N  \\nATOM   6011  N   TYR A  41      78.239 121.357  -1.871  1.00 59.40           N  \\nATOM   6012  CA  TYR A  41      77.023 120.897  -2.546  1.00 59.40           C  \\nATOM   6013  C   TYR A  41      75.761 121.511  -1.896  1.00 59.40           C  \\nATOM   6014  O   TYR A  41      75.711 121.695  -0.672  1.00 59.40           O  \\nATOM   6015  CB  TYR A  41      76.977 119.356  -2.519  1.00 37.17           C  \\nATOM   6016  CG  TYR A  41      77.894 118.667  -3.528  1.00 37.17           C  \\nATOM   6017  CD1 TYR A  41      77.617 118.732  -4.896  1.00 37.17           C  \\nATOM   6018  CD2 TYR A  41      79.025 117.943  -3.118  1.00 37.17           C  \\nATOM   6019  CE1 TYR A  41      78.437 118.095  -5.843  1.00 37.17           C  \\nATOM   6020  CE2 TYR A  41      79.865 117.300  -4.065  1.00 37.17           C  \\nATOM   6021  CZ  TYR A  41      79.560 117.384  -5.430  1.00 37.17           C  \\nATOM   6022  OH  TYR A  41      80.359 116.797  -6.404  1.00 37.17           O  \\nATOM   6023  N   ARG A  42      74.755 121.833  -2.713  1.00 50.55           N  \\nATOM   6024  CA  ARG A  42      73.515 122.447  -2.219  1.00 50.55           C  \\nATOM   6025  C   ARG A  42      72.647 121.528  -1.367  1.00 50.55           C  \\nATOM   6026  O   ARG A  42      72.639 120.311  -1.565  1.00 50.55           O  \\nATOM   6027  CB  ARG A  42      72.690 123.029  -3.368  1.00 81.38           C  \\nATOM   6028  CG  ARG A  42      73.298 124.271  -3.970  1.00 81.38           C  \\nATOM   6029  CD  ARG A  42      72.321 124.990  -4.865  1.00 81.38           C  \\nATOM   6030  NE  ARG A  42      73.002 125.963  -5.713  1.00 81.38           N  \\nATOM   6031  CZ  ARG A  42      72.679 126.213  -6.984  1.00 81.38           C  \\nATOM   6032  NH1 ARG A  42      71.661 125.569  -7.553  1.00 81.38           N  \\nATOM   6033  NH2 ARG A  42      73.445 127.022  -7.725  1.00 81.38           N  \\nATOM   6034  N   PRO A  43      71.890 122.100  -0.406  1.00 42.50           N  \\nATOM   6035  CA  PRO A  43      71.054 121.233   0.426  1.00 42.50           C  \\nATOM   6036  C   PRO A  43      70.061 120.426  -0.408  1.00 42.50           C  \\nATOM   6037  O   PRO A  43      69.377 120.968  -1.290  1.00 42.50           O  \\nATOM   6038  CB  PRO A  43      70.402 122.212   1.410  1.00 52.35           C  \\nATOM   6039  CG  PRO A  43      70.406 123.518   0.683  1.00 52.35           C  \\nATOM   6040  CD  PRO A  43      71.735 123.516  -0.021  1.00 52.35           C  \\nATOM   6041  N   GLY A  44      70.126 119.107  -0.218  1.00 40.87           N  \\nATOM   6042  CA  GLY A  44      69.264 118.184  -0.930  1.00 40.87           C  \\nATOM   6043  C   GLY A  44      69.949 117.423  -2.055  1.00 40.87           C  \\nATOM   6044  O   GLY A  44      69.379 116.459  -2.578  1.00 40.87           O  \\nATOM   6045  N   THR A  45      71.164 117.827  -2.430  1.00 38.61           N  \\nATOM   6046  CA  THR A  45      71.890 117.162  -3.520  1.00 38.61           C  \\nATOM   6047  C   THR A  45      72.576 115.888  -3.085  1.00 38.61           C  \\nATOM   6048  O   THR A  45      72.438 114.860  -3.730  1.00 38.61           O  \\nATOM   6049  CB  THR A  45      72.935 118.086  -4.182  1.00 42.13           C  \\nATOM   6050  OG1 THR A  45      72.275 119.223  -4.745  1.00 42.13           O  \\nATOM   6051  CG2 THR A  45      73.662 117.353  -5.299  1.00 42.13           C  \\nATOM   6052  N   VAL A  46      73.362 115.972  -2.023  1.00 38.80           N  \\nATOM   6053  CA  VAL A  46      74.047 114.799  -1.504  1.00 38.80           C  \\nATOM   6054  C   VAL A  46      72.987 113.755  -1.109  1.00 38.80           C  \\nATOM   6055  O   VAL A  46      73.125 112.575  -1.431  1.00 38.80           O  \\nATOM   6056  CB  VAL A  46      74.952 115.171  -0.302  1.00 50.21           C  \\nATOM   6057  CG1 VAL A  46      75.609 113.938   0.292  1.00 50.21           C  \\nATOM   6058  CG2 VAL A  46      76.014 116.148  -0.757  1.00 50.21           C  \\nATOM   6059  N   ALA A  47      71.902 114.217  -0.485  1.00 43.20           N  \\nATOM   6060  CA  ALA A  47      70.791 113.346  -0.075  1.00 43.20           C  \\nATOM   6061  C   ALA A  47      70.265 112.594  -1.295  1.00 43.20           C  \\nATOM   6062  O   ALA A  47      70.002 111.392  -1.244  1.00 43.20           O  \\nATOM   6063  CB  ALA A  47      69.650 114.176   0.545  1.00  7.11           C  \\nATOM   6064  N   LEU A  48      70.122 113.319  -2.397  1.00 29.41           N  \\nATOM   6065  CA  LEU A  48      69.647 112.750  -3.647  1.00 29.41           C  \\nATOM   6066  C   LEU A  48      70.531 111.580  -4.122  1.00 29.41           C  \\nATOM   6067  O   LEU A  48      70.033 110.487  -4.366  1.00 29.41           O  \\nATOM   6068  CB  LEU A  48      69.558 113.854  -4.710  1.00 42.76           C  \\nATOM   6069  CG  LEU A  48      68.243 114.033  -5.480  1.00 42.76           C  \\nATOM   6070  CD1 LEU A  48      67.070 113.820  -4.560  1.00 42.76           C  \\nATOM   6071  CD2 LEU A  48      68.177 115.423  -6.101  1.00 42.76           C  \\nATOM   6072  N   ARG A  49      71.841 111.776  -4.216  1.00 34.24           N  \\nATOM   6073  CA  ARG A  49      72.687 110.675  -4.668  1.00 34.24           C  \\nATOM   6074  C   ARG A  49      72.774 109.519  -3.655  1.00 34.24           C  \\nATOM   6075  O   ARG A  49      73.093 108.389  -4.017  1.00 34.24           O  \\nATOM   6076  CB  ARG A  49      74.065 111.167  -5.116  1.00 43.06           C  \\nATOM   6077  CG  ARG A  49      75.001 111.613  -4.008  1.00 43.06           C  \\nATOM   6078  CD  ARG A  49      76.418 111.847  -4.576  1.00 43.06           C  \\nATOM   6079  NE  ARG A  49      77.182 112.798  -3.772  1.00 43.06           N  \\nATOM   6080  CZ  ARG A  49      77.421 114.060  -4.121  1.00 43.06           C  \\nATOM   6081  NH1 ARG A  49      76.985 114.550  -5.289  1.00 43.06           N  \\nATOM   6082  NH2 ARG A  49      77.970 114.870  -3.224  1.00 43.06           N  \\nATOM   6083  N   GLU A  50      72.524 109.821  -2.386  1.00 21.20           N  \\nATOM   6084  CA  GLU A  50      72.494 108.806  -1.345  1.00 21.20           C  \\nATOM   6085  C   GLU A  50      71.278 107.914  -1.619  1.00 21.20           C  \\nATOM   6086  O   GLU A  50      71.327 106.697  -1.436  1.00 21.20           O  \\nATOM   6087  CB  GLU A  50      72.344 109.444   0.027  1.00 31.05           C  \\nATOM   6088  CG  GLU A  50      73.598 110.035   0.584  1.00 31.05           C  \\nATOM   6089  CD  GLU A  50      73.391 110.568   1.993  1.00 31.05           C  \\nATOM   6090  OE1 GLU A  50      72.900 109.827   2.876  1.00 31.05           O  \\nATOM   6091  OE2 GLU A  50      73.700 111.752   2.227  1.00 31.05           O  \\nATOM   6092  N   ILE A  51      70.169 108.534  -2.010  1.00 20.69           N  \\nATOM   6093  CA  ILE A  51      68.962 107.786  -2.342  1.00 20.69           C  \\nATOM   6094  C   ILE A  51      69.353 106.880  -3.489  1.00 20.69           C  \\nATOM   6095  O   ILE A  51      69.295 105.669  -3.370  1.00 20.69           O  \\nATOM   6096  CB  ILE A  51      67.800 108.745  -2.732  1.00  9.99           C  \\nATOM   6097  CG1 ILE A  51      67.312 109.466  -1.477  1.00  9.99           C  \\nATOM   6098  CG2 ILE A  51      66.642 108.014  -3.377  1.00  9.99           C  \\nATOM   6099  CD1 ILE A  51      66.251 110.456  -1.750  1.00  9.99           C  \\nATOM   6100  N   ARG A  52      69.889 107.461  -4.547  1.00 18.39           N  \\nATOM   6101  CA  ARG A  52      70.304 106.663  -5.680  1.00 18.39           C  \\nATOM   6102  C   ARG A  52      71.193 105.472  -5.298  1.00 18.39           C  \\nATOM   6103  O   ARG A  52      70.942 104.352  -5.770  1.00 18.39           O  \\nATOM   6104  CB  ARG A  52      70.915 107.553  -6.759  1.00 59.59           C  \\nATOM   6105  CG  ARG A  52      69.859 108.512  -7.256  1.00 59.59           C  \\nATOM   6106  CD  ARG A  52      70.253 109.442  -8.388  1.00 59.59           C  \\nATOM   6107  NE  ARG A  52      69.254 110.514  -8.481  1.00 59.59           N  \\nATOM   6108  CZ  ARG A  52      69.471 111.702  -9.031  1.00 59.59           C  \\nATOM   6109  NH1 ARG A  52      70.648 111.975  -9.565  1.00 59.59           N  \\nATOM   6110  NH2 ARG A  52      68.547 112.649  -8.959  1.00 59.59           N  \\nATOM   6111  N   ARG A  53      72.160 105.689  -4.400  1.00 34.07           N  \\nATOM   6112  CA  ARG A  53      73.072 104.627  -3.944  1.00 34.07           C  \\nATOM   6113  C   ARG A  53      72.417 103.530  -3.100  1.00 34.07           C  \\nATOM   6114  O   ARG A  53      72.595 102.335  -3.369  1.00 34.07           O  \\nATOM   6115  CB  ARG A  53      74.244 105.210  -3.151  1.00 50.84           C  \\nATOM   6116  CG  ARG A  53      75.073 104.171  -2.370  1.00 50.84           C  \\nATOM   6117  CD  ARG A  53      75.897 104.856  -1.297  1.00 50.84           C  \\nATOM   6118  NE  ARG A  53      76.464 106.101  -1.829  1.00 50.84           N  \\nATOM   6119  CZ  ARG A  53      76.654 107.231  -1.141  1.00 50.84           C  \\nATOM   6120  NH1 ARG A  53      76.337 107.309   0.148  1.00 50.84           N  \\nATOM   6121  NH2 ARG A  53      77.127 108.311  -1.764  1.00 50.84           N  \\nATOM   6122  N   TYR A  54      71.695 103.929  -2.058  1.00 27.70           N  \\nATOM   6123  CA  TYR A  54      71.058 102.961  -1.191  1.00 27.70           C  \\nATOM   6124  C   TYR A  54      69.964 102.185  -1.880  1.00 27.70           C  \\nATOM   6125  O   TYR A  54      69.709 101.035  -1.533  1.00 27.70           O  \\nATOM   6126  CB  TYR A  54      70.553 103.626   0.069  1.00 34.70           C  \\nATOM   6127  CG  TYR A  54      71.679 104.107   0.919  1.00 34.70           C  \\nATOM   6128  CD1 TYR A  54      72.706 103.239   1.304  1.00 34.70           C  \\nATOM   6129  CD2 TYR A  54      71.761 105.441   1.305  1.00 34.70           C  \\nATOM   6130  CE1 TYR A  54      73.802 103.697   2.055  1.00 34.70           C  \\nATOM   6131  CE2 TYR A  54      72.841 105.914   2.059  1.00 34.70           C  \\nATOM   6132  CZ  TYR A  54      73.855 105.038   2.425  1.00 34.70           C  \\nATOM   6133  OH  TYR A  54      74.903 105.526   3.163  1.00 34.70           O  \\nATOM   6134  N   GLN A  55      69.289 102.808  -2.834  1.00 25.84           N  \\nATOM   6135  CA  GLN A  55      68.255 102.087  -3.559  1.00 25.84           C  \\nATOM   6136  C   GLN A  55      68.874 100.981  -4.421  1.00 25.84           C  \\nATOM   6137  O   GLN A  55      68.318  99.883  -4.517  1.00 25.84           O  \\nATOM   6138  CB  GLN A  55      67.388 103.047  -4.370  1.00 37.88           C  \\nATOM   6139  CG  GLN A  55      66.524 103.909  -3.456  1.00 37.88           C  \\nATOM   6140  CD  GLN A  55      65.351 104.563  -4.165  1.00 37.88           C  \\nATOM   6141  OE1 GLN A  55      65.374 104.757  -5.384  1.00 37.88           O  \\nATOM   6142  NE2 GLN A  55      64.303 104.888  -3.406  1.00 37.88           N  \\nATOM   6143  N   LYS A  56      70.067 101.253  -4.957  1.00 32.05           N  \\nATOM   6144  CA  LYS A  56      70.814 100.307  -5.795  1.00 32.05           C  \\nATOM   6145  C   LYS A  56      71.347  99.095  -5.025  1.00 32.05           C  \\nATOM   6146  O   LYS A  56      71.294  97.966  -5.523  1.00 32.05           O  \\nATOM   6147  CB  LYS A  56      71.981 101.013  -6.502  1.00 92.65           C  \\nATOM   6148  CG  LYS A  56      71.563 102.003  -7.577  1.00 92.65           C  \\nATOM   6149  CD  LYS A  56      72.765 102.748  -8.168  1.00 92.65           C  \\nATOM   6150  CE  LYS A  56      72.328 103.780  -9.225  1.00 92.65           C  \\nATOM   6151  NZ  LYS A  56      73.454 104.621  -9.752  1.00 92.65           N  \\nATOM   6152  N   SER A  57      71.893  99.338  -3.835  1.00 27.56           N  \\nATOM   6153  CA  SER A  57      72.446  98.271  -3.011  1.00 27.56           C  \\nATOM   6154  C   SER A  57      71.381  97.528  -2.196  1.00 27.56           C  \\nATOM   6155  O   SER A  57      70.183  97.839  -2.305  1.00 27.56           O  \\nATOM   6156  CB  SER A  57      73.524  98.840  -2.098  1.00 27.72           C  \\nATOM   6157  OG  SER A  57      73.004  99.866  -1.272  1.00 27.72           O  \\nATOM   6158  N   THR A  58      71.820  96.539  -1.400  1.00 20.76           N  \\nATOM   6159  CA  THR A  58      70.920  95.737  -0.563  1.00 20.76           C  \\nATOM   6160  C   THR A  58      71.471  95.419   0.824  1.00 20.76           C  \\nATOM   6161  O   THR A  58      70.818  94.754   1.614  1.00 20.76           O  \\nATOM   6162  CB  THR A  58      70.580  94.381  -1.214  1.00 18.87           C  \\nATOM   6163  OG1 THR A  58      71.745  93.555  -1.211  1.00 18.87           O  \\nATOM   6164  CG2 THR A  58      70.065  94.550  -2.664  1.00 18.87           C  \\nATOM   6165  N   GLU A  59      72.678  95.880   1.112  1.00 20.79           N  \\nATOM   6166  CA  GLU A  59      73.324  95.633   2.406  1.00 20.79           C  \\nATOM   6167  C   GLU A  59      72.454  96.142   3.550  1.00 20.79           C  \\nATOM   6168  O   GLU A  59      71.641  97.037   3.348  1.00 20.79           O  \\nATOM   6169  CB  GLU A  59      74.700  96.315   2.442  1.00 49.37           C  \\nATOM   6170  CG  GLU A  59      75.028  97.245   1.234  1.00 49.37           C  \\nATOM   6171  CD  GLU A  59      74.631  98.718   1.438  1.00 49.37           C  \\nATOM   6172  OE1 GLU A  59      74.040  99.042   2.484  1.00 49.37           O  \\nATOM   6173  OE2 GLU A  59      74.933  99.567   0.564  1.00 49.37           O  \\nATOM   6174  N   LEU A  60      72.551  95.538   4.725  1.00 23.94           N  \\nATOM   6175  CA  LEU A  60      71.750  96.025   5.846  1.00 23.94           C  \\nATOM   6176  C   LEU A  60      72.263  97.420   6.185  1.00 23.94           C  \\nATOM   6177  O   LEU A  60      73.340  97.785   5.749  1.00 23.94           O  \\nATOM   6178  CB  LEU A  60      71.865  95.091   7.041  1.00 28.99           C  \\nATOM   6179  CG  LEU A  60      71.216  93.731   6.795  1.00 28.99           C  \\nATOM   6180  CD1 LEU A  60      71.326  92.877   8.048  1.00 28.99           C  \\nATOM   6181  CD2 LEU A  60      69.763  93.939   6.406  1.00 28.99           C  \\nATOM   6182  N   LEU A  61      71.541  98.205   6.971  1.00 16.11           N  \\nATOM   6183  CA  LEU A  61      72.008  99.557   7.224  1.00 16.11           C  \\nATOM   6184  C   LEU A  61      72.103  99.932   8.673  1.00 16.11           C  \\nATOM   6185  O   LEU A  61      72.622 100.999   9.002  1.00 16.11           O  \\nATOM   6186  CB  LEU A  61      71.143 100.568   6.468  1.00 17.45           C  \\nATOM   6187  CG  LEU A  61      70.920 100.289   4.977  1.00 17.45           C  \\nATOM   6188  CD1 LEU A  61      69.761 101.117   4.432  1.00 17.45           C  \\nATOM   6189  CD2 LEU A  61      72.177 100.545   4.206  1.00 17.45           C  \\nATOM   6190  N   ILE A  62      71.555  99.108   9.546  1.00 25.59           N  \\nATOM   6191  CA  ILE A  62      71.679  99.393  10.966  1.00 25.59           C  \\nATOM   6192  C   ILE A  62      72.970  98.666  11.392  1.00 25.59           C  \\nATOM   6193  O   ILE A  62      73.379  97.677  10.773  1.00 25.59           O  \\nATOM   6194  CB  ILE A  62      70.468  98.855  11.772  1.00 20.19           C  \\nATOM   6195  CG1 ILE A  62      69.156  99.387  11.202  1.00 20.19           C  \\nATOM   6196  CG2 ILE A  62      70.543  99.332  13.212  1.00 20.19           C  \\nATOM   6197  CD1 ILE A  62      67.957  98.734  11.839  1.00 20.19           C  \\nATOM   6198  N   ARG A  63      73.672  99.167  12.391  1.00 57.10           N  \\nATOM   6199  CA  ARG A  63      74.872  98.447  12.780  1.00 57.10           C  \\nATOM   6200  C   ARG A  63      74.501  97.161  13.559  1.00 57.10           C  \\nATOM   6201  O   ARG A  63      73.710  97.183  14.503  1.00 57.10           O  \\nATOM   6202  CB  ARG A  63      75.852  99.382  13.501  1.00 79.09           C  \\nATOM   6203  CG  ARG A  63      76.911  99.974  12.547  1.00 79.09           C  \\nATOM   6204  CD  ARG A  63      77.401 101.371  12.934  1.00 79.09           C  \\nATOM   6205  NE  ARG A  63      77.537 101.579  14.379  1.00 79.09           N  \\nATOM   6206  CZ  ARG A  63      76.774 102.417  15.084  1.00 79.09           C  \\nATOM   6207  NH1 ARG A  63      75.829 103.125  14.466  1.00 79.09           N  \\nATOM   6208  NH2 ARG A  63      76.932 102.536  16.401  1.00 79.09           N  \\nATOM   6209  N   LYS A  64      75.016  96.031  13.078  1.00 31.58           N  \\nATOM   6210  CA  LYS A  64      74.749  94.700  13.647  1.00 31.58           C  \\nATOM   6211  C   LYS A  64      74.779  94.511  15.172  1.00 31.58           C  \\nATOM   6212  O   LYS A  64      73.833  93.991  15.744  1.00 31.58           O  \\nATOM   6213  CB  LYS A  64      75.627  93.652  12.955  1.00 55.38           C  \\nATOM   6214  CG  LYS A  64      75.503  93.675  11.442  1.00 55.38           C  \\nATOM   6215  CD  LYS A  64      75.417  92.275  10.869  1.00 55.38           C  \\nATOM   6216  CE  LYS A  64      74.725  92.287   9.513  1.00 55.38           C  \\nATOM   6217  NZ  LYS A  64      74.675  90.932   8.899  1.00 55.38           N  \\nATOM   6218  N   LEU A  65      75.856  94.901  15.839  1.00 45.79           N  \\nATOM   6219  CA  LEU A  65      75.911  94.741  17.289  1.00 45.79           C  \\nATOM   6220  C   LEU A  65      74.819  95.515  18.024  1.00 45.79           C  \\nATOM   6221  O   LEU A  65      74.118  94.942  18.845  1.00 45.79           O  \\nATOM   6222  CB  LEU A  65      77.287  95.121  17.845  1.00 68.84           C  \\nATOM   6223  CG  LEU A  65      77.401  95.152  19.375  1.00 68.84           C  \\nATOM   6224  CD1 LEU A  65      77.065  93.780  19.970  1.00 68.84           C  \\nATOM   6225  CD2 LEU A  65      78.796  95.603  19.771  1.00 68.84           C  \\nATOM   6226  N   PRO A  66      74.652  96.825  17.736  1.00 51.32           N  \\nATOM   6227  CA  PRO A  66      73.598  97.573  18.442  1.00 51.32           C  \\nATOM   6228  C   PRO A  66      72.262  96.841  18.304  1.00 51.32           C  \\nATOM   6229  O   PRO A  66      71.535  96.652  19.276  1.00 51.32           O  \\nATOM   6230  CB  PRO A  66      73.552  98.902  17.688  1.00 24.78           C  \\nATOM   6231  CG  PRO A  66      74.937  99.048  17.106  1.00 24.78           C  \\nATOM   6232  CD  PRO A  66      75.300  97.652  16.694  1.00 24.78           C  \\nATOM   6233  N   PHE A  67      71.967  96.405  17.081  1.00 27.70           N  \\nATOM   6234  CA  PHE A  67      70.743  95.685  16.794  1.00 27.70           C  \\nATOM   6235  C   PHE A  67      70.685  94.388  17.615  1.00 27.70           C  \\nATOM   6236  O   PHE A  67      69.668  94.085  18.244  1.00 27.70           O  \\nATOM   6237  CB  PHE A  67      70.667  95.403  15.301  1.00 39.08           C  \\nATOM   6238  CG  PHE A  67      69.338  94.894  14.860  1.00 39.08           C  \\nATOM   6239  CD1 PHE A  67      68.307  95.773  14.597  1.00 39.08           C  \\nATOM   6240  CD2 PHE A  67      69.096  93.529  14.766  1.00 39.08           C  \\nATOM   6241  CE1 PHE A  67      67.053  95.298  14.258  1.00 39.08           C  \\nATOM   6242  CE2 PHE A  67      67.840  93.048  14.426  1.00 39.08           C  \\nATOM   6243  CZ  PHE A  67      66.818  93.931  14.175  1.00 39.08           C  \\nATOM   6244  N   GLN A  68      71.798  93.650  17.618  1.00 28.04           N  \\nATOM   6245  CA  GLN A  68      71.955  92.406  18.367  1.00 28.04           C  \\nATOM   6246  C   GLN A  68      71.547  92.682  19.798  1.00 28.04           C  \\nATOM   6247  O   GLN A  68      70.645  92.058  20.331  1.00 28.04           O  \\nATOM   6248  CB  GLN A  68      73.418  92.004  18.365  1.00 61.85           C  \\nATOM   6249  CG  GLN A  68      73.695  90.694  19.029  1.00 61.85           C  \\nATOM   6250  CD  GLN A  68      73.596  89.551  18.054  1.00 61.85           C  \\nATOM   6251  OE1 GLN A  68      73.947  89.695  16.881  1.00 61.85           O  \\nATOM   6252  NE2 GLN A  68      73.120  88.406  18.524  1.00 61.85           N  \\nATOM   6253  N   ARG A  69      72.178  93.691  20.381  1.00 24.75           N  \\nATOM   6254  CA  ARG A  69      71.933  94.108  21.760  1.00 24.75           C  \\nATOM   6255  C   ARG A  69      70.483  94.488  22.034  1.00 24.75           C  \\nATOM   6256  O   ARG A  69      69.936  94.127  23.073  1.00 24.75           O  \\nATOM   6257  CB  ARG A  69      72.854  95.280  22.119  1.00 53.70           C  \\nATOM   6258  CG  ARG A  69      73.504  95.171  23.491  1.00 53.70           C  \\nATOM   6259  CD  ARG A  69      74.324  96.416  23.826  1.00 53.70           C  \\nATOM   6260  NE  ARG A  69      75.365  96.685  22.841  1.00 53.70           N  \\nATOM   6261  CZ  ARG A  69      75.457  97.803  22.126  1.00 53.70           C  \\nATOM   6262  NH1 ARG A  69      74.568  98.784  22.273  1.00 53.70           N  \\nATOM   6263  NH2 ARG A  69      76.453  97.941  21.265  1.00 53.70           N  \\nATOM   6264  N   LEU A  70      69.887  95.245  21.111  1.00 42.28           N  \\nATOM   6265  CA  LEU A  70      68.498  95.675  21.225  1.00 42.28           C  \\nATOM   6266  C   LEU A  70      67.534  94.481  21.235  1.00 42.28           C  \\nATOM   6267  O   LEU A  70      66.696  94.362  22.129  1.00 42.28           O  \\nATOM   6268  CB  LEU A  70      68.162  96.628  20.090  1.00 24.78           C  \\nATOM   6269  CG  LEU A  70      66.775  97.262  20.145  1.00 24.78           C  \\nATOM   6270  CD1 LEU A  70      66.501  97.859  21.510  1.00 24.78           C  \\nATOM   6271  CD2 LEU A  70      66.716  98.341  19.100  1.00 24.78           C  \\nATOM   6272  N   VAL A  71      67.676  93.591  20.255  1.00 16.88           N  \\nATOM   6273  CA  VAL A  71      66.863  92.379  20.170  1.00 16.88           C  \\nATOM   6274  C   VAL A  71      66.921  91.603  21.512  1.00 16.88           C  \\nATOM   6275  O   VAL A  71      65.892  91.286  22.128  1.00 16.88           O  \\nATOM   6276  CB  VAL A  71      67.381  91.485  19.020  1.00 29.66           C  \\nATOM   6277  CG1 VAL A  71      66.870  90.065  19.169  1.00 29.66           C  \\nATOM   6278  CG2 VAL A  71      66.967  92.057  17.684  1.00 29.66           C  \\nATOM   6279  N   ARG A  72      68.138  91.327  21.978  1.00 33.20           N  \\nATOM   6280  CA  ARG A  72      68.346  90.613  23.239  1.00 33.20           C  \\nATOM   6281  C   ARG A  72      67.722  91.303  24.439  1.00 33.20           C  \\nATOM   6282  O   ARG A  72      67.181  90.627  25.310  1.00 33.20           O  \\nATOM   6283  CB  ARG A  72      69.829  90.404  23.487  1.00 31.62           C  \\nATOM   6284  CG  ARG A  72      70.449  89.476  22.505  1.00 31.62           C  \\nATOM   6285  CD  ARG A  72      71.908  89.411  22.741  1.00 31.62           C  \\nATOM   6286  NE  ARG A  72      72.546  88.669  21.671  1.00 31.62           N  \\nATOM   6287  CZ  ARG A  72      72.569  87.346  21.625  1.00 31.62           C  \\nATOM   6288  NH1 ARG A  72      71.990  86.649  22.610  1.00 31.62           N  \\nATOM   6289  NH2 ARG A  72      73.129  86.721  20.588  1.00 31.62           N  \\nATOM   6290  N   GLU A  73      67.825  92.637  24.492  1.00 34.93           N  \\nATOM   6291  CA  GLU A  73      67.256  93.422  25.583  1.00 34.93           C  \\nATOM   6292  C   GLU A  73      65.762  93.216  25.658  1.00 34.93           C  \\nATOM   6293  O   GLU A  73      65.236  92.946  26.740  1.00 34.93           O  \\nATOM   6294  CB  GLU A  73      67.542  94.916  25.424  1.00 61.50           C  \\nATOM   6295  CG  GLU A  73      66.894  95.772  26.525  1.00 61.50           C  \\nATOM   6296  CD  GLU A  73      66.830  97.256  26.183  1.00 61.50           C  \\nATOM   6297  OE1 GLU A  73      67.829  97.965  26.424  1.00 61.50           O  \\nATOM   6298  OE2 GLU A  73      65.779  97.719  25.679  1.00 61.50           O  \\nATOM   6299  N   ILE A  74      65.080  93.339  24.515  1.00 41.09           N  \\nATOM   6300  CA  ILE A  74      63.625  93.166  24.455  1.00 41.09           C  \\nATOM   6301  C   ILE A  74      63.215  91.752  24.831  1.00 41.09           C  \\nATOM   6302  O   ILE A  74      62.276  91.551  25.616  1.00 41.09           O  \\nATOM   6303  CB  ILE A  74      63.071  93.422  23.058  1.00 17.06           C  \\nATOM   6304  CG1 ILE A  74      63.276  94.876  22.640  1.00 17.06           C  \\nATOM   6305  CG2 ILE A  74      61.607  93.080  23.012  1.00 17.06           C  \\nATOM   6306  CD1 ILE A  74      63.088  95.090  21.146  1.00 17.06           C  \\nATOM   6307  N   ALA A  75      63.897  90.771  24.245  1.00 20.97           N  \\nATOM   6308  CA  ALA A  75      63.611  89.367  24.523  1.00 20.97           C  \\nATOM   6309  C   ALA A  75      63.674  88.985  26.019  1.00 20.97           C  \\nATOM   6310  O   ALA A  75      62.897  88.147  26.483  1.00 20.97           O  \\nATOM   6311  CB  ALA A  75      64.529  88.493  23.699  1.00 12.53           C  \\nATOM   6312  N   GLN A  76      64.618  89.570  26.759  1.00 41.77           N  \\nATOM   6313  CA  GLN A  76      64.766  89.309  28.197  1.00 41.77           C  \\nATOM   6314  C   GLN A  76      63.467  89.557  28.973  1.00 41.77           C  \\nATOM   6315  O   GLN A  76      63.231  88.919  30.007  1.00 41.77           O  \\nATOM   6316  CB  GLN A  76      65.890  90.169  28.785  1.00 57.41           C  \\nATOM   6317  CG  GLN A  76      66.298  89.801  30.217  1.00 57.41           C  \\nATOM   6318  CD  GLN A  76      67.035  88.474  30.318  1.00 57.41           C  \\nATOM   6319  OE1 GLN A  76      67.027  87.646  29.398  1.00 57.41           O  \\nATOM   6320  NE2 GLN A  76      67.665  88.263  31.451  1.00 57.41           N  \\nATOM   6321  N   ASP A  77      62.656  90.506  28.489  1.00 36.47           N  \\nATOM   6322  CA  ASP A  77      61.368  90.830  29.101  1.00 36.47           C  \\nATOM   6323  C   ASP A  77      60.439  89.652  28.950  1.00 36.47           C  \\nATOM   6324  O   ASP A  77      59.582  89.446  29.786  1.00 36.47           O  \\nATOM   6325  CB  ASP A  77      60.708  92.025  28.416  1.00 84.41           C  \\nATOM   6326  CG  ASP A  77      61.380  93.331  28.742  1.00 84.41           C  \\nATOM   6327  OD1 ASP A  77      61.716  93.549  29.929  1.00 84.41           O  \\nATOM   6328  OD2 ASP A  77      61.553  94.147  27.808  1.00 84.41           O  \\nATOM   6329  N   PHE A  78      60.623  88.882  27.877  1.00 30.32           N  \\nATOM   6330  CA  PHE A  78      59.786  87.713  27.579  1.00 30.32           C  \\nATOM   6331  C   PHE A  78      60.191  86.393  28.264  1.00 30.32           C  \\nATOM   6332  O   PHE A  78      59.342  85.599  28.685  1.00 30.32           O  \\nATOM   6333  CB  PHE A  78      59.683  87.542  26.055  1.00 44.69           C  \\nATOM   6334  CG  PHE A  78      59.082  88.744  25.342  1.00 44.69           C  \\nATOM   6335  CD1 PHE A  78      58.019  89.462  25.914  1.00 44.69           C  \\nATOM   6336  CD2 PHE A  78      59.576  89.154  24.103  1.00 44.69           C  \\nATOM   6337  CE1 PHE A  78      57.463  90.565  25.268  1.00 44.69           C  \\nATOM   6338  CE2 PHE A  78      59.026  90.256  23.449  1.00 44.69           C  \\nATOM   6339  CZ  PHE A  78      57.967  90.964  24.034  1.00 44.69           C  \\nATOM   6340  N   LYS A  79      61.486  86.124  28.286  1.00 35.07           N  \\nATOM   6341  CA  LYS A  79      62.014  84.939  28.942  1.00 35.07           C  \\nATOM   6342  C   LYS A  79      63.497  85.162  29.162  1.00 35.07           C  \\nATOM   6343  O   LYS A  79      64.196  85.686  28.287  1.00 35.07           O  \\nATOM   6344  CB  LYS A  79      61.788  83.686  28.123  1.00 56.97           C  \\nATOM   6345  CG  LYS A  79      62.194  82.452  28.884  1.00 56.97           C  \\nATOM   6346  CD  LYS A  79      62.137  81.215  28.028  1.00 56.97           C  \\nATOM   6347  CE  LYS A  79      62.841  80.065  28.712  1.00 56.97           C  \\nATOM   6348  NZ  LYS A  79      62.923  78.913  27.775  1.00 56.97           N  \\nATOM   6349  N   THR A  80      63.971  84.800  30.348  1.00 52.81           N  \\nATOM   6350  CA  THR A  80      65.369  84.992  30.695  1.00 52.81           C  \\nATOM   6351  C   THR A  80      66.318  83.876  30.313  1.00 52.81           C  \\nATOM   6352  O   THR A  80      65.929  82.706  30.183  1.00 52.81           O  \\nATOM   6353  CB  THR A  80      65.527  85.259  32.170  1.00 41.91           C  \\nATOM   6354  OG1 THR A  80      64.689  84.353  32.898  1.00 41.91           O  \\nATOM   6355  CG2 THR A  80      65.149  86.678  32.483  1.00 41.91           C  \\nATOM   6356  N   ASP A  81      67.583  84.277  30.186  1.00 52.49           N  \\nATOM   6357  CA  ASP A  81      68.700  83.412  29.816  1.00 52.49           C  \\nATOM   6358  C   ASP A  81      68.443  82.743  28.487  1.00 52.49           C  \\nATOM   6359  O   ASP A  81      68.246  81.531  28.398  1.00 52.49           O  \\nATOM   6360  CB  ASP A  81      69.004  82.376  30.897  1.00 67.39           C  \\nATOM   6361  CG  ASP A  81      70.358  81.721  30.704  1.00 67.39           C  \\nATOM   6362  OD1 ASP A  81      71.208  82.262  29.942  1.00 67.39           O  \\nATOM   6363  OD2 ASP A  81      70.568  80.661  31.326  1.00 67.39           O  \\nATOM   6364  N   LEU A  82      68.440  83.565  27.451  1.00 26.75           N  \\nATOM   6365  CA  LEU A  82      68.190  83.083  26.109  1.00 26.75           C  \\nATOM   6366  C   LEU A  82      69.355  83.200  25.136  1.00 26.75           C  \\nATOM   6367  O   LEU A  82      70.113  84.166  25.154  1.00 26.75           O  \\nATOM   6368  CB  LEU A  82      66.966  83.793  25.525  1.00 39.45           C  \\nATOM   6369  CG  LEU A  82      65.602  83.325  26.016  1.00 39.45           C  \\nATOM   6370  CD1 LEU A  82      64.508  84.165  25.413  1.00 39.45           C  \\nATOM   6371  CD2 LEU A  82      65.423  81.884  25.619  1.00 39.45           C  \\nATOM   6372  N   ARG A  83      69.542  82.164  24.338  1.00 31.29           N  \\nATOM   6373  CA  ARG A  83      70.579  82.218  23.342  1.00 31.29           C  \\nATOM   6374  C   ARG A  83      69.841  82.498  22.035  1.00 31.29           C  \\nATOM   6375  O   ARG A  83      68.650  82.173  21.893  1.00 31.29           O  \\nATOM   6376  CB  ARG A  83      71.367  80.909  23.266  1.00112.49           C  \\nATOM   6377  CG  ARG A  83      72.220  80.602  24.491  1.00112.49           C  \\nATOM   6378  CD  ARG A  83      73.280  79.563  24.162  1.00112.49           C  \\nATOM   6379  NE  ARG A  83      72.724  78.471  23.361  1.00112.49           N  \\nATOM   6380  CZ  ARG A  83      73.440  77.547  22.721  1.00112.49           C  \\nATOM   6381  NH1 ARG A  83      74.768  77.556  22.769  1.00112.49           N  \\nATOM   6382  NH2 ARG A  83      72.814  76.617  22.012  1.00112.49           N  \\nATOM   6383  N   PHE A  84      70.525  83.178  21.123  1.00 50.30           N  \\nATOM   6384  CA  PHE A  84      69.979  83.519  19.820  1.00 50.30           C  \\nATOM   6385  C   PHE A  84      70.843  82.973  18.692  1.00 50.30           C  \\nATOM   6386  O   PHE A  84      72.015  83.341  18.509  1.00 50.30           O  \\nATOM   6387  CB  PHE A  84      69.845  85.036  19.659  1.00 38.50           C  \\nATOM   6388  CG  PHE A  84      68.523  85.580  20.094  1.00 38.50           C  \\nATOM   6389  CD1 PHE A  84      67.467  85.666  19.197  1.00 38.50           C  \\nATOM   6390  CD2 PHE A  84      68.323  86.001  21.402  1.00 38.50           C  \\nATOM   6391  CE1 PHE A  84      66.227  86.164  19.602  1.00 38.50           C  \\nATOM   6392  CE2 PHE A  84      67.087  86.498  21.814  1.00 38.50           C  \\nATOM   6393  CZ  PHE A  84      66.040  86.576  20.911  1.00 38.50           C  \\nATOM   6394  N   GLN A  85      70.232  82.107  17.912  1.00 24.04           N  \\nATOM   6395  CA  GLN A  85      70.878  81.515  16.774  1.00 24.04           C  \\nATOM   6396  C   GLN A  85      71.339  82.711  15.892  1.00 24.04           C  \\nATOM   6397  O   GLN A  85      70.632  83.709  15.752  1.00 24.04           O  \\nATOM   6398  CB  GLN A  85      69.822  80.641  16.100  1.00 24.74           C  \\nATOM   6399  CG  GLN A  85      70.326  79.677  15.121  1.00 24.74           C  \\nATOM   6400  CD  GLN A  85      69.406  78.488  14.987  1.00 24.74           C  \\nATOM   6401  OE1 GLN A  85      68.503  78.487  14.141  1.00 24.74           O  \\nATOM   6402  NE2 GLN A  85      69.619  77.460  15.828  1.00 24.74           N  \\nATOM   6403  N   SER A  86      72.562  82.666  15.382  1.00 27.51           N  \\nATOM   6404  CA  SER A  86      73.084  83.748  14.537  1.00 27.51           C  \\nATOM   6405  C   SER A  86      72.109  84.077  13.430  1.00 27.51           C  \\nATOM   6406  O   SER A  86      71.916  85.238  13.089  1.00 27.51           O  \\nATOM   6407  CB  SER A  86      74.405  83.337  13.907  1.00 49.92           C  \\nATOM   6408  OG  SER A  86      74.630  84.078  12.726  1.00 49.92           O  \\nATOM   6409  N   SER A  87      71.508  83.031  12.868  1.00 30.54           N  \\nATOM   6410  CA  SER A  87      70.528  83.167  11.783  1.00 30.54           C  \\nATOM   6411  C   SER A  87      69.203  83.804  12.237  1.00 30.54           C  \\nATOM   6412  O   SER A  87      68.555  84.501  11.453  1.00 30.54           O  \\nATOM   6413  CB  SER A  87      70.283  81.815  11.083  1.00 37.41           C  \\nATOM   6414  OG  SER A  87      70.703  80.707  11.869  1.00 37.41           O  \\nATOM   6415  N   ALA A  88      68.822  83.595  13.503  1.00 25.82           N  \\nATOM   6416  CA  ALA A  88      67.592  84.187  14.053  1.00 25.82           C  \\nATOM   6417  C   ALA A  88      67.713  85.704  14.044  1.00 25.82           C  \\nATOM   6418  O   ALA A  88      66.801  86.410  13.613  1.00 25.82           O  \\nATOM   6419  CB  ALA A  88      67.346  83.707  15.463  1.00 18.97           C  \\nATOM   6420  N   VAL A  89      68.863  86.196  14.496  1.00 20.15           N  \\nATOM   6421  CA  VAL A  89      69.108  87.629  14.522  1.00 20.15           C  \\nATOM   6422  C   VAL A  89      69.189  88.248  13.126  1.00 20.15           C  \\nATOM   6423  O   VAL A  89      68.607  89.299  12.884  1.00 20.15           O  \\nATOM   6424  CB  VAL A  89      70.339  87.986  15.337  1.00 10.54           C  \\nATOM   6425  CG1 VAL A  89      70.506  89.498  15.345  1.00 10.54           C  \\nATOM   6426  CG2 VAL A  89      70.171  87.477  16.758  1.00 10.54           C  \\nATOM   6427  N   MET A  90      69.918  87.619  12.211  1.00 38.44           N  \\nATOM   6428  CA  MET A  90      69.983  88.138  10.856  1.00 38.44           C  \\nATOM   6429  C   MET A  90      68.547  88.230  10.304  1.00 38.44           C  \\nATOM   6430  O   MET A  90      68.169  89.232   9.706  1.00 38.44           O  \\nATOM   6431  CB  MET A  90      70.825  87.226   9.975  1.00 62.99           C  \\nATOM   6432  CG  MET A  90      72.263  87.649   9.807  1.00 62.99           C  \\nATOM   6433  SD  MET A  90      73.044  86.567   8.584  1.00 62.99           S  \\nATOM   6434  CE  MET A  90      72.411  87.289   6.968  1.00 62.99           C  \\nATOM   6435  N   ALA A  91      67.736  87.198  10.528  1.00 51.18           N  \\nATOM   6436  CA  ALA A  91      66.348  87.205  10.068  1.00 51.18           C  \\nATOM   6437  C   ALA A  91      65.600  88.426  10.606  1.00 51.18           C  \\nATOM   6438  O   ALA A  91      65.034  89.190   9.826  1.00 51.18           O  \\nATOM   6439  CB  ALA A  91      65.652  85.936  10.491  1.00 13.60           C  \\nATOM   6440  N   LEU A  92      65.597  88.605  11.930  1.00 26.26           N  \\nATOM   6441  CA  LEU A  92      64.940  89.758  12.544  1.00 26.26           C  \\nATOM   6442  C   LEU A  92      65.439  91.075  11.953  1.00 26.26           C  \\nATOM   6443  O   LEU A  92      64.641  91.963  11.679  1.00 26.26           O  \\nATOM   6444  CB  LEU A  92      65.154  89.775  14.052  1.00 18.67           C  \\nATOM   6445  CG  LEU A  92      64.309  88.820  14.910  1.00 18.67           C  \\nATOM   6446  CD1 LEU A  92      64.851  88.762  16.311  1.00 18.67           C  \\nATOM   6447  CD2 LEU A  92      62.872  89.267  14.943  1.00 18.67           C  \\nATOM   6448  N   GLN A  93      66.744  91.209  11.730  1.00  9.93           N  \\nATOM   6449  CA  GLN A  93      67.235  92.434  11.150  1.00  9.93           C  \\nATOM   6450  C   GLN A  93      66.741  92.622   9.738  1.00  9.93           C  \\nATOM   6451  O   GLN A  93      66.317  93.706   9.371  1.00  9.93           O  \\nATOM   6452  CB  GLN A  93      68.743  92.519  11.194  1.00 20.57           C  \\nATOM   6453  CG  GLN A  93      69.252  93.842  10.666  1.00 20.57           C  \\nATOM   6454  CD  GLN A  93      70.608  94.210  11.210  1.00 20.57           C  \\nATOM   6455  OE1 GLN A  93      71.150  93.526  12.088  1.00 20.57           O  \\nATOM   6456  NE2 GLN A  93      71.169  95.307  10.695  1.00 20.57           N  \\nATOM   6457  N   GLU A  94      66.772  91.574   8.938  1.00 19.06           N  \\nATOM   6458  CA  GLU A  94      66.267  91.664   7.580  1.00 19.06           C  \\nATOM   6459  C   GLU A  94      64.806  92.124   7.586  1.00 19.06           C  \\nATOM   6460  O   GLU A  94      64.454  93.082   6.902  1.00 19.06           O  \\nATOM   6461  CB  GLU A  94      66.346  90.301   6.921  1.00 27.58           C  \\nATOM   6462  CG  GLU A  94      67.725  89.903   6.486  1.00 27.58           C  \\nATOM   6463  CD  GLU A  94      68.116  90.502   5.155  1.00 27.58           C  \\nATOM   6464  OE1 GLU A  94      67.246  90.769   4.297  1.00 27.58           O  \\nATOM   6465  OE2 GLU A  94      69.324  90.703   4.954  1.00 27.58           O  \\nATOM   6466  N   ALA A  95      63.970  91.453   8.376  1.00 29.50           N  \\nATOM   6467  CA  ALA A  95      62.560  91.793   8.474  1.00 29.50           C  \\nATOM   6468  C   ALA A  95      62.331  93.220   8.943  1.00 29.50           C  \\nATOM   6469  O   ALA A  95      61.551  93.950   8.347  1.00 29.50           O  \\nATOM   6470  CB  ALA A  95      61.847  90.834   9.387  1.00  5.00           C  \\nATOM   6471  N   SER A  96      63.011  93.624  10.007  1.00 13.19           N  \\nATOM   6472  CA  SER A  96      62.874  94.976  10.552  1.00 13.19           C  \\nATOM   6473  C   SER A  96      63.195  96.053   9.544  1.00 13.19           C  \\nATOM   6474  O   SER A  96      62.379  96.906   9.263  1.00 13.19           O  \\nATOM   6475  CB  SER A  96      63.753  95.134  11.779  1.00 21.66           C  \\nATOM   6476  OG  SER A  96      63.344  94.210  12.778  1.00 21.66           O  \\nATOM   6477  N   GLU A  97      64.373  95.989   8.946  1.00 12.43           N  \\nATOM   6478  CA  GLU A  97      64.730  96.983   7.951  1.00 12.43           C  \\nATOM   6479  C   GLU A  97      63.745  96.973   6.785  1.00 12.43           C  \\nATOM   6480  O   GLU A  97      63.277  98.015   6.373  1.00 12.43           O  \\nATOM   6481  CB  GLU A  97      66.151  96.759   7.480  1.00 29.48           C  \\nATOM   6482  CG  GLU A  97      67.163  96.996   8.574  1.00 29.48           C  \\nATOM   6483  CD  GLU A  97      68.542  97.184   8.016  1.00 29.48           C  \\nATOM   6484  OE1 GLU A  97      68.636  97.710   6.881  1.00 29.48           O  \\nATOM   6485  OE2 GLU A  97      69.523  96.805   8.695  1.00 29.48           O  \\nATOM   6486  N   ALA A  98      63.421  95.796   6.266  1.00 17.19           N  \\nATOM   6487  CA  ALA A  98      62.460  95.683   5.176  1.00 17.19           C  \\nATOM   6488  C   ALA A  98      61.197  96.444   5.566  1.00 17.19           C  \\nATOM   6489  O   ALA A  98      60.623  97.178   4.758  1.00 17.19           O  \\nATOM   6490  CB  ALA A  98      62.126  94.205   4.922  1.00 10.58           C  \\nATOM   6491  N   TYR A  99      60.801  96.284   6.826  1.00 27.15           N  \\nATOM   6492  CA  TYR A  99      59.629  96.936   7.387  1.00 27.15           C  \\nATOM   6493  C   TYR A  99      59.754  98.453   7.415  1.00 27.15           C  \\nATOM   6494  O   TYR A  99      58.868  99.156   6.939  1.00 27.15           O  \\nATOM   6495  CB  TYR A  99      59.383  96.403   8.792  1.00 16.67           C  \\nATOM   6496  CG  TYR A  99      58.404  97.226   9.558  1.00 16.67           C  \\nATOM   6497  CD1 TYR A  99      57.062  97.272   9.192  1.00 16.67           C  \\nATOM   6498  CD2 TYR A  99      58.806  97.991  10.626  1.00 16.67           C  \\nATOM   6499  CE1 TYR A  99      56.143  98.063   9.876  1.00 16.67           C  \\nATOM   6500  CE2 TYR A  99      57.892  98.788  11.314  1.00 16.67           C  \\nATOM   6501  CZ  TYR A  99      56.568  98.812  10.931  1.00 16.67           C  \\nATOM   6502  OH  TYR A  99      55.683  99.590  11.630  1.00 16.67           O  \\nATOM   6503  N   LEU A 100      60.835  98.942   8.009  1.00 12.09           N  \\nATOM   6504  CA  LEU A 100      61.103 100.365   8.104  1.00 12.09           C  \\nATOM   6505  C   LEU A 100      61.220 101.048   6.759  1.00 12.09           C  \\nATOM   6506  O   LEU A 100      60.610 102.080   6.534  1.00 12.09           O  \\nATOM   6507  CB  LEU A 100      62.368 100.614   8.905  1.00 17.79           C  \\nATOM   6508  CG  LEU A 100      62.141 100.291  10.384  1.00 17.79           C  \\nATOM   6509  CD1 LEU A 100      63.400 100.532  11.188  1.00 17.79           C  \\nATOM   6510  CD2 LEU A 100      60.998 101.154  10.909  1.00 17.79           C  \\nATOM   6511  N   VAL A 101      61.987 100.476   5.848  1.00 26.76           N  \\nATOM   6512  CA  VAL A 101      62.138 101.076   4.539  1.00 26.76           C  \\nATOM   6513  C   VAL A 101      60.795 101.375   3.902  1.00 26.76           C  \\nATOM   6514  O   VAL A 101      60.593 102.488   3.418  1.00 26.76           O  \\nATOM   6515  CB  VAL A 101      62.944 100.176   3.603  1.00  7.17           C  \\nATOM   6516  CG1 VAL A 101      62.840 100.678   2.162  1.00  7.17           C  \\nATOM   6517  CG2 VAL A 101      64.395 100.130   4.071  1.00  7.17           C  \\nATOM   6518  N   ALA A 102      59.880 100.396   3.920  1.00 17.92           N  \\nATOM   6519  CA  ALA A 102      58.535 100.551   3.328  1.00 17.92           C  \\nATOM   6520  C   ALA A 102      57.679 101.560   4.075  1.00 17.92           C  \\nATOM   6521  O   ALA A 102      56.903 102.303   3.478  1.00 17.92           O  \\nATOM   6522  CB  ALA A 102      57.845  99.239   3.261  1.00  5.00           C  \\nATOM   6523  N   LEU A 103      57.798 101.563   5.390  1.00 15.01           N  \\nATOM   6524  CA  LEU A 103      57.069 102.539   6.178  1.00 15.01           C  \\nATOM   6525  C   LEU A 103      57.550 103.929   5.740  1.00 15.01           C  \\nATOM   6526  O   LEU A 103      56.753 104.861   5.650  1.00 15.01           O  \\nATOM   6527  CB  LEU A 103      57.292 102.322   7.685  1.00 12.43           C  \\nATOM   6528  CG  LEU A 103      56.518 103.267   8.608  1.00 12.43           C  \\nATOM   6529  CD1 LEU A 103      55.013 103.117   8.422  1.00 12.43           C  \\nATOM   6530  CD2 LEU A 103      56.901 102.992  10.028  1.00 12.43           C  \\nATOM   6531  N   PHE A 104      58.850 104.072   5.473  1.00 20.53           N  \\nATOM   6532  CA  PHE A 104      59.382 105.350   4.993  1.00 20.53           C  \\nATOM   6533  C   PHE A 104      58.804 105.659   3.598  1.00 20.53           C  \\nATOM   6534  O   PHE A 104      58.569 106.806   3.273  1.00 20.53           O  \\nATOM   6535  CB  PHE A 104      60.920 105.366   5.000  1.00 11.05           C  \\nATOM   6536  CG  PHE A 104      61.535 105.626   6.378  1.00 11.05           C  \\nATOM   6537  CD1 PHE A 104      61.223 106.779   7.102  1.00 11.05           C  \\nATOM   6538  CD2 PHE A 104      62.409 104.711   6.958  1.00 11.05           C  \\nATOM   6539  CE1 PHE A 104      61.755 107.016   8.379  1.00 11.05           C  \\nATOM   6540  CE2 PHE A 104      62.951 104.946   8.244  1.00 11.05           C  \\nATOM   6541  CZ  PHE A 104      62.616 106.106   8.946  1.00 11.05           C  \\nATOM   6542  N   GLU A 105      58.495 104.642   2.799  1.00 22.12           N  \\nATOM   6543  CA  GLU A 105      57.896 104.886   1.483  1.00 22.12           C  \\nATOM   6544  C   GLU A 105      56.550 105.546   1.670  1.00 22.12           C  \\nATOM   6545  O   GLU A 105      56.316 106.666   1.224  1.00 22.12           O  \\nATOM   6546  CB  GLU A 105      57.701 103.585   0.719  1.00 35.59           C  \\nATOM   6547  CG  GLU A 105      58.994 102.997   0.231  1.00 35.59           C  \\nATOM   6548  CD  GLU A 105      58.832 101.681  -0.493  1.00 35.59           C  \\nATOM   6549  OE1 GLU A 105      57.776 101.451  -1.135  1.00 35.59           O  \\nATOM   6550  OE2 GLU A 105      59.788 100.881  -0.431  1.00 35.59           O  \\nATOM   6551  N   ASP A 106      55.679 104.853   2.380  1.00 30.69           N  \\nATOM   6552  CA  ASP A 106      54.348 105.355   2.636  1.00 30.69           C  \\nATOM   6553  C   ASP A 106      54.414 106.720   3.287  1.00 30.69           C  \\nATOM   6554  O   ASP A 106      53.724 107.645   2.855  1.00 30.69           O  \\nATOM   6555  CB  ASP A 106      53.585 104.382   3.526  1.00 26.48           C  \\nATOM   6556  CG  ASP A 106      53.364 103.029   2.861  1.00 26.48           C  \\nATOM   6557  OD1 ASP A 106      53.423 102.938   1.599  1.00 26.48           O  \\nATOM   6558  OD2 ASP A 106      53.137 102.059   3.621  1.00 26.48           O  \\nATOM   6559  N   THR A 107      55.249 106.845   4.322  1.00 19.57           N  \\nATOM   6560  CA  THR A 107      55.429 108.111   5.053  1.00 19.57           C  \\nATOM   6561  C   THR A 107      55.712 109.250   4.061  1.00 19.57           C  \\nATOM   6562  O   THR A 107      55.131 110.333   4.150  1.00 19.57           O  \\nATOM   6563  CB  THR A 107      56.603 108.013   6.065  1.00 10.91           C  \\nATOM   6564  OG1 THR A 107      56.327 107.010   7.059  1.00 10.91           O  \\nATOM   6565  CG2 THR A 107      56.857 109.353   6.727  1.00 10.91           C  \\nATOM   6566  N   ASN A 108      56.560 108.970   3.075  1.00 23.14           N  \\nATOM   6567  CA  ASN A 108      56.913 109.957   2.083  1.00 23.14           C  \\nATOM   6568  C   ASN A 108      55.690 110.432   1.355  1.00 23.14           C  \\nATOM   6569  O   ASN A 108      55.487 111.631   1.216  1.00 23.14           O  \\nATOM   6570  CB  ASN A 108      57.919 109.401   1.088  1.00 20.45           C  \\nATOM   6571  CG  ASN A 108      58.955 110.426   0.705  1.00 20.45           C  \\nATOM   6572  OD1 ASN A 108      59.286 111.294   1.511  1.00 20.45           O  \\nATOM   6573  ND2 ASN A 108      59.471 110.345  -0.514  1.00 20.45           N  \\nATOM   6574  N   LEU A 109      54.883 109.491   0.880  1.00 19.44           N  \\nATOM   6575  CA  LEU A 109      53.647 109.823   0.167  1.00 19.44           C  \\nATOM   6576  C   LEU A 109      52.735 110.725   0.996  1.00 19.44           C  \\nATOM   6577  O   LEU A 109      52.092 111.621   0.463  1.00 19.44           O  \\nATOM   6578  CB  LEU A 109      52.897 108.556  -0.219  1.00 14.09           C  \\nATOM   6579  CG  LEU A 109      53.730 107.628  -1.096  1.00 14.09           C  \\nATOM   6580  CD1 LEU A 109      52.976 106.341  -1.385  1.00 14.09           C  \\nATOM   6581  CD2 LEU A 109      54.083 108.370  -2.394  1.00 14.09           C  \\nATOM   6582  N   CYS A 110      52.648 110.463   2.291  1.00 14.96           N  \\nATOM   6583  CA  CYS A 110      51.836 111.292   3.147  1.00 14.96           C  \\nATOM   6584  C   CYS A 110      52.346 112.728   3.156  1.00 14.96           C  \\nATOM   6585  O   CYS A 110      51.579 113.671   2.930  1.00 14.96           O  \\nATOM   6586  CB  CYS A 110      51.823 110.741   4.560  1.00 17.45           C  \\nATOM   6587  SG  CYS A 110      50.854 109.266   4.653  1.00 17.45           S  \\nATOM   6588  N   ALA A 111      53.641 112.892   3.418  1.00 22.03           N  \\nATOM   6589  CA  ALA A 111      54.258 114.213   3.445  1.00 22.03           C  \\nATOM   6590  C   ALA A 111      54.025 114.943   2.130  1.00 22.03           C  \\nATOM   6591  O   ALA A 111      53.649 116.115   2.096  1.00 22.03           O  \\nATOM   6592  CB  ALA A 111      55.716 114.075   3.702  1.00  9.33           C  \\nATOM   6593  N   ILE A 112      54.249 114.242   1.039  1.00 15.55           N  \\nATOM   6594  CA  ILE A 112      54.047 114.820  -0.263  1.00 15.55           C  \\nATOM   6595  C   ILE A 112      52.575 115.141  -0.454  1.00 15.55           C  \\nATOM   6596  O   ILE A 112      52.214 116.174  -1.033  1.00 15.55           O  \\nATOM   6597  CB  ILE A 112      54.533 113.853  -1.334  1.00 14.57           C  \\nATOM   6598  CG1 ILE A 112      55.991 113.492  -1.031  1.00 14.57           C  \\nATOM   6599  CG2 ILE A 112      54.396 114.462  -2.714  1.00 14.57           C  \\nATOM   6600  CD1 ILE A 112      56.612 112.611  -2.047  1.00 14.57           C  \\nATOM   6601  N   HIS A 113      51.714 114.271   0.051  1.00 26.92           N  \\nATOM   6602  CA  HIS A 113      50.287 114.498  -0.068  1.00 26.92           C  \\nATOM   6603  C   HIS A 113      49.970 115.866   0.524  1.00 26.92           C  \\nATOM   6604  O   HIS A 113      49.105 116.602   0.031  1.00 26.92           O  \\nATOM   6605  CB  HIS A 113      49.518 113.429   0.694  1.00 18.28           C  \\nATOM   6606  CG  HIS A 113      48.040 113.498   0.482  1.00 18.28           C  \\nATOM   6607  ND1 HIS A 113      47.159 113.831   1.490  1.00 18.28           N  \\nATOM   6608  CD2 HIS A 113      47.287 113.271  -0.619  1.00 18.28           C  \\nATOM   6609  CE1 HIS A 113      45.925 113.806   1.021  1.00 18.28           C  \\nATOM   6610  NE2 HIS A 113      45.975 113.468  -0.256  1.00 18.28           N  \\nATOM   6611  N   ALA A 114      50.656 116.167   1.616  1.00 18.46           N  \\nATOM   6612  CA  ALA A 114      50.484 117.423   2.296  1.00 18.46           C  \\nATOM   6613  C   ALA A 114      51.389 118.533   1.750  1.00 18.46           C  \\nATOM   6614  O   ALA A 114      51.749 119.488   2.458  1.00 18.46           O  \\nATOM   6615  CB  ALA A 114      50.667 117.233   3.770  1.00  5.00           C  \\nATOM   6616  N   LYS A 115      51.701 118.433   0.464  1.00 30.35           N  \\nATOM   6617  CA  LYS A 115      52.512 119.429  -0.209  1.00 30.35           C  \\nATOM   6618  C   LYS A 115      53.854 119.669   0.466  1.00 30.35           C  \\nATOM   6619  O   LYS A 115      54.358 120.789   0.482  1.00 30.35           O  \\nATOM   6620  CB  LYS A 115      51.734 120.740  -0.335  1.00 79.74           C  \\nATOM   6621  CG  LYS A 115      50.431 120.607  -1.105  1.00 79.74           C  \\nATOM   6622  CD  LYS A 115      49.632 121.889  -1.049  1.00 79.74           C  \\nATOM   6623  CE  LYS A 115      48.333 121.758  -1.810  1.00 79.74           C  \\nATOM   6624  NZ  LYS A 115      47.567 123.040  -1.824  1.00 79.74           N  \\nATOM   6625  N   ARG A 116      54.415 118.630   1.075  1.00 18.65           N  \\nATOM   6626  CA  ARG A 116      55.720 118.767   1.708  1.00 18.65           C  \\nATOM   6627  C   ARG A 116      56.756 117.887   1.022  1.00 18.65           C  \\nATOM   6628  O   ARG A 116      56.468 117.196   0.048  1.00 18.65           O  \\nATOM   6629  CB  ARG A 116      55.651 118.486   3.221  1.00 31.71           C  \\nATOM   6630  CG  ARG A 116      55.060 119.629   4.030  1.00 31.71           C  \\nATOM   6631  CD  ARG A 116      55.110 119.369   5.510  1.00 31.71           C  \\nATOM   6632  NE  ARG A 116      54.019 118.509   5.969  1.00 31.71           N  \\nATOM   6633  CZ  ARG A 116      54.157 117.248   6.390  1.00 31.71           C  \\nATOM   6634  NH1 ARG A 116      55.343 116.658   6.406  1.00 31.71           N  \\nATOM   6635  NH2 ARG A 116      53.107 116.580   6.851  1.00 31.71           N  \\nATOM   6636  N   VAL A 117      57.970 117.968   1.544  1.00 27.74           N  \\nATOM   6637  CA  VAL A 117      59.135 117.250   1.059  1.00 27.74           C  \\nATOM   6638  C   VAL A 117      59.861 116.659   2.277  1.00 27.74           C  \\nATOM   6639  O   VAL A 117      60.673 115.720   2.175  1.00 27.74           O  \\nATOM   6640  CB  VAL A 117      60.054 118.250   0.352  1.00 18.19           C  \\nATOM   6641  CG1 VAL A 117      61.434 117.680   0.217  1.00 18.19           C  \\nATOM   6642  CG2 VAL A 117      59.481 118.597  -1.009  1.00 18.19           C  \\nATOM   6643  N   THR A 118      59.610 117.306   3.409  1.00 32.53           N  \\nATOM   6644  CA  THR A 118      60.149 116.930   4.703  1.00 32.53           C  \\nATOM   6645  C   THR A 118      59.166 116.028   5.452  1.00 32.53           C  \\nATOM   6646  O   THR A 118      58.083 116.474   5.831  1.00 32.53           O  \\nATOM   6647  CB  THR A 118      60.344 118.190   5.577  1.00 15.25           C  \\nATOM   6648  OG1 THR A 118      60.900 119.248   4.783  1.00 15.25           O  \\nATOM   6649  CG2 THR A 118      61.234 117.885   6.779  1.00 15.25           C  \\nATOM   6650  N   ILE A 119      59.542 114.776   5.688  1.00 27.40           N  \\nATOM   6651  CA  ILE A 119      58.667 113.876   6.431  1.00 27.40           C  \\nATOM   6652  C   ILE A 119      58.766 114.183   7.928  1.00 27.40           C  \\nATOM   6653  O   ILE A 119      59.848 114.447   8.445  1.00 27.40           O  \\nATOM   6654  CB  ILE A 119      59.027 112.414   6.216  1.00 10.86           C  \\nATOM   6655  CG1 ILE A 119      60.459 112.170   6.677  1.00 10.86           C  \\nATOM   6656  CG2 ILE A 119      58.805 112.038   4.768  1.00 10.86           C  \\nATOM   6657  CD1 ILE A 119      60.823 110.703   6.963  1.00 10.86           C  \\nATOM   6658  N   MET A 120      57.624 114.178   8.604  1.00 16.70           N  \\nATOM   6659  CA  MET A 120      57.551 114.455  10.030  1.00 16.70           C  \\nATOM   6660  C   MET A 120      56.793 113.336  10.731  1.00 16.70           C  \\nATOM   6661  O   MET A 120      56.288 112.417  10.085  1.00 16.70           O  \\nATOM   6662  CB  MET A 120      56.841 115.801  10.293  1.00 26.53           C  \\nATOM   6663  CG  MET A 120      56.733 116.726   9.093  1.00 26.53           C  \\nATOM   6664  SD  MET A 120      56.342 118.427   9.514  1.00 26.53           S  \\nATOM   6665  CE  MET A 120      57.586 119.235   8.455  1.00 26.53           C  \\nATOM   6666  N   PRO A 121      56.719 113.392  12.072  1.00 25.85           N  \\nATOM   6667  CA  PRO A 121      56.009 112.364  12.828  1.00 25.85           C  \\nATOM   6668  C   PRO A 121      54.567 112.168  12.332  1.00 25.85           C  \\nATOM   6669  O   PRO A 121      54.118 111.022  12.197  1.00 25.85           O  \\nATOM   6670  CB  PRO A 121      56.054 112.918  14.251  1.00 45.14           C  \\nATOM   6671  CG  PRO A 121      57.362 113.631  14.274  1.00 45.14           C  \\nATOM   6672  CD  PRO A 121      57.317 114.382  12.988  1.00 45.14           C  \\nATOM   6673  N   LYS A 122      53.863 113.276  12.042  1.00 23.23           N  \\nATOM   6674  CA  LYS A 122      52.483 113.225  11.539  1.00 23.23           C  \\nATOM   6675  C   LYS A 122      52.385 112.195  10.409  1.00 23.23           C  \\nATOM   6676  O   LYS A 122      51.424 111.432  10.337  1.00 23.23           O  \\nATOM   6677  CB  LYS A 122      52.041 114.529  10.877  1.00 44.36           C  \\nATOM   6678  CG  LYS A 122      52.497 115.860  11.389  1.00 44.36           C  \\nATOM   6679  CD  LYS A 122      52.104 116.852  10.284  1.00 44.36           C  \\nATOM   6680  CE  LYS A 122      52.160 118.314  10.703  1.00 44.36           C  \\nATOM   6681  NZ  LYS A 122      51.937 119.212   9.501  1.00 44.36           N  \\nATOM   6682  N   ASP A 123      53.350 112.250   9.488  1.00 16.39           N  \\nATOM   6683  CA  ASP A 123      53.404 111.356   8.350  1.00 16.39           C  \\nATOM   6684  C   ASP A 123      53.564 109.909   8.760  1.00 16.39           C  \\nATOM   6685  O   ASP A 123      52.856 109.057   8.241  1.00 16.39           O  \\nATOM   6686  CB  ASP A 123      54.515 111.779   7.414  1.00 34.42           C  \\nATOM   6687  CG  ASP A 123      54.382 113.220   6.992  1.00 34.42           C  \\nATOM   6688  OD1 ASP A 123      53.390 113.570   6.342  1.00 34.42           O  \\nATOM   6689  OD2 ASP A 123      55.246 114.030   7.319  1.00 34.42           O  \\nATOM   6690  N   ILE A 124      54.467 109.593   9.682  1.00 20.35           N  \\nATOM   6691  CA  ILE A 124      54.573 108.190  10.090  1.00 20.35           C  \\nATOM   6692  C   ILE A 124      53.247 107.747  10.719  1.00 20.35           C  \\nATOM   6693  O   ILE A 124      52.676 106.744  10.321  1.00 20.35           O  \\nATOM   6694  CB  ILE A 124      55.729 107.918  11.079  1.00 32.31           C  \\nATOM   6695  CG1 ILE A 124      57.068 107.944  10.350  1.00 32.31           C  \\nATOM   6696  CG2 ILE A 124      55.584 106.531  11.714  1.00 32.31           C  \\nATOM   6697  CD1 ILE A 124      58.243 107.789  11.298  1.00 32.31           C  \\nATOM   6698  N   GLN A 125      52.721 108.552  11.636  1.00 29.36           N  \\nATOM   6699  CA  GLN A 125      51.467 108.257  12.332  1.00 29.36           C  \\nATOM   6700  C   GLN A 125      50.283 107.986  11.427  1.00 29.36           C  \\nATOM   6701  O   GLN A 125      49.596 106.991  11.593  1.00 29.36           O  \\nATOM   6702  CB  GLN A 125      51.145 109.393  13.277  1.00 45.90           C  \\nATOM   6703  CG  GLN A 125      52.205 109.564  14.331  1.00 45.90           C  \\nATOM   6704  CD  GLN A 125      52.073 110.856  15.066  1.00 45.90           C  \\nATOM   6705  OE1 GLN A 125      51.162 111.642  14.805  1.00 45.90           O  \\nATOM   6706  NE2 GLN A 125      52.993 111.104  15.985  1.00 45.90           N  \\nATOM   6707  N   LEU A 126      50.037 108.878  10.478  1.00 11.90           N  \\nATOM   6708  CA  LEU A 126      48.952 108.713   9.533  1.00 11.90           C  \\nATOM   6709  C   LEU A 126      49.120 107.358   8.852  1.00 11.90           C  \\nATOM   6710  O   LEU A 126      48.228 106.509   8.916  1.00 11.90           O  \\nATOM   6711  CB  LEU A 126      48.974 109.838   8.481  1.00  5.00           C  \\nATOM   6712  CG  LEU A 126      47.983 109.707   7.310  1.00  5.00           C  \\nATOM   6713  CD1 LEU A 126      46.577 109.841   7.865  1.00  5.00           C  \\nATOM   6714  CD2 LEU A 126      48.220 110.709   6.177  1.00  5.00           C  \\nATOM   6715  N   ALA A 127      50.285 107.135   8.244  1.00 16.60           N  \\nATOM   6716  CA  ALA A 127      50.547 105.879   7.559  1.00 16.60           C  \\nATOM   6717  C   ALA A 127      50.285 104.672   8.476  1.00 16.60           C  \\nATOM   6718  O   ALA A 127      49.551 103.778   8.121  1.00 16.60           O  \\nATOM   6719  CB  ALA A 127      51.947 105.873   7.005  1.00  5.00           C  \\nATOM   6720  N   ARG A 128      50.810 104.664   9.684  1.00 17.84           N  \\nATOM   6721  CA  ARG A 128      50.522 103.548  10.557  1.00 17.84           C  \\nATOM   6722  C   ARG A 128      49.009 103.394  10.791  1.00 17.84           C  \\nATOM   6723  O   ARG A 128      48.510 102.275  10.813  1.00 17.84           O  \\nATOM   6724  CB  ARG A 128      51.301 103.659  11.867  1.00 21.08           C  \\nATOM   6725  CG  ARG A 128      52.791 103.404  11.676  1.00 21.08           C  \\nATOM   6726  CD  ARG A 128      53.514 103.273  12.986  1.00 21.08           C  \\nATOM   6727  NE  ARG A 128      53.180 102.051  13.708  1.00 21.08           N  \\nATOM   6728  CZ  ARG A 128      52.955 102.003  15.021  1.00 21.08           C  \\nATOM   6729  NH1 ARG A 128      53.015 103.106  15.752  1.00 21.08           N  \\nATOM   6730  NH2 ARG A 128      52.742 100.846  15.633  1.00 21.08           N  \\nATOM   6731  N   ARG A 129      48.269 104.498  10.938  1.00 18.14           N  \\nATOM   6732  CA  ARG A 129      46.806 104.425  11.115  1.00 18.14           C  \\nATOM   6733  C   ARG A 129      46.124 103.710   9.942  1.00 18.14           C  \\nATOM   6734  O   ARG A 129      45.473 102.684  10.106  1.00 18.14           O  \\nATOM   6735  CB  ARG A 129      46.218 105.815  11.275  1.00126.87           C  \\nATOM   6736  CG  ARG A 129      46.757 106.506  12.478  1.00126.87           C  \\nATOM   6737  CD  ARG A 129      46.477 107.976  12.433  1.00126.87           C  \\nATOM   6738  NE  ARG A 129      47.159 108.662  13.524  1.00126.87           N  \\nATOM   6739  CZ  ARG A 129      46.633 109.663  14.220  1.00126.87           C  \\nATOM   6740  NH1 ARG A 129      45.410 110.104  13.940  1.00126.87           N  \\nATOM   6741  NH2 ARG A 129      47.333 110.218  15.200  1.00126.87           N  \\nATOM   6742  N   ILE A 130      46.348 104.213   8.741  1.00 20.19           N  \\nATOM   6743  CA  ILE A 130      45.743 103.630   7.566  1.00 20.19           C  \\nATOM   6744  C   ILE A 130      46.187 102.187   7.341  1.00 20.19           C  \\nATOM   6745  O   ILE A 130      45.417 101.372   6.837  1.00 20.19           O  \\nATOM   6746  CB  ILE A 130      46.015 104.517   6.354  1.00 12.22           C  \\nATOM   6747  CG1 ILE A 130      45.465 105.905   6.641  1.00 12.22           C  \\nATOM   6748  CG2 ILE A 130      45.333 103.976   5.082  1.00 12.22           C  \\nATOM   6749  CD1 ILE A 130      45.771 106.859   5.532  1.00 12.22           C  \\nATOM   6750  N   ARG A 131      47.426 101.884   7.720  1.00 30.25           N  \\nATOM   6751  CA  ARG A 131      48.001 100.546   7.606  1.00 30.25           C  \\nATOM   6752  C   ARG A 131      47.337  99.534   8.540  1.00 30.25           C  \\nATOM   6753  O   ARG A 131      47.445  98.320   8.339  1.00 30.25           O  \\nATOM   6754  CB  ARG A 131      49.478 100.604   7.943  1.00 24.89           C  \\nATOM   6755  CG  ARG A 131      50.382 100.895   6.776  1.00 24.89           C  \\nATOM   6756  CD  ARG A 131      51.806 100.801   7.287  1.00 24.89           C  \\nATOM   6757  NE  ARG A 131      52.837 100.745   6.255  1.00 24.89           N  \\nATOM   6758  CZ  ARG A 131      53.976 100.079   6.390  1.00 24.89           C  \\nATOM   6759  NH1 ARG A 131      54.228  99.387   7.503  1.00 24.89           N  \\nATOM   6760  NH2 ARG A 131      54.887 100.154   5.428  1.00 24.89           N  \\nATOM   6761  N   GLY A 132      46.710 100.046   9.595  1.00 24.85           N  \\nATOM   6762  CA  GLY A 132      46.026  99.202  10.547  1.00 24.85           C  \\nATOM   6763  C   GLY A 132      46.820  98.915  11.799  1.00 24.85           C  \\nATOM   6764  O   GLY A 132      46.341  98.218  12.685  1.00 24.85           O  \\nATOM   6765  N   GLU A 133      47.983  99.534  11.942  1.00 48.90           N  \\nATOM   6766  CA  GLU A 133      48.834  99.284  13.099  1.00 48.90           C  \\nATOM   6767  C   GLU A 133      48.501 100.218  14.263  1.00 48.90           C  \\nATOM   6768  O   GLU A 133      48.916  99.986  15.406  1.00 48.90           O  \\nATOM   6769  CB  GLU A 133      50.305  99.426  12.684  1.00 38.49           C  \\nATOM   6770  CG  GLU A 133      50.688  98.567  11.457  1.00 38.49           C  \\nATOM   6771  CD  GLU A 133      52.002  98.970  10.798  1.00 38.49           C  \\nATOM   6772  OE1 GLU A 133      52.811  99.660  11.456  1.00 38.49           O  \\nATOM   6773  OE2 GLU A 133      52.228  98.594   9.619  1.00 38.49           O  \\nATOM   6774  N   ARG A 134      47.720 101.255  13.967  1.00106.93           N  \\nATOM   6775  CA  ARG A 134      47.310 102.250  14.958  1.00106.93           C  \\nATOM   6776  C   ARG A 134      45.788 102.448  14.960  1.00106.93           C  \\nATOM   6777  O   ARG A 134      45.195 102.723  16.005  1.00106.93           O  \\nATOM   6778  CB  ARG A 134      47.977 103.589  14.643  1.00104.85           C  \\nATOM   6779  CG  ARG A 134      48.931 104.111  15.684  1.00104.85           C  \\nATOM   6780  CD  ARG A 134      49.533 105.415  15.184  1.00104.85           C  \\nATOM   6781  NE  ARG A 134      50.582 105.925  16.064  1.00104.85           N  \\nATOM   6782  CZ  ARG A 134      51.814 106.237  15.665  1.00104.85           C  \\nATOM   6783  NH1 ARG A 134      52.166 106.086  14.392  1.00104.85           N  \\nATOM   6784  NH2 ARG A 134      52.694 106.703  16.545  1.00104.85           N  \\nATOM   6785  N   ALA A 135      45.172 102.353  13.781  1.00111.01           N  \\nATOM   6786  CA  ALA A 135      43.726 102.533  13.643  1.00111.01           C  \\nATOM   6787  C   ALA A 135      43.000 101.199  13.511  1.00111.01           C  \\nATOM   6788  O   ALA A 135      42.049 100.971  14.289  1.00155.71           O  \\nATOM   6789  CB  ALA A 135      43.406 103.441  12.440  1.00155.71           C  \\nATOM   6790  OXT ALA A 135      43.390 100.394  12.636  1.00155.71           O  \\nTER    6791      ALA A 135                                                      \\nATOM   6792  N   LYS B  20      80.171 110.516  27.125  1.00137.95           N  \\nATOM   6793  CA  LYS B  20      79.905 109.494  26.071  1.00137.95           C  \\nATOM   6794  C   LYS B  20      80.444 108.117  26.468  1.00137.95           C  \\nATOM   6795  O   LYS B  20      81.617 107.807  26.233  1.00137.95           O  \\nATOM   6796  CB  LYS B  20      80.510 109.936  24.728  1.00111.72           C  \\nATOM   6797  CG  LYS B  20      80.126 109.033  23.557  1.00111.72           C  \\nATOM   6798  CD  LYS B  20      80.729 109.479  22.227  1.00111.72           C  \\nATOM   6799  CE  LYS B  20      80.265 108.553  21.103  1.00111.72           C  \\nATOM   6800  NZ  LYS B  20      80.860 108.887  19.779  1.00111.72           N  \\nATOM   6801  N   VAL B  21      79.581 107.315  27.092  1.00162.32           N  \\nATOM   6802  CA  VAL B  21      79.910 105.954  27.537  1.00162.32           C  \\nATOM   6803  C   VAL B  21      78.655 105.162  27.958  1.00162.32           C  \\nATOM   6804  O   VAL B  21      78.349 104.110  27.391  1.00162.32           O  \\nATOM   6805  CB  VAL B  21      80.951 105.934  28.727  1.00139.26           C  \\nATOM   6806  CG1 VAL B  21      82.392 105.831  28.199  1.00139.26           C  \\nATOM   6807  CG2 VAL B  21      80.789 107.171  29.626  1.00139.26           C  \\nATOM   6808  N   LEU B  22      77.914 105.716  28.915  1.00115.40           N  \\nATOM   6809  CA  LEU B  22      76.700 105.112  29.484  1.00115.40           C  \\nATOM   6810  C   LEU B  22      75.513 105.173  28.520  1.00115.40           C  \\nATOM   6811  O   LEU B  22      74.654 106.050  28.627  1.00115.40           O  \\nATOM   6812  CB  LEU B  22      76.348 105.836  30.789  1.00120.13           C  \\nATOM   6813  CG  LEU B  22      77.491 106.656  31.412  1.00120.13           C  \\nATOM   6814  CD1 LEU B  22      76.950 107.641  32.434  1.00120.13           C  \\nATOM   6815  CD2 LEU B  22      78.560 105.737  32.010  1.00120.13           C  \\nATOM   6816  N   ARG B  23      75.442 104.192  27.626  1.00124.86           N  \\nATOM   6817  CA  ARG B  23      74.400 104.128  26.604  1.00124.86           C  \\nATOM   6818  C   ARG B  23      73.157 103.291  26.877  1.00124.86           C  \\nATOM   6819  O   ARG B  23      73.131 102.439  27.772  1.00124.86           O  \\nATOM   6820  CB  ARG B  23      75.012 103.636  25.294  1.00 93.82           C  \\nATOM   6821  CG  ARG B  23      75.344 104.713  24.290  1.00 93.82           C  \\nATOM   6822  CD  ARG B  23      76.230 104.123  23.201  1.00 93.82           C  \\nATOM   6823  NE  ARG B  23      76.000 104.727  21.890  1.00 93.82           N  \\nATOM   6824  CZ  ARG B  23      75.390 104.112  20.880  1.00 93.82           C  \\nATOM   6825  NH1 ARG B  23      74.944 102.873  21.033  1.00 93.82           N  \\nATOM   6826  NH2 ARG B  23      75.233 104.726  19.714  1.00 93.82           N  \\nATOM   6827  N   ASP B  24      72.135 103.564  26.064  1.00 60.17           N  \\nATOM   6828  CA  ASP B  24      70.857 102.856  26.086  1.00 60.17           C  \\nATOM   6829  C   ASP B  24      70.813 102.156  24.726  1.00 60.17           C  \\nATOM   6830  O   ASP B  24      71.234 102.726  23.714  1.00 60.17           O  \\nATOM   6831  CB  ASP B  24      69.684 103.825  26.234  1.00104.31           C  \\nATOM   6832  CG  ASP B  24      68.462 103.160  26.842  1.00104.31           C  \\nATOM   6833  OD1 ASP B  24      67.962 102.163  26.263  1.00104.31           O  \\nATOM   6834  OD2 ASP B  24      68.020 103.627  27.915  1.00104.31           O  \\nATOM   6835  N   ASN B  25      70.277 100.941  24.699  1.00 36.20           N  \\nATOM   6836  CA  ASN B  25      70.252 100.125  23.484  1.00 36.20           C  \\nATOM   6837  C   ASN B  25      69.468 100.569  22.263  1.00 36.20           C  \\nATOM   6838  O   ASN B  25      69.966 100.458  21.132  1.00 36.20           O  \\nATOM   6839  CB  ASN B  25      69.927  98.692  23.858  1.00 39.32           C  \\nATOM   6840  CG  ASN B  25      70.992  98.104  24.734  1.00 39.32           C  \\nATOM   6841  OD1 ASN B  25      72.177  98.299  24.477  1.00 39.32           O  \\nATOM   6842  ND2 ASN B  25      70.593  97.473  25.819  1.00 39.32           N  \\nATOM   6843  N   ILE B  26      68.251 101.061  22.487  1.00 44.14           N  \\nATOM   6844  CA  ILE B  26      67.417 101.554  21.396  1.00 44.14           C  \\nATOM   6845  C   ILE B  26      68.086 102.812  20.808  1.00 44.14           C  \\nATOM   6846  O   ILE B  26      67.937 103.123  19.623  1.00 44.14           O  \\nATOM   6847  CB  ILE B  26      66.018 101.884  21.899  1.00 31.25           C  \\nATOM   6848  CG1 ILE B  26      65.107 102.257  20.721  1.00 31.25           C  \\nATOM   6849  CG2 ILE B  26      66.094 103.000  22.918  1.00 31.25           C  \\nATOM   6850  CD1 ILE B  26      64.767 101.108  19.773  1.00 31.25           C  \\nATOM   6851  N   GLN B  27      68.839 103.513  21.657  1.00 29.81           N  \\nATOM   6852  CA  GLN B  27      69.592 104.700  21.259  1.00 29.81           C  \\nATOM   6853  C   GLN B  27      70.782 104.249  20.424  1.00 29.81           C  \\nATOM   6854  O   GLN B  27      71.458 105.066  19.791  1.00 29.81           O  \\nATOM   6855  CB  GLN B  27      70.076 105.480  22.484  1.00 41.60           C  \\nATOM   6856  CG  GLN B  27      68.965 106.173  23.281  1.00 41.60           C  \\nATOM   6857  CD  GLN B  27      68.082 107.054  22.415  1.00 41.60           C  \\nATOM   6858  OE1 GLN B  27      68.558 107.714  21.489  1.00 41.60           O  \\nATOM   6859  NE2 GLN B  27      66.782 107.055  22.705  1.00 41.60           N  \\nATOM   6860  N   GLY B  28      70.993 102.930  20.418  1.00 42.84           N  \\nATOM   6861  CA  GLY B  28      72.063 102.298  19.662  1.00 42.84           C  \\nATOM   6862  C   GLY B  28      71.750 102.309  18.184  1.00 42.84           C  \\nATOM   6863  O   GLY B  28      72.652 102.178  17.343  1.00 42.84           O  \\nATOM   6864  N   ILE B  29      70.455 102.415  17.875  1.00 35.71           N  \\nATOM   6865  CA  ILE B  29      69.985 102.496  16.496  1.00 35.71           C  \\nATOM   6866  C   ILE B  29      70.164 103.984  16.226  1.00 35.71           C  \\nATOM   6867  O   ILE B  29      69.310 104.790  16.593  1.00 35.71           O  \\nATOM   6868  CB  ILE B  29      68.503 102.157  16.396  1.00 22.51           C  \\nATOM   6869  CG1 ILE B  29      68.168 100.924  17.249  1.00 22.51           C  \\nATOM   6870  CG2 ILE B  29      68.128 101.970  14.937  1.00 22.51           C  \\nATOM   6871  CD1 ILE B  29      68.853  99.664  16.833  1.00 22.51           C  \\nATOM   6872  N   THR B  30      71.317 104.329  15.653  1.00 52.84           N  \\nATOM   6873  CA  THR B  30      71.717 105.717  15.407  1.00 52.84           C  \\nATOM   6874  C   THR B  30      71.069 106.513  14.298  1.00 52.84           C  \\nATOM   6875  O   THR B  30      70.551 105.960  13.331  1.00 52.84           O  \\nATOM   6876  CB  THR B  30      73.260 105.824  15.223  1.00 31.69           C  \\nATOM   6877  OG1 THR B  30      73.671 105.148  14.019  1.00 31.69           O  \\nATOM   6878  CG2 THR B  30      73.976 105.225  16.426  1.00 31.69           C  \\nATOM   6879  N   LYS B  31      71.161 107.835  14.432  1.00 37.51           N  \\nATOM   6880  CA  LYS B  31      70.625 108.758  13.438  1.00 37.51           C  \\nATOM   6881  C   LYS B  31      71.101 108.478  11.996  1.00 37.51           C  \\nATOM   6882  O   LYS B  31      70.289 108.419  11.089  1.00 37.51           O  \\nATOM   6883  CB  LYS B  31      70.915 110.208  13.837  1.00 34.80           C  \\nATOM   6884  CG  LYS B  31      70.790 111.199  12.693  1.00 34.80           C  \\nATOM   6885  CD  LYS B  31      70.947 112.619  13.184  1.00 34.80           C  \\nATOM   6886  CE  LYS B  31      70.822 113.626  12.050  1.00 34.80           C  \\nATOM   6887  NZ  LYS B  31      70.754 115.012  12.597  1.00 34.80           N  \\nATOM   6888  N   PRO B  32      72.416 108.322  11.760  1.00 28.54           N  \\nATOM   6889  CA  PRO B  32      72.841 108.047  10.372  1.00 28.54           C  \\nATOM   6890  C   PRO B  32      72.289 106.727   9.819  1.00 28.54           C  \\nATOM   6891  O   PRO B  32      72.054 106.599   8.610  1.00 28.54           O  \\nATOM   6892  CB  PRO B  32      74.362 108.033  10.470  1.00 36.76           C  \\nATOM   6893  CG  PRO B  32      74.607 107.677  11.932  1.00 36.76           C  \\nATOM   6894  CD  PRO B  32      73.579 108.481  12.645  1.00 36.76           C  \\nATOM   6895  N   ALA B  33      72.090 105.742  10.703  1.00 34.01           N  \\nATOM   6896  CA  ALA B  33      71.519 104.449  10.293  1.00 34.01           C  \\nATOM   6897  C   ALA B  33      70.071 104.665   9.870  1.00 34.01           C  \\nATOM   6898  O   ALA B  33      69.651 104.267   8.784  1.00 34.01           O  \\nATOM   6899  CB  ALA B  33      71.587 103.458  11.424  1.00 25.17           C  \\nATOM   6900  N   ILE B  34      69.307 105.300  10.746  1.00 22.01           N  \\nATOM   6901  CA  ILE B  34      67.922 105.609  10.431  1.00 22.01           C  \\nATOM   6902  C   ILE B  34      67.889 106.473   9.162  1.00 22.01           C  \\nATOM   6903  O   ILE B  34      67.036 106.294   8.296  1.00 22.01           O  \\nATOM   6904  CB  ILE B  34      67.250 106.379  11.567  1.00  5.92           C  \\nATOM   6905  CG1 ILE B  34      67.182 105.524  12.837  1.00  5.92           C  \\nATOM   6906  CG2 ILE B  34      65.891 106.853  11.130  1.00  5.92           C  \\nATOM   6907  CD1 ILE B  34      66.586 106.268  14.007  1.00  5.92           C  \\nATOM   6908  N   ARG B  35      68.818 107.411   9.055  1.00 34.93           N  \\nATOM   6909  CA  ARG B  35      68.886 108.259   7.886  1.00 34.93           C  \\nATOM   6910  C   ARG B  35      69.086 107.368   6.651  1.00 34.93           C  \\nATOM   6911  O   ARG B  35      68.404 107.555   5.645  1.00 34.93           O  \\nATOM   6912  CB  ARG B  35      70.005 109.286   8.041  1.00 68.42           C  \\nATOM   6913  CG  ARG B  35      70.243 110.156   6.824  1.00 68.42           C  \\nATOM   6914  CD  ARG B  35      71.082 111.360   7.183  1.00 68.42           C  \\nATOM   6915  NE  ARG B  35      70.347 112.253   8.079  1.00 68.42           N  \\nATOM   6916  CZ  ARG B  35      70.034 113.521   7.802  1.00 68.42           C  \\nATOM   6917  NH1 ARG B  35      70.397 114.072   6.644  1.00 68.42           N  \\nATOM   6918  NH2 ARG B  35      69.269 114.211   8.644  1.00 68.42           N  \\nATOM   6919  N   ARG B  36      69.988 106.382   6.720  1.00 22.76           N  \\nATOM   6920  CA  ARG B  36      70.202 105.475   5.582  1.00 22.76           C  \\nATOM   6921  C   ARG B  36      68.918 104.723   5.183  1.00 22.76           C  \\nATOM   6922  O   ARG B  36      68.590 104.594   3.999  1.00 22.76           O  \\nATOM   6923  CB  ARG B  36      71.318 104.475   5.890  1.00 30.75           C  \\nATOM   6924  CG  ARG B  36      72.718 105.055   5.849  1.00 30.75           C  \\nATOM   6925  CD  ARG B  36      73.766 103.942   5.817  1.00 30.75           C  \\nATOM   6926  NE  ARG B  36      73.912 103.277   7.109  1.00 30.75           N  \\nATOM   6927  CZ  ARG B  36      74.522 103.820   8.161  1.00 30.75           C  \\nATOM   6928  NH1 ARG B  36      75.051 105.045   8.080  1.00 30.75           N  \\nATOM   6929  NH2 ARG B  36      74.554 103.153   9.310  1.00 30.75           N  \\nATOM   6930  N   LEU B  37      68.197 104.216   6.180  1.00 28.37           N  \\nATOM   6931  CA  LEU B  37      66.941 103.513   5.942  1.00 28.37           C  \\nATOM   6932  C   LEU B  37      65.999 104.396   5.132  1.00 28.37           C  \\nATOM   6933  O   LEU B  37      65.594 104.043   4.025  1.00 28.37           O  \\nATOM   6934  CB  LEU B  37      66.324 103.120   7.274  1.00 10.93           C  \\nATOM   6935  CG  LEU B  37      67.060 101.872   7.770  1.00 10.93           C  \\nATOM   6936  CD1 LEU B  37      66.720 101.557   9.201  1.00 10.93           C  \\nATOM   6937  CD2 LEU B  37      66.745 100.678   6.848  1.00 10.93           C  \\nATOM   6938  N   ALA B  38      65.739 105.590   5.660  1.00 25.13           N  \\nATOM   6939  CA  ALA B  38      64.887 106.589   5.007  1.00 25.13           C  \\nATOM   6940  C   ALA B  38      65.253 106.804   3.536  1.00 25.13           C  \\nATOM   6941  O   ALA B  38      64.386 106.880   2.680  1.00 25.13           O  \\nATOM   6942  CB  ALA B  38      64.983 107.908   5.759  1.00  5.00           C  \\nATOM   6943  N   ARG B  39      66.543 106.949   3.261  1.00 25.01           N  \\nATOM   6944  CA  ARG B  39      67.024 107.160   1.905  1.00 25.01           C  \\nATOM   6945  C   ARG B  39      66.643 106.028   0.969  1.00 25.01           C  \\nATOM   6946  O   ARG B  39      66.250 106.276  -0.171  1.00 25.01           O  \\nATOM   6947  CB  ARG B  39      68.533 107.382   1.902  1.00 29.79           C  \\nATOM   6948  CG  ARG B  39      68.978 108.655   2.623  1.00 29.79           C  \\nATOM   6949  CD  ARG B  39      68.987 109.881   1.702  1.00 29.79           C  \\nATOM   6950  NE  ARG B  39      69.561 111.047   2.371  1.00 29.79           N  \\nATOM   6951  CZ  ARG B  39      68.889 111.836   3.205  1.00 29.79           C  \\nATOM   6952  NH1 ARG B  39      67.618 111.597   3.477  1.00 29.79           N  \\nATOM   6953  NH2 ARG B  39      69.470 112.890   3.760  1.00 29.79           N  \\nATOM   6954  N   ARG B  40      66.784 104.788   1.431  1.00 33.70           N  \\nATOM   6955  CA  ARG B  40      66.414 103.627   0.617  1.00 33.70           C  \\nATOM   6956  C   ARG B  40      64.901 103.713   0.342  1.00 33.70           C  \\nATOM   6957  O   ARG B  40      64.403 103.225  -0.692  1.00 33.70           O  \\nATOM   6958  CB  ARG B  40      66.771 102.347   1.359  1.00 29.79           C  \\nATOM   6959  CG  ARG B  40      66.703 101.105   0.506  1.00 29.79           C  \\nATOM   6960  CD  ARG B  40      67.395  99.919   1.171  1.00 29.79           C  \\nATOM   6961  NE  ARG B  40      68.771  99.710   0.702  1.00 29.79           N  \\nATOM   6962  CZ  ARG B  40      69.690  99.009   1.362  1.00 29.79           C  \\nATOM   6963  NH1 ARG B  40      69.396  98.442   2.528  1.00 29.79           N  \\nATOM   6964  NH2 ARG B  40      70.914  98.884   0.875  1.00 29.79           N  \\nATOM   6965  N   GLY B  41      64.186 104.331   1.295  1.00 32.71           N  \\nATOM   6966  CA  GLY B  41      62.751 104.561   1.177  1.00 32.71           C  \\nATOM   6967  C   GLY B  41      62.411 105.751   0.271  1.00 32.71           C  \\nATOM   6968  O   GLY B  41      61.245 106.030   0.008  1.00 32.71           O  \\nATOM   6969  N   GLY B  42      63.432 106.466  -0.193  1.00 16.73           N  \\nATOM   6970  CA  GLY B  42      63.225 107.594  -1.079  1.00 16.73           C  \\nATOM   6971  C   GLY B  42      62.995 108.965  -0.455  1.00 16.73           C  \\nATOM   6972  O   GLY B  42      62.558 109.886  -1.163  1.00 16.73           O  \\nATOM   6973  N   VAL B  43      63.252 109.094   0.848  1.00 31.31           N  \\nATOM   6974  CA  VAL B  43      63.087 110.356   1.583  1.00 31.31           C  \\nATOM   6975  C   VAL B  43      64.279 111.304   1.325  1.00 31.31           C  \\nATOM   6976  O   VAL B  43      65.435 110.878   1.389  1.00 31.31           O  \\nATOM   6977  CB  VAL B  43      62.971 110.069   3.091  1.00 13.12           C  \\nATOM   6978  CG1 VAL B  43      62.828 111.336   3.870  1.00 13.12           C  \\nATOM   6979  CG2 VAL B  43      61.820 109.122   3.356  1.00 13.12           C  \\nATOM   6980  N   LYS B  44      63.991 112.584   1.066  1.00 29.43           N  \\nATOM   6981  CA  LYS B  44      65.025 113.577   0.772  1.00 29.43           C  \\nATOM   6982  C   LYS B  44      65.387 114.507   1.935  1.00 29.43           C  \\nATOM   6983  O   LYS B  44      66.563 114.812   2.161  1.00 29.43           O  \\nATOM   6984  CB  LYS B  44      64.603 114.408  -0.430  1.00 46.92           C  \\nATOM   6985  CG  LYS B  44      65.566 115.527  -0.802  1.00 46.92           C  \\nATOM   6986  CD  LYS B  44      65.024 116.340  -1.969  1.00 46.92           C  \\nATOM   6987  CE  LYS B  44      66.026 117.355  -2.471  1.00 46.92           C  \\nATOM   6988  NZ  LYS B  44      65.510 117.996  -3.716  1.00 46.92           N  \\nATOM   6989  N   ARG B  45      64.376 115.013   2.631  1.00 21.86           N  \\nATOM   6990  CA  ARG B  45      64.581 115.907   3.767  1.00 21.86           C  \\nATOM   6991  C   ARG B  45      63.868 115.232   4.956  1.00 21.86           C  \\nATOM   6992  O   ARG B  45      62.769 114.676   4.791  1.00 21.86           O  \\nATOM   6993  CB  ARG B  45      63.992 117.281   3.430  1.00 42.28           C  \\nATOM   6994  CG  ARG B  45      64.574 118.432   4.212  1.00 42.28           C  \\nATOM   6995  CD  ARG B  45      64.265 119.772   3.551  1.00 42.28           C  \\nATOM   6996  NE  ARG B  45      64.981 120.864   4.202  1.00 42.28           N  \\nATOM   6997  CZ  ARG B  45      64.555 121.508   5.288  1.00 42.28           C  \\nATOM   6998  NH1 ARG B  45      63.395 121.188   5.857  1.00 42.28           N  \\nATOM   6999  NH2 ARG B  45      65.308 122.473   5.819  1.00 42.28           N  \\nATOM   7000  N   ILE B  46      64.498 115.264   6.139  1.00 27.20           N  \\nATOM   7001  CA  ILE B  46      63.963 114.618   7.343  1.00 27.20           C  \\nATOM   7002  C   ILE B  46      63.875 115.494   8.599  1.00 27.20           C  \\nATOM   7003  O   ILE B  46      64.889 115.959   9.104  1.00 27.20           O  \\nATOM   7004  CB  ILE B  46      64.843 113.399   7.686  1.00  9.84           C  \\nATOM   7005  CG1 ILE B  46      64.863 112.408   6.507  1.00  9.84           C  \\nATOM   7006  CG2 ILE B  46      64.385 112.737   8.983  1.00  9.84           C  \\nATOM   7007  CD1 ILE B  46      65.955 111.332   6.607  1.00  9.84           C  \\nATOM   7008  N   SER B  47      62.672 115.634   9.149  1.00 29.26           N  \\nATOM   7009  CA  SER B  47      62.447 116.414  10.370  1.00 29.26           C  \\nATOM   7010  C   SER B  47      63.256 115.864  11.547  1.00 29.26           C  \\nATOM   7011  O   SER B  47      63.369 114.642  11.731  1.00 29.26           O  \\nATOM   7012  CB  SER B  47      60.950 116.429  10.741  1.00 27.36           C  \\nATOM   7013  OG  SER B  47      60.729 116.713  12.125  1.00 27.36           O  \\nATOM   7014  N   GLY B  48      63.719 116.777  12.397  1.00 30.03           N  \\nATOM   7015  CA  GLY B  48      64.512 116.391  13.542  1.00 30.03           C  \\nATOM   7016  C   GLY B  48      63.854 115.398  14.468  1.00 30.03           C  \\nATOM   7017  O   GLY B  48      64.535 114.623  15.133  1.00 30.03           O  \\nATOM   7018  N   LEU B  49      62.529 115.343  14.447  1.00 29.92           N  \\nATOM   7019  CA  LEU B  49      61.804 114.445  15.346  1.00 29.92           C  \\nATOM   7020  C   LEU B  49      61.573 113.013  14.872  1.00 29.92           C  \\nATOM   7021  O   LEU B  49      61.085 112.157  15.636  1.00 29.92           O  \\nATOM   7022  CB  LEU B  49      60.488 115.092  15.725  1.00 35.14           C  \\nATOM   7023  CG  LEU B  49      60.790 116.405  16.426  1.00 35.14           C  \\nATOM   7024  CD1 LEU B  49      59.529 117.216  16.550  1.00 35.14           C  \\nATOM   7025  CD2 LEU B  49      61.433 116.104  17.780  1.00 35.14           C  \\nATOM   7026  N   ILE B  50      61.986 112.735  13.639  1.00 23.59           N  \\nATOM   7027  CA  ILE B  50      61.813 111.406  13.065  1.00 23.59           C  \\nATOM   7028  C   ILE B  50      62.586 110.280  13.755  1.00 23.59           C  \\nATOM   7029  O   ILE B  50      62.085 109.176  13.864  1.00 23.59           O  \\nATOM   7030  CB  ILE B  50      62.134 111.415  11.558  1.00 14.73           C  \\nATOM   7031  CG1 ILE B  50      60.996 112.108  10.786  1.00 14.73           C  \\nATOM   7032  CG2 ILE B  50      62.443 110.004  11.062  1.00 14.73           C  \\nATOM   7033  CD1 ILE B  50      59.628 111.408  10.854  1.00 14.73           C  \\nATOM   7034  N   TYR B  51      63.754 110.588  14.306  1.00 29.80           N  \\nATOM   7035  CA  TYR B  51      64.575 109.560  14.943  1.00 29.80           C  \\nATOM   7036  C   TYR B  51      63.931 108.930  16.151  1.00 29.80           C  \\nATOM   7037  O   TYR B  51      63.844 107.707  16.239  1.00 29.80           O  \\nATOM   7038  CB  TYR B  51      65.976 110.098  15.235  1.00 22.15           C  \\nATOM   7039  CG  TYR B  51      66.520 110.820  14.015  1.00 22.15           C  \\nATOM   7040  CD1 TYR B  51      67.014 110.117  12.899  1.00 22.15           C  \\nATOM   7041  CD2 TYR B  51      66.411 112.203  13.919  1.00 22.15           C  \\nATOM   7042  CE1 TYR B  51      67.368 110.802  11.725  1.00 22.15           C  \\nATOM   7043  CE2 TYR B  51      66.756 112.876  12.763  1.00 22.15           C  \\nATOM   7044  CZ  TYR B  51      67.226 112.189  11.679  1.00 22.15           C  \\nATOM   7045  OH  TYR B  51      67.510 112.931  10.557  1.00 22.15           O  \\nATOM   7046  N   GLU B  52      63.401 109.754  17.044  1.00 40.91           N  \\nATOM   7047  CA  GLU B  52      62.755 109.203  18.216  1.00 40.91           C  \\nATOM   7048  C   GLU B  52      61.502 108.490  17.786  1.00 40.91           C  \\nATOM   7049  O   GLU B  52      61.246 107.369  18.211  1.00 40.91           O  \\nATOM   7050  CB  GLU B  52      62.463 110.279  19.254  1.00 53.48           C  \\nATOM   7051  CG  GLU B  52      63.634 110.504  20.187  1.00 53.48           C  \\nATOM   7052  CD  GLU B  52      63.944 109.282  21.055  1.00 53.48           C  \\nATOM   7053  OE1 GLU B  52      63.297 109.154  22.120  1.00 53.48           O  \\nATOM   7054  OE2 GLU B  52      64.826 108.463  20.688  1.00 53.48           O  \\nATOM   7055  N   GLU B  53      60.769 109.098  16.866  1.00 29.91           N  \\nATOM   7056  CA  GLU B  53      59.546 108.482  16.381  1.00 29.91           C  \\nATOM   7057  C   GLU B  53      59.858 107.080  15.824  1.00 29.91           C  \\nATOM   7058  O   GLU B  53      59.257 106.092  16.251  1.00 29.91           O  \\nATOM   7059  CB  GLU B  53      58.880 109.399  15.330  1.00 36.25           C  \\nATOM   7060  CG  GLU B  53      57.416 109.082  14.965  1.00 36.25           C  \\nATOM   7061  CD  GLU B  53      56.444 109.147  16.148  1.00 36.25           C  \\nATOM   7062  OE1 GLU B  53      56.681 109.930  17.098  1.00 36.25           O  \\nATOM   7063  OE2 GLU B  53      55.432 108.404  16.131  1.00 36.25           O  \\nATOM   7064  N   THR B  54      60.869 106.998  14.959  1.00 20.76           N  \\nATOM   7065  CA  THR B  54      61.287 105.743  14.323  1.00 20.76           C  \\nATOM   7066  C   THR B  54      61.722 104.692  15.344  1.00 20.76           C  \\nATOM   7067  O   THR B  54      61.387 103.506  15.222  1.00 20.76           O  \\nATOM   7068  CB  THR B  54      62.455 105.960  13.305  1.00 14.31           C  \\nATOM   7069  OG1 THR B  54      62.197 107.109  12.488  1.00 14.31           O  \\nATOM   7070  CG2 THR B  54      62.611 104.757  12.394  1.00 14.31           C  \\nATOM   7071  N   ARG B  55      62.493 105.107  16.340  1.00 34.75           N  \\nATOM   7072  CA  ARG B  55      62.934 104.160  17.356  1.00 34.75           C  \\nATOM   7073  C   ARG B  55      61.735 103.506  18.023  1.00 34.75           C  \\nATOM   7074  O   ARG B  55      61.721 102.313  18.242  1.00 34.75           O  \\nATOM   7075  CB  ARG B  55      63.848 104.834  18.378  1.00 28.55           C  \\nATOM   7076  CG  ARG B  55      65.198 105.211  17.800  1.00 28.55           C  \\nATOM   7077  CD  ARG B  55      66.259 105.507  18.873  1.00 28.55           C  \\nATOM   7078  NE  ARG B  55      67.406 106.105  18.205  1.00 28.55           N  \\nATOM   7079  CZ  ARG B  55      67.628 107.410  18.127  1.00 28.55           C  \\nATOM   7080  NH1 ARG B  55      66.821 108.272  18.724  1.00 28.55           N  \\nATOM   7081  NH2 ARG B  55      68.516 107.856  17.255  1.00 28.55           N  \\nATOM   7082  N   GLY B  56      60.687 104.279  18.245  1.00 17.78           N  \\nATOM   7083  CA  GLY B  56      59.494 103.740  18.868  1.00 17.78           C  \\nATOM   7084  C   GLY B  56      58.750 102.740  18.014  1.00 17.78           C  \\nATOM   7085  O   GLY B  56      58.153 101.787  18.529  1.00 17.78           O  \\nATOM   7086  N   VAL B  57      58.718 103.003  16.714  1.00 32.52           N  \\nATOM   7087  CA  VAL B  57      58.072 102.106  15.769  1.00 32.52           C  \\nATOM   7088  C   VAL B  57      58.850 100.798  15.798  1.00 32.52           C  \\nATOM   7089  O   VAL B  57      58.267  99.726  15.933  1.00 32.52           O  \\nATOM   7090  CB  VAL B  57      58.140 102.665  14.318  1.00 16.43           C  \\nATOM   7091  CG1 VAL B  57      57.605 101.651  13.316  1.00 16.43           C  \\nATOM   7092  CG2 VAL B  57      57.381 103.949  14.207  1.00 16.43           C  \\nATOM   7093  N   LEU B  58      60.175 100.898  15.701  1.00 25.14           N  \\nATOM   7094  CA  LEU B  58      61.013  99.708  15.686  1.00 25.14           C  \\nATOM   7095  C   LEU B  58      60.870  98.870  16.929  1.00 25.14           C  \\nATOM   7096  O   LEU B  58      60.908  97.652  16.856  1.00 25.14           O  \\nATOM   7097  CB  LEU B  58      62.476 100.060  15.451  1.00 22.90           C  \\nATOM   7098  CG  LEU B  58      63.386  98.837  15.269  1.00 22.90           C  \\nATOM   7099  CD1 LEU B  58      62.875  97.913  14.185  1.00 22.90           C  \\nATOM   7100  CD2 LEU B  58      64.765  99.327  14.924  1.00 22.90           C  \\nATOM   7101  N   LYS B  59      60.741  99.522  18.071  1.00 29.02           N  \\nATOM   7102  CA  LYS B  59      60.554  98.813  19.320  1.00 29.02           C  \\nATOM   7103  C   LYS B  59      59.249  98.003  19.273  1.00 29.02           C  \\nATOM   7104  O   LYS B  59      59.257  96.816  19.606  1.00 29.02           O  \\nATOM   7105  CB  LYS B  59      60.528  99.786  20.487  1.00 44.35           C  \\nATOM   7106  CG  LYS B  59      60.800  99.130  21.810  1.00 44.35           C  \\nATOM   7107  CD  LYS B  59      60.772 100.146  22.928  1.00 44.35           C  \\nATOM   7108  CE  LYS B  59      61.110  99.511  24.259  1.00 44.35           C  \\nATOM   7109  NZ  LYS B  59      60.348 100.179  25.343  1.00 44.35           N  \\nATOM   7110  N   VAL B  60      58.140  98.622  18.842  1.00 17.05           N  \\nATOM   7111  CA  VAL B  60      56.859  97.914  18.739  1.00 17.05           C  \\nATOM   7112  C   VAL B  60      57.024  96.765  17.750  1.00 17.05           C  \\nATOM   7113  O   VAL B  60      56.601  95.647  18.029  1.00 17.05           O  \\nATOM   7114  CB  VAL B  60      55.715  98.849  18.306  1.00 26.72           C  \\nATOM   7115  CG1 VAL B  60      54.497  98.057  17.933  1.00 26.72           C  \\nATOM   7116  CG2 VAL B  60      55.358  99.798  19.432  1.00 26.72           C  \\nATOM   7117  N   PHE B  61      57.697  97.012  16.630  1.00 17.06           N  \\nATOM   7118  CA  PHE B  61      57.922  95.946  15.665  1.00 17.06           C  \\nATOM   7119  C   PHE B  61      58.606  94.750  16.333  1.00 17.06           C  \\nATOM   7120  O   PHE B  61      58.029  93.655  16.411  1.00 17.06           O  \\nATOM   7121  CB  PHE B  61      58.767  96.415  14.467  1.00 14.75           C  \\nATOM   7122  CG  PHE B  61      58.818  95.398  13.327  1.00 14.75           C  \\nATOM   7123  CD1 PHE B  61      57.808  95.358  12.362  1.00 14.75           C  \\nATOM   7124  CD2 PHE B  61      59.823  94.424  13.275  1.00 14.75           C  \\nATOM   7125  CE1 PHE B  61      57.793  94.364  11.373  1.00 14.75           C  \\nATOM   7126  CE2 PHE B  61      59.809  93.422  12.282  1.00 14.75           C  \\nATOM   7127  CZ  PHE B  61      58.795  93.395  11.335  1.00 14.75           C  \\nATOM   7128  N   LEU B  62      59.810  94.970  16.854  1.00 15.90           N  \\nATOM   7129  CA  LEU B  62      60.567  93.913  17.507  1.00 15.90           C  \\nATOM   7130  C   LEU B  62      59.797  93.239  18.633  1.00 15.90           C  \\nATOM   7131  O   LEU B  62      59.708  92.017  18.639  1.00 15.90           O  \\nATOM   7132  CB  LEU B  62      61.924  94.438  17.979  1.00 21.23           C  \\nATOM   7133  CG  LEU B  62      62.823  94.861  16.805  1.00 21.23           C  \\nATOM   7134  CD1 LEU B  62      64.070  95.545  17.295  1.00 21.23           C  \\nATOM   7135  CD2 LEU B  62      63.180  93.659  15.959  1.00 21.23           C  \\nATOM   7136  N   GLU B  63      59.176  94.021  19.528  1.00  8.40           N  \\nATOM   7137  CA  GLU B  63      58.373  93.477  20.647  1.00  8.40           C  \\nATOM   7138  C   GLU B  63      57.364  92.463  20.146  1.00  8.40           C  \\nATOM   7139  O   GLU B  63      57.449  91.293  20.497  1.00  8.40           O  \\nATOM   7140  CB  GLU B  63      57.646  94.590  21.421  1.00 23.16           C  \\nATOM   7141  CG  GLU B  63      58.594  95.525  22.196  1.00 23.16           C  \\nATOM   7142  CD  GLU B  63      57.892  96.600  23.039  1.00 23.16           C  \\nATOM   7143  OE1 GLU B  63      56.671  96.783  22.863  1.00 23.16           O  \\nATOM   7144  OE2 GLU B  63      58.565  97.267  23.877  1.00 23.16           O  \\nATOM   7145  N   ASN B  64      56.495  92.877  19.230  1.00 23.87           N  \\nATOM   7146  CA  ASN B  64      55.478  91.974  18.684  1.00 23.87           C  \\nATOM   7147  C   ASN B  64      56.027  90.675  18.134  1.00 23.87           C  \\nATOM   7148  O   ASN B  64      55.586  89.592  18.543  1.00 23.87           O  \\nATOM   7149  CB  ASN B  64      54.650  92.647  17.591  1.00 41.03           C  \\nATOM   7150  CG  ASN B  64      53.732  93.712  18.131  1.00 41.03           C  \\nATOM   7151  OD1 ASN B  64      53.460  93.773  19.344  1.00 41.03           O  \\nATOM   7152  ND2 ASN B  64      53.249  94.570  17.237  1.00 41.03           N  \\nATOM   7153  N   VAL B  65      57.002  90.783  17.230  1.00 27.49           N  \\nATOM   7154  CA  VAL B  65      57.603  89.606  16.601  1.00 27.49           C  \\nATOM   7155  C   VAL B  65      58.312  88.685  17.600  1.00 27.49           C  \\nATOM   7156  O   VAL B  65      58.048  87.478  17.636  1.00 27.49           O  \\nATOM   7157  CB  VAL B  65      58.612  89.994  15.484  1.00 22.96           C  \\nATOM   7158  CG1 VAL B  65      58.901  88.804  14.597  1.00 22.96           C  \\nATOM   7159  CG2 VAL B  65      58.076  91.109  14.647  1.00 22.96           C  \\nATOM   7160  N   ILE B  66      59.179  89.259  18.435  1.00 24.75           N  \\nATOM   7161  CA  ILE B  66      59.942  88.477  19.408  1.00 24.75           C  \\nATOM   7162  C   ILE B  66      59.034  87.793  20.393  1.00 24.75           C  \\nATOM   7163  O   ILE B  66      59.297  86.661  20.761  1.00 24.75           O  \\nATOM   7164  CB  ILE B  66      61.018  89.324  20.165  1.00 16.46           C  \\nATOM   7165  CG1 ILE B  66      62.037  89.888  19.153  1.00 16.46           C  \\nATOM   7166  CG2 ILE B  66      61.699  88.466  21.254  1.00 16.46           C  \\nATOM   7167  CD1 ILE B  66      62.985  90.952  19.690  1.00 16.46           C  \\nATOM   7168  N   ARG B  67      57.962  88.469  20.803  1.00 28.78           N  \\nATOM   7169  CA  ARG B  67      57.026  87.868  21.736  1.00 28.78           C  \\nATOM   7170  C   ARG B  67      56.569  86.534  21.183  1.00 28.78           C  \\nATOM   7171  O   ARG B  67      56.581  85.535  21.892  1.00 28.78           O  \\nATOM   7172  CB  ARG B  67      55.814  88.746  21.973  1.00 53.98           C  \\nATOM   7173  CG  ARG B  67      54.950  88.200  23.090  1.00 53.98           C  \\nATOM   7174  CD  ARG B  67      53.636  88.935  23.235  1.00 53.98           C  \\nATOM   7175  NE  ARG B  67      53.826  90.378  23.333  1.00 53.98           N  \\nATOM   7176  CZ  ARG B  67      53.553  91.229  22.345  1.00 53.98           C  \\nATOM   7177  NH1 ARG B  67      53.065  90.775  21.184  1.00 53.98           N  \\nATOM   7178  NH2 ARG B  67      53.814  92.528  22.493  1.00 53.98           N  \\nATOM   7179  N   ASP B  68      56.177  86.520  19.913  1.00 22.59           N  \\nATOM   7180  CA  ASP B  68      55.732  85.289  19.280  1.00 22.59           C  \\nATOM   7181  C   ASP B  68      56.876  84.281  19.113  1.00 22.59           C  \\nATOM   7182  O   ASP B  68      56.723  83.101  19.459  1.00 22.59           O  \\nATOM   7183  CB  ASP B  68      55.059  85.579  17.941  1.00 22.38           C  \\nATOM   7184  CG  ASP B  68      53.685  86.217  18.093  1.00 22.38           C  \\nATOM   7185  OD1 ASP B  68      53.308  86.668  19.209  1.00 22.38           O  \\nATOM   7186  OD2 ASP B  68      52.974  86.267  17.071  1.00 22.38           O  \\nATOM   7187  N   ALA B  69      58.017  84.737  18.588  1.00 15.96           N  \\nATOM   7188  CA  ALA B  69      59.188  83.867  18.416  1.00 15.96           C  \\nATOM   7189  C   ALA B  69      59.514  83.172  19.749  1.00 15.96           C  \\nATOM   7190  O   ALA B  69      59.477  81.957  19.854  1.00 15.96           O  \\nATOM   7191  CB  ALA B  69      60.383  84.672  17.933  1.00 37.17           C  \\nATOM   7192  N   VAL B  70      59.764  83.947  20.790  1.00 21.46           N  \\nATOM   7193  CA  VAL B  70      60.044  83.359  22.087  1.00 21.46           C  \\nATOM   7194  C   VAL B  70      58.926  82.399  22.544  1.00 21.46           C  \\nATOM   7195  O   VAL B  70      59.217  81.382  23.160  1.00 21.46           O  \\nATOM   7196  CB  VAL B  70      60.328  84.438  23.137  1.00 11.71           C  \\nATOM   7197  CG1 VAL B  70      60.367  83.838  24.509  1.00 11.71           C  \\nATOM   7198  CG2 VAL B  70      61.657  85.093  22.843  1.00 11.71           C  \\nATOM   7199  N   THR B  71      57.665  82.702  22.224  1.00 15.44           N  \\nATOM   7200  CA  THR B  71      56.544  81.818  22.563  1.00 15.44           C  \\nATOM   7201  C   THR B  71      56.740  80.497  21.844  1.00 15.44           C  \\nATOM   7202  O   THR B  71      56.430  79.439  22.373  1.00 15.44           O  \\nATOM   7203  CB  THR B  71      55.173  82.429  22.181  1.00 25.57           C  \\nATOM   7204  OG1 THR B  71      54.472  82.761  23.377  1.00 25.57           O  \\nATOM   7205  CG2 THR B  71      54.308  81.452  21.401  1.00 25.57           C  \\nATOM   7206  N   TYR B  72      57.209  80.552  20.609  1.00 15.76           N  \\nATOM   7207  CA  TYR B  72      57.456  79.321  19.894  1.00 15.76           C  \\nATOM   7208  C   TYR B  72      58.634  78.624  20.558  1.00 15.76           C  \\nATOM   7209  O   TYR B  72      58.596  77.425  20.766  1.00 15.76           O  \\nATOM   7210  CB  TYR B  72      57.777  79.606  18.447  1.00 18.40           C  \\nATOM   7211  CG  TYR B  72      56.575  79.863  17.561  1.00 18.40           C  \\nATOM   7212  CD1 TYR B  72      55.608  78.881  17.375  1.00 18.40           C  \\nATOM   7213  CD2 TYR B  72      56.465  81.046  16.825  1.00 18.40           C  \\nATOM   7214  CE1 TYR B  72      54.568  79.061  16.469  1.00 18.40           C  \\nATOM   7215  CE2 TYR B  72      55.432  81.240  15.919  1.00 18.40           C  \\nATOM   7216  CZ  TYR B  72      54.482  80.242  15.737  1.00 18.40           C  \\nATOM   7217  OH  TYR B  72      53.461  80.398  14.814  1.00 18.40           O  \\nATOM   7218  N   THR B  73      59.664  79.387  20.930  1.00 33.08           N  \\nATOM   7219  CA  THR B  73      60.843  78.820  21.582  1.00 33.08           C  \\nATOM   7220  C   THR B  73      60.419  78.034  22.796  1.00 33.08           C  \\nATOM   7221  O   THR B  73      60.690  76.846  22.875  1.00 33.08           O  \\nATOM   7222  CB  THR B  73      61.852  79.891  22.038  1.00  8.96           C  \\nATOM   7223  OG1 THR B  73      62.249  80.680  20.910  1.00  8.96           O  \\nATOM   7224  CG2 THR B  73      63.089  79.225  22.627  1.00  8.96           C  \\nATOM   7225  N   GLU B  74      59.735  78.699  23.722  1.00 26.40           N  \\nATOM   7226  CA  GLU B  74      59.271  78.073  24.958  1.00 26.40           C  \\nATOM   7227  C   GLU B  74      58.488  76.797  24.653  1.00 26.40           C  \\nATOM   7228  O   GLU B  74      58.776  75.736  25.190  1.00 26.40           O  \\nATOM   7229  CB  GLU B  74      58.389  79.033  25.780  1.00 92.82           C  \\nATOM   7230  CG  GLU B  74      59.125  80.055  26.668  1.00 92.82           C  \\nATOM   7231  CD  GLU B  74      58.166  80.946  27.481  1.00 92.82           C  \\nATOM   7232  OE1 GLU B  74      57.186  80.422  28.055  1.00 92.82           O  \\nATOM   7233  OE2 GLU B  74      58.386  82.176  27.550  1.00 92.82           O  \\nATOM   7234  N   HIS B  75      57.506  76.878  23.770  1.00 44.41           N  \\nATOM   7235  CA  HIS B  75      56.748  75.689  23.463  1.00 44.41           C  \\nATOM   7236  C   HIS B  75      57.640  74.546  22.999  1.00 44.41           C  \\nATOM   7237  O   HIS B  75      57.383  73.393  23.307  1.00 44.41           O  \\nATOM   7238  CB  HIS B  75      55.708  75.977  22.408  1.00 29.94           C  \\nATOM   7239  CG  HIS B  75      54.769  74.841  22.199  1.00 29.94           C  \\nATOM   7240  ND1 HIS B  75      54.937  73.916  21.196  1.00 29.94           N  \\nATOM   7241  CD2 HIS B  75      53.684  74.443  22.902  1.00 29.94           C  \\nATOM   7242  CE1 HIS B  75      53.997  72.994  21.286  1.00 29.94           C  \\nATOM   7243  NE2 HIS B  75      53.224  73.292  22.313  1.00 29.94           N  \\nATOM   7244  N   ALA B  76      58.671  74.869  22.231  1.00 44.71           N  \\nATOM   7245  CA  ALA B  76      59.604  73.871  21.726  1.00 44.71           C  \\nATOM   7246  C   ALA B  76      60.531  73.358  22.821  1.00 44.71           C  \\nATOM   7247  O   ALA B  76      61.466  72.603  22.542  1.00 44.71           O  \\nATOM   7248  CB  ALA B  76      60.420  74.455  20.593  1.00 15.73           C  \\nATOM   7249  N   LYS B  77      60.275  73.786  24.057  1.00 37.32           N  \\nATOM   7250  CA  LYS B  77      61.063  73.394  25.224  1.00 37.32           C  \\nATOM   7251  C   LYS B  77      62.540  73.807  25.095  1.00 37.32           C  \\nATOM   7252  O   LYS B  77      63.387  73.272  25.814  1.00 37.32           O  \\nATOM   7253  CB  LYS B  77      60.951  71.875  25.459  1.00 75.40           C  \\nATOM   7254  CG  LYS B  77      59.533  71.369  25.709  1.00 75.40           C  \\nATOM   7255  CD  LYS B  77      59.470  69.846  25.787  1.00 75.40           C  \\nATOM   7256  CE  LYS B  77      58.064  69.380  26.178  1.00 75.40           C  \\nATOM   7257  NZ  LYS B  77      57.974  67.913  26.429  1.00 75.40           N  \\nATOM   7258  N   ARG B  78      62.837  74.766  24.207  1.00 40.18           N  \\nATOM   7259  CA  ARG B  78      64.210  75.241  23.978  1.00 40.18           C  \\nATOM   7260  C   ARG B  78      64.592  76.501  24.744  1.00 40.18           C  \\nATOM   7261  O   ARG B  78      63.732  77.289  25.132  1.00 40.18           O  \\nATOM   7262  CB  ARG B  78      64.467  75.480  22.491  1.00 43.03           C  \\nATOM   7263  CG  ARG B  78      64.825  74.237  21.721  1.00 43.03           C  \\nATOM   7264  CD  ARG B  78      65.046  74.535  20.260  1.00 43.03           C  \\nATOM   7265  NE  ARG B  78      63.797  74.777  19.543  1.00 43.03           N  \\nATOM   7266  CZ  ARG B  78      63.254  75.981  19.372  1.00 43.03           C  \\nATOM   7267  NH1 ARG B  78      63.842  77.068  19.869  1.00 43.03           N  \\nATOM   7268  NH2 ARG B  78      62.125  76.110  18.692  1.00 43.03           N  \\nATOM   7269  N   LYS B  79      65.897  76.680  24.939  1.00 28.50           N  \\nATOM   7270  CA  LYS B  79      66.462  77.825  25.636  1.00 28.50           C  \\nATOM   7271  C   LYS B  79      67.177  78.727  24.611  1.00 28.50           C  \\nATOM   7272  O   LYS B  79      67.835  79.716  24.971  1.00 28.50           O  \\nATOM   7273  CB  LYS B  79      67.434  77.345  26.707  1.00 82.66           C  \\nATOM   7274  CG  LYS B  79      67.296  78.116  27.985  1.00 82.66           C  \\nATOM   7275  CD  LYS B  79      68.323  77.698  28.998  1.00 82.66           C  \\nATOM   7276  CE  LYS B  79      68.248  78.594  30.223  1.00 82.66           C  \\nATOM   7277  NZ  LYS B  79      69.389  78.339  31.140  1.00 82.66           N  \\nATOM   7278  N   THR B  80      66.982  78.413  23.325  1.00 28.17           N  \\nATOM   7279  CA  THR B  80      67.590  79.169  22.233  1.00 28.17           C  \\nATOM   7280  C   THR B  80      66.588  79.456  21.133  1.00 28.17           C  \\nATOM   7281  O   THR B  80      65.979  78.533  20.578  1.00 28.17           O  \\nATOM   7282  CB  THR B  80      68.749  78.394  21.582  1.00 46.58           C  \\nATOM   7283  OG1 THR B  80      69.734  78.062  22.570  1.00 46.58           O  \\nATOM   7284  CG2 THR B  80      69.394  79.238  20.482  1.00 46.58           C  \\nATOM   7285  N   VAL B  81      66.494  80.729  20.755  1.00 23.08           N  \\nATOM   7286  CA  VAL B  81      65.567  81.167  19.709  1.00 23.08           C  \\nATOM   7287  C   VAL B  81      66.102  80.830  18.315  1.00 23.08           C  \\nATOM   7288  O   VAL B  81      67.113  81.374  17.877  1.00 23.08           O  \\nATOM   7289  CB  VAL B  81      65.312  82.676  19.815  1.00 15.28           C  \\nATOM   7290  CG1 VAL B  81      64.297  83.113  18.782  1.00 15.28           C  \\nATOM   7291  CG2 VAL B  81      64.842  83.019  21.207  1.00 15.28           C  \\nATOM   7292  N   THR B  82      65.436  79.927  17.614  1.00 16.08           N  \\nATOM   7293  CA  THR B  82      65.915  79.558  16.289  1.00 16.08           C  \\nATOM   7294  C   THR B  82      65.401  80.465  15.195  1.00 16.08           C  \\nATOM   7295  O   THR B  82      64.405  81.138  15.372  1.00 16.08           O  \\nATOM   7296  CB  THR B  82      65.552  78.114  15.951  1.00 21.76           C  \\nATOM   7297  OG1 THR B  82      64.148  78.011  15.681  1.00 21.76           O  \\nATOM   7298  CG2 THR B  82      65.926  77.213  17.136  1.00 21.76           C  \\nATOM   7299  N   ALA B  83      66.090  80.487  14.059  1.00 27.09           N  \\nATOM   7300  CA  ALA B  83      65.659  81.304  12.937  1.00 27.09           C  \\nATOM   7301  C   ALA B  83      64.253  80.839  12.590  1.00 27.09           C  \\nATOM   7302  O   ALA B  83      63.407  81.644  12.246  1.00 27.09           O  \\nATOM   7303  CB  ALA B  83      66.572  81.110  11.764  1.00 33.80           C  \\nATOM   7304  N   MET B  84      63.991  79.540  12.749  1.00 10.33           N  \\nATOM   7305  CA  MET B  84      62.674  78.982  12.477  1.00 10.33           C  \\nATOM   7306  C   MET B  84      61.636  79.693  13.301  1.00 10.33           C  \\nATOM   7307  O   MET B  84      60.631  80.164  12.771  1.00 10.33           O  \\nATOM   7308  CB  MET B  84      62.648  77.499  12.787  1.00 52.77           C  \\nATOM   7309  CG  MET B  84      63.310  76.710  11.706  1.00 52.77           C  \\nATOM   7310  SD  MET B  84      62.752  77.371  10.127  1.00 52.77           S  \\nATOM   7311  CE  MET B  84      61.591  76.132   9.599  1.00 52.77           C  \\nATOM   7312  N   ASP B  85      61.899  79.821  14.595  1.00 18.96           N  \\nATOM   7313  CA  ASP B  85      60.954  80.496  15.481  1.00 18.96           C  \\nATOM   7314  C   ASP B  85      60.679  81.903  14.975  1.00 18.96           C  \\nATOM   7315  O   ASP B  85      59.540  82.324  14.945  1.00 18.96           O  \\nATOM   7316  CB  ASP B  85      61.448  80.532  16.940  1.00 24.55           C  \\nATOM   7317  CG  ASP B  85      61.768  79.146  17.504  1.00 24.55           C  \\nATOM   7318  OD1 ASP B  85      61.227  78.131  17.009  1.00 24.55           O  \\nATOM   7319  OD2 ASP B  85      62.579  79.070  18.448  1.00 24.55           O  \\nATOM   7320  N   VAL B  86      61.712  82.614  14.533  1.00 21.48           N  \\nATOM   7321  CA  VAL B  86      61.537  83.977  14.017  1.00 21.48           C  \\nATOM   7322  C   VAL B  86      60.691  84.021  12.743  1.00 21.48           C  \\nATOM   7323  O   VAL B  86      59.833  84.882  12.576  1.00 21.48           O  \\nATOM   7324  CB  VAL B  86      62.877  84.623  13.750  1.00 13.43           C  \\nATOM   7325  CG1 VAL B  86      62.693  85.964  13.089  1.00 13.43           C  \\nATOM   7326  CG2 VAL B  86      63.620  84.755  15.054  1.00 13.43           C  \\nATOM   7327  N   VAL B  87      60.942  83.076  11.851  1.00 17.90           N  \\nATOM   7328  CA  VAL B  87      60.209  82.961  10.604  1.00 17.90           C  \\nATOM   7329  C   VAL B  87      58.743  82.672  10.800  1.00 17.90           C  \\nATOM   7330  O   VAL B  87      57.907  83.282  10.148  1.00 17.90           O  \\nATOM   7331  CB  VAL B  87      60.789  81.864   9.742  1.00 17.42           C  \\nATOM   7332  CG1 VAL B  87      59.869  81.589   8.567  1.00 17.42           C  \\nATOM   7333  CG2 VAL B  87      62.172  82.292   9.255  1.00 17.42           C  \\nATOM   7334  N   TYR B  88      58.449  81.687  11.638  1.00 27.78           N  \\nATOM   7335  CA  TYR B  88      57.079  81.303  11.949  1.00 27.78           C  \\nATOM   7336  C   TYR B  88      56.315  82.495  12.533  1.00 27.78           C  \\nATOM   7337  O   TYR B  88      55.146  82.692  12.214  1.00 27.78           O  \\nATOM   7338  CB  TYR B  88      57.076  80.165  12.970  1.00 30.89           C  \\nATOM   7339  CG  TYR B  88      57.596  78.834  12.480  1.00 30.89           C  \\nATOM   7340  CD1 TYR B  88      57.437  78.447  11.156  1.00 30.89           C  \\nATOM   7341  CD2 TYR B  88      58.171  77.927  13.365  1.00 30.89           C  \\nATOM   7342  CE1 TYR B  88      57.818  77.194  10.721  1.00 30.89           C  \\nATOM   7343  CE2 TYR B  88      58.555  76.665  12.945  1.00 30.89           C  \\nATOM   7344  CZ  TYR B  88      58.365  76.303  11.618  1.00 30.89           C  \\nATOM   7345  OH  TYR B  88      58.637  75.019  11.198  1.00 30.89           O  \\nATOM   7346  N   ALA B  89      56.963  83.254  13.424  1.00 26.47           N  \\nATOM   7347  CA  ALA B  89      56.364  84.441  14.053  1.00 26.47           C  \\nATOM   7348  C   ALA B  89      56.050  85.501  13.009  1.00 26.47           C  \\nATOM   7349  O   ALA B  89      55.024  86.160  13.100  1.00 26.47           O  \\nATOM   7350  CB  ALA B  89      57.292  85.016  15.108  1.00 21.23           C  \\nATOM   7351  N   LEU B  90      56.973  85.717  12.073  1.00 15.46           N  \\nATOM   7352  CA  LEU B  90      56.758  86.666  11.001  1.00 15.46           C  \\nATOM   7353  C   LEU B  90      55.559  86.242  10.137  1.00 15.46           C  \\nATOM   7354  O   LEU B  90      54.677  87.059   9.852  1.00 15.46           O  \\nATOM   7355  CB  LEU B  90      58.021  86.816  10.148  1.00 18.59           C  \\nATOM   7356  CG  LEU B  90      59.194  87.607  10.765  1.00 18.59           C  \\nATOM   7357  CD1 LEU B  90      60.437  87.509   9.934  1.00 18.59           C  \\nATOM   7358  CD2 LEU B  90      58.823  89.056  10.924  1.00 18.59           C  \\nATOM   7359  N   LYS B  91      55.487  84.974   9.739  1.00 23.84           N  \\nATOM   7360  CA  LYS B  91      54.350  84.540   8.921  1.00 23.84           C  \\nATOM   7361  C   LYS B  91      53.018  84.895   9.567  1.00 23.84           C  \\nATOM   7362  O   LYS B  91      52.077  85.251   8.865  1.00 23.84           O  \\nATOM   7363  CB  LYS B  91      54.402  83.056   8.582  1.00 36.83           C  \\nATOM   7364  CG  LYS B  91      53.411  82.699   7.494  1.00 36.83           C  \\nATOM   7365  CD  LYS B  91      53.923  81.633   6.551  1.00 36.83           C  \\nATOM   7366  CE  LYS B  91      54.307  80.382   7.318  1.00 36.83           C  \\nATOM   7367  NZ  LYS B  91      55.274  79.488   6.582  1.00 36.83           N  \\nATOM   7368  N   ARG B  92      52.942  84.773  10.893  1.00 36.26           N  \\nATOM   7369  CA  ARG B  92      51.738  85.126  11.641  1.00 36.26           C  \\nATOM   7370  C   ARG B  92      51.522  86.618  11.621  1.00 36.26           C  \\nATOM   7371  O   ARG B  92      50.385  87.063  11.710  1.00 36.26           O  \\nATOM   7372  CB  ARG B  92      51.841  84.766  13.108  1.00 34.11           C  \\nATOM   7373  CG  ARG B  92      51.906  83.336  13.440  1.00 34.11           C  \\nATOM   7374  CD  ARG B  92      51.678  83.222  14.919  1.00 34.11           C  \\nATOM   7375  NE  ARG B  92      50.278  83.461  15.212  1.00 34.11           N  \\nATOM   7376  CZ  ARG B  92      49.804  84.524  15.843  1.00 34.11           C  \\nATOM   7377  NH1 ARG B  92      50.623  85.479  16.262  1.00 34.11           N  \\nATOM   7378  NH2 ARG B  92      48.497  84.631  16.038  1.00 34.11           N  \\nATOM   7379  N   GLN B  93      52.601  87.393  11.705  1.00 24.43           N  \\nATOM   7380  CA  GLN B  93      52.443  88.844  11.661  1.00 24.43           C  \\nATOM   7381  C   GLN B  93      51.985  89.228  10.253  1.00 24.43           C  \\nATOM   7382  O   GLN B  93      51.521  90.338  10.023  1.00 24.43           O  \\nATOM   7383  CB  GLN B  93      53.757  89.591  11.980  1.00 38.51           C  \\nATOM   7384  CG  GLN B  93      54.376  89.367  13.346  1.00 38.51           C  \\nATOM   7385  CD  GLN B  93      53.352  89.262  14.457  1.00 38.51           C  \\nATOM   7386  OE1 GLN B  93      52.666  90.223  14.793  1.00 38.51           O  \\nATOM   7387  NE2 GLN B  93      53.236  88.074  15.025  1.00 38.51           N  \\nATOM   7388  N   GLY B  94      52.122  88.302   9.313  1.00 18.83           N  \\nATOM   7389  CA  GLY B  94      51.752  88.587   7.943  1.00 18.83           C  \\nATOM   7390  C   GLY B  94      52.955  89.293   7.359  1.00 18.83           C  \\nATOM   7391  O   GLY B  94      52.830  90.139   6.472  1.00 18.83           O  \\nATOM   7392  N   ARG B  95      54.124  88.950   7.905  1.00 24.27           N  \\nATOM   7393  CA  ARG B  95      55.398  89.507   7.507  1.00 24.27           C  \\nATOM   7394  C   ARG B  95      56.306  88.490   6.851  1.00 24.27           C  \\nATOM   7395  O   ARG B  95      57.516  88.656   6.874  1.00 24.27           O  \\nATOM   7396  CB  ARG B  95      56.094  90.082   8.725  1.00 49.19           C  \\nATOM   7397  CG  ARG B  95      55.546  91.405   9.135  1.00 49.19           C  \\nATOM   7398  CD  ARG B  95      56.169  92.481   8.313  1.00 49.19           C  \\nATOM   7399  NE  ARG B  95      55.212  93.519   7.974  1.00 49.19           N  \\nATOM   7400  CZ  ARG B  95      54.460  94.186   8.853  1.00 49.19           C  \\nATOM   7401  NH1 ARG B  95      54.541  93.929  10.161  1.00 49.19           N  \\nATOM   7402  NH2 ARG B  95      53.616  95.126   8.414  1.00 49.19           N  \\nATOM   7403  N   THR B  96      55.720  87.472   6.232  1.00 34.74           N  \\nATOM   7404  CA  THR B  96      56.452  86.398   5.561  1.00 34.74           C  \\nATOM   7405  C   THR B  96      57.837  86.749   5.000  1.00 34.74           C  \\nATOM   7406  O   THR B  96      57.944  87.631   4.137  1.00 34.74           O  \\nATOM   7407  CB  THR B  96      55.595  85.820   4.423  1.00 21.96           C  \\nATOM   7408  OG1 THR B  96      54.549  85.025   4.979  1.00 21.96           O  \\nATOM   7409  CG2 THR B  96      56.435  84.969   3.444  1.00 21.96           C  \\nATOM   7410  N   LEU B  97      58.872  86.002   5.433  1.00 27.88           N  \\nATOM   7411  CA  LEU B  97      60.274  86.207   4.986  1.00 27.88           C  \\nATOM   7412  C   LEU B  97      60.949  85.026   4.250  1.00 27.88           C  \\nATOM   7413  O   LEU B  97      61.016  83.923   4.774  1.00 27.88           O  \\nATOM   7414  CB  LEU B  97      61.135  86.581   6.196  1.00 17.85           C  \\nATOM   7415  CG  LEU B  97      62.643  86.850   6.029  1.00 17.85           C  \\nATOM   7416  CD1 LEU B  97      62.883  88.183   5.316  1.00 17.85           C  \\nATOM   7417  CD2 LEU B  97      63.330  86.821   7.409  1.00 17.85           C  \\nATOM   7418  N   TYR B  98      61.516  85.267   3.072  1.00 27.30           N  \\nATOM   7419  CA  TYR B  98      62.186  84.181   2.349  1.00 27.30           C  \\nATOM   7420  C   TYR B  98      63.686  84.207   2.637  1.00 27.30           C  \\nATOM   7421  O   TYR B  98      64.284  85.279   2.739  1.00 27.30           O  \\nATOM   7422  CB  TYR B  98      61.989  84.292   0.831  1.00 18.12           C  \\nATOM   7423  CG  TYR B  98      60.620  83.934   0.273  1.00 18.12           C  \\nATOM   7424  CD1 TYR B  98      59.597  83.419   1.080  1.00 18.12           C  \\nATOM   7425  CD2 TYR B  98      60.350  84.126  -1.073  1.00 18.12           C  \\nATOM   7426  CE1 TYR B  98      58.339  83.105   0.549  1.00 18.12           C  \\nATOM   7427  CE2 TYR B  98      59.109  83.820  -1.612  1.00 18.12           C  \\nATOM   7428  CZ  TYR B  98      58.114  83.308  -0.802  1.00 18.12           C  \\nATOM   7429  OH  TYR B  98      56.919  82.975  -1.392  1.00 18.12           O  \\nATOM   7430  N   GLY B  99      64.293  83.027   2.755  1.00 24.18           N  \\nATOM   7431  CA  GLY B  99      65.723  82.947   2.996  1.00 24.18           C  \\nATOM   7432  C   GLY B  99      66.207  82.331   4.285  1.00 24.18           C  \\nATOM   7433  O   GLY B  99      67.404  82.160   4.487  1.00 24.18           O  \\nATOM   7434  N   PHE B 100      65.300  82.001   5.179  1.00 28.64           N  \\nATOM   7435  CA  PHE B 100      65.747  81.423   6.426  1.00 28.64           C  \\nATOM   7436  C   PHE B 100      65.023  80.113   6.752  1.00 28.64           C  \\nATOM   7437  O   PHE B 100      64.891  79.740   7.917  1.00 28.64           O  \\nATOM   7438  CB  PHE B 100      65.636  82.461   7.551  1.00 33.11           C  \\nATOM   7439  CG  PHE B 100      66.460  83.718   7.309  1.00 33.11           C  \\nATOM   7440  CD1 PHE B 100      65.998  84.731   6.475  1.00 33.11           C  \\nATOM   7441  CD2 PHE B 100      67.716  83.880   7.898  1.00 33.11           C  \\nATOM   7442  CE1 PHE B 100      66.780  85.882   6.230  1.00 33.11           C  \\nATOM   7443  CE2 PHE B 100      68.500  85.035   7.654  1.00 33.11           C  \\nATOM   7444  CZ  PHE B 100      68.027  86.026   6.822  1.00 33.11           C  \\nATOM   7445  N   GLY B 101      64.601  79.404   5.705  1.00102.38           N  \\nATOM   7446  CA  GLY B 101      63.911  78.138   5.881  1.00102.38           C  \\nATOM   7447  C   GLY B 101      62.921  77.813   4.772  1.00102.38           C  \\nATOM   7448  O   GLY B 101      63.289  77.679   3.596  1.00102.38           O  \\nATOM   7449  N   GLY B 102      61.655  77.668   5.160  1.00133.12           N  \\nATOM   7450  CA  GLY B 102      60.604  77.353   4.210  1.00133.12           C  \\nATOM   7451  C   GLY B 102      59.275  77.025   4.873  1.00133.12           C  \\nATOM   7452  O   GLY B 102      58.222  77.405   4.315  1.00129.84           O  \\nATOM   7453  OXT GLY B 102      59.275  76.385   5.948  1.00129.84           O  \\nTER    7454      GLY B 102                                                      \\nATOM   7455  N   GLY C   4      31.804  39.350  28.925  1.00123.40           N  \\nATOM   7456  CA  GLY C   4      32.039  40.417  29.944  1.00123.40           C  \\nATOM   7457  C   GLY C   4      31.229  41.687  29.725  1.00123.40           C  \\nATOM   7458  O   GLY C   4      31.620  42.760  30.194  1.00123.40           O  \\nATOM   7459  N   LYS C   5      30.097  41.569  29.027  1.00147.93           N  \\nATOM   7460  CA  LYS C   5      29.225  42.718  28.751  1.00147.93           C  \\nATOM   7461  C   LYS C   5      28.214  42.948  29.875  1.00147.93           C  \\nATOM   7462  O   LYS C   5      27.151  43.539  29.659  1.00147.93           O  \\nATOM   7463  CB  LYS C   5      28.484  42.547  27.414  1.00103.49           C  \\nATOM   7464  CG  LYS C   5      29.395  42.346  26.199  1.00103.49           C  \\nATOM   7465  CD  LYS C   5      30.268  43.559  25.924  1.00103.49           C  \\nATOM   7466  CE  LYS C   5      31.540  43.154  25.200  1.00103.49           C  \\nATOM   7467  NZ  LYS C   5      32.438  42.342  26.076  1.00103.49           N  \\nATOM   7468  N   GLN C   6      28.564  42.487  31.076  1.00150.26           N  \\nATOM   7469  CA  GLN C   6      27.715  42.646  32.254  1.00150.26           C  \\nATOM   7470  C   GLN C   6      27.709  44.115  32.702  1.00150.26           C  \\nATOM   7471  O   GLN C   6      26.865  44.523  33.504  1.00150.26           O  \\nATOM   7472  CB  GLN C   6      28.192  41.716  33.395  1.00114.92           C  \\nATOM   7473  CG  GLN C   6      29.133  42.331  34.471  1.00114.92           C  \\nATOM   7474  CD  GLN C   6      30.586  42.493  34.028  1.00114.92           C  \\nATOM   7475  OE1 GLN C   6      31.153  41.623  33.365  1.00114.92           O  \\nATOM   7476  NE2 GLN C   6      31.205  43.595  34.438  1.00114.92           N  \\nATOM   7477  N   GLY C   7      28.638  44.899  32.149  1.00160.45           N  \\nATOM   7478  CA  GLY C   7      28.758  46.311  32.482  1.00160.45           C  \\nATOM   7479  C   GLY C   7      27.754  47.264  31.849  1.00160.45           C  \\nATOM   7480  O   GLY C   7      27.507  48.341  32.398  1.00160.45           O  \\nATOM   7481  N   GLY C   8      27.188  46.892  30.699  1.00116.43           N  \\nATOM   7482  CA  GLY C   8      26.214  47.746  30.036  1.00116.43           C  \\nATOM   7483  C   GLY C   8      24.813  47.575  30.601  1.00116.43           C  \\nATOM   7484  O   GLY C   8      23.888  47.225  29.862  1.00116.43           O  \\nATOM   7485  N   LYS C   9      24.663  47.827  31.906  1.00164.89           N  \\nATOM   7486  CA  LYS C   9      23.382  47.699  32.614  1.00164.89           C  \\nATOM   7487  C   LYS C   9      23.210  48.645  33.829  1.00164.89           C  \\nATOM   7488  O   LYS C   9      23.826  49.715  33.878  1.00164.89           O  \\nATOM   7489  CB  LYS C   9      23.141  46.235  33.022  1.00101.49           C  \\nATOM   7490  CG  LYS C   9      22.698  45.323  31.872  1.00101.49           C  \\nATOM   7491  CD  LYS C   9      22.515  43.887  32.330  1.00101.49           C  \\nATOM   7492  CE  LYS C   9      22.051  42.995  31.194  1.00101.49           C  \\nATOM   7493  NZ  LYS C   9      21.907  41.591  31.665  1.00101.49           N  \\nATOM   7494  N   THR C  10      22.380  48.235  34.797  1.00200.00           N  \\nATOM   7495  CA  THR C  10      22.051  49.016  36.009  1.00200.00           C  \\nATOM   7496  C   THR C  10      23.173  49.645  36.852  1.00200.00           C  \\nATOM   7497  O   THR C  10      24.352  49.305  36.710  1.00200.00           O  \\nATOM   7498  CB  THR C  10      21.132  48.214  36.983  1.00117.52           C  \\nATOM   7499  OG1 THR C  10      21.803  47.022  37.408  1.00117.52           O  \\nATOM   7500  CG2 THR C  10      19.800  47.851  36.318  1.00117.52           C  \\nATOM   7501  N   ARG C  11      22.761  50.556  37.740  1.00190.26           N  \\nATOM   7502  CA  ARG C  11      23.634  51.295  38.664  1.00190.26           C  \\nATOM   7503  C   ARG C  11      24.693  52.218  38.029  1.00190.26           C  \\nATOM   7504  O   ARG C  11      25.054  52.055  36.858  1.00190.26           O  \\nATOM   7505  CB  ARG C  11      24.263  50.351  39.706  1.00136.27           C  \\nATOM   7506  CG  ARG C  11      23.264  49.788  40.719  1.00136.27           C  \\nATOM   7507  CD  ARG C  11      23.962  49.052  41.856  1.00136.27           C  \\nATOM   7508  NE  ARG C  11      23.006  48.549  42.841  1.00136.27           N  \\nATOM   7509  CZ  ARG C  11      23.014  48.863  44.136  1.00136.27           C  \\nATOM   7510  NH1 ARG C  11      23.932  49.687  44.628  1.00136.27           N  \\nATOM   7511  NH2 ARG C  11      22.095  48.355  44.943  1.00136.27           N  \\nATOM   7512  N   ALA C  12      25.156  53.196  38.818  1.00182.74           N  \\nATOM   7513  CA  ALA C  12      26.159  54.200  38.416  1.00182.74           C  \\nATOM   7514  C   ALA C  12      25.575  55.315  37.536  1.00182.74           C  \\nATOM   7515  O   ALA C  12      25.199  56.378  38.040  1.00182.74           O  \\nATOM   7516  CB  ALA C  12      27.373  53.535  37.725  1.00 59.54           C  \\nATOM   7517  N   LYS C  13      25.518  55.059  36.228  1.00160.17           N  \\nATOM   7518  CA  LYS C  13      24.982  55.982  35.218  1.00160.17           C  \\nATOM   7519  C   LYS C  13      25.815  57.219  34.829  1.00160.17           C  \\nATOM   7520  O   LYS C  13      26.339  57.944  35.681  1.00160.17           O  \\nATOM   7521  CB  LYS C  13      23.522  56.341  35.530  1.00117.36           C  \\nATOM   7522  CG  LYS C  13      22.558  55.135  35.428  1.00117.36           C  \\nATOM   7523  CD  LYS C  13      22.536  54.518  34.013  1.00117.36           C  \\nATOM   7524  CE  LYS C  13      21.549  53.352  33.888  1.00117.36           C  \\nATOM   7525  NZ  LYS C  13      21.404  52.918  32.470  1.00117.36           N  \\nATOM   7526  N   ALA C  14      25.886  57.437  33.513  1.00122.68           N  \\nATOM   7527  CA  ALA C  14      26.642  58.509  32.854  1.00122.68           C  \\nATOM   7528  C   ALA C  14      26.756  59.908  33.462  1.00122.68           C  \\nATOM   7529  O   ALA C  14      26.083  60.268  34.428  1.00122.68           O  \\nATOM   7530  CB  ALA C  14      26.207  58.618  31.383  1.00 51.52           C  \\nATOM   7531  N   LYS C  15      27.628  60.692  32.838  1.00 63.03           N  \\nATOM   7532  CA  LYS C  15      27.919  62.055  33.239  1.00 63.03           C  \\nATOM   7533  C   LYS C  15      28.709  62.687  32.091  1.00 63.03           C  \\nATOM   7534  O   LYS C  15      29.737  62.154  31.662  1.00 63.03           O  \\nATOM   7535  CB  LYS C  15      28.753  62.038  34.514  1.00 82.58           C  \\nATOM   7536  CG  LYS C  15      28.933  63.388  35.122  1.00 82.58           C  \\nATOM   7537  CD  LYS C  15      29.278  63.278  36.588  1.00 82.58           C  \\nATOM   7538  CE  LYS C  15      29.318  64.657  37.228  1.00 82.58           C  \\nATOM   7539  NZ  LYS C  15      29.686  64.630  38.673  1.00 82.58           N  \\nATOM   7540  N   THR C  16      28.214  63.805  31.574  1.00 36.52           N  \\nATOM   7541  CA  THR C  16      28.885  64.465  30.462  1.00 36.52           C  \\nATOM   7542  C   THR C  16      30.253  65.009  30.835  1.00 36.52           C  \\nATOM   7543  O   THR C  16      30.524  65.341  31.990  1.00 36.52           O  \\nATOM   7544  CB  THR C  16      28.063  65.628  29.863  1.00 36.53           C  \\nATOM   7545  OG1 THR C  16      27.672  66.530  30.910  1.00 36.53           O  \\nATOM   7546  CG2 THR C  16      26.853  65.110  29.087  1.00 36.53           C  \\nATOM   7547  N   ARG C  17      31.094  65.147  29.816  1.00 44.30           N  \\nATOM   7548  CA  ARG C  17      32.439  65.653  30.002  1.00 44.30           C  \\nATOM   7549  C   ARG C  17      32.444  67.141  30.314  1.00 44.30           C  \\nATOM   7550  O   ARG C  17      33.344  67.637  30.996  1.00 44.30           O  \\nATOM   7551  CB  ARG C  17      33.294  65.337  28.786  1.00 35.38           C  \\nATOM   7552  CG  ARG C  17      33.516  63.837  28.604  1.00 35.38           C  \\nATOM   7553  CD  ARG C  17      34.701  63.541  27.705  1.00 35.38           C  \\nATOM   7554  NE  ARG C  17      34.368  63.615  26.292  1.00 35.38           N  \\nATOM   7555  CZ  ARG C  17      35.242  63.931  25.346  1.00 35.38           C  \\nATOM   7556  NH1 ARG C  17      36.515  64.212  25.664  1.00 35.38           N  \\nATOM   7557  NH2 ARG C  17      34.849  63.898  24.078  1.00 35.38           N  \\nATOM   7558  N   SER C  18      31.425  67.859  29.844  1.00 27.18           N  \\nATOM   7559  CA  SER C  18      31.349  69.280  30.153  1.00 27.18           C  \\nATOM   7560  C   SER C  18      31.086  69.326  31.644  1.00 27.18           C  \\nATOM   7561  O   SER C  18      31.701  70.096  32.354  1.00 27.18           O  \\nATOM   7562  CB  SER C  18      30.236  69.946  29.366  1.00 24.08           C  \\nATOM   7563  OG  SER C  18      30.425  69.682  27.991  1.00 24.08           O  \\nATOM   7564  N   SER C  19      30.225  68.425  32.110  1.00 34.32           N  \\nATOM   7565  CA  SER C  19      29.887  68.304  33.523  1.00 34.32           C  \\nATOM   7566  C   SER C  19      31.161  68.104  34.372  1.00 34.32           C  \\nATOM   7567  O   SER C  19      31.388  68.791  35.388  1.00 34.32           O  \\nATOM   7568  CB  SER C  19      28.932  67.128  33.684  1.00 56.76           C  \\nATOM   7569  OG  SER C  19      28.762  66.800  35.038  1.00 56.76           O  \\nATOM   7570  N   ARG C  20      31.983  67.147  33.952  1.00 31.04           N  \\nATOM   7571  CA  ARG C  20      33.251  66.859  34.618  1.00 31.04           C  \\nATOM   7572  C   ARG C  20      34.190  68.082  34.622  1.00 31.04           C  \\nATOM   7573  O   ARG C  20      34.740  68.431  35.667  1.00 31.04           O  \\nATOM   7574  CB  ARG C  20      33.920  65.660  33.951  1.00 96.39           C  \\nATOM   7575  CG  ARG C  20      33.035  64.437  33.943  1.00 96.39           C  \\nATOM   7576  CD  ARG C  20      33.631  63.309  33.161  1.00 96.39           C  \\nATOM   7577  NE  ARG C  20      32.844  62.101  33.352  1.00 96.39           N  \\nATOM   7578  CZ  ARG C  20      33.136  60.929  32.803  1.00 96.39           C  \\nATOM   7579  NH1 ARG C  20      34.199  60.808  32.017  1.00 96.39           N  \\nATOM   7580  NH2 ARG C  20      32.386  59.869  33.067  1.00 96.39           N  \\nATOM   7581  N   ALA C  21      34.345  68.749  33.474  1.00 30.60           N  \\nATOM   7582  CA  ALA C  21      35.210  69.933  33.372  1.00 30.60           C  \\nATOM   7583  C   ALA C  21      34.711  71.144  34.161  1.00 30.60           C  \\nATOM   7584  O   ALA C  21      35.500  72.020  34.504  1.00 30.60           O  \\nATOM   7585  CB  ALA C  21      35.405  70.312  31.930  1.00 34.29           C  \\nATOM   7586  N   GLY C  22      33.396  71.195  34.398  1.00 32.80           N  \\nATOM   7587  CA  GLY C  22      32.760  72.278  35.137  1.00 32.80           C  \\nATOM   7588  C   GLY C  22      32.322  73.334  34.148  1.00 32.80           C  \\nATOM   7589  O   GLY C  22      32.238  74.523  34.471  1.00 32.80           O  \\nATOM   7590  N   LEU C  23      31.983  72.879  32.947  1.00 19.16           N  \\nATOM   7591  CA  LEU C  23      31.607  73.780  31.867  1.00 19.16           C  \\nATOM   7592  C   LEU C  23      30.188  73.712  31.293  1.00 19.16           C  \\nATOM   7593  O   LEU C  23      29.495  72.685  31.367  1.00 19.16           O  \\nATOM   7594  CB  LEU C  23      32.606  73.626  30.701  1.00 24.74           C  \\nATOM   7595  CG  LEU C  23      34.127  73.683  30.920  1.00 24.74           C  \\nATOM   7596  CD1 LEU C  23      34.841  73.463  29.592  1.00 24.74           C  \\nATOM   7597  CD2 LEU C  23      34.540  75.009  31.527  1.00 24.74           C  \\nATOM   7598  N   GLN C  24      29.795  74.829  30.680  1.00 26.26           N  \\nATOM   7599  CA  GLN C  24      28.504  74.963  30.032  1.00 26.26           C  \\nATOM   7600  C   GLN C  24      28.651  74.484  28.595  1.00 26.26           C  \\nATOM   7601  O   GLN C  24      27.807  73.742  28.118  1.00 26.26           O  \\nATOM   7602  CB  GLN C  24      28.015  76.419  30.047  1.00 20.89           C  \\nATOM   7603  CG  GLN C  24      27.845  77.066  31.445  1.00 20.89           C  \\nATOM   7604  CD  GLN C  24      26.904  76.296  32.341  1.00 20.89           C  \\nATOM   7605  OE1 GLN C  24      25.735  76.091  32.019  1.00 20.89           O  \\nATOM   7606  NE2 GLN C  24      27.423  75.840  33.465  1.00 20.89           N  \\nATOM   7607  N   PHE C  25      29.751  74.873  27.941  1.00 27.29           N  \\nATOM   7608  CA  PHE C  25      30.051  74.494  26.546  1.00 27.29           C  \\nATOM   7609  C   PHE C  25      30.239  72.972  26.357  1.00 27.29           C  \\nATOM   7610  O   PHE C  25      30.633  72.268  27.296  1.00 27.29           O  \\nATOM   7611  CB  PHE C  25      31.268  75.280  26.030  1.00 29.98           C  \\nATOM   7612  CG  PHE C  25      30.915  76.611  25.398  1.00 29.98           C  \\nATOM   7613  CD1 PHE C  25      29.913  77.423  25.944  1.00 29.98           C  \\nATOM   7614  CD2 PHE C  25      31.519  77.010  24.199  1.00 29.98           C  \\nATOM   7615  CE1 PHE C  25      29.508  78.611  25.301  1.00 29.98           C  \\nATOM   7616  CE2 PHE C  25      31.121  78.196  23.546  1.00 29.98           C  \\nATOM   7617  CZ  PHE C  25      30.108  78.993  24.100  1.00 29.98           C  \\nATOM   7618  N   PRO C  26      29.972  72.454  25.131  1.00 28.33           N  \\nATOM   7619  CA  PRO C  26      30.059  71.042  24.718  1.00 28.33           C  \\nATOM   7620  C   PRO C  26      31.433  70.441  24.493  1.00 28.33           C  \\nATOM   7621  O   PRO C  26      31.931  70.470  23.380  1.00 28.33           O  \\nATOM   7622  CB  PRO C  26      29.276  71.032  23.413  1.00 22.13           C  \\nATOM   7623  CG  PRO C  26      29.704  72.313  22.794  1.00 22.13           C  \\nATOM   7624  CD  PRO C  26      29.630  73.299  23.969  1.00 22.13           C  \\nATOM   7625  N   VAL C  27      32.008  69.825  25.523  1.00 19.54           N  \\nATOM   7626  CA  VAL C  27      33.321  69.207  25.404  1.00 19.54           C  \\nATOM   7627  C   VAL C  27      33.204  68.063  24.416  1.00 19.54           C  \\nATOM   7628  O   VAL C  27      34.077  67.872  23.564  1.00 19.54           O  \\nATOM   7629  CB  VAL C  27      33.780  68.676  26.741  1.00  9.81           C  \\nATOM   7630  CG1 VAL C  27      35.050  67.840  26.581  1.00  9.81           C  \\nATOM   7631  CG2 VAL C  27      33.996  69.835  27.689  1.00  9.81           C  \\nATOM   7632  N   GLY C  28      32.078  67.356  24.497  1.00 22.10           N  \\nATOM   7633  CA  GLY C  28      31.840  66.254  23.592  1.00 22.10           C  \\nATOM   7634  C   GLY C  28      31.932  66.750  22.162  1.00 22.10           C  \\nATOM   7635  O   GLY C  28      32.791  66.313  21.411  1.00 22.10           O  \\nATOM   7636  N   ARG C  29      31.092  67.722  21.813  1.00 26.79           N  \\nATOM   7637  CA  ARG C  29      31.053  68.295  20.458  1.00 26.79           C  \\nATOM   7638  C   ARG C  29      32.358  68.941  19.972  1.00 26.79           C  \\nATOM   7639  O   ARG C  29      32.737  68.807  18.816  1.00 26.79           O  \\nATOM   7640  CB  ARG C  29      29.892  69.299  20.352  1.00 40.02           C  \\nATOM   7641  CG  ARG C  29      30.024  70.288  19.216  1.00 40.02           C  \\nATOM   7642  CD  ARG C  29      28.866  70.225  18.281  1.00 40.02           C  \\nATOM   7643  NE  ARG C  29      27.783  71.144  18.615  1.00 40.02           N  \\nATOM   7644  CZ  ARG C  29      26.559  70.757  18.971  1.00 40.02           C  \\nATOM   7645  NH1 ARG C  29      26.252  69.465  19.063  1.00 40.02           N  \\nATOM   7646  NH2 ARG C  29      25.603  71.653  19.143  1.00 40.02           N  \\nATOM   7647  N   VAL C  30      33.011  69.693  20.843  1.00 26.10           N  \\nATOM   7648  CA  VAL C  30      34.259  70.344  20.506  1.00 26.10           C  \\nATOM   7649  C   VAL C  30      35.313  69.287  20.148  1.00 26.10           C  \\nATOM   7650  O   VAL C  30      35.898  69.359  19.076  1.00 26.10           O  \\nATOM   7651  CB  VAL C  30      34.720  71.263  21.670  1.00 12.73           C  \\nATOM   7652  CG1 VAL C  30      36.153  71.686  21.490  1.00 12.73           C  \\nATOM   7653  CG2 VAL C  30      33.828  72.494  21.755  1.00 12.73           C  \\nATOM   7654  N   HIS C  31      35.502  68.272  20.998  1.00 38.23           N  \\nATOM   7655  CA  HIS C  31      36.480  67.194  20.737  1.00 38.23           C  \\nATOM   7656  C   HIS C  31      36.212  66.595  19.369  1.00 38.23           C  \\nATOM   7657  O   HIS C  31      37.124  66.306  18.607  1.00 38.23           O  \\nATOM   7658  CB  HIS C  31      36.348  66.081  21.783  1.00 40.63           C  \\nATOM   7659  CG  HIS C  31      37.442  65.058  21.732  1.00 40.63           C  \\nATOM   7660  ND1 HIS C  31      38.716  65.344  21.290  1.00 40.63           N  \\nATOM   7661  CD2 HIS C  31      37.460  63.757  22.107  1.00 40.63           C  \\nATOM   7662  CE1 HIS C  31      39.473  64.267  21.399  1.00 40.63           C  \\nATOM   7663  NE2 HIS C  31      38.734  63.291  21.892  1.00 40.63           N  \\nATOM   7664  N   ARG C  32      34.935  66.400  19.086  1.00 53.53           N  \\nATOM   7665  CA  ARG C  32      34.487  65.851  17.824  1.00 53.53           C  \\nATOM   7666  C   ARG C  32      34.857  66.730  16.623  1.00 53.53           C  \\nATOM   7667  O   ARG C  32      35.311  66.222  15.593  1.00 53.53           O  \\nATOM   7668  CB  ARG C  32      32.977  65.653  17.887  1.00 39.79           C  \\nATOM   7669  CG  ARG C  32      32.419  64.860  16.745  1.00 39.79           C  \\nATOM   7670  CD  ARG C  32      30.921  64.815  16.821  1.00 39.79           C  \\nATOM   7671  NE  ARG C  32      30.301  65.818  15.961  1.00 39.79           N  \\nATOM   7672  CZ  ARG C  32      29.533  66.813  16.399  1.00 39.79           C  \\nATOM   7673  NH1 ARG C  32      29.293  66.975  17.694  1.00 39.79           N  \\nATOM   7674  NH2 ARG C  32      28.906  67.580  15.529  1.00 39.79           N  \\nATOM   7675  N   LEU C  33      34.624  68.039  16.736  1.00 52.46           N  \\nATOM   7676  CA  LEU C  33      34.943  68.980  15.658  1.00 52.46           C  \\nATOM   7677  C   LEU C  33      36.433  69.057  15.368  1.00 52.46           C  \\nATOM   7678  O   LEU C  33      36.833  69.390  14.250  1.00 52.46           O  \\nATOM   7679  CB  LEU C  33      34.416  70.374  15.973  1.00 21.73           C  \\nATOM   7680  CG  LEU C  33      32.901  70.513  16.055  1.00 21.73           C  \\nATOM   7681  CD1 LEU C  33      32.514  71.928  16.553  1.00 21.73           C  \\nATOM   7682  CD2 LEU C  33      32.283  70.206  14.699  1.00 21.73           C  \\nATOM   7683  N   LEU C  34      37.242  68.844  16.404  1.00 35.66           N  \\nATOM   7684  CA  LEU C  34      38.695  68.840  16.271  1.00 35.66           C  \\nATOM   7685  C   LEU C  34      39.181  67.689  15.370  1.00 35.66           C  \\nATOM   7686  O   LEU C  34      40.103  67.861  14.567  1.00 35.66           O  \\nATOM   7687  CB  LEU C  34      39.345  68.771  17.653  1.00  9.33           C  \\nATOM   7688  CG  LEU C  34      39.366  70.086  18.452  1.00  9.33           C  \\nATOM   7689  CD1 LEU C  34      40.000  69.908  19.832  1.00  9.33           C  \\nATOM   7690  CD2 LEU C  34      40.159  71.140  17.677  1.00  9.33           C  \\nATOM   7691  N   ARG C  35      38.576  66.515  15.522  1.00 52.98           N  \\nATOM   7692  CA  ARG C  35      38.928  65.370  14.698  1.00 52.98           C  \\nATOM   7693  C   ARG C  35      38.544  65.646  13.252  1.00 52.98           C  \\nATOM   7694  O   ARG C  35      39.406  65.663  12.368  1.00 52.98           O  \\nATOM   7695  CB  ARG C  35      38.191  64.117  15.160  1.00 48.67           C  \\nATOM   7696  CG  ARG C  35      38.459  63.726  16.581  1.00 48.67           C  \\nATOM   7697  CD  ARG C  35      37.649  62.513  16.958  1.00 48.67           C  \\nATOM   7698  NE  ARG C  35      37.898  62.116  18.339  1.00 48.67           N  \\nATOM   7699  CZ  ARG C  35      39.095  61.794  18.828  1.00 48.67           C  \\nATOM   7700  NH1 ARG C  35      40.180  61.818  18.049  1.00 48.67           N  \\nATOM   7701  NH2 ARG C  35      39.210  61.436  20.105  1.00 48.67           N  \\nATOM   7702  N   LYS C  36      37.267  65.953  13.027  1.00 33.81           N  \\nATOM   7703  CA  LYS C  36      36.766  66.191  11.668  1.00 33.81           C  \\nATOM   7704  C   LYS C  36      37.276  67.407  10.885  1.00 33.81           C  \\nATOM   7705  O   LYS C  36      36.921  67.588   9.713  1.00 33.81           O  \\nATOM   7706  CB  LYS C  36      35.237  66.109  11.653  1.00120.36           C  \\nATOM   7707  CG  LYS C  36      34.754  64.688  11.908  1.00120.36           C  \\nATOM   7708  CD  LYS C  36      33.267  64.600  12.176  1.00120.36           C  \\nATOM   7709  CE  LYS C  36      32.887  63.181  12.599  1.00120.36           C  \\nATOM   7710  NZ  LYS C  36      31.449  63.075  12.968  1.00120.36           N  \\nATOM   7711  N   GLY C  37      38.174  68.178  11.505  1.00 26.55           N  \\nATOM   7712  CA  GLY C  37      38.737  69.364  10.873  1.00 26.55           C  \\nATOM   7713  C   GLY C  37      40.157  69.162  10.389  1.00 26.55           C  \\nATOM   7714  O   GLY C  37      40.749  70.076   9.802  1.00 26.55           O  \\nATOM   7715  N   ASN C  38      40.703  67.975  10.659  1.00 50.66           N  \\nATOM   7716  CA  ASN C  38      42.049  67.596  10.244  1.00 50.66           C  \\nATOM   7717  C   ASN C  38      43.100  68.613  10.603  1.00 50.66           C  \\nATOM   7718  O   ASN C  38      43.598  69.370   9.754  1.00 50.66           O  \\nATOM   7719  CB  ASN C  38      42.087  67.309   8.753  1.00 95.21           C  \\nATOM   7720  CG  ASN C  38      41.230  66.137   8.372  1.00 95.21           C  \\nATOM   7721  OD1 ASN C  38      40.960  65.933   7.194  1.00 95.21           O  \\nATOM   7722  ND2 ASN C  38      40.744  65.385   9.366  1.00 95.21           N  \\nATOM   7723  N   TYR C  39      43.416  68.636  11.886  1.00 45.69           N  \\nATOM   7724  CA  TYR C  39      44.402  69.554  12.406  1.00 45.69           C  \\nATOM   7725  C   TYR C  39      45.686  68.815  12.705  1.00 45.69           C  \\nATOM   7726  O   TYR C  39      46.779  69.302  12.438  1.00 45.69           O  \\nATOM   7727  CB  TYR C  39      43.824  70.216  13.644  1.00 32.01           C  \\nATOM   7728  CG  TYR C  39      42.669  71.113  13.289  1.00 32.01           C  \\nATOM   7729  CD1 TYR C  39      42.866  72.220  12.459  1.00 32.01           C  \\nATOM   7730  CD2 TYR C  39      41.399  70.880  13.781  1.00 32.01           C  \\nATOM   7731  CE1 TYR C  39      41.832  73.081  12.134  1.00 32.01           C  \\nATOM   7732  CE2 TYR C  39      40.341  71.738  13.459  1.00 32.01           C  \\nATOM   7733  CZ  TYR C  39      40.561  72.850  12.633  1.00 32.01           C  \\nATOM   7734  OH  TYR C  39      39.533  73.746  12.327  1.00 32.01           O  \\nATOM   7735  N   ALA C  40      45.536  67.610  13.230  1.00 27.55           N  \\nATOM   7736  CA  ALA C  40      46.666  66.768  13.560  1.00 27.55           C  \\nATOM   7737  C   ALA C  40      46.163  65.346  13.447  1.00 27.55           C  \\nATOM   7738  O   ALA C  40      44.961  65.135  13.298  1.00 27.55           O  \\nATOM   7739  CB  ALA C  40      47.133  67.058  14.961  1.00  5.11           C  \\nATOM   7740  N   GLU C  41      47.063  64.368  13.481  1.00 43.32           N  \\nATOM   7741  CA  GLU C  41      46.628  62.974  13.389  1.00 43.32           C  \\nATOM   7742  C   GLU C  41      45.736  62.615  14.577  1.00 43.32           C  \\nATOM   7743  O   GLU C  41      44.556  62.304  14.418  1.00 43.32           O  \\nATOM   7744  CB  GLU C  41      47.832  62.029  13.317  1.00165.44           C  \\nATOM   7745  CG  GLU C  41      48.629  62.124  12.017  1.00165.44           C  \\nATOM   7746  CD  GLU C  41      47.781  61.896  10.765  1.00165.44           C  \\nATOM   7747  OE1 GLU C  41      46.791  61.131  10.823  1.00165.44           O  \\nATOM   7748  OE2 GLU C  41      48.109  62.484   9.712  1.00165.44           O  \\nATOM   7749  N   ARG C  42      46.278  62.783  15.771  1.00 23.94           N  \\nATOM   7750  CA  ARG C  42      45.561  62.472  16.985  1.00 23.94           C  \\nATOM   7751  C   ARG C  42      45.230  63.739  17.795  1.00 23.94           C  \\nATOM   7752  O   ARG C  42      45.903  64.762  17.656  1.00 23.94           O  \\nATOM   7753  CB  ARG C  42      46.411  61.531  17.844  1.00 66.90           C  \\nATOM   7754  CG  ARG C  42      46.914  60.283  17.143  1.00 66.90           C  \\nATOM   7755  CD  ARG C  42      48.165  59.733  17.837  1.00 66.90           C  \\nATOM   7756  NE  ARG C  42      48.024  58.339  18.264  1.00 66.90           N  \\nATOM   7757  CZ  ARG C  42      48.224  57.916  19.512  1.00 66.90           C  \\nATOM   7758  NH1 ARG C  42      48.573  58.786  20.461  1.00 66.90           N  \\nATOM   7759  NH2 ARG C  42      48.080  56.623  19.814  1.00 66.90           N  \\nATOM   7760  N   VAL C  43      44.220  63.631  18.669  1.00 28.22           N  \\nATOM   7761  CA  VAL C  43      43.771  64.713  19.554  1.00 28.22           C  \\nATOM   7762  C   VAL C  43      43.584  64.141  20.948  1.00 28.22           C  \\nATOM   7763  O   VAL C  43      42.728  63.287  21.157  1.00 28.22           O  \\nATOM   7764  CB  VAL C  43      42.412  65.337  19.093  1.00 15.12           C  \\nATOM   7765  CG1 VAL C  43      41.837  66.257  20.175  1.00 15.12           C  \\nATOM   7766  CG2 VAL C  43      42.612  66.141  17.845  1.00 15.12           C  \\nATOM   7767  N   GLY C  44      44.325  64.672  21.912  1.00 20.39           N  \\nATOM   7768  CA  GLY C  44      44.235  64.169  23.275  1.00 20.39           C  \\nATOM   7769  C   GLY C  44      42.967  64.605  23.962  1.00 20.39           C  \\nATOM   7770  O   GLY C  44      42.300  65.512  23.481  1.00 20.39           O  \\nATOM   7771  N   ALA C  45      42.653  64.000  25.101  1.00 32.90           N  \\nATOM   7772  CA  ALA C  45      41.437  64.336  25.857  1.00 32.90           C  \\nATOM   7773  C   ALA C  45      41.356  65.774  26.380  1.00 32.90           C  \\nATOM   7774  O   ALA C  45      40.292  66.394  26.386  1.00 32.90           O  \\nATOM   7775  CB  ALA C  45      41.259  63.365  27.013  1.00 33.28           C  \\nATOM   7776  N   GLY C  46      42.480  66.297  26.838  1.00 29.38           N  \\nATOM   7777  CA  GLY C  46      42.483  67.639  27.366  1.00 29.38           C  \\nATOM   7778  C   GLY C  46      42.273  68.682  26.296  1.00 29.38           C  \\nATOM   7779  O   GLY C  46      41.789  69.752  26.584  1.00 29.38           O  \\nATOM   7780  N   ALA C  47      42.588  68.372  25.049  1.00 21.17           N  \\nATOM   7781  CA  ALA C  47      42.430  69.362  23.998  1.00 21.17           C  \\nATOM   7782  C   ALA C  47      41.054  69.998  23.985  1.00 21.17           C  \\nATOM   7783  O   ALA C  47      40.927  71.196  24.202  1.00 21.17           O  \\nATOM   7784  CB  ALA C  47      42.771  68.771  22.621  1.00 50.96           C  \\nATOM   7785  N   PRO C  48      39.995  69.189  23.817  1.00 27.08           N  \\nATOM   7786  CA  PRO C  48      38.660  69.786  23.791  1.00 27.08           C  \\nATOM   7787  C   PRO C  48      38.285  70.509  25.079  1.00 27.08           C  \\nATOM   7788  O   PRO C  48      37.724  71.597  25.027  1.00 27.08           O  \\nATOM   7789  CB  PRO C  48      37.763  68.590  23.489  1.00 19.04           C  \\nATOM   7790  CG  PRO C  48      38.503  67.445  24.114  1.00 19.04           C  \\nATOM   7791  CD  PRO C  48      39.914  67.723  23.699  1.00 19.04           C  \\nATOM   7792  N   VAL C  49      38.636  69.935  26.226  1.00 17.06           N  \\nATOM   7793  CA  VAL C  49      38.335  70.561  27.515  1.00 17.06           C  \\nATOM   7794  C   VAL C  49      38.845  72.005  27.570  1.00 17.06           C  \\nATOM   7795  O   VAL C  49      38.124  72.933  27.944  1.00 17.06           O  \\nATOM   7796  CB  VAL C  49      38.970  69.776  28.676  1.00 18.11           C  \\nATOM   7797  CG1 VAL C  49      38.743  70.504  29.990  1.00 18.11           C  \\nATOM   7798  CG2 VAL C  49      38.406  68.381  28.734  1.00 18.11           C  \\nATOM   7799  N   TYR C  50      40.096  72.182  27.180  1.00 27.15           N  \\nATOM   7800  CA  TYR C  50      40.727  73.487  27.167  1.00 27.15           C  \\nATOM   7801  C   TYR C  50      40.063  74.436  26.195  1.00 27.15           C  \\nATOM   7802  O   TYR C  50      39.704  75.550  26.541  1.00 27.15           O  \\nATOM   7803  CB  TYR C  50      42.185  73.342  26.763  1.00 27.13           C  \\nATOM   7804  CG  TYR C  50      43.027  74.461  27.288  1.00 27.13           C  \\nATOM   7805  CD1 TYR C  50      42.875  75.756  26.808  1.00 27.13           C  \\nATOM   7806  CD2 TYR C  50      43.978  74.225  28.279  1.00 27.13           C  \\nATOM   7807  CE1 TYR C  50      43.648  76.782  27.299  1.00 27.13           C  \\nATOM   7808  CE2 TYR C  50      44.752  75.241  28.779  1.00 27.13           C  \\nATOM   7809  CZ  TYR C  50      44.589  76.516  28.283  1.00 27.13           C  \\nATOM   7810  OH  TYR C  50      45.400  77.518  28.750  1.00 27.13           O  \\nATOM   7811  N   LEU C  51      39.957  74.002  24.953  1.00 17.39           N  \\nATOM   7812  CA  LEU C  51      39.356  74.819  23.925  1.00 17.39           C  \\nATOM   7813  C   LEU C  51      37.964  75.241  24.348  1.00 17.39           C  \\nATOM   7814  O   LEU C  51      37.613  76.405  24.235  1.00 17.39           O  \\nATOM   7815  CB  LEU C  51      39.317  74.065  22.601  1.00 18.01           C  \\nATOM   7816  CG  LEU C  51      38.849  74.958  21.460  1.00 18.01           C  \\nATOM   7817  CD1 LEU C  51      39.588  76.282  21.479  1.00 18.01           C  \\nATOM   7818  CD2 LEU C  51      39.085  74.257  20.174  1.00 18.01           C  \\nATOM   7819  N   ALA C  52      37.194  74.306  24.888  1.00 24.24           N  \\nATOM   7820  CA  ALA C  52      35.849  74.601  25.349  1.00 24.24           C  \\nATOM   7821  C   ALA C  52      35.867  75.665  26.463  1.00 24.24           C  \\nATOM   7822  O   ALA C  52      35.050  76.583  26.473  1.00 24.24           O  \\nATOM   7823  CB  ALA C  52      35.188  73.340  25.827  1.00 16.03           C  \\nATOM   7824  N   ALA C  53      36.817  75.562  27.383  1.00 26.35           N  \\nATOM   7825  CA  ALA C  53      36.929  76.534  28.463  1.00 26.35           C  \\nATOM   7826  C   ALA C  53      37.212  77.921  27.904  1.00 26.35           C  \\nATOM   7827  O   ALA C  53      36.617  78.917  28.324  1.00 26.35           O  \\nATOM   7828  CB  ALA C  53      38.025  76.113  29.428  1.00 29.90           C  \\nATOM   7829  N   VAL C  54      38.123  77.978  26.942  1.00 11.25           N  \\nATOM   7830  CA  VAL C  54      38.487  79.234  26.317  1.00 11.25           C  \\nATOM   7831  C   VAL C  54      37.319  79.841  25.523  1.00 11.25           C  \\nATOM   7832  O   VAL C  54      36.988  81.003  25.683  1.00 11.25           O  \\nATOM   7833  CB  VAL C  54      39.741  79.024  25.444  1.00 21.58           C  \\nATOM   7834  CG1 VAL C  54      40.103  80.279  24.653  1.00 21.58           C  \\nATOM   7835  CG2 VAL C  54      40.895  78.631  26.331  1.00 21.58           C  \\nATOM   7836  N   LEU C  55      36.667  79.048  24.689  1.00 25.41           N  \\nATOM   7837  CA  LEU C  55      35.553  79.560  23.917  1.00 25.41           C  \\nATOM   7838  C   LEU C  55      34.459  80.056  24.857  1.00 25.41           C  \\nATOM   7839  O   LEU C  55      33.956  81.156  24.696  1.00 25.41           O  \\nATOM   7840  CB  LEU C  55      35.016  78.475  23.001  1.00 12.38           C  \\nATOM   7841  CG  LEU C  55      35.902  77.940  21.867  1.00 12.38           C  \\nATOM   7842  CD1 LEU C  55      35.607  76.483  21.727  1.00 12.38           C  \\nATOM   7843  CD2 LEU C  55      35.695  78.634  20.511  1.00 12.38           C  \\nATOM   7844  N   GLU C  56      34.105  79.265  25.861  1.00 18.75           N  \\nATOM   7845  CA  GLU C  56      33.082  79.685  26.802  1.00 18.75           C  \\nATOM   7846  C   GLU C  56      33.467  81.008  27.443  1.00 18.75           C  \\nATOM   7847  O   GLU C  56      32.663  81.946  27.495  1.00 18.75           O  \\nATOM   7848  CB  GLU C  56      32.916  78.641  27.897  1.00 21.43           C  \\nATOM   7849  CG  GLU C  56      31.962  79.033  29.020  1.00 21.43           C  \\nATOM   7850  CD  GLU C  56      31.594  77.854  29.920  1.00 21.43           C  \\nATOM   7851  OE1 GLU C  56      31.482  76.714  29.407  1.00 21.43           O  \\nATOM   7852  OE2 GLU C  56      31.375  78.060  31.132  1.00 21.43           O  \\nATOM   7853  N   TYR C  57      34.708  81.075  27.926  1.00 18.22           N  \\nATOM   7854  CA  TYR C  57      35.219  82.261  28.589  1.00 18.22           C  \\nATOM   7855  C   TYR C  57      35.061  83.475  27.724  1.00 18.22           C  \\nATOM   7856  O   TYR C  57      34.542  84.474  28.171  1.00 18.22           O  \\nATOM   7857  CB  TYR C  57      36.693  82.081  28.977  1.00 29.28           C  \\nATOM   7858  CG  TYR C  57      37.407  83.385  29.254  1.00 29.28           C  \\nATOM   7859  CD1 TYR C  57      37.000  84.216  30.292  1.00 29.28           C  \\nATOM   7860  CD2 TYR C  57      38.433  83.831  28.415  1.00 29.28           C  \\nATOM   7861  CE1 TYR C  57      37.580  85.469  30.483  1.00 29.28           C  \\nATOM   7862  CE2 TYR C  57      39.028  85.082  28.599  1.00 29.28           C  \\nATOM   7863  CZ  TYR C  57      38.587  85.897  29.633  1.00 29.28           C  \\nATOM   7864  OH  TYR C  57      39.119  87.160  29.788  1.00 29.28           O  \\nATOM   7865  N   LEU C  58      35.492  83.391  26.478  1.00 21.30           N  \\nATOM   7866  CA  LEU C  58      35.386  84.516  25.577  1.00 21.30           C  \\nATOM   7867  C   LEU C  58      33.938  84.936  25.336  1.00 21.30           C  \\nATOM   7868  O   LEU C  58      33.640  86.138  25.337  1.00 21.30           O  \\nATOM   7869  CB  LEU C  58      36.077  84.202  24.256  1.00  8.81           C  \\nATOM   7870  CG  LEU C  58      37.597  83.988  24.257  1.00  8.81           C  \\nATOM   7871  CD1 LEU C  58      38.035  83.370  22.954  1.00  8.81           C  \\nATOM   7872  CD2 LEU C  58      38.323  85.320  24.488  1.00  8.81           C  \\nATOM   7873  N   THR C  59      33.027  83.980  25.128  1.00 20.47           N  \\nATOM   7874  CA  THR C  59      31.637  84.369  24.907  1.00 20.47           C  \\nATOM   7875  C   THR C  59      31.085  85.076  26.166  1.00 20.47           C  \\nATOM   7876  O   THR C  59      30.340  86.040  26.057  1.00 20.47           O  \\nATOM   7877  CB  THR C  59      30.706  83.204  24.370  1.00 14.78           C  \\nATOM   7878  OG1 THR C  59      29.962  82.632  25.444  1.00 14.78           O  \\nATOM   7879  CG2 THR C  59      31.489  82.120  23.658  1.00 14.78           C  \\nATOM   7880  N   ALA C  60      31.486  84.651  27.364  1.00 18.29           N  \\nATOM   7881  CA  ALA C  60      31.029  85.357  28.580  1.00 18.29           C  \\nATOM   7882  C   ALA C  60      31.495  86.816  28.556  1.00 18.29           C  \\nATOM   7883  O   ALA C  60      30.767  87.705  28.931  1.00 18.29           O  \\nATOM   7884  CB  ALA C  60      31.546  84.683  29.817  1.00 14.20           C  \\nATOM   7885  N   GLU C  61      32.725  87.038  28.114  1.00 11.63           N  \\nATOM   7886  CA  GLU C  61      33.319  88.363  28.009  1.00 11.63           C  \\nATOM   7887  C   GLU C  61      32.521  89.254  27.052  1.00 11.63           C  \\nATOM   7888  O   GLU C  61      32.134  90.370  27.394  1.00 11.63           O  \\nATOM   7889  CB  GLU C  61      34.764  88.211  27.535  1.00 35.41           C  \\nATOM   7890  CG  GLU C  61      35.609  89.458  27.614  1.00 35.41           C  \\nATOM   7891  CD  GLU C  61      35.651  90.103  29.003  1.00 35.41           C  \\nATOM   7892  OE1 GLU C  61      35.499  89.385  30.031  1.00 35.41           O  \\nATOM   7893  OE2 GLU C  61      35.855  91.345  29.057  1.00 35.41           O  \\nATOM   7894  N   ILE C  62      32.252  88.768  25.849  1.00 18.09           N  \\nATOM   7895  CA  ILE C  62      31.488  89.563  24.895  1.00 18.09           C  \\nATOM   7896  C   ILE C  62      30.061  89.828  25.370  1.00 18.09           C  \\nATOM   7897  O   ILE C  62      29.558  90.931  25.164  1.00 18.09           O  \\nATOM   7898  CB  ILE C  62      31.443  88.910  23.500  1.00 38.01           C  \\nATOM   7899  CG1 ILE C  62      32.832  88.935  22.873  1.00 38.01           C  \\nATOM   7900  CG2 ILE C  62      30.458  89.634  22.601  1.00 38.01           C  \\nATOM   7901  CD1 ILE C  62      32.819  89.147  21.357  1.00 38.01           C  \\nATOM   7902  N   LEU C  63      29.415  88.816  25.974  1.00 12.07           N  \\nATOM   7903  CA  LEU C  63      28.028  88.913  26.489  1.00 12.07           C  \\nATOM   7904  C   LEU C  63      27.925  89.874  27.690  1.00 12.07           C  \\nATOM   7905  O   LEU C  63      27.004  90.683  27.773  1.00 12.07           O  \\nATOM   7906  CB  LEU C  63      27.448  87.522  26.816  1.00  7.20           C  \\nATOM   7907  CG  LEU C  63      27.134  86.500  25.683  1.00  7.20           C  \\nATOM   7908  CD1 LEU C  63      26.664  85.182  26.244  1.00  7.20           C  \\nATOM   7909  CD2 LEU C  63      26.072  87.000  24.729  1.00  7.20           C  \\nATOM   7910  N   GLU C  64      28.883  89.815  28.607  1.00 12.85           N  \\nATOM   7911  CA  GLU C  64      28.877  90.746  29.727  1.00 12.85           C  \\nATOM   7912  C   GLU C  64      28.979  92.118  29.109  1.00 12.85           C  \\nATOM   7913  O   GLU C  64      28.114  92.929  29.320  1.00 12.85           O  \\nATOM   7914  CB  GLU C  64      30.045  90.513  30.687  1.00 24.48           C  \\nATOM   7915  CG  GLU C  64      30.127  91.527  31.827  1.00 24.48           C  \\nATOM   7916  CD  GLU C  64      29.194  91.247  33.016  1.00 24.48           C  \\nATOM   7917  OE1 GLU C  64      29.252  90.133  33.580  1.00 24.48           O  \\nATOM   7918  OE2 GLU C  64      28.444  92.160  33.439  1.00 24.48           O  \\nATOM   7919  N   LEU C  65      29.959  92.338  28.240  1.00 19.43           N  \\nATOM   7920  CA  LEU C  65      30.111  93.661  27.612  1.00 19.43           C  \\nATOM   7921  C   LEU C  65      28.896  94.150  26.794  1.00 19.43           C  \\nATOM   7922  O   LEU C  65      28.468  95.301  26.956  1.00 19.43           O  \\nATOM   7923  CB  LEU C  65      31.398  93.727  26.776  1.00 22.04           C  \\nATOM   7924  CG  LEU C  65      32.733  93.794  27.537  1.00 22.04           C  \\nATOM   7925  CD1 LEU C  65      33.903  93.766  26.569  1.00 22.04           C  \\nATOM   7926  CD2 LEU C  65      32.768  95.062  28.390  1.00 22.04           C  \\nATOM   7927  N   ALA C  66      28.351  93.279  25.937  1.00 29.10           N  \\nATOM   7928  CA  ALA C  66      27.176  93.590  25.113  1.00 29.10           C  \\nATOM   7929  C   ALA C  66      25.910  93.842  25.945  1.00 29.10           C  \\nATOM   7930  O   ALA C  66      25.124  94.749  25.654  1.00 29.10           O  \\nATOM   7931  CB  ALA C  66      26.926  92.482  24.105  1.00 16.64           C  \\nATOM   7932  N   GLY C  67      25.700  93.035  26.975  1.00 11.25           N  \\nATOM   7933  CA  GLY C  67      24.553  93.245  27.820  1.00 11.25           C  \\nATOM   7934  C   GLY C  67      24.580  94.649  28.403  1.00 11.25           C  \\nATOM   7935  O   GLY C  67      23.530  95.251  28.615  1.00 11.25           O  \\nATOM   7936  N   ASN C  68      25.769  95.164  28.717  1.00 21.17           N  \\nATOM   7937  CA  ASN C  68      25.867  96.514  29.267  1.00 21.17           C  \\nATOM   7938  C   ASN C  68      25.404  97.499  28.217  1.00 21.17           C  \\nATOM   7939  O   ASN C  68      24.640  98.407  28.508  1.00 21.17           O  \\nATOM   7940  CB  ASN C  68      27.297  96.863  29.678  1.00 28.26           C  \\nATOM   7941  CG  ASN C  68      27.817  96.003  30.811  1.00 28.26           C  \\nATOM   7942  OD1 ASN C  68      27.065  95.403  31.566  1.00 28.26           O  \\nATOM   7943  ND2 ASN C  68      29.127  95.948  30.931  1.00 28.26           N  \\nATOM   7944  N   ALA C  69      25.882  97.335  26.991  1.00 20.87           N  \\nATOM   7945  CA  ALA C  69      25.467  98.232  25.943  1.00 20.87           C  \\nATOM   7946  C   ALA C  69      23.946  98.198  25.876  1.00 20.87           C  \\nATOM   7947  O   ALA C  69      23.307  99.222  25.678  1.00 20.87           O  \\nATOM   7948  CB  ALA C  69      26.090  97.838  24.633  1.00 11.60           C  \\nATOM   7949  N   ALA C  70      23.367  97.023  26.096  1.00 22.08           N  \\nATOM   7950  CA  ALA C  70      21.918  96.886  26.090  1.00 22.08           C  \\nATOM   7951  C   ALA C  70      21.327  97.799  27.155  1.00 22.08           C  \\nATOM   7952  O   ALA C  70      20.450  98.590  26.866  1.00 22.08           O  \\nATOM   7953  CB  ALA C  70      21.524  95.444  26.344  1.00 29.84           C  \\nATOM   7954  N   ARG C  71      21.789  97.663  28.391  1.00 27.17           N  \\nATOM   7955  CA  ARG C  71      21.335  98.499  29.510  1.00 27.17           C  \\nATOM   7956  C   ARG C  71      21.463  99.980  29.158  1.00 27.17           C  \\nATOM   7957  O   ARG C  71      20.511 100.735  29.302  1.00 27.17           O  \\nATOM   7958  CB  ARG C  71      22.169  98.215  30.760  1.00153.29           C  \\nATOM   7959  CG  ARG C  71      21.785  96.959  31.525  1.00153.29           C  \\nATOM   7960  CD  ARG C  71      20.926  97.294  32.738  1.00153.29           C  \\nATOM   7961  NE  ARG C  71      21.571  98.262  33.631  1.00153.29           N  \\nATOM   7962  CZ  ARG C  71      21.787  98.072  34.934  1.00153.29           C  \\nATOM   7963  NH1 ARG C  71      21.415  96.940  35.519  1.00153.29           N  \\nATOM   7964  NH2 ARG C  71      22.364  99.024  35.663  1.00153.29           N  \\nATOM   7965  N   ASP C  72      22.627 100.376  28.652  1.00 37.53           N  \\nATOM   7966  CA  ASP C  72      22.900 101.760  28.281  1.00 37.53           C  \\nATOM   7967  C   ASP C  72      21.861 102.385  27.380  1.00 37.53           C  \\nATOM   7968  O   ASP C  72      21.562 103.559  27.523  1.00 37.53           O  \\nATOM   7969  CB  ASP C  72      24.247 101.872  27.588  1.00 45.02           C  \\nATOM   7970  CG  ASP C  72      25.404 101.474  28.480  1.00 45.02           C  \\nATOM   7971  OD1 ASP C  72      25.241 101.484  29.721  1.00 45.02           O  \\nATOM   7972  OD2 ASP C  72      26.484 101.153  27.929  1.00 45.02           O  \\nATOM   7973  N   ASN C  73      21.381 101.636  26.395  1.00 29.61           N  \\nATOM   7974  CA  ASN C  73      20.377 102.156  25.474  1.00 29.61           C  \\nATOM   7975  C   ASN C  73      18.960 101.773  25.844  1.00 29.61           C  \\nATOM   7976  O   ASN C  73      18.044 101.799  25.012  1.00 29.61           O  \\nATOM   7977  CB  ASN C  73      20.720 101.741  24.058  1.00 61.07           C  \\nATOM   7978  CG  ASN C  73      22.105 102.181  23.676  1.00 61.07           C  \\nATOM   7979  OD1 ASN C  73      22.328 103.343  23.342  1.00 61.07           O  \\nATOM   7980  ND2 ASN C  73      23.069 101.291  23.844  1.00 61.07           N  \\nATOM   7981  N   LYS C  74      18.802 101.413  27.111  1.00 27.77           N  \\nATOM   7982  CA  LYS C  74      17.518 101.048  27.697  1.00 27.77           C  \\nATOM   7983  C   LYS C  74      16.763  99.888  27.029  1.00 27.77           C  \\nATOM   7984  O   LYS C  74      15.539  99.779  27.118  1.00 27.77           O  \\nATOM   7985  CB  LYS C  74      16.674 102.323  27.860  1.00112.03           C  \\nATOM   7986  CG  LYS C  74      17.381 103.344  28.780  1.00112.03           C  \\nATOM   7987  CD  LYS C  74      16.914 104.787  28.638  1.00112.03           C  \\nATOM   7988  CE  LYS C  74      17.830 105.699  29.457  1.00112.03           C  \\nATOM   7989  NZ  LYS C  74      17.433 107.130  29.413  1.00112.03           N  \\nATOM   7990  N   LYS C  75      17.533  98.965  26.458  1.00 33.45           N  \\nATOM   7991  CA  LYS C  75      16.990  97.792  25.796  1.00 33.45           C  \\nATOM   7992  C   LYS C  75      17.242  96.561  26.660  1.00 33.45           C  \\nATOM   7993  O   LYS C  75      18.103  96.562  27.546  1.00 33.45           O  \\nATOM   7994  CB  LYS C  75      17.673  97.620  24.463  1.00 30.01           C  \\nATOM   7995  CG  LYS C  75      17.610  98.853  23.625  1.00 30.01           C  \\nATOM   7996  CD  LYS C  75      16.407  98.861  22.703  1.00 30.01           C  \\nATOM   7997  CE  LYS C  75      16.438 100.097  21.796  1.00 30.01           C  \\nATOM   7998  NZ  LYS C  75      16.124 101.357  22.548  1.00 30.01           N  \\nATOM   7999  N   THR C  76      16.517  95.496  26.366  1.00 35.80           N  \\nATOM   8000  CA  THR C  76      16.633  94.262  27.115  1.00 35.80           C  \\nATOM   8001  C   THR C  76      17.103  93.128  26.231  1.00 35.80           C  \\nATOM   8002  O   THR C  76      17.628  92.123  26.715  1.00 35.80           O  \\nATOM   8003  CB  THR C  76      15.272  93.924  27.740  1.00 32.82           C  \\nATOM   8004  OG1 THR C  76      15.218  94.523  29.037  1.00 32.82           O  \\nATOM   8005  CG2 THR C  76      14.992  92.382  27.799  1.00 32.82           C  \\nATOM   8006  N   ARG C  77      16.853  93.258  24.934  1.00 25.08           N  \\nATOM   8007  CA  ARG C  77      17.268  92.241  24.010  1.00 25.08           C  \\nATOM   8008  C   ARG C  77      18.489  92.789  23.289  1.00 25.08           C  \\nATOM   8009  O   ARG C  77      18.436  93.843  22.647  1.00 25.08           O  \\nATOM   8010  CB  ARG C  77      16.153  91.929  23.019  1.00 41.83           C  \\nATOM   8011  CG  ARG C  77      16.282  90.557  22.391  1.00 41.83           C  \\nATOM   8012  CD  ARG C  77      15.158  90.262  21.423  1.00 41.83           C  \\nATOM   8013  NE  ARG C  77      13.847  90.244  22.074  1.00 41.83           N  \\nATOM   8014  CZ  ARG C  77      12.860  91.097  21.788  1.00 41.83           C  \\nATOM   8015  NH1 ARG C  77      13.035  92.027  20.859  1.00 41.83           N  \\nATOM   8016  NH2 ARG C  77      11.710  91.052  22.459  1.00 41.83           N  \\nATOM   8017  N   ILE C  78      19.608  92.107  23.477  1.00 20.39           N  \\nATOM   8018  CA  ILE C  78      20.857  92.463  22.825  1.00 20.39           C  \\nATOM   8019  C   ILE C  78      20.649  92.313  21.318  1.00 20.39           C  \\nATOM   8020  O   ILE C  78      20.033  91.343  20.859  1.00 20.39           O  \\nATOM   8021  CB  ILE C  78      21.996  91.463  23.190  1.00  7.96           C  \\nATOM   8022  CG1 ILE C  78      22.377  91.566  24.659  1.00  7.96           C  \\nATOM   8023  CG2 ILE C  78      23.204  91.666  22.296  1.00  7.96           C  \\nATOM   8024  CD1 ILE C  78      23.247  90.427  25.137  1.00  7.96           C  \\nATOM   8025  N   ILE C  79      21.149  93.283  20.562  1.00 26.88           N  \\nATOM   8026  CA  ILE C  79      21.080  93.223  19.120  1.00 26.88           C  \\nATOM   8027  C   ILE C  79      22.499  93.433  18.633  1.00 26.88           C  \\nATOM   8028  O   ILE C  79      23.382  93.757  19.416  1.00 26.88           O  \\nATOM   8029  CB  ILE C  79      20.139  94.288  18.528  1.00 16.98           C  \\nATOM   8030  CG1 ILE C  79      20.596  95.690  18.900  1.00 16.98           C  \\nATOM   8031  CG2 ILE C  79      18.704  94.015  18.958  1.00 16.98           C  \\nATOM   8032  CD1 ILE C  79      19.753  96.747  18.261  1.00 16.98           C  \\nATOM   8033  N   PRO C  80      22.750  93.217  17.338  1.00 31.46           N  \\nATOM   8034  CA  PRO C  80      24.102  93.401  16.799  1.00 31.46           C  \\nATOM   8035  C   PRO C  80      24.776  94.704  17.174  1.00 31.46           C  \\nATOM   8036  O   PRO C  80      25.958  94.693  17.488  1.00 31.46           O  \\nATOM   8037  CB  PRO C  80      23.883  93.294  15.305  1.00 19.69           C  \\nATOM   8038  CG  PRO C  80      22.794  92.236  15.236  1.00 19.69           C  \\nATOM   8039  CD  PRO C  80      21.836  92.678  16.315  1.00 19.69           C  \\nATOM   8040  N   ARG C  81      24.051  95.825  17.166  1.00 11.81           N  \\nATOM   8041  CA  ARG C  81      24.681  97.098  17.541  1.00 11.81           C  \\nATOM   8042  C   ARG C  81      25.337  97.014  18.926  1.00 11.81           C  \\nATOM   8043  O   ARG C  81      26.406  97.590  19.165  1.00 11.81           O  \\nATOM   8044  CB  ARG C  81      23.710  98.288  17.495  1.00 12.63           C  \\nATOM   8045  CG  ARG C  81      24.092  99.356  18.521  1.00 12.63           C  \\nATOM   8046  CD  ARG C  81      24.413 100.773  18.021  1.00 12.63           C  \\nATOM   8047  NE  ARG C  81      25.433 100.881  16.970  1.00 12.63           N  \\nATOM   8048  CZ  ARG C  81      26.179 101.973  16.739  1.00 12.63           C  \\nATOM   8049  NH1 ARG C  81      26.080 103.064  17.501  1.00 12.63           N  \\nATOM   8050  NH2 ARG C  81      26.938 102.023  15.646  1.00 12.63           N  \\nATOM   8051  N   HIS C  82      24.711  96.271  19.830  1.00 25.22           N  \\nATOM   8052  CA  HIS C  82      25.239  96.121  21.176  1.00 25.22           C  \\nATOM   8053  C   HIS C  82      26.554  95.354  21.122  1.00 25.22           C  \\nATOM   8054  O   HIS C  82      27.493  95.694  21.836  1.00 25.22           O  \\nATOM   8055  CB  HIS C  82      24.201  95.458  22.076  1.00 27.97           C  \\nATOM   8056  CG  HIS C  82      22.902  96.202  22.132  1.00 27.97           C  \\nATOM   8057  ND1 HIS C  82      21.732  95.632  22.573  1.00 27.97           N  \\nATOM   8058  CD2 HIS C  82      22.590  97.477  21.797  1.00 27.97           C  \\nATOM   8059  CE1 HIS C  82      20.754  96.518  22.509  1.00 27.97           C  \\nATOM   8060  NE2 HIS C  82      21.249  97.648  22.039  1.00 27.97           N  \\nATOM   8061  N   LEU C  83      26.638  94.365  20.227  1.00 11.71           N  \\nATOM   8062  CA  LEU C  83      27.869  93.591  20.027  1.00 11.71           C  \\nATOM   8063  C   LEU C  83      28.979  94.507  19.460  1.00 11.71           C  \\nATOM   8064  O   LEU C  83      30.100  94.506  19.984  1.00 11.71           O  \\nATOM   8065  CB  LEU C  83      27.618  92.407  19.085  1.00  6.54           C  \\nATOM   8066  CG  LEU C  83      26.644  91.357  19.628  1.00  6.54           C  \\nATOM   8067  CD1 LEU C  83      26.223  90.333  18.555  1.00  6.54           C  \\nATOM   8068  CD2 LEU C  83      27.273  90.667  20.862  1.00  6.54           C  \\nATOM   8069  N   GLN C  84      28.665  95.299  18.419  1.00 11.71           N  \\nATOM   8070  CA  GLN C  84      29.652  96.220  17.827  1.00 11.71           C  \\nATOM   8071  C   GLN C  84      30.199  97.147  18.883  1.00 11.71           C  \\nATOM   8072  O   GLN C  84      31.408  97.249  19.055  1.00 11.71           O  \\nATOM   8073  CB  GLN C  84      29.055  97.115  16.747  1.00 21.58           C  \\nATOM   8074  CG  GLN C  84      29.554  96.848  15.345  1.00 21.58           C  \\nATOM   8075  CD  GLN C  84      30.998  97.284  15.011  1.00 21.58           C  \\nATOM   8076  OE1 GLN C  84      31.262  98.465  14.793  1.00 21.58           O  \\nATOM   8077  NE2 GLN C  84      31.880  96.298  14.790  1.00 21.58           N  \\nATOM   8078  N   LEU C  85      29.292  97.847  19.559  1.00 12.34           N  \\nATOM   8079  CA  LEU C  85      29.666  98.774  20.602  1.00 12.34           C  \\nATOM   8080  C   LEU C  85      30.580  98.095  21.586  1.00 12.34           C  \\nATOM   8081  O   LEU C  85      31.678  98.573  21.787  1.00 12.34           O  \\nATOM   8082  CB  LEU C  85      28.436  99.326  21.302  1.00 21.97           C  \\nATOM   8083  CG  LEU C  85      27.540 100.159  20.388  1.00 21.97           C  \\nATOM   8084  CD1 LEU C  85      26.271 100.505  21.107  1.00 21.97           C  \\nATOM   8085  CD2 LEU C  85      28.261 101.410  19.928  1.00 21.97           C  \\nATOM   8086  N   ALA C  86      30.175  96.949  22.135  1.00 23.23           N  \\nATOM   8087  CA  ALA C  86      30.994  96.205  23.100  1.00 23.23           C  \\nATOM   8088  C   ALA C  86      32.427  95.902  22.638  1.00 23.23           C  \\nATOM   8089  O   ALA C  86      33.388  96.107  23.388  1.00 23.23           O  \\nATOM   8090  CB  ALA C  86      30.300  94.922  23.475  1.00 29.12           C  \\nATOM   8091  N   VAL C  87      32.547  95.370  21.424  1.00 17.48           N  \\nATOM   8092  CA  VAL C  87      33.822  95.040  20.814  1.00 17.48           C  \\nATOM   8093  C   VAL C  87      34.649  96.296  20.537  1.00 17.48           C  \\nATOM   8094  O   VAL C  87      35.695  96.504  21.130  1.00 17.48           O  \\nATOM   8095  CB  VAL C  87      33.573  94.255  19.518  1.00  7.89           C  \\nATOM   8096  CG1 VAL C  87      34.807  94.199  18.661  1.00  7.89           C  \\nATOM   8097  CG2 VAL C  87      33.079  92.854  19.858  1.00  7.89           C  \\nATOM   8098  N   ARG C  88      34.114  97.196  19.734  1.00 20.27           N  \\nATOM   8099  CA  ARG C  88      34.837  98.394  19.392  1.00 20.27           C  \\nATOM   8100  C   ARG C  88      35.243  99.250  20.584  1.00 20.27           C  \\nATOM   8101  O   ARG C  88      36.218 100.003  20.496  1.00 20.27           O  \\nATOM   8102  CB  ARG C  88      34.067  99.213  18.343  1.00  8.63           C  \\nATOM   8103  CG  ARG C  88      33.774  98.443  17.053  1.00  8.63           C  \\nATOM   8104  CD  ARG C  88      34.950  97.555  16.652  1.00  8.63           C  \\nATOM   8105  NE  ARG C  88      34.568  96.527  15.689  1.00  8.63           N  \\nATOM   8106  CZ  ARG C  88      35.345  95.510  15.308  1.00  8.63           C  \\nATOM   8107  NH1 ARG C  88      36.566  95.371  15.808  1.00  8.63           N  \\nATOM   8108  NH2 ARG C  88      34.921  94.641  14.393  1.00  8.63           N  \\nATOM   8109  N   ASN C  89      34.520  99.155  21.693  1.00 24.83           N  \\nATOM   8110  CA  ASN C  89      34.873  99.949  22.880  1.00 24.83           C  \\nATOM   8111  C   ASN C  89      35.901  99.313  23.801  1.00 24.83           C  \\nATOM   8112  O   ASN C  89      36.427  99.973  24.703  1.00 24.83           O  \\nATOM   8113  CB  ASN C  89      33.634 100.309  23.694  1.00 36.18           C  \\nATOM   8114  CG  ASN C  89      32.871 101.470  23.102  1.00 36.18           C  \\nATOM   8115  OD1 ASN C  89      33.448 102.522  22.799  1.00 36.18           O  \\nATOM   8116  ND2 ASN C  89      31.569 101.290  22.930  1.00 36.18           N  \\nATOM   8117  N   ASP C  90      36.185  98.037  23.552  1.00 30.38           N  \\nATOM   8118  CA  ASP C  90      37.122  97.256  24.332  1.00 30.38           C  \\nATOM   8119  C   ASP C  90      38.352  97.089  23.465  1.00 30.38           C  \\nATOM   8120  O   ASP C  90      38.278  96.500  22.387  1.00 30.38           O  \\nATOM   8121  CB  ASP C  90      36.503  95.899  24.612  1.00 26.41           C  \\nATOM   8122  CG  ASP C  90      37.317  95.079  25.546  1.00 26.41           C  \\nATOM   8123  OD1 ASP C  90      37.460  95.521  26.706  1.00 26.41           O  \\nATOM   8124  OD2 ASP C  90      37.805  94.001  25.124  1.00 26.41           O  \\nATOM   8125  N   GLU C  91      39.494  97.572  23.954  1.00 22.86           N  \\nATOM   8126  CA  GLU C  91      40.748  97.510  23.207  1.00 22.86           C  \\nATOM   8127  C   GLU C  91      41.107  96.129  22.735  1.00 22.86           C  \\nATOM   8128  O   GLU C  91      41.422  95.947  21.557  1.00 22.86           O  \\nATOM   8129  CB  GLU C  91      41.897  98.067  24.038  1.00 76.59           C  \\nATOM   8130  CG  GLU C  91      42.273  99.484  23.669  1.00 76.59           C  \\nATOM   8131  CD  GLU C  91      43.284 100.089  24.620  1.00 76.59           C  \\nATOM   8132  OE1 GLU C  91      44.191  99.357  25.094  1.00 76.59           O  \\nATOM   8133  OE2 GLU C  91      43.166 101.306  24.887  1.00 76.59           O  \\nATOM   8134  N   GLU C  92      40.994  95.151  23.641  1.00 24.82           N  \\nATOM   8135  CA  GLU C  92      41.355  93.766  23.332  1.00 24.82           C  \\nATOM   8136  C   GLU C  92      40.434  93.016  22.407  1.00 24.82           C  \\nATOM   8137  O   GLU C  92      40.899  92.376  21.457  1.00 24.82           O  \\nATOM   8138  CB  GLU C  92      41.704  92.992  24.591  1.00 34.30           C  \\nATOM   8139  CG  GLU C  92      43.183  93.193  24.895  1.00 34.30           C  \\nATOM   8140  CD  GLU C  92      43.593  92.837  26.302  1.00 34.30           C  \\nATOM   8141  OE1 GLU C  92      42.816  92.131  26.978  1.00 34.30           O  \\nATOM   8142  OE2 GLU C  92      44.700  93.270  26.728  1.00 34.30           O  \\nATOM   8143  N   LEU C  93      39.130  93.135  22.640  1.00 16.31           N  \\nATOM   8144  CA  LEU C  93      38.162  92.509  21.753  1.00 16.31           C  \\nATOM   8145  C   LEU C  93      38.296  93.176  20.388  1.00 16.31           C  \\nATOM   8146  O   LEU C  93      38.238  92.521  19.357  1.00 16.31           O  \\nATOM   8147  CB  LEU C  93      36.757  92.686  22.304  1.00 17.29           C  \\nATOM   8148  CG  LEU C  93      36.308  91.665  23.352  1.00 17.29           C  \\nATOM   8149  CD1 LEU C  93      34.948  92.038  23.858  1.00 17.29           C  \\nATOM   8150  CD2 LEU C  93      36.229  90.269  22.736  1.00 17.29           C  \\nATOM   8151  N   ASN C  94      38.521  94.486  20.390  1.00 17.48           N  \\nATOM   8152  CA  ASN C  94      38.687  95.216  19.144  1.00 17.48           C  \\nATOM   8153  C   ASN C  94      39.882  94.703  18.360  1.00 17.48           C  \\nATOM   8154  O   ASN C  94      39.844  94.658  17.134  1.00 17.48           O  \\nATOM   8155  CB  ASN C  94      38.859  96.704  19.395  1.00 28.92           C  \\nATOM   8156  CG  ASN C  94      38.837  97.498  18.116  1.00 28.92           C  \\nATOM   8157  OD1 ASN C  94      37.963  97.298  17.280  1.00 28.92           O  \\nATOM   8158  ND2 ASN C  94      39.819  98.361  17.929  1.00 28.92           N  \\nATOM   8159  N   LYS C  95      40.969  94.400  19.066  1.00 19.82           N  \\nATOM   8160  CA  LYS C  95      42.157  93.865  18.420  1.00 19.82           C  \\nATOM   8161  C   LYS C  95      41.821  92.496  17.838  1.00 19.82           C  \\nATOM   8162  O   LYS C  95      41.855  92.299  16.634  1.00 19.82           O  \\nATOM   8163  CB  LYS C  95      43.321  93.762  19.405  1.00 70.14           C  \\nATOM   8164  CG  LYS C  95      44.651  93.501  18.723  1.00 70.14           C  \\nATOM   8165  CD  LYS C  95      45.822  93.802  19.637  1.00 70.14           C  \\nATOM   8166  CE  LYS C  95      47.149  93.605  18.904  1.00 70.14           C  \\nATOM   8167  NZ  LYS C  95      48.349  93.952  19.740  1.00 70.14           N  \\nATOM   8168  N   LEU C  96      41.347  91.602  18.693  1.00 14.03           N  \\nATOM   8169  CA  LEU C  96      40.992  90.243  18.303  1.00 14.03           C  \\nATOM   8170  C   LEU C  96      40.069  90.139  17.122  1.00 14.03           C  \\nATOM   8171  O   LEU C  96      40.101  89.127  16.436  1.00 14.03           O  \\nATOM   8172  CB  LEU C  96      40.355  89.515  19.493  1.00 15.02           C  \\nATOM   8173  CG  LEU C  96      39.842  88.078  19.367  1.00 15.02           C  \\nATOM   8174  CD1 LEU C  96      40.912  87.157  18.788  1.00 15.02           C  \\nATOM   8175  CD2 LEU C  96      39.444  87.586  20.750  1.00 15.02           C  \\nATOM   8176  N   LEU C  97      39.168  91.118  16.971  1.00 24.89           N  \\nATOM   8177  CA  LEU C  97      38.178  91.136  15.889  1.00 24.89           C  \\nATOM   8178  C   LEU C  97      38.385  92.335  14.985  1.00 24.89           C  \\nATOM   8179  O   LEU C  97      37.433  92.904  14.425  1.00 24.89           O  \\nATOM   8180  CB  LEU C  97      36.769  91.149  16.487  1.00 16.23           C  \\nATOM   8181  CG  LEU C  97      36.468  89.981  17.441  1.00 16.23           C  \\nATOM   8182  CD1 LEU C  97      35.139  90.169  18.118  1.00 16.23           C  \\nATOM   8183  CD2 LEU C  97      36.494  88.641  16.713  1.00 16.23           C  \\nATOM   8184  N   GLY C  98      39.653  92.696  14.836  1.00 17.33           N  \\nATOM   8185  CA  GLY C  98      40.020  93.834  14.019  1.00 17.33           C  \\nATOM   8186  C   GLY C  98      39.928  93.676  12.513  1.00 17.33           C  \\nATOM   8187  O   GLY C  98      40.153  94.646  11.785  1.00 17.33           O  \\nATOM   8188  N   ARG C  99      39.675  92.455  12.044  1.00 25.00           N  \\nATOM   8189  CA  ARG C  99      39.540  92.173  10.617  1.00 25.00           C  \\nATOM   8190  C   ARG C  99      38.182  91.492  10.435  1.00 25.00           C  \\nATOM   8191  O   ARG C  99      37.936  90.770   9.461  1.00 25.00           O  \\nATOM   8192  CB  ARG C  99      40.682  91.270  10.149  1.00 72.76           C  \\nATOM   8193  CG  ARG C  99      42.018  91.974  10.015  1.00 72.76           C  \\nATOM   8194  CD  ARG C  99      42.156  92.636   8.652  1.00 72.76           C  \\nATOM   8195  NE  ARG C  99      43.375  93.444   8.532  1.00 72.76           N  \\nATOM   8196  CZ  ARG C  99      44.470  93.099   7.847  1.00 72.76           C  \\nATOM   8197  NH1 ARG C  99      44.528  91.938   7.198  1.00 72.76           N  \\nATOM   8198  NH2 ARG C  99      45.514  93.928   7.803  1.00 72.76           N  \\nATOM   8199  N   VAL C 100      37.303  91.735  11.401  1.00 16.39           N  \\nATOM   8200  CA  VAL C 100      35.970  91.158  11.394  1.00 16.39           C  \\nATOM   8201  C   VAL C 100      34.887  92.209  11.310  1.00 16.39           C  \\nATOM   8202  O   VAL C 100      34.971  93.262  11.952  1.00 16.39           O  \\nATOM   8203  CB  VAL C 100      35.714  90.317  12.651  1.00  9.64           C  \\nATOM   8204  CG1 VAL C 100      34.258  89.989  12.776  1.00  9.64           C  \\nATOM   8205  CG2 VAL C 100      36.497  89.032  12.572  1.00  9.64           C  \\nATOM   8206  N   THR C 101      33.912  91.964  10.445  1.00 10.48           N  \\nATOM   8207  CA  THR C 101      32.807  92.887  10.342  1.00 10.48           C  \\nATOM   8208  C   THR C 101      31.513  92.195  10.797  1.00 10.48           C  \\nATOM   8209  O   THR C 101      31.190  91.120  10.344  1.00 10.48           O  \\nATOM   8210  CB  THR C 101      32.726  93.633   8.936  1.00 24.76           C  \\nATOM   8211  OG1 THR C 101      31.475  93.357   8.297  1.00 24.76           O  \\nATOM   8212  CG2 THR C 101      33.882  93.258   8.013  1.00 24.76           C  \\nATOM   8213  N   ILE C 102      30.952  92.731  11.877  1.00  8.73           N  \\nATOM   8214  CA  ILE C 102      29.707  92.298  12.509  1.00  8.73           C  \\nATOM   8215  C   ILE C 102      28.590  92.983  11.715  1.00  8.73           C  \\nATOM   8216  O   ILE C 102      28.420  94.212  11.793  1.00  8.73           O  \\nATOM   8217  CB  ILE C 102      29.622  92.858  13.958  1.00  5.00           C  \\nATOM   8218  CG1 ILE C 102      30.689  92.232  14.856  1.00  5.00           C  \\nATOM   8219  CG2 ILE C 102      28.230  92.721  14.519  1.00  5.00           C  \\nATOM   8220  CD1 ILE C 102      30.674  92.776  16.287  1.00  5.00           C  \\nATOM   8221  N   ALA C 103      27.856  92.208  10.924  1.00 17.87           N  \\nATOM   8222  CA  ALA C 103      26.773  92.756  10.132  1.00 17.87           C  \\nATOM   8223  C   ALA C 103      25.775  93.502  11.052  1.00 17.87           C  \\nATOM   8224  O   ALA C 103      25.642  93.151  12.228  1.00 17.87           O  \\nATOM   8225  CB  ALA C 103      26.099  91.640   9.364  1.00  5.00           C  \\nATOM   8226  N   GLN C 104      25.157  94.567  10.517  1.00 20.70           N  \\nATOM   8227  CA  GLN C 104      24.193  95.448  11.191  1.00 20.70           C  \\nATOM   8228  C   GLN C 104      24.686  96.076  12.491  1.00 20.70           C  \\nATOM   8229  O   GLN C 104      23.886  96.406  13.390  1.00 20.70           O  \\nATOM   8230  CB  GLN C 104      22.836  94.766  11.398  1.00 26.73           C  \\nATOM   8231  CG  GLN C 104      21.873  94.811  10.182  1.00 26.73           C  \\nATOM   8232  CD  GLN C 104      21.459  96.247   9.720  1.00 26.73           C  \\nATOM   8233  OE1 GLN C 104      20.778  97.006  10.452  1.00 26.73           O  \\nATOM   8234  NE2 GLN C 104      21.835  96.593   8.480  1.00 26.73           N  \\nATOM   8235  N   GLY C 105      26.000  96.268  12.594  1.00 13.32           N  \\nATOM   8236  CA  GLY C 105      26.545  96.866  13.804  1.00 13.32           C  \\nATOM   8237  C   GLY C 105      26.840  98.363  13.734  1.00 13.32           C  \\nATOM   8238  O   GLY C 105      26.944  99.029  14.780  1.00 13.32           O  \\nATOM   8239  N   GLY C 106      26.961  98.895  12.509  1.00 17.90           N  \\nATOM   8240  CA  GLY C 106      27.253 100.303  12.332  1.00 17.90           C  \\nATOM   8241  C   GLY C 106      28.652 100.646  12.807  1.00 17.90           C  \\nATOM   8242  O   GLY C 106      29.540  99.780  12.904  1.00 17.90           O  \\nATOM   8243  N   VAL C 107      28.851 101.910  13.160  1.00 19.93           N  \\nATOM   8244  CA  VAL C 107      30.166 102.373  13.587  1.00 19.93           C  \\nATOM   8245  C   VAL C 107      30.037 103.142  14.878  1.00 19.93           C  \\nATOM   8246  O   VAL C 107      28.933 103.503  15.263  1.00 19.93           O  \\nATOM   8247  CB  VAL C 107      30.799 103.308  12.510  1.00  5.00           C  \\nATOM   8248  CG1 VAL C 107      30.940 102.574  11.175  1.00  5.00           C  \\nATOM   8249  CG2 VAL C 107      29.977 104.614  12.344  1.00  5.00           C  \\nATOM   8250  N   LEU C 108      31.158 103.357  15.565  1.00 31.65           N  \\nATOM   8251  CA  LEU C 108      31.146 104.127  16.811  1.00 31.65           C  \\nATOM   8252  C   LEU C 108      31.038 105.591  16.440  1.00 31.65           C  \\nATOM   8253  O   LEU C 108      31.678 106.038  15.482  1.00 31.65           O  \\nATOM   8254  CB  LEU C 108      32.438 103.937  17.599  1.00 10.35           C  \\nATOM   8255  CG  LEU C 108      32.712 102.607  18.290  1.00 10.35           C  \\nATOM   8256  CD1 LEU C 108      33.811 102.846  19.272  1.00 10.35           C  \\nATOM   8257  CD2 LEU C 108      31.475 102.100  19.014  1.00 10.35           C  \\nATOM   8258  N   PRO C 109      30.164 106.342  17.129  1.00 24.79           N  \\nATOM   8259  CA  PRO C 109      30.061 107.759  16.773  1.00 24.79           C  \\nATOM   8260  C   PRO C 109      31.335 108.474  17.148  1.00 24.79           C  \\nATOM   8261  O   PRO C 109      31.754 108.425  18.304  1.00 24.79           O  \\nATOM   8262  CB  PRO C 109      28.848 108.245  17.574  1.00 20.28           C  \\nATOM   8263  CG  PRO C 109      28.656 107.216  18.642  1.00 20.28           C  \\nATOM   8264  CD  PRO C 109      29.041 105.928  17.986  1.00 20.28           C  \\nATOM   8265  N   ASN C 110      31.983 109.070  16.145  1.00 20.40           N  \\nATOM   8266  CA  ASN C 110      33.238 109.784  16.350  1.00 20.40           C  \\nATOM   8267  C   ASN C 110      33.520 110.800  15.262  1.00 20.40           C  \\nATOM   8268  O   ASN C 110      33.844 110.426  14.125  1.00 20.40           O  \\nATOM   8269  CB  ASN C 110      34.403 108.777  16.418  1.00 57.71           C  \\nATOM   8270  CG  ASN C 110      35.756 109.435  16.671  1.00 57.71           C  \\nATOM   8271  OD1 ASN C 110      35.852 110.480  17.322  1.00 57.71           O  \\nATOM   8272  ND2 ASN C 110      36.813 108.805  16.175  1.00 57.71           N  \\nATOM   8273  N   ILE C 111      33.434 112.078  15.632  1.00 28.97           N  \\nATOM   8274  CA  ILE C 111      33.713 113.187  14.717  1.00 28.97           C  \\nATOM   8275  C   ILE C 111      35.065 113.837  15.022  1.00 28.97           C  \\nATOM   8276  O   ILE C 111      35.289 114.295  16.144  1.00 28.97           O  \\nATOM   8277  CB  ILE C 111      32.682 114.309  14.843  1.00 24.04           C  \\nATOM   8278  CG1 ILE C 111      31.320 113.850  14.351  1.00 24.04           C  \\nATOM   8279  CG2 ILE C 111      33.126 115.510  14.037  1.00 24.04           C  \\nATOM   8280  CD1 ILE C 111      30.246 114.908  14.492  1.00 24.04           C  \\nATOM   8281  N   GLN C 112      35.917 113.959  14.000  1.00 18.78           N  \\nATOM   8282  CA  GLN C 112      37.238 114.568  14.140  1.00 18.78           C  \\nATOM   8283  C   GLN C 112      37.048 115.984  14.622  1.00 18.78           C  \\nATOM   8284  O   GLN C 112      36.198 116.698  14.099  1.00 18.78           O  \\nATOM   8285  CB  GLN C 112      37.954 114.554  12.805  1.00 27.63           C  \\nATOM   8286  CG  GLN C 112      38.144 113.158  12.270  1.00 27.63           C  \\nATOM   8287  CD  GLN C 112      38.991 112.316  13.190  1.00 27.63           C  \\nATOM   8288  OE1 GLN C 112      40.142 112.651  13.451  1.00 27.63           O  \\nATOM   8289  NE2 GLN C 112      38.425 111.233  13.707  1.00 27.63           N  \\nATOM   8290  N   SER C 113      37.833 116.363  15.630  1.00 41.64           N  \\nATOM   8291  CA  SER C 113      37.784 117.683  16.267  1.00 41.64           C  \\nATOM   8292  C   SER C 113      37.725 118.890  15.335  1.00 41.64           C  \\nATOM   8293  O   SER C 113      36.907 119.782  15.505  1.00 34.99           O  \\nATOM   8294  CB  SER C 113      38.993 117.850  17.177  1.00 65.70           C  \\nATOM   8295  OG  SER C 113      39.349 116.610  17.747  1.00 65.70           O  \\nATOM   8296  N   VAL C 114      38.575 118.899  14.325  1.00 30.24           N  \\nATOM   8297  CA  VAL C 114      38.637 120.010  13.396  1.00 30.24           C  \\nATOM   8298  C   VAL C 114      37.422 120.158  12.501  1.00 30.24           C  \\nATOM   8299  O   VAL C 114      37.408 121.016  11.614  1.00 30.24           O  \\nATOM   8300  CB  VAL C 114      39.876 119.901  12.513  1.00 37.79           C  \\nATOM   8301  CG1 VAL C 114      41.140 119.889  13.384  1.00 37.79           C  \\nATOM   8302  CG2 VAL C 114      39.797 118.651  11.675  1.00 37.79           C  \\nATOM   8303  N   LEU C 115      36.420 119.305  12.700  1.00 26.44           N  \\nATOM   8304  CA  LEU C 115      35.198 119.358  11.896  1.00 26.44           C  \\nATOM   8305  C   LEU C 115      34.086 120.089  12.638  1.00 26.44           C  \\nATOM   8306  O   LEU C 115      33.114 120.517  12.028  1.00 26.44           O  \\nATOM   8307  CB  LEU C 115      34.744 117.941  11.505  1.00 19.01           C  \\nATOM   8308  CG  LEU C 115      35.695 117.108  10.629  1.00 19.01           C  \\nATOM   8309  CD1 LEU C 115      35.099 115.757  10.323  1.00 19.01           C  \\nATOM   8310  CD2 LEU C 115      35.999 117.850   9.354  1.00 19.01           C  \\nATOM   8311  N   LEU C 116      34.254 120.240  13.950  1.00 24.39           N  \\nATOM   8312  CA  LEU C 116      33.288 120.935  14.781  1.00 24.39           C  \\nATOM   8313  C   LEU C 116      33.389 122.438  14.486  1.00 24.39           C  \\nATOM   8314  O   LEU C 116      34.418 122.918  14.008  1.00 24.39           O  \\nATOM   8315  CB  LEU C 116      33.576 120.676  16.257  1.00 19.78           C  \\nATOM   8316  CG  LEU C 116      33.634 119.222  16.732  1.00 19.78           C  \\nATOM   8317  CD1 LEU C 116      34.027 119.221  18.204  1.00 19.78           C  \\nATOM   8318  CD2 LEU C 116      32.319 118.495  16.518  1.00 19.78           C  \\nATOM   8319  N   PRO C 117      32.317 123.200  14.778  1.00 72.63           N  \\nATOM   8320  CA  PRO C 117      32.241 124.651  14.555  1.00 72.63           C  \\nATOM   8321  C   PRO C 117      33.195 125.511  15.397  1.00 72.63           C  \\nATOM   8322  O   PRO C 117      33.977 124.988  16.196  1.00 72.63           O  \\nATOM   8323  CB  PRO C 117      30.778 124.969  14.893  1.00 55.90           C  \\nATOM   8324  CG  PRO C 117      30.062 123.671  14.686  1.00 55.90           C  \\nATOM   8325  CD  PRO C 117      31.027 122.690  15.277  1.00 55.90           C  \\nATOM   8326  N   LYS C 118      33.077 126.833  15.223  1.00120.09           N  \\nATOM   8327  CA  LYS C 118      33.885 127.843  15.915  1.00120.09           C  \\nATOM   8328  C   LYS C 118      33.918 127.734  17.444  1.00120.09           C  \\nATOM   8329  O   LYS C 118      35.044 127.711  18.001  1.00 56.68           O  \\nATOM   8330  CB  LYS C 118      33.413 129.252  15.531  1.00 92.79           C  \\nATOM   8331  CG  LYS C 118      34.122 130.332  16.322  1.00 92.79           C  \\nATOM   8332  CD  LYS C 118      33.680 131.733  15.989  1.00 92.79           C  \\nATOM   8333  CE  LYS C 118      34.625 132.714  16.681  1.00 92.79           C  \\nATOM   8334  NZ  LYS C 118      34.372 134.147  16.366  1.00 92.79           N  \\nTER    8335      LYS C 118                                                      \\nATOM   8336  N   LYS D  24       5.819  58.872  -0.632  1.00107.71           N  \\nATOM   8337  CA  LYS D  24       6.907  59.854  -0.352  1.00107.71           C  \\nATOM   8338  C   LYS D  24       7.776  59.411   0.821  1.00107.71           C  \\nATOM   8339  O   LYS D  24       7.797  58.230   1.168  1.00107.71           O  \\nATOM   8340  CB  LYS D  24       6.309  61.230  -0.077  1.00 69.93           C  \\nATOM   8341  CG  LYS D  24       5.572  61.807  -1.262  1.00 69.93           C  \\nATOM   8342  CD  LYS D  24       5.160  63.230  -0.981  1.00 69.93           C  \\nATOM   8343  CE  LYS D  24       5.233  64.043  -2.253  1.00 69.93           C  \\nATOM   8344  NZ  LYS D  24       5.212  65.493  -1.951  1.00 69.93           N  \\nATOM   8345  N   LYS D  25       8.490  60.351   1.438  1.00109.97           N  \\nATOM   8346  CA  LYS D  25       9.371  60.013   2.558  1.00109.97           C  \\nATOM   8347  C   LYS D  25       9.397  61.080   3.674  1.00109.97           C  \\nATOM   8348  O   LYS D  25       8.715  62.107   3.589  1.00109.97           O  \\nATOM   8349  CB  LYS D  25      10.806  59.793   2.040  1.00121.69           C  \\nATOM   8350  CG  LYS D  25      10.956  58.924   0.777  1.00121.69           C  \\nATOM   8351  CD  LYS D  25      12.420  58.822   0.350  1.00121.69           C  \\nATOM   8352  CE  LYS D  25      12.595  58.021  -0.930  1.00121.69           C  \\nATOM   8353  NZ  LYS D  25      14.040  57.874  -1.275  1.00121.69           N  \\nATOM   8354  N   ARG D  26      10.188  60.811   4.716  1.00150.56           N  \\nATOM   8355  CA  ARG D  26      10.368  61.713   5.863  1.00150.56           C  \\nATOM   8356  C   ARG D  26      11.776  62.319   5.742  1.00150.56           C  \\nATOM   8357  O   ARG D  26      12.758  61.760   6.243  1.00150.56           O  \\nATOM   8358  CB  ARG D  26      10.249  60.922   7.172  1.00133.59           C  \\nATOM   8359  CG  ARG D  26      10.328  61.749   8.457  1.00133.59           C  \\nATOM   8360  CD  ARG D  26      11.064  60.981   9.557  1.00133.59           C  \\nATOM   8361  NE  ARG D  26      10.726  59.558   9.544  1.00133.59           N  \\nATOM   8362  CZ  ARG D  26      11.589  58.576   9.281  1.00133.59           C  \\nATOM   8363  NH1 ARG D  26      12.861  58.848   9.014  1.00133.59           N  \\nATOM   8364  NH2 ARG D  26      11.166  57.320   9.233  1.00133.59           N  \\nATOM   8365  N   ARG D  27      11.863  63.472   5.088  1.00148.32           N  \\nATOM   8366  CA  ARG D  27      13.145  64.124   4.859  1.00148.32           C  \\nATOM   8367  C   ARG D  27      13.502  65.273   5.818  1.00148.32           C  \\nATOM   8368  O   ARG D  27      13.055  66.411   5.642  1.00148.32           O  \\nATOM   8369  CB  ARG D  27      13.220  64.563   3.388  1.00 75.01           C  \\nATOM   8370  CG  ARG D  27      13.053  63.391   2.380  1.00 75.01           C  \\nATOM   8371  CD  ARG D  27      13.156  63.843   0.904  1.00 75.01           C  \\nATOM   8372  NE  ARG D  27      13.082  62.737  -0.062  1.00 75.01           N  \\nATOM   8373  CZ  ARG D  27      13.436  62.815  -1.349  1.00 75.01           C  \\nATOM   8374  NH1 ARG D  27      13.903  63.943  -1.871  1.00 75.01           N  \\nATOM   8375  NH2 ARG D  27      13.277  61.765  -2.142  1.00 75.01           N  \\nATOM   8376  N   LYS D  28      14.316  64.952   6.827  1.00125.26           N  \\nATOM   8377  CA  LYS D  28      14.772  65.922   7.830  1.00125.26           C  \\nATOM   8378  C   LYS D  28      15.876  66.819   7.259  1.00125.26           C  \\nATOM   8379  O   LYS D  28      15.934  67.031   6.046  1.00125.26           O  \\nATOM   8380  CB  LYS D  28      15.309  65.198   9.069  1.00118.41           C  \\nATOM   8381  CG  LYS D  28      14.266  64.609  10.008  1.00118.41           C  \\nATOM   8382  CD  LYS D  28      14.953  64.097  11.279  1.00118.41           C  \\nATOM   8383  CE  LYS D  28      13.966  63.640  12.344  1.00118.41           C  \\nATOM   8384  NZ  LYS D  28      14.668  63.324  13.621  1.00118.41           N  \\nATOM   8385  N   THR D  29      16.754  67.331   8.128  1.00116.78           N  \\nATOM   8386  CA  THR D  29      17.858  68.203   7.694  1.00116.78           C  \\nATOM   8387  C   THR D  29      19.102  68.275   8.634  1.00116.78           C  \\nATOM   8388  O   THR D  29      20.208  67.883   8.241  1.00116.78           O  \\nATOM   8389  CB  THR D  29      17.334  69.636   7.374  1.00 97.47           C  \\nATOM   8390  OG1 THR D  29      15.918  69.710   7.615  1.00 97.47           O  \\nATOM   8391  CG2 THR D  29      17.608  69.992   5.910  1.00 97.47           C  \\nATOM   8392  N   ARG D  30      18.893  68.786   9.853  1.00108.78           N  \\nATOM   8393  CA  ARG D  30      19.904  68.959  10.929  1.00108.78           C  \\nATOM   8394  C   ARG D  30      21.193  69.763  10.717  1.00108.78           C  \\nATOM   8395  O   ARG D  30      22.101  69.337   9.999  1.00108.78           O  \\nATOM   8396  CB  ARG D  30      20.248  67.639  11.640  1.00 83.99           C  \\nATOM   8397  CG  ARG D  30      21.104  67.873  12.888  1.00 83.99           C  \\nATOM   8398  CD  ARG D  30      21.110  66.722  13.870  1.00 83.99           C  \\nATOM   8399  NE  ARG D  30      21.546  67.190  15.188  1.00 83.99           N  \\nATOM   8400  CZ  ARG D  30      22.201  66.453  16.085  1.00 83.99           C  \\nATOM   8401  NH1 ARG D  30      22.514  65.194  15.822  1.00 83.99           N  \\nATOM   8402  NH2 ARG D  30      22.559  66.977  17.250  1.00 83.99           N  \\nATOM   8403  N   LYS D  31      21.289  70.865  11.470  1.00 56.71           N  \\nATOM   8404  CA  LYS D  31      22.423  71.800  11.452  1.00 56.71           C  \\nATOM   8405  C   LYS D  31      22.735  72.304  12.879  1.00 56.71           C  \\nATOM   8406  O   LYS D  31      22.031  73.164  13.419  1.00 56.71           O  \\nATOM   8407  CB  LYS D  31      22.118  73.015  10.551  1.00108.63           C  \\nATOM   8408  CG  LYS D  31      21.608  72.691   9.139  1.00108.63           C  \\nATOM   8409  CD  LYS D  31      20.213  73.275   8.922  1.00108.63           C  \\nATOM   8410  CE  LYS D  31      19.354  72.379   8.047  1.00108.63           C  \\nATOM   8411  NZ  LYS D  31      17.919  72.583   8.384  1.00108.63           N  \\nATOM   8412  N   GLU D  32      23.804  71.778  13.472  1.00 33.93           N  \\nATOM   8413  CA  GLU D  32      24.233  72.146  14.825  1.00 33.93           C  \\nATOM   8414  C   GLU D  32      24.597  73.634  14.993  1.00 33.93           C  \\nATOM   8415  O   GLU D  32      24.992  74.301  14.035  1.00 33.93           O  \\nATOM   8416  CB  GLU D  32      25.426  71.296  15.192  1.00 90.36           C  \\nATOM   8417  CG  GLU D  32      26.514  71.419  14.152  1.00 90.36           C  \\nATOM   8418  CD  GLU D  32      27.561  70.366  14.292  1.00 90.36           C  \\nATOM   8419  OE1 GLU D  32      27.729  69.878  15.422  1.00 90.36           O  \\nATOM   8420  OE2 GLU D  32      28.208  70.026  13.276  1.00 90.36           O  \\nATOM   8421  N   SER D  33      24.530  74.118  16.232  1.00 25.89           N  \\nATOM   8422  CA  SER D  33      24.809  75.519  16.568  1.00 25.89           C  \\nATOM   8423  C   SER D  33      25.396  75.545  17.972  1.00 25.89           C  \\nATOM   8424  O   SER D  33      25.616  74.496  18.541  1.00 25.89           O  \\nATOM   8425  CB  SER D  33      23.478  76.297  16.537  1.00 32.72           C  \\nATOM   8426  OG  SER D  33      23.579  77.620  17.030  1.00 32.72           O  \\nATOM   8427  N   TYR D  34      25.782  76.719  18.466  1.00 24.46           N  \\nATOM   8428  CA  TYR D  34      26.300  76.862  19.836  1.00 24.46           C  \\nATOM   8429  C   TYR D  34      25.260  77.659  20.608  1.00 24.46           C  \\nATOM   8430  O   TYR D  34      25.465  77.996  21.769  1.00 24.46           O  \\nATOM   8431  CB  TYR D  34      27.619  77.638  19.888  1.00 23.16           C  \\nATOM   8432  CG  TYR D  34      28.822  76.869  19.420  1.00 23.16           C  \\nATOM   8433  CD1 TYR D  34      29.570  76.084  20.308  1.00 23.16           C  \\nATOM   8434  CD2 TYR D  34      29.243  76.942  18.098  1.00 23.16           C  \\nATOM   8435  CE1 TYR D  34      30.721  75.394  19.878  1.00 23.16           C  \\nATOM   8436  CE2 TYR D  34      30.370  76.260  17.667  1.00 23.16           C  \\nATOM   8437  CZ  TYR D  34      31.104  75.493  18.556  1.00 23.16           C  \\nATOM   8438  OH  TYR D  34      32.223  74.834  18.093  1.00 23.16           O  \\nATOM   8439  N   ALA D  35      24.164  77.982  19.922  1.00 30.67           N  \\nATOM   8440  CA  ALA D  35      23.054  78.753  20.468  1.00 30.67           C  \\nATOM   8441  C   ALA D  35      22.639  78.462  21.918  1.00 30.67           C  \\nATOM   8442  O   ALA D  35      22.687  79.352  22.768  1.00 30.67           O  \\nATOM   8443  CB  ALA D  35      21.846  78.659  19.530  1.00 60.44           C  \\nATOM   8444  N   ILE D  36      22.244  77.229  22.214  1.00 28.93           N  \\nATOM   8445  CA  ILE D  36      21.831  76.905  23.573  1.00 28.93           C  \\nATOM   8446  C   ILE D  36      22.963  77.189  24.560  1.00 28.93           C  \\nATOM   8447  O   ILE D  36      22.733  77.686  25.665  1.00 28.93           O  \\nATOM   8448  CB  ILE D  36      21.353  75.429  23.708  1.00 23.57           C  \\nATOM   8449  CG1 ILE D  36      22.504  74.460  23.482  1.00 23.57           C  \\nATOM   8450  CG2 ILE D  36      20.252  75.133  22.708  1.00 23.57           C  \\nATOM   8451  CD1 ILE D  36      22.086  73.023  23.654  1.00 23.57           C  \\nATOM   8452  N   TYR D  37      24.195  76.952  24.134  1.00 24.80           N  \\nATOM   8453  CA  TYR D  37      25.322  77.192  25.022  1.00 24.80           C  \\nATOM   8454  C   TYR D  37      25.586  78.685  25.199  1.00 24.80           C  \\nATOM   8455  O   TYR D  37      25.862  79.136  26.314  1.00 24.80           O  \\nATOM   8456  CB  TYR D  37      26.549  76.440  24.526  1.00 30.83           C  \\nATOM   8457  CG  TYR D  37      26.257  74.986  24.304  1.00 30.83           C  \\nATOM   8458  CD1 TYR D  37      26.058  74.135  25.380  1.00 30.83           C  \\nATOM   8459  CD2 TYR D  37      26.112  74.473  23.012  1.00 30.83           C  \\nATOM   8460  CE1 TYR D  37      25.717  72.804  25.195  1.00 30.83           C  \\nATOM   8461  CE2 TYR D  37      25.773  73.124  22.800  1.00 30.83           C  \\nATOM   8462  CZ  TYR D  37      25.572  72.293  23.904  1.00 30.83           C  \\nATOM   8463  OH  TYR D  37      25.224  70.957  23.729  1.00 30.83           O  \\nATOM   8464  N   VAL D  38      25.497  79.457  24.112  1.00  9.62           N  \\nATOM   8465  CA  VAL D  38      25.683  80.901  24.203  1.00  9.62           C  \\nATOM   8466  C   VAL D  38      24.623  81.334  25.178  1.00  9.62           C  \\nATOM   8467  O   VAL D  38      24.942  81.930  26.199  1.00  9.62           O  \\nATOM   8468  CB  VAL D  38      25.475  81.630  22.864  1.00  8.16           C  \\nATOM   8469  CG1 VAL D  38      25.486  83.116  23.078  1.00  8.16           C  \\nATOM   8470  CG2 VAL D  38      26.580  81.283  21.927  1.00  8.16           C  \\nATOM   8471  N   TYR D  39      23.383  80.893  24.943  1.00 18.17           N  \\nATOM   8472  CA  TYR D  39      22.272  81.223  25.828  1.00 18.17           C  \\nATOM   8473  C   TYR D  39      22.525  80.898  27.333  1.00 18.17           C  \\nATOM   8474  O   TYR D  39      22.367  81.778  28.181  1.00 18.17           O  \\nATOM   8475  CB  TYR D  39      20.981  80.603  25.317  1.00 56.31           C  \\nATOM   8476  CG  TYR D  39      19.769  81.355  25.789  1.00 56.31           C  \\nATOM   8477  CD1 TYR D  39      19.265  82.442  25.067  1.00 56.31           C  \\nATOM   8478  CD2 TYR D  39      19.137  81.009  26.986  1.00 56.31           C  \\nATOM   8479  CE1 TYR D  39      18.142  83.180  25.538  1.00 56.31           C  \\nATOM   8480  CE2 TYR D  39      18.019  81.729  27.473  1.00 56.31           C  \\nATOM   8481  CZ  TYR D  39      17.519  82.814  26.750  1.00 56.31           C  \\nATOM   8482  OH  TYR D  39      16.401  83.492  27.240  1.00 56.31           O  \\nATOM   8483  N   LYS D  40      22.969  79.685  27.674  1.00 22.61           N  \\nATOM   8484  CA  LYS D  40      23.228  79.357  29.085  1.00 22.61           C  \\nATOM   8485  C   LYS D  40      24.124  80.398  29.723  1.00 22.61           C  \\nATOM   8486  O   LYS D  40      23.785  80.985  30.761  1.00 22.61           O  \\nATOM   8487  CB  LYS D  40      23.882  77.990  29.251  1.00 50.79           C  \\nATOM   8488  CG  LYS D  40      22.976  76.824  28.989  1.00 50.79           C  \\nATOM   8489  CD  LYS D  40      23.675  75.517  29.328  1.00 50.79           C  \\nATOM   8490  CE  LYS D  40      22.853  74.295  28.920  1.00 50.79           C  \\nATOM   8491  NZ  LYS D  40      23.535  73.039  29.358  1.00 50.79           N  \\nATOM   8492  N   VAL D  41      25.248  80.658  29.062  1.00 47.68           N  \\nATOM   8493  CA  VAL D  41      26.220  81.627  29.547  1.00 47.68           C  \\nATOM   8494  C   VAL D  41      25.563  82.996  29.633  1.00 47.68           C  \\nATOM   8495  O   VAL D  41      25.744  83.721  30.615  1.00 47.68           O  \\nATOM   8496  CB  VAL D  41      27.470  81.676  28.638  1.00 38.76           C  \\nATOM   8497  CG1 VAL D  41      28.437  82.749  29.128  1.00 38.76           C  \\nATOM   8498  CG2 VAL D  41      28.162  80.322  28.629  1.00 38.76           C  \\nATOM   8499  N   LEU D  42      24.787  83.334  28.607  1.00 21.97           N  \\nATOM   8500  CA  LEU D  42      24.075  84.604  28.582  1.00 21.97           C  \\nATOM   8501  C   LEU D  42      23.317  84.808  29.886  1.00 21.97           C  \\nATOM   8502  O   LEU D  42      23.402  85.876  30.514  1.00 21.97           O  \\nATOM   8503  CB  LEU D  42      23.073  84.649  27.437  1.00 10.75           C  \\nATOM   8504  CG  LEU D  42      22.168  85.894  27.507  1.00 10.75           C  \\nATOM   8505  CD1 LEU D  42      23.028  87.179  27.604  1.00 10.75           C  \\nATOM   8506  CD2 LEU D  42      21.189  85.951  26.319  1.00 10.75           C  \\nATOM   8507  N   LYS D  43      22.592  83.768  30.291  1.00 26.05           N  \\nATOM   8508  CA  LYS D  43      21.803  83.825  31.509  1.00 26.05           C  \\nATOM   8509  C   LYS D  43      22.641  83.939  32.741  1.00 26.05           C  \\nATOM   8510  O   LYS D  43      22.184  84.467  33.749  1.00 26.05           O  \\nATOM   8511  CB  LYS D  43      20.814  82.662  31.590  1.00 44.66           C  \\nATOM   8512  CG  LYS D  43      19.661  82.839  30.618  1.00 44.66           C  \\nATOM   8513  CD  LYS D  43      19.242  84.294  30.640  1.00 44.66           C  \\nATOM   8514  CE  LYS D  43      17.961  84.547  29.909  1.00 44.66           C  \\nATOM   8515  NZ  LYS D  43      17.517  85.935  30.183  1.00 44.66           N  \\nATOM   8516  N   GLN D  44      23.874  83.457  32.655  1.00 20.19           N  \\nATOM   8517  CA  GLN D  44      24.794  83.549  33.785  1.00 20.19           C  \\nATOM   8518  C   GLN D  44      25.287  84.984  34.066  1.00 20.19           C  \\nATOM   8519  O   GLN D  44      25.281  85.426  35.220  1.00 20.19           O  \\nATOM   8520  CB  GLN D  44      25.998  82.615  33.585  1.00 34.11           C  \\nATOM   8521  CG  GLN D  44      25.738  81.134  33.860  1.00 34.11           C  \\nATOM   8522  CD  GLN D  44      26.978  80.267  33.649  1.00 34.11           C  \\nATOM   8523  OE1 GLN D  44      27.752  80.492  32.713  1.00 34.11           O  \\nATOM   8524  NE2 GLN D  44      27.169  79.273  34.512  1.00 34.11           N  \\nATOM   8525  N   VAL D  45      25.699  85.714  33.021  1.00 36.55           N  \\nATOM   8526  CA  VAL D  45      26.236  87.075  33.198  1.00 36.55           C  \\nATOM   8527  C   VAL D  45      25.214  88.167  33.490  1.00 36.55           C  \\nATOM   8528  O   VAL D  45      25.383  88.971  34.431  1.00 36.55           O  \\nATOM   8529  CB  VAL D  45      27.167  87.487  32.013  1.00 24.97           C  \\nATOM   8530  CG1 VAL D  45      28.339  86.495  31.912  1.00 24.97           C  \\nATOM   8531  CG2 VAL D  45      26.396  87.549  30.696  1.00 24.97           C  \\nATOM   8532  N   HIS D  46      24.139  88.132  32.700  1.00 21.80           N  \\nATOM   8533  CA  HIS D  46      23.004  89.054  32.774  1.00 21.80           C  \\nATOM   8534  C   HIS D  46      21.723  88.206  32.734  1.00 21.80           C  \\nATOM   8535  O   HIS D  46      21.102  88.022  31.684  1.00 21.80           O  \\nATOM   8536  CB  HIS D  46      23.032  89.992  31.578  1.00 14.96           C  \\nATOM   8537  CG  HIS D  46      24.176  90.946  31.591  1.00 14.96           C  \\nATOM   8538  ND1 HIS D  46      25.077  91.032  30.554  1.00 14.96           N  \\nATOM   8539  CD2 HIS D  46      24.541  91.887  32.493  1.00 14.96           C  \\nATOM   8540  CE1 HIS D  46      25.948  91.987  30.814  1.00 14.96           C  \\nATOM   8541  NE2 HIS D  46      25.645  92.523  31.982  1.00 14.96           N  \\nATOM   8542  N   PRO D  47      21.247  87.787  33.908  1.00 26.89           N  \\nATOM   8543  CA  PRO D  47      20.055  86.951  34.114  1.00 26.89           C  \\nATOM   8544  C   PRO D  47      18.745  87.380  33.444  1.00 26.89           C  \\nATOM   8545  O   PRO D  47      17.975  86.533  32.980  1.00 26.89           O  \\nATOM   8546  CB  PRO D  47      19.922  86.929  35.643  1.00 25.83           C  \\nATOM   8547  CG  PRO D  47      21.305  87.310  36.145  1.00 25.83           C  \\nATOM   8548  CD  PRO D  47      21.693  88.366  35.186  1.00 25.83           C  \\nATOM   8549  N   ASP D  48      18.528  88.687  33.340  1.00 28.06           N  \\nATOM   8550  CA  ASP D  48      17.286  89.192  32.760  1.00 28.06           C  \\nATOM   8551  C   ASP D  48      17.400  89.817  31.362  1.00 28.06           C  \\nATOM   8552  O   ASP D  48      16.536  90.591  30.957  1.00 28.06           O  \\nATOM   8553  CB  ASP D  48      16.612  90.174  33.749  1.00 40.32           C  \\nATOM   8554  CG  ASP D  48      16.301  89.532  35.128  1.00 40.32           C  \\nATOM   8555  OD1 ASP D  48      16.074  88.299  35.212  1.00 40.32           O  \\nATOM   8556  OD2 ASP D  48      16.278  90.269  36.139  1.00 40.32           O  \\nATOM   8557  N   THR D  49      18.416  89.426  30.598  1.00  7.13           N  \\nATOM   8558  CA  THR D  49      18.614  89.976  29.256  1.00  7.13           C  \\nATOM   8559  C   THR D  49      18.401  88.904  28.172  1.00  7.13           C  \\nATOM   8560  O   THR D  49      18.631  87.726  28.405  1.00  7.13           O  \\nATOM   8561  CB  THR D  49      20.046  90.597  29.160  1.00 14.55           C  \\nATOM   8562  OG1 THR D  49      20.242  91.504  30.257  1.00 14.55           O  \\nATOM   8563  CG2 THR D  49      20.252  91.344  27.851  1.00 14.55           C  \\nATOM   8564  N   GLY D  50      17.927  89.314  27.007  1.00 25.20           N  \\nATOM   8565  CA  GLY D  50      17.718  88.366  25.932  1.00 25.20           C  \\nATOM   8566  C   GLY D  50      18.661  88.644  24.767  1.00 25.20           C  \\nATOM   8567  O   GLY D  50      19.582  89.440  24.897  1.00 25.20           O  \\nATOM   8568  N   ILE D  51      18.390  88.049  23.606  1.00 36.28           N  \\nATOM   8569  CA  ILE D  51      19.235  88.245  22.430  1.00 36.28           C  \\nATOM   8570  C   ILE D  51      18.460  87.912  21.149  1.00 36.28           C  \\nATOM   8571  O   ILE D  51      17.854  86.843  21.042  1.00 36.28           O  \\nATOM   8572  CB  ILE D  51      20.548  87.396  22.548  1.00 20.49           C  \\nATOM   8573  CG1 ILE D  51      21.473  87.631  21.343  1.00 20.49           C  \\nATOM   8574  CG2 ILE D  51      20.241  85.904  22.704  1.00 20.49           C  \\nATOM   8575  CD1 ILE D  51      22.901  87.033  21.505  1.00 20.49           C  \\nATOM   8576  N   SER D  52      18.454  88.841  20.191  1.00 23.83           N  \\nATOM   8577  CA  SER D  52      17.738  88.627  18.938  1.00 23.83           C  \\nATOM   8578  C   SER D  52      18.368  87.470  18.181  1.00 23.83           C  \\nATOM   8579  O   SER D  52      19.488  87.082  18.477  1.00 23.83           O  \\nATOM   8580  CB  SER D  52      17.728  89.894  18.079  1.00 34.42           C  \\nATOM   8581  OG  SER D  52      19.011  90.232  17.594  1.00 34.42           O  \\nATOM   8582  N   SER D  53      17.667  86.902  17.207  1.00 24.91           N  \\nATOM   8583  CA  SER D  53      18.238  85.779  16.475  1.00 24.91           C  \\nATOM   8584  C   SER D  53      19.428  86.241  15.647  1.00 24.91           C  \\nATOM   8585  O   SER D  53      20.385  85.488  15.464  1.00 24.91           O  \\nATOM   8586  CB  SER D  53      17.193  85.116  15.581  1.00 29.05           C  \\nATOM   8587  OG  SER D  53      16.867  85.959  14.498  1.00 29.05           O  \\nATOM   8588  N   LYS D  54      19.373  87.485  15.171  1.00 26.31           N  \\nATOM   8589  CA  LYS D  54      20.461  88.035  14.376  1.00 26.31           C  \\nATOM   8590  C   LYS D  54      21.708  88.102  15.239  1.00 26.31           C  \\nATOM   8591  O   LYS D  54      22.766  87.649  14.830  1.00 26.31           O  \\nATOM   8592  CB  LYS D  54      20.118  89.416  13.825  1.00 57.06           C  \\nATOM   8593  CG  LYS D  54      19.174  89.400  12.643  1.00 57.06           C  \\nATOM   8594  CD  LYS D  54      19.054  90.791  11.991  1.00 57.06           C  \\nATOM   8595  CE  LYS D  54      18.050  90.808  10.813  1.00 57.06           C  \\nATOM   8596  NZ  LYS D  54      17.962  92.144  10.139  1.00 57.06           N  \\nATOM   8597  N   ALA D  55      21.592  88.636  16.449  1.00 20.14           N  \\nATOM   8598  CA  ALA D  55      22.738  88.696  17.343  1.00 20.14           C  \\nATOM   8599  C   ALA D  55      23.264  87.292  17.673  1.00 20.14           C  \\nATOM   8600  O   ALA D  55      24.474  87.072  17.715  1.00 20.14           O  \\nATOM   8601  CB  ALA D  55      22.386  89.431  18.604  1.00 16.06           C  \\nATOM   8602  N   MET D  56      22.374  86.335  17.914  1.00 23.36           N  \\nATOM   8603  CA  MET D  56      22.827  84.981  18.203  1.00 23.36           C  \\nATOM   8604  C   MET D  56      23.594  84.450  17.011  1.00 23.36           C  \\nATOM   8605  O   MET D  56      24.665  83.894  17.163  1.00 23.36           O  \\nATOM   8606  CB  MET D  56      21.673  84.053  18.562  1.00 15.09           C  \\nATOM   8607  CG  MET D  56      22.115  82.631  18.841  1.00 15.09           C  \\nATOM   8608  SD  MET D  56      23.278  82.500  20.205  1.00 15.09           S  \\nATOM   8609  CE  MET D  56      22.171  82.731  21.660  1.00 15.09           C  \\nATOM   8610  N   SER D  57      23.071  84.661  15.816  1.00 25.65           N  \\nATOM   8611  CA  SER D  57      23.768  84.221  14.618  1.00 25.65           C  \\nATOM   8612  C   SER D  57      25.206  84.706  14.672  1.00 25.65           C  \\nATOM   8613  O   SER D  57      26.147  83.959  14.421  1.00 25.65           O  \\nATOM   8614  CB  SER D  57      23.110  84.803  13.386  1.00 19.09           C  \\nATOM   8615  OG  SER D  57      23.849  84.416  12.254  1.00 19.09           O  \\nATOM   8616  N   ILE D  58      25.360  85.978  14.996  1.00 13.01           N  \\nATOM   8617  CA  ILE D  58      26.677  86.580  15.128  1.00 13.01           C  \\nATOM   8618  C   ILE D  58      27.531  85.891  16.197  1.00 13.01           C  \\nATOM   8619  O   ILE D  58      28.684  85.523  15.936  1.00 13.01           O  \\nATOM   8620  CB  ILE D  58      26.548  88.107  15.372  1.00 13.30           C  \\nATOM   8621  CG1 ILE D  58      26.305  88.789  14.022  1.00 13.30           C  \\nATOM   8622  CG2 ILE D  58      27.785  88.664  16.048  1.00 13.30           C  \\nATOM   8623  CD1 ILE D  58      26.047  90.216  14.135  1.00 13.30           C  \\nATOM   8624  N   MET D  59      26.956  85.678  17.382  1.00 12.73           N  \\nATOM   8625  CA  MET D  59      27.679  85.010  18.466  1.00 12.73           C  \\nATOM   8626  C   MET D  59      28.149  83.647  18.021  1.00 12.73           C  \\nATOM   8627  O   MET D  59      29.241  83.189  18.380  1.00 12.73           O  \\nATOM   8628  CB  MET D  59      26.810  84.900  19.697  1.00 19.19           C  \\nATOM   8629  CG  MET D  59      26.740  86.199  20.444  1.00 19.19           C  \\nATOM   8630  SD  MET D  59      28.416  86.827  20.808  1.00 19.19           S  \\nATOM   8631  CE  MET D  59      28.871  85.879  22.278  1.00 19.19           C  \\nATOM   8632  N   ASN D  60      27.339  83.032  17.169  1.00 14.11           N  \\nATOM   8633  CA  ASN D  60      27.679  81.734  16.642  1.00 14.11           C  \\nATOM   8634  C   ASN D  60      28.855  81.837  15.687  1.00 14.11           C  \\nATOM   8635  O   ASN D  60      29.766  81.011  15.757  1.00 14.11           O  \\nATOM   8636  CB  ASN D  60      26.482  81.066  15.985  1.00 20.73           C  \\nATOM   8637  CG  ASN D  60      26.555  79.579  16.103  1.00 20.73           C  \\nATOM   8638  OD1 ASN D  60      26.659  79.058  17.203  1.00 20.73           O  \\nATOM   8639  ND2 ASN D  60      26.585  78.882  14.977  1.00 20.73           N  \\nATOM   8640  N   SER D  61      28.834  82.843  14.804  1.00 25.59           N  \\nATOM   8641  CA  SER D  61      29.932  83.078  13.859  1.00 25.59           C  \\nATOM   8642  C   SER D  61      31.228  83.275  14.627  1.00 25.59           C  \\nATOM   8643  O   SER D  61      32.228  82.614  14.349  1.00 25.59           O  \\nATOM   8644  CB  SER D  61      29.685  84.320  13.001  1.00 34.21           C  \\nATOM   8645  OG  SER D  61      28.742  84.068  11.976  1.00 34.21           O  \\nATOM   8646  N   PHE D  62      31.181  84.160  15.621  1.00 20.95           N  \\nATOM   8647  CA  PHE D  62      32.324  84.469  16.462  1.00 20.95           C  \\nATOM   8648  C   PHE D  62      32.965  83.204  17.021  1.00 20.95           C  \\nATOM   8649  O   PHE D  62      34.139  82.946  16.793  1.00 20.95           O  \\nATOM   8650  CB  PHE D  62      31.866  85.353  17.594  1.00 17.36           C  \\nATOM   8651  CG  PHE D  62      32.857  85.482  18.692  1.00 17.36           C  \\nATOM   8652  CD1 PHE D  62      34.055  86.152  18.494  1.00 17.36           C  \\nATOM   8653  CD2 PHE D  62      32.587  84.968  19.946  1.00 17.36           C  \\nATOM   8654  CE1 PHE D  62      34.973  86.310  19.538  1.00 17.36           C  \\nATOM   8655  CE2 PHE D  62      33.499  85.124  20.996  1.00 17.36           C  \\nATOM   8656  CZ  PHE D  62      34.686  85.795  20.788  1.00 17.36           C  \\nATOM   8657  N   VAL D  63      32.176  82.410  17.735  1.00 21.26           N  \\nATOM   8658  CA  VAL D  63      32.651  81.166  18.333  1.00 21.26           C  \\nATOM   8659  C   VAL D  63      33.382  80.257  17.348  1.00 21.26           C  \\nATOM   8660  O   VAL D  63      34.485  79.791  17.621  1.00 21.26           O  \\nATOM   8661  CB  VAL D  63      31.481  80.385  18.950  1.00 17.21           C  \\nATOM   8662  CG1 VAL D  63      31.958  79.044  19.416  1.00 17.21           C  \\nATOM   8663  CG2 VAL D  63      30.865  81.168  20.108  1.00 17.21           C  \\nATOM   8664  N   ASN D  64      32.762  79.998  16.203  1.00 14.46           N  \\nATOM   8665  CA  ASN D  64      33.379  79.144  15.199  1.00 14.46           C  \\nATOM   8666  C   ASN D  64      34.662  79.768  14.707  1.00 14.46           C  \\nATOM   8667  O   ASN D  64      35.683  79.108  14.645  1.00 14.46           O  \\nATOM   8668  CB  ASN D  64      32.411  78.868  14.054  1.00 46.77           C  \\nATOM   8669  CG  ASN D  64      31.271  77.956  14.482  1.00 46.77           C  \\nATOM   8670  OD1 ASN D  64      31.501  76.872  15.038  1.00 46.77           O  \\nATOM   8671  ND2 ASN D  64      30.036  78.390  14.237  1.00 46.77           N  \\nATOM   8672  N   ASP D  65      34.619  81.067  14.438  1.00 24.22           N  \\nATOM   8673  CA  ASP D  65      35.781  81.804  13.974  1.00 24.22           C  \\nATOM   8674  C   ASP D  65      36.954  81.581  14.902  1.00 24.22           C  \\nATOM   8675  O   ASP D  65      37.967  81.043  14.508  1.00 24.22           O  \\nATOM   8676  CB  ASP D  65      35.479  83.292  13.933  1.00 33.89           C  \\nATOM   8677  CG  ASP D  65      36.591  84.079  13.304  1.00 33.89           C  \\nATOM   8678  OD1 ASP D  65      37.102  83.621  12.262  1.00 33.89           O  \\nATOM   8679  OD2 ASP D  65      36.954  85.142  13.841  1.00 33.89           O  \\nATOM   8680  N   VAL D  66      36.790  81.970  16.153  1.00 24.26           N  \\nATOM   8681  CA  VAL D  66      37.839  81.810  17.135  1.00 24.26           C  \\nATOM   8682  C   VAL D  66      38.272  80.342  17.206  1.00 24.26           C  \\nATOM   8683  O   VAL D  66      39.462  80.033  17.305  1.00 24.26           O  \\nATOM   8684  CB  VAL D  66      37.372  82.292  18.505  1.00  5.83           C  \\nATOM   8685  CG1 VAL D  66      38.465  82.058  19.517  1.00  5.83           C  \\nATOM   8686  CG2 VAL D  66      36.941  83.767  18.451  1.00  5.83           C  \\nATOM   8687  N   PHE D  67      37.308  79.434  17.140  1.00 21.67           N  \\nATOM   8688  CA  PHE D  67      37.617  78.013  17.162  1.00 21.67           C  \\nATOM   8689  C   PHE D  67      38.602  77.615  16.040  1.00 21.67           C  \\nATOM   8690  O   PHE D  67      39.621  76.979  16.291  1.00 21.67           O  \\nATOM   8691  CB  PHE D  67      36.318  77.217  17.046  1.00 33.21           C  \\nATOM   8692  CG  PHE D  67      36.520  75.745  16.876  1.00 33.21           C  \\nATOM   8693  CD1 PHE D  67      36.638  74.919  17.978  1.00 33.21           C  \\nATOM   8694  CD2 PHE D  67      36.597  75.184  15.607  1.00 33.21           C  \\nATOM   8695  CE1 PHE D  67      36.836  73.553  17.818  1.00 33.21           C  \\nATOM   8696  CE2 PHE D  67      36.796  73.823  15.442  1.00 33.21           C  \\nATOM   8697  CZ  PHE D  67      36.915  73.009  16.556  1.00 33.21           C  \\nATOM   8698  N   GLU D  68      38.297  77.977  14.799  1.00 26.19           N  \\nATOM   8699  CA  GLU D  68      39.176  77.643  13.680  1.00 26.19           C  \\nATOM   8700  C   GLU D  68      40.534  78.328  13.785  1.00 26.19           C  \\nATOM   8701  O   GLU D  68      41.531  77.834  13.261  1.00 26.19           O  \\nATOM   8702  CB  GLU D  68      38.510  78.002  12.361  1.00 72.74           C  \\nATOM   8703  CG  GLU D  68      37.322  77.132  12.052  1.00 72.74           C  \\nATOM   8704  CD  GLU D  68      36.238  77.853  11.282  1.00 72.74           C  \\nATOM   8705  OE1 GLU D  68      36.548  78.791  10.510  1.00 72.74           O  \\nATOM   8706  OE2 GLU D  68      35.061  77.474  11.458  1.00 72.74           O  \\nATOM   8707  N   ARG D  69      40.559  79.492  14.427  1.00 20.80           N  \\nATOM   8708  CA  ARG D  69      41.790  80.247  14.602  1.00 20.80           C  \\nATOM   8709  C   ARG D  69      42.703  79.564  15.573  1.00 20.80           C  \\nATOM   8710  O   ARG D  69      43.886  79.353  15.293  1.00 20.80           O  \\nATOM   8711  CB  ARG D  69      41.466  81.645  15.064  1.00 22.98           C  \\nATOM   8712  CG  ARG D  69      40.762  82.418  13.972  1.00 22.98           C  \\nATOM   8713  CD  ARG D  69      41.182  83.858  13.977  1.00 22.98           C  \\nATOM   8714  NE  ARG D  69      40.091  84.757  14.297  1.00 22.98           N  \\nATOM   8715  CZ  ARG D  69      40.259  85.894  14.945  1.00 22.98           C  \\nATOM   8716  NH1 ARG D  69      41.458  86.249  15.355  1.00 22.98           N  \\nATOM   8717  NH2 ARG D  69      39.250  86.725  15.104  1.00 22.98           N  \\nATOM   8718  N   ILE D  70      42.121  79.159  16.695  1.00 23.63           N  \\nATOM   8719  CA  ILE D  70      42.857  78.454  17.723  1.00 23.63           C  \\nATOM   8720  C   ILE D  70      43.272  77.065  17.262  1.00 23.63           C  \\nATOM   8721  O   ILE D  70      44.420  76.675  17.472  1.00 23.63           O  \\nATOM   8722  CB  ILE D  70      42.047  78.356  18.997  1.00 13.50           C  \\nATOM   8723  CG1 ILE D  70      42.069  79.707  19.711  1.00 13.50           C  \\nATOM   8724  CG2 ILE D  70      42.615  77.272  19.880  1.00 13.50           C  \\nATOM   8725  CD1 ILE D  70      41.261  79.766  20.966  1.00 13.50           C  \\nATOM   8726  N   ALA D  71      42.347  76.336  16.618  1.00 17.31           N  \\nATOM   8727  CA  ALA D  71      42.608  74.982  16.102  1.00 17.31           C  \\nATOM   8728  C   ALA D  71      43.660  75.055  15.010  1.00 17.31           C  \\nATOM   8729  O   ALA D  71      44.533  74.204  14.916  1.00 17.31           O  \\nATOM   8730  CB  ALA D  71      41.328  74.354  15.569  1.00 12.33           C  \\nATOM   8731  N   GLY D  72      43.598  76.125  14.236  1.00 20.95           N  \\nATOM   8732  CA  GLY D  72      44.562  76.320  13.178  1.00 20.95           C  \\nATOM   8733  C   GLY D  72      45.949  76.545  13.764  1.00 20.95           C  \\nATOM   8734  O   GLY D  72      46.923  75.926  13.320  1.00 20.95           O  \\nATOM   8735  N   GLU D  73      46.055  77.460  14.729  1.00 32.31           N  \\nATOM   8736  CA  GLU D  73      47.336  77.717  15.372  1.00 32.31           C  \\nATOM   8737  C   GLU D  73      47.876  76.381  15.841  1.00 32.31           C  \\nATOM   8738  O   GLU D  73      48.936  75.950  15.404  1.00 32.31           O  \\nATOM   8739  CB  GLU D  73      47.187  78.655  16.580  1.00 47.12           C  \\nATOM   8740  CG  GLU D  73      47.173  80.139  16.261  1.00 47.12           C  \\nATOM   8741  CD  GLU D  73      48.357  80.593  15.414  1.00 47.12           C  \\nATOM   8742  OE1 GLU D  73      49.463  80.000  15.514  1.00 47.12           O  \\nATOM   8743  OE2 GLU D  73      48.173  81.554  14.637  1.00 47.12           O  \\nATOM   8744  N   ALA D  74      47.092  75.705  16.678  1.00 20.51           N  \\nATOM   8745  CA  ALA D  74      47.449  74.398  17.221  1.00 20.51           C  \\nATOM   8746  C   ALA D  74      47.963  73.471  16.131  1.00 20.51           C  \\nATOM   8747  O   ALA D  74      49.016  72.878  16.278  1.00 20.51           O  \\nATOM   8748  CB  ALA D  74      46.252  73.778  17.910  1.00 27.58           C  \\nATOM   8749  N   SER D  75      47.220  73.352  15.041  1.00 20.45           N  \\nATOM   8750  CA  SER D  75      47.650  72.510  13.941  1.00 20.45           C  \\nATOM   8751  C   SER D  75      49.093  72.806  13.543  1.00 20.45           C  \\nATOM   8752  O   SER D  75      49.942  71.926  13.615  1.00 20.45           O  \\nATOM   8753  CB  SER D  75      46.739  72.696  12.725  1.00 28.27           C  \\nATOM   8754  OG  SER D  75      47.163  71.851  11.672  1.00 28.27           O  \\nATOM   8755  N   ARG D  76      49.367  74.058  13.182  1.00 20.62           N  \\nATOM   8756  CA  ARG D  76      50.695  74.489  12.759  1.00 20.62           C  \\nATOM   8757  C   ARG D  76      51.742  74.303  13.822  1.00 20.62           C  \\nATOM   8758  O   ARG D  76      52.846  73.855  13.533  1.00 20.62           O  \\nATOM   8759  CB  ARG D  76      50.672  75.942  12.305  1.00 46.88           C  \\nATOM   8760  CG  ARG D  76      50.341  76.101  10.839  1.00 46.88           C  \\nATOM   8761  CD  ARG D  76      49.977  77.533  10.502  1.00 46.88           C  \\nATOM   8762  NE  ARG D  76      48.524  77.729  10.501  1.00 46.88           N  \\nATOM   8763  CZ  ARG D  76      47.869  78.573  11.300  1.00 46.88           C  \\nATOM   8764  NH1 ARG D  76      48.523  79.323  12.191  1.00 46.88           N  \\nATOM   8765  NH2 ARG D  76      46.554  78.682  11.198  1.00 46.88           N  \\nATOM   8766  N   LEU D  77      51.412  74.652  15.054  1.00 27.75           N  \\nATOM   8767  CA  LEU D  77      52.338  74.476  16.167  1.00 27.75           C  \\nATOM   8768  C   LEU D  77      52.827  73.009  16.209  1.00 27.75           C  \\nATOM   8769  O   LEU D  77      54.023  72.752  16.267  1.00 27.75           O  \\nATOM   8770  CB  LEU D  77      51.625  74.841  17.459  1.00 18.60           C  \\nATOM   8771  CG  LEU D  77      52.427  75.098  18.724  1.00 18.60           C  \\nATOM   8772  CD1 LEU D  77      53.676  75.946  18.432  1.00 18.60           C  \\nATOM   8773  CD2 LEU D  77      51.506  75.799  19.717  1.00 18.60           C  \\nATOM   8774  N   ALA D  78      51.895  72.056  16.140  1.00 34.33           N  \\nATOM   8775  CA  ALA D  78      52.210  70.631  16.147  1.00 34.33           C  \\nATOM   8776  C   ALA D  78      53.165  70.204  15.019  1.00 34.33           C  \\nATOM   8777  O   ALA D  78      54.082  69.425  15.244  1.00 34.33           O  \\nATOM   8778  CB  ALA D  78      50.930  69.826  16.074  1.00 22.89           C  \\nATOM   8779  N   HIS D  79      52.917  70.634  13.788  1.00 19.86           N  \\nATOM   8780  CA  HIS D  79      53.826  70.254  12.713  1.00 19.86           C  \\nATOM   8781  C   HIS D  79      55.198  70.893  12.940  1.00 19.86           C  \\nATOM   8782  O   HIS D  79      56.200  70.209  12.891  1.00 19.86           O  \\nATOM   8783  CB  HIS D  79      53.231  70.554  11.336  1.00 98.39           C  \\nATOM   8784  CG  HIS D  79      52.038  69.704  11.006  1.00 98.39           C  \\nATOM   8785  ND1 HIS D  79      51.526  69.596   9.730  1.00 98.39           N  \\nATOM   8786  CD2 HIS D  79      51.256  68.923  11.792  1.00 98.39           C  \\nATOM   8787  CE1 HIS D  79      50.480  68.789   9.744  1.00 98.39           C  \\nATOM   8788  NE2 HIS D  79      50.295  68.368  10.983  1.00 98.39           N  \\nATOM   8789  N   TYR D  80      55.231  72.156  13.350  1.00 39.77           N  \\nATOM   8790  CA  TYR D  80      56.498  72.845  13.630  1.00 39.77           C  \\nATOM   8791  C   TYR D  80      57.394  72.041  14.557  1.00 39.77           C  \\nATOM   8792  O   TYR D  80      58.614  72.241  14.582  1.00 39.77           O  \\nATOM   8793  CB  TYR D  80      56.241  74.204  14.277  1.00 56.56           C  \\nATOM   8794  CG  TYR D  80      55.509  75.162  13.384  1.00 56.56           C  \\nATOM   8795  CD1 TYR D  80      55.369  74.899  12.020  1.00 56.56           C  \\nATOM   8796  CD2 TYR D  80      54.972  76.342  13.888  1.00 56.56           C  \\nATOM   8797  CE1 TYR D  80      54.715  75.787  11.175  1.00 56.56           C  \\nATOM   8798  CE2 TYR D  80      54.317  77.243  13.055  1.00 56.56           C  \\nATOM   8799  CZ  TYR D  80      54.190  76.962  11.693  1.00 56.56           C  \\nATOM   8800  OH  TYR D  80      53.546  77.853  10.846  1.00 56.56           O  \\nATOM   8801  N   ASN D  81      56.776  71.146  15.326  1.00 29.42           N  \\nATOM   8802  CA  ASN D  81      57.502  70.318  16.277  1.00 29.42           C  \\nATOM   8803  C   ASN D  81      57.458  68.836  16.000  1.00 29.42           C  \\nATOM   8804  O   ASN D  81      57.788  68.043  16.874  1.00 29.42           O  \\nATOM   8805  CB  ASN D  81      57.006  70.574  17.698  1.00 33.90           C  \\nATOM   8806  CG  ASN D  81      57.319  71.968  18.175  1.00 33.90           C  \\nATOM   8807  OD1 ASN D  81      58.338  72.202  18.823  1.00 33.90           O  \\nATOM   8808  ND2 ASN D  81      56.462  72.916  17.830  1.00 33.90           N  \\nATOM   8809  N   LYS D  82      57.081  68.460  14.786  1.00 42.10           N  \\nATOM   8810  CA  LYS D  82      56.987  67.050  14.401  1.00 42.10           C  \\nATOM   8811  C   LYS D  82      56.143  66.239  15.392  1.00 42.10           C  \\nATOM   8812  O   LYS D  82      56.473  65.098  15.725  1.00 42.10           O  \\nATOM   8813  CB  LYS D  82      58.389  66.461  14.210  1.00 46.61           C  \\nATOM   8814  CG  LYS D  82      59.225  67.291  13.249  1.00 46.61           C  \\nATOM   8815  CD  LYS D  82      60.662  66.857  13.200  1.00 46.61           C  \\nATOM   8816  CE  LYS D  82      61.506  67.864  12.406  1.00 46.61           C  \\nATOM   8817  NZ  LYS D  82      62.978  67.519  12.402  1.00 46.61           N  \\nATOM   8818  N   ARG D  83      55.095  66.895  15.901  1.00 54.16           N  \\nATOM   8819  CA  ARG D  83      54.129  66.321  16.832  1.00 54.16           C  \\nATOM   8820  C   ARG D  83      52.919  65.906  16.010  1.00 54.16           C  \\nATOM   8821  O   ARG D  83      52.498  66.629  15.095  1.00 54.16           O  \\nATOM   8822  CB  ARG D  83      53.651  67.347  17.864  1.00118.10           C  \\nATOM   8823  CG  ARG D  83      54.353  67.291  19.193  1.00118.10           C  \\nATOM   8824  CD  ARG D  83      55.617  68.094  19.146  1.00118.10           C  \\nATOM   8825  NE  ARG D  83      56.781  67.335  19.586  1.00118.10           N  \\nATOM   8826  CZ  ARG D  83      57.036  67.029  20.854  1.00118.10           C  \\nATOM   8827  NH1 ARG D  83      56.204  67.418  21.817  1.00118.10           N  \\nATOM   8828  NH2 ARG D  83      58.132  66.353  21.165  1.00118.10           N  \\nATOM   8829  N   SER D  84      52.349  64.751  16.336  1.00 32.97           N  \\nATOM   8830  CA  SER D  84      51.188  64.277  15.606  1.00 32.97           C  \\nATOM   8831  C   SER D  84      49.900  64.369  16.419  1.00 32.97           C  \\nATOM   8832  O   SER D  84      48.820  64.105  15.890  1.00 32.97           O  \\nATOM   8833  CB  SER D  84      51.422  62.865  15.077  1.00 24.81           C  \\nATOM   8834  OG  SER D  84      51.965  62.066  16.098  1.00 24.81           O  \\nATOM   8835  N   THR D  85      50.008  64.693  17.711  1.00 34.98           N  \\nATOM   8836  CA  THR D  85      48.807  64.851  18.537  1.00 34.98           C  \\nATOM   8837  C   THR D  85      48.704  66.289  19.042  1.00 34.98           C  \\nATOM   8838  O   THR D  85      49.724  66.948  19.293  1.00 34.98           O  \\nATOM   8839  CB  THR D  85      48.765  63.905  19.776  1.00 57.56           C  \\nATOM   8840  OG1 THR D  85      49.644  64.396  20.784  1.00 57.56           O  \\nATOM   8841  CG2 THR D  85      49.203  62.514  19.423  1.00 57.56           C  \\nATOM   8842  N   ILE D  86      47.475  66.793  19.077  1.00 36.02           N  \\nATOM   8843  CA  ILE D  86      47.218  68.129  19.598  1.00 36.02           C  \\nATOM   8844  C   ILE D  86      46.669  67.971  21.019  1.00 36.02           C  \\nATOM   8845  O   ILE D  86      45.558  67.467  21.225  1.00 36.02           O  \\nATOM   8846  CB  ILE D  86      46.196  68.939  18.749  1.00 23.29           C  \\nATOM   8847  CG1 ILE D  86      46.785  69.287  17.386  1.00 23.29           C  \\nATOM   8848  CG2 ILE D  86      45.837  70.247  19.463  1.00 23.29           C  \\nATOM   8849  CD1 ILE D  86      45.804  69.988  16.473  1.00 23.29           C  \\nATOM   8850  N   THR D  87      47.470  68.367  21.998  1.00 21.80           N  \\nATOM   8851  CA  THR D  87      47.057  68.254  23.372  1.00 21.80           C  \\nATOM   8852  C   THR D  87      46.704  69.611  23.971  1.00 21.80           C  \\nATOM   8853  O   THR D  87      46.809  70.655  23.317  1.00 21.80           O  \\nATOM   8854  CB  THR D  87      48.168  67.614  24.192  1.00 24.46           C  \\nATOM   8855  OG1 THR D  87      49.342  68.432  24.106  1.00 24.46           O  \\nATOM   8856  CG2 THR D  87      48.490  66.255  23.646  1.00 24.46           C  \\nATOM   8857  N   SER D  88      46.300  69.596  25.232  1.00 36.60           N  \\nATOM   8858  CA  SER D  88      45.958  70.827  25.911  1.00 36.60           C  \\nATOM   8859  C   SER D  88      47.102  71.841  25.801  1.00 36.60           C  \\nATOM   8860  O   SER D  88      46.862  73.043  25.672  1.00 36.60           O  \\nATOM   8861  CB  SER D  88      45.623  70.543  27.383  1.00 24.19           C  \\nATOM   8862  OG  SER D  88      46.755  70.102  28.110  1.00 24.19           O  \\nATOM   8863  N   ARG D  89      48.336  71.344  25.720  1.00 27.44           N  \\nATOM   8864  CA  ARG D  89      49.518  72.214  25.629  1.00 27.44           C  \\nATOM   8865  C   ARG D  89      49.592  73.025  24.319  1.00 27.44           C  \\nATOM   8866  O   ARG D  89      50.023  74.184  24.298  1.00 27.44           O  \\nATOM   8867  CB  ARG D  89      50.781  71.382  25.790  1.00 46.42           C  \\nATOM   8868  CG  ARG D  89      52.008  72.224  25.955  1.00 46.42           C  \\nATOM   8869  CD  ARG D  89      53.247  71.393  26.279  1.00 46.42           C  \\nATOM   8870  NE  ARG D  89      54.371  72.274  26.605  1.00 46.42           N  \\nATOM   8871  CZ  ARG D  89      55.326  72.621  25.755  1.00 46.42           C  \\nATOM   8872  NH1 ARG D  89      55.321  72.151  24.519  1.00 46.42           N  \\nATOM   8873  NH2 ARG D  89      56.242  73.499  26.131  1.00 46.42           N  \\nATOM   8874  N   GLU D  90      49.184  72.405  23.219  1.00 33.49           N  \\nATOM   8875  CA  GLU D  90      49.195  73.105  21.951  1.00 33.49           C  \\nATOM   8876  C   GLU D  90      48.141  74.200  22.076  1.00 33.49           C  \\nATOM   8877  O   GLU D  90      48.432  75.370  21.853  1.00 33.49           O  \\nATOM   8878  CB  GLU D  90      48.867  72.176  20.773  1.00 29.09           C  \\nATOM   8879  CG  GLU D  90      49.285  70.694  20.886  1.00 29.09           C  \\nATOM   8880  CD  GLU D  90      50.711  70.457  21.372  1.00 29.09           C  \\nATOM   8881  OE1 GLU D  90      51.676  70.953  20.754  1.00 29.09           O  \\nATOM   8882  OE2 GLU D  90      50.859  69.741  22.382  1.00 29.09           O  \\nATOM   8883  N   ILE D  91      46.947  73.819  22.532  1.00 21.46           N  \\nATOM   8884  CA  ILE D  91      45.841  74.770  22.711  1.00 21.46           C  \\nATOM   8885  C   ILE D  91      46.304  75.947  23.543  1.00 21.46           C  \\nATOM   8886  O   ILE D  91      46.072  77.093  23.166  1.00 21.46           O  \\nATOM   8887  CB  ILE D  91      44.589  74.135  23.427  1.00 13.51           C  \\nATOM   8888  CG1 ILE D  91      44.138  72.865  22.691  1.00 13.51           C  \\nATOM   8889  CG2 ILE D  91      43.418  75.149  23.518  1.00 13.51           C  \\nATOM   8890  CD1 ILE D  91      43.865  73.082  21.249  1.00 13.51           C  \\nATOM   8891  N   GLN D  92      47.003  75.674  24.641  1.00 25.30           N  \\nATOM   8892  CA  GLN D  92      47.474  76.761  25.489  1.00 25.30           C  \\nATOM   8893  C   GLN D  92      48.357  77.781  24.773  1.00 25.30           C  \\nATOM   8894  O   GLN D  92      48.107  78.979  24.891  1.00 25.30           O  \\nATOM   8895  CB  GLN D  92      48.137  76.272  26.781  1.00 53.72           C  \\nATOM   8896  CG  GLN D  92      48.383  77.432  27.747  1.00 53.72           C  \\nATOM   8897  CD  GLN D  92      48.830  77.027  29.148  1.00 53.72           C  \\nATOM   8898  OE1 GLN D  92      50.019  77.026  29.447  1.00 53.72           O  \\nATOM   8899  NE2 GLN D  92      47.871  76.786  30.033  1.00 53.72           N  \\nATOM   8900  N   THR D  93      49.376  77.344  24.030  1.00 20.58           N  \\nATOM   8901  CA  THR D  93      50.196  78.333  23.323  1.00 20.58           C  \\nATOM   8902  C   THR D  93      49.448  78.943  22.121  1.00 20.58           C  \\nATOM   8903  O   THR D  93      49.654  80.091  21.777  1.00 20.58           O  \\nATOM   8904  CB  THR D  93      51.621  77.812  22.968  1.00 32.75           C  \\nATOM   8905  OG1 THR D  93      51.524  76.501  22.420  1.00 32.75           O  \\nATOM   8906  CG2 THR D  93      52.495  77.749  24.232  1.00 32.75           C  \\nATOM   8907  N   ALA D  94      48.536  78.197  21.514  1.00 13.14           N  \\nATOM   8908  CA  ALA D  94      47.746  78.741  20.411  1.00 13.14           C  \\nATOM   8909  C   ALA D  94      47.022  79.959  20.969  1.00 13.14           C  \\nATOM   8910  O   ALA D  94      47.028  81.031  20.372  1.00 13.14           O  \\nATOM   8911  CB  ALA D  94      46.735  77.720  19.949  1.00 17.14           C  \\nATOM   8912  N   VAL D  95      46.415  79.770  22.143  1.00 15.28           N  \\nATOM   8913  CA  VAL D  95      45.690  80.821  22.843  1.00 15.28           C  \\nATOM   8914  C   VAL D  95      46.595  82.014  23.093  1.00 15.28           C  \\nATOM   8915  O   VAL D  95      46.185  83.138  22.895  1.00 15.28           O  \\nATOM   8916  CB  VAL D  95      45.159  80.323  24.204  1.00 14.13           C  \\nATOM   8917  CG1 VAL D  95      44.667  81.489  25.030  1.00 14.13           C  \\nATOM   8918  CG2 VAL D  95      44.051  79.289  23.995  1.00 14.13           C  \\nATOM   8919  N   ARG D  96      47.808  81.761  23.575  1.00 31.61           N  \\nATOM   8920  CA  ARG D  96      48.773  82.828  23.854  1.00 31.61           C  \\nATOM   8921  C   ARG D  96      49.188  83.584  22.590  1.00 31.61           C  \\nATOM   8922  O   ARG D  96      49.354  84.810  22.609  1.00 31.61           O  \\nATOM   8923  CB  ARG D  96      50.000  82.254  24.547  1.00 42.27           C  \\nATOM   8924  CG  ARG D  96      49.712  81.635  25.898  1.00 42.27           C  \\nATOM   8925  CD  ARG D  96      50.064  82.587  27.034  1.00 42.27           C  \\nATOM   8926  NE  ARG D  96      50.044  81.933  28.347  1.00 42.27           N  \\nATOM   8927  CZ  ARG D  96      50.856  80.942  28.727  1.00 42.27           C  \\nATOM   8928  NH1 ARG D  96      51.782  80.464  27.901  1.00 42.27           N  \\nATOM   8929  NH2 ARG D  96      50.729  80.406  29.937  1.00 42.27           N  \\nATOM   8930  N   LEU D  97      49.357  82.853  21.494  1.00 29.71           N  \\nATOM   8931  CA  LEU D  97      49.735  83.456  20.230  1.00 29.71           C  \\nATOM   8932  C   LEU D  97      48.621  84.276  19.618  1.00 29.71           C  \\nATOM   8933  O   LEU D  97      48.885  85.280  18.967  1.00 29.71           O  \\nATOM   8934  CB  LEU D  97      50.152  82.391  19.227  1.00 13.82           C  \\nATOM   8935  CG  LEU D  97      51.515  81.735  19.428  1.00 13.82           C  \\nATOM   8936  CD1 LEU D  97      51.564  80.425  18.618  1.00 13.82           C  \\nATOM   8937  CD2 LEU D  97      52.637  82.718  19.039  1.00 13.82           C  \\nATOM   8938  N   LEU D  98      47.382  83.851  19.831  1.00 17.35           N  \\nATOM   8939  CA  LEU D  98      46.242  84.537  19.259  1.00 17.35           C  \\nATOM   8940  C   LEU D  98      45.528  85.612  20.098  1.00 17.35           C  \\nATOM   8941  O   LEU D  98      45.123  86.659  19.590  1.00 17.35           O  \\nATOM   8942  CB  LEU D  98      45.262  83.482  18.761  1.00 25.48           C  \\nATOM   8943  CG  LEU D  98      44.077  83.980  17.955  1.00 25.48           C  \\nATOM   8944  CD1 LEU D  98      44.475  84.213  16.535  1.00 25.48           C  \\nATOM   8945  CD2 LEU D  98      42.993  82.950  18.025  1.00 25.48           C  \\nATOM   8946  N   LEU D  99      45.358  85.379  21.377  1.00 23.96           N  \\nATOM   8947  CA  LEU D  99      44.661  86.364  22.183  1.00 23.96           C  \\nATOM   8948  C   LEU D  99      45.547  87.465  22.732  1.00 23.96           C  \\nATOM   8949  O   LEU D  99      46.675  87.217  23.180  1.00 23.96           O  \\nATOM   8950  CB  LEU D  99      43.954  85.686  23.351  1.00 19.68           C  \\nATOM   8951  CG  LEU D  99      43.076  84.504  22.978  1.00 19.68           C  \\nATOM   8952  CD1 LEU D  99      42.344  84.027  24.216  1.00 19.68           C  \\nATOM   8953  CD2 LEU D  99      42.104  84.925  21.907  1.00 19.68           C  \\nATOM   8954  N   PRO D 100      45.060  88.712  22.674  1.00 33.99           N  \\nATOM   8955  CA  PRO D 100      45.813  89.859  23.183  1.00 33.99           C  \\nATOM   8956  C   PRO D 100      45.918  89.853  24.702  1.00 33.99           C  \\nATOM   8957  O   PRO D 100      45.174  89.165  25.374  1.00 33.99           O  \\nATOM   8958  CB  PRO D 100      45.009  91.057  22.669  1.00 45.52           C  \\nATOM   8959  CG  PRO D 100      43.640  90.502  22.444  1.00 45.52           C  \\nATOM   8960  CD  PRO D 100      43.942  89.168  21.833  1.00 45.52           C  \\nATOM   8961  N   GLY D 101      46.928  90.562  25.202  1.00 15.80           N  \\nATOM   8962  CA  GLY D 101      47.218  90.716  26.622  1.00 15.80           C  \\nATOM   8963  C   GLY D 101      46.368  90.127  27.712  1.00 15.80           C  \\nATOM   8964  O   GLY D 101      46.422  88.938  27.939  1.00 15.80           O  \\nATOM   8965  N   GLU D 102      45.591  90.965  28.393  1.00 24.73           N  \\nATOM   8966  CA  GLU D 102      44.750  90.520  29.509  1.00 24.73           C  \\nATOM   8967  C   GLU D 102      43.765  89.374  29.233  1.00 24.73           C  \\nATOM   8968  O   GLU D 102      43.536  88.528  30.092  1.00 24.73           O  \\nATOM   8969  CB  GLU D 102      44.025  91.710  30.135  1.00 59.05           C  \\nATOM   8970  CG  GLU D 102      43.653  91.517  31.608  1.00 59.05           C  \\nATOM   8971  CD  GLU D 102      44.862  91.361  32.541  1.00 59.05           C  \\nATOM   8972  OE1 GLU D 102      46.003  91.687  32.134  1.00 59.05           O  \\nATOM   8973  OE2 GLU D 102      44.665  90.911  33.696  1.00 59.05           O  \\nATOM   8974  N   LEU D 103      43.247  89.306  28.014  1.00 35.08           N  \\nATOM   8975  CA  LEU D 103      42.293  88.276  27.607  1.00 35.08           C  \\nATOM   8976  C   LEU D 103      42.981  86.917  27.537  1.00 35.08           C  \\nATOM   8977  O   LEU D 103      42.426  85.916  27.970  1.00 35.08           O  \\nATOM   8978  CB  LEU D 103      41.722  88.655  26.246  1.00 17.41           C  \\nATOM   8979  CG  LEU D 103      40.280  88.394  25.851  1.00 17.41           C  \\nATOM   8980  CD1 LEU D 103      39.310  88.707  26.990  1.00 17.41           C  \\nATOM   8981  CD2 LEU D 103      39.996  89.253  24.619  1.00 17.41           C  \\nATOM   8982  N   ALA D 104      44.189  86.884  26.979  1.00 28.75           N  \\nATOM   8983  CA  ALA D 104      44.972  85.655  26.884  1.00 28.75           C  \\nATOM   8984  C   ALA D 104      45.257  85.161  28.300  1.00 28.75           C  \\nATOM   8985  O   ALA D 104      45.120  83.971  28.596  1.00 28.75           O  \\nATOM   8986  CB  ALA D 104      46.267  85.915  26.153  1.00  5.90           C  \\nATOM   8987  N   LYS D 105      45.616  86.094  29.179  1.00 25.77           N  \\nATOM   8988  CA  LYS D 105      45.893  85.784  30.571  1.00 25.77           C  \\nATOM   8989  C   LYS D 105      44.703  85.077  31.203  1.00 25.77           C  \\nATOM   8990  O   LYS D 105      44.856  84.005  31.795  1.00 25.77           O  \\nATOM   8991  CB  LYS D 105      46.226  87.062  31.333  1.00 66.01           C  \\nATOM   8992  CG  LYS D 105      46.521  86.870  32.806  1.00 66.01           C  \\nATOM   8993  CD  LYS D 105      47.262  88.078  33.380  1.00 66.01           C  \\nATOM   8994  CE  LYS D 105      48.638  88.254  32.724  1.00 66.01           C  \\nATOM   8995  NZ  LYS D 105      49.384  89.446  33.228  1.00 66.01           N  \\nATOM   8996  N   HIS D 106      43.509  85.640  31.033  1.00 27.76           N  \\nATOM   8997  CA  HIS D 106      42.314  85.027  31.611  1.00 27.76           C  \\nATOM   8998  C   HIS D 106      41.886  83.690  30.985  1.00 27.76           C  \\nATOM   8999  O   HIS D 106      41.505  82.766  31.725  1.00 27.76           O  \\nATOM   9000  CB  HIS D 106      41.143  86.022  31.701  1.00 33.04           C  \\nATOM   9001  CG  HIS D 106      41.311  87.081  32.758  1.00 33.04           C  \\nATOM   9002  ND1 HIS D 106      40.923  88.391  32.566  1.00 33.04           N  \\nATOM   9003  CD2 HIS D 106      41.818  87.022  34.014  1.00 33.04           C  \\nATOM   9004  CE1 HIS D 106      41.188  89.095  33.653  1.00 33.04           C  \\nATOM   9005  NE2 HIS D 106      41.731  88.288  34.546  1.00 33.04           N  \\nATOM   9006  N   ALA D 107      41.946  83.574  29.649  1.00 28.67           N  \\nATOM   9007  CA  ALA D 107      41.601  82.308  28.960  1.00 28.67           C  \\nATOM   9008  C   ALA D 107      42.451  81.154  29.495  1.00 28.67           C  \\nATOM   9009  O   ALA D 107      41.934  80.076  29.766  1.00 28.67           O  \\nATOM   9010  CB  ALA D 107      41.800  82.430  27.470  1.00  7.98           C  \\nATOM   9011  N   VAL D 108      43.751  81.401  29.667  1.00 24.38           N  \\nATOM   9012  CA  VAL D 108      44.674  80.399  30.204  1.00 24.38           C  \\nATOM   9013  C   VAL D 108      44.278  79.904  31.580  1.00 24.38           C  \\nATOM   9014  O   VAL D 108      44.321  78.700  31.822  1.00 24.38           O  \\nATOM   9015  CB  VAL D 108      46.122  80.905  30.238  1.00 23.34           C  \\nATOM   9016  CG1 VAL D 108      47.048  79.828  30.824  1.00 23.34           C  \\nATOM   9017  CG2 VAL D 108      46.561  81.260  28.816  1.00 23.34           C  \\nATOM   9018  N   SER D 109      43.939  80.820  32.492  1.00 32.26           N  \\nATOM   9019  CA  SER D 109      43.487  80.411  33.825  1.00 32.26           C  \\nATOM   9020  C   SER D 109      42.287  79.484  33.662  1.00 32.26           C  \\nATOM   9021  O   SER D 109      42.301  78.357  34.129  1.00 32.26           O  \\nATOM   9022  CB  SER D 109      43.076  81.606  34.671  1.00 46.18           C  \\nATOM   9023  OG  SER D 109      44.211  82.345  35.058  1.00 46.18           O  \\nATOM   9024  N   GLU D 110      41.279  79.943  32.937  1.00 29.42           N  \\nATOM   9025  CA  GLU D 110      40.092  79.144  32.709  1.00 29.42           C  \\nATOM   9026  C   GLU D 110      40.434  77.786  32.096  1.00 29.42           C  \\nATOM   9027  O   GLU D 110      39.981  76.754  32.582  1.00 29.42           O  \\nATOM   9028  CB  GLU D 110      39.108  79.903  31.817  1.00 82.75           C  \\nATOM   9029  CG  GLU D 110      38.442  81.101  32.492  1.00 82.75           C  \\nATOM   9030  CD  GLU D 110      37.007  80.832  32.924  1.00 82.75           C  \\nATOM   9031  OE1 GLU D 110      36.419  79.806  32.510  1.00 82.75           O  \\nATOM   9032  OE2 GLU D 110      36.456  81.672  33.664  1.00 82.75           O  \\nATOM   9033  N   GLY D 111      41.247  77.780  31.045  1.00 23.14           N  \\nATOM   9034  CA  GLY D 111      41.626  76.531  30.407  1.00 23.14           C  \\nATOM   9035  C   GLY D 111      42.271  75.566  31.378  1.00 23.14           C  \\nATOM   9036  O   GLY D 111      41.766  74.479  31.602  1.00 23.14           O  \\nATOM   9037  N   THR D 112      43.370  75.976  31.995  1.00 33.21           N  \\nATOM   9038  CA  THR D 112      44.052  75.129  32.957  1.00 33.21           C  \\nATOM   9039  C   THR D 112      43.048  74.659  34.006  1.00 33.21           C  \\nATOM   9040  O   THR D 112      42.929  73.474  34.246  1.00 33.21           O  \\nATOM   9041  CB  THR D 112      45.165  75.891  33.648  1.00 27.40           C  \\nATOM   9042  OG1 THR D 112      45.944  76.578  32.663  1.00 27.40           O  \\nATOM   9043  CG2 THR D 112      46.048  74.937  34.419  1.00 27.40           C  \\nATOM   9044  N   LYS D 113      42.283  75.593  34.566  1.00 22.13           N  \\nATOM   9045  CA  LYS D 113      41.271  75.308  35.571  1.00 22.13           C  \\nATOM   9046  C   LYS D 113      40.417  74.117  35.118  1.00 22.13           C  \\nATOM   9047  O   LYS D 113      40.376  73.085  35.774  1.00 22.13           O  \\nATOM   9048  CB  LYS D 113      40.388  76.543  35.743  1.00 73.02           C  \\nATOM   9049  CG  LYS D 113      39.643  76.659  37.057  1.00 73.02           C  \\nATOM   9050  CD  LYS D 113      38.628  77.802  36.974  1.00 73.02           C  \\nATOM   9051  CE  LYS D 113      38.199  78.318  38.346  1.00 73.02           C  \\nATOM   9052  NZ  LYS D 113      37.499  77.321  39.201  1.00 73.02           N  \\nATOM   9053  N   ALA D 114      39.788  74.238  33.958  1.00 25.11           N  \\nATOM   9054  CA  ALA D 114      38.947  73.185  33.433  1.00 25.11           C  \\nATOM   9055  C   ALA D 114      39.680  71.867  33.272  1.00 25.11           C  \\nATOM   9056  O   ALA D 114      39.196  70.820  33.690  1.00 25.11           O  \\nATOM   9057  CB  ALA D 114      38.356  73.607  32.127  1.00 14.18           C  \\nATOM   9058  N   VAL D 115      40.852  71.898  32.671  1.00 29.90           N  \\nATOM   9059  CA  VAL D 115      41.594  70.655  32.490  1.00 29.90           C  \\nATOM   9060  C   VAL D 115      41.901  69.957  33.815  1.00 29.90           C  \\nATOM   9061  O   VAL D 115      41.571  68.790  33.984  1.00 29.90           O  \\nATOM   9062  CB  VAL D 115      42.867  70.884  31.669  1.00 24.44           C  \\nATOM   9063  CG1 VAL D 115      43.741  69.661  31.707  1.00 24.44           C  \\nATOM   9064  CG2 VAL D 115      42.477  71.233  30.213  1.00 24.44           C  \\nATOM   9065  N   THR D 116      42.474  70.697  34.760  1.00 25.58           N  \\nATOM   9066  CA  THR D 116      42.796  70.189  36.087  1.00 25.58           C  \\nATOM   9067  C   THR D 116      41.564  69.512  36.699  1.00 25.58           C  \\nATOM   9068  O   THR D 116      41.654  68.376  37.178  1.00 25.58           O  \\nATOM   9069  CB  THR D 116      43.237  71.330  37.018  1.00 25.88           C  \\nATOM   9070  OG1 THR D 116      44.379  71.976  36.460  1.00 25.88           O  \\nATOM   9071  CG2 THR D 116      43.615  70.806  38.385  1.00 25.88           C  \\nATOM   9072  N   LYS D 117      40.418  70.202  36.670  1.00 49.18           N  \\nATOM   9073  CA  LYS D 117      39.182  69.650  37.209  1.00 49.18           C  \\nATOM   9074  C   LYS D 117      38.730  68.405  36.461  1.00 49.18           C  \\nATOM   9075  O   LYS D 117      38.230  67.463  37.073  1.00 49.18           O  \\nATOM   9076  CB  LYS D 117      38.036  70.669  37.215  1.00 32.95           C  \\nATOM   9077  CG  LYS D 117      36.824  70.116  38.000  1.00 32.95           C  \\nATOM   9078  CD  LYS D 117      35.528  70.936  37.983  1.00 32.95           C  \\nATOM   9079  CE  LYS D 117      34.565  70.433  39.092  1.00 32.95           C  \\nATOM   9080  NZ  LYS D 117      33.096  70.720  38.935  1.00 32.95           N  \\nATOM   9081  N   TYR D 118      38.841  68.418  35.139  1.00 28.93           N  \\nATOM   9082  CA  TYR D 118      38.445  67.260  34.348  1.00 28.93           C  \\nATOM   9083  C   TYR D 118      39.219  65.998  34.731  1.00 28.93           C  \\nATOM   9084  O   TYR D 118      38.612  64.959  34.980  1.00 28.93           O  \\nATOM   9085  CB  TYR D 118      38.662  67.538  32.872  1.00 49.98           C  \\nATOM   9086  CG  TYR D 118      38.395  66.354  31.969  1.00 49.98           C  \\nATOM   9087  CD1 TYR D 118      37.100  66.035  31.581  1.00 49.98           C  \\nATOM   9088  CD2 TYR D 118      39.446  65.606  31.432  1.00 49.98           C  \\nATOM   9089  CE1 TYR D 118      36.850  65.011  30.668  1.00 49.98           C  \\nATOM   9090  CE2 TYR D 118      39.208  64.579  30.517  1.00 49.98           C  \\nATOM   9091  CZ  TYR D 118      37.905  64.291  30.133  1.00 49.98           C  \\nATOM   9092  OH  TYR D 118      37.650  63.321  29.178  1.00 49.98           O  \\nATOM   9093  N   THR D 119      40.550  66.099  34.774  1.00 54.75           N  \\nATOM   9094  CA  THR D 119      41.418  64.968  35.118  1.00 54.75           C  \\nATOM   9095  C   THR D 119      41.244  64.467  36.542  1.00 54.75           C  \\nATOM   9096  O   THR D 119      41.786  63.411  36.884  1.00 54.75           O  \\nATOM   9097  CB  THR D 119      42.904  65.303  34.942  1.00 49.95           C  \\nATOM   9098  OG1 THR D 119      43.284  66.316  35.884  1.00 49.95           O  \\nATOM   9099  CG2 THR D 119      43.172  65.779  33.544  1.00 49.95           C  \\nATOM   9100  N   SER D 120      40.566  65.267  37.374  1.00 52.09           N  \\nATOM   9101  CA  SER D 120      40.282  64.934  38.776  1.00 52.09           C  \\nATOM   9102  C   SER D 120      39.217  63.853  38.905  1.00 52.09           C  \\nATOM   9103  O   SER D 120      38.916  63.402  40.017  1.00 52.09           O  \\nATOM   9104  CB  SER D 120      39.832  66.169  39.555  1.00 46.30           C  \\nATOM   9105  OG  SER D 120      40.881  67.114  39.649  1.00 46.30           O  \\nATOM   9106  N   ALA D 121      38.625  63.476  37.772  1.00101.37           N  \\nATOM   9107  CA  ALA D 121      37.607  62.434  37.721  1.00101.37           C  \\nATOM   9108  C   ALA D 121      38.284  61.068  37.609  1.00101.37           C  \\nATOM   9109  O   ALA D 121      39.012  60.801  36.648  1.00101.37           O  \\nATOM   9110  CB  ALA D 121      36.672  62.664  36.533  1.00115.63           C  \\nATOM   9111  N   LYS D 122      38.061  60.227  38.615  1.00131.28           N  \\nATOM   9112  CA  LYS D 122      38.633  58.886  38.656  1.00131.28           C  \\nATOM   9113  C   LYS D 122      37.745  57.878  37.919  1.00131.28           C  \\nATOM   9114  O   LYS D 122      38.186  57.416  36.843  1.00 93.89           O  \\nATOM   9115  CB  LYS D 122      38.857  58.455  40.111  1.00 93.89           C  \\nATOM   9116  CG  LYS D 122      39.295  57.013  40.294  1.00 93.89           C  \\nATOM   9117  CD  LYS D 122      39.533  56.715  41.756  1.00 93.89           C  \\nATOM   9118  CE  LYS D 122      39.931  55.274  41.968  1.00 93.89           C  \\nATOM   9119  NZ  LYS D 122      40.659  55.134  43.257  1.00 93.89           N  \\nATOM   9120  OXT LYS D 122      36.628  57.571  38.406  1.00 93.89           O  \\nTER    9121      LYS D 122                                                      \\nATOM   9122  N   LEU E  20     -14.486 153.224  11.692  1.00106.36           N  \\nATOM   9123  CA  LEU E  20     -13.348 153.712  12.530  1.00106.36           C  \\nATOM   9124  C   LEU E  20     -12.884 155.127  12.154  1.00106.36           C  \\nATOM   9125  O   LEU E  20     -12.574 155.407  10.993  1.00106.36           O  \\nATOM   9126  CB  LEU E  20     -12.167 152.724  12.473  1.00128.73           C  \\nATOM   9127  CG  LEU E  20     -12.309 151.374  13.195  1.00128.73           C  \\nATOM   9128  CD1 LEU E  20     -11.098 150.489  12.913  1.00128.73           C  \\nATOM   9129  CD2 LEU E  20     -12.467 151.596  14.695  1.00128.73           C  \\nATOM   9130  N   ALA E  21     -12.841 156.002  13.160  1.00 91.92           N  \\nATOM   9131  CA  ALA E  21     -12.430 157.408  13.027  1.00 91.92           C  \\nATOM   9132  C   ALA E  21     -11.630 157.784  14.285  1.00 91.92           C  \\nATOM   9133  O   ALA E  21     -10.769 158.675  14.261  1.00 91.92           O  \\nATOM   9134  CB  ALA E  21     -13.670 158.307  12.908  1.00 42.87           C  \\nATOM   9135  N   THR E  22     -11.903 157.024  15.350  1.00177.26           N  \\nATOM   9136  CA  THR E  22     -11.321 157.144  16.692  1.00177.26           C  \\nATOM   9137  C   THR E  22      -9.813 157.436  16.784  1.00177.26           C  \\nATOM   9138  O   THR E  22      -9.084 157.398  15.790  1.00177.26           O  \\nATOM   9139  CB  THR E  22     -11.649 155.861  17.536  1.00118.64           C  \\nATOM   9140  OG1 THR E  22     -12.936 155.358  17.155  1.00118.64           O  \\nATOM   9141  CG2 THR E  22     -11.681 156.167  19.040  1.00118.64           C  \\nATOM   9142  N   LYS E  23      -9.378 157.713  18.010  1.00182.95           N  \\nATOM   9143  CA  LYS E  23      -8.000 158.041  18.372  1.00182.95           C  \\nATOM   9144  C   LYS E  23      -6.827 157.251  17.755  1.00182.95           C  \\nATOM   9145  O   LYS E  23      -6.235 157.688  16.763  1.00182.95           O  \\nATOM   9146  CB  LYS E  23      -7.877 158.014  19.899  1.00143.82           C  \\nATOM   9147  CG  LYS E  23      -8.862 158.909  20.649  1.00143.82           C  \\nATOM   9148  CD  LYS E  23      -9.068 158.376  22.056  1.00143.82           C  \\nATOM   9149  CE  LYS E  23      -7.732 158.123  22.734  1.00143.82           C  \\nATOM   9150  NZ  LYS E  23      -7.855 157.189  23.880  1.00143.82           N  \\nATOM   9151  N   ALA E  24      -6.488 156.101  18.346  1.00156.15           N  \\nATOM   9152  CA  ALA E  24      -5.347 155.302  17.883  1.00156.15           C  \\nATOM   9153  C   ALA E  24      -5.606 154.052  17.041  1.00156.15           C  \\nATOM   9154  O   ALA E  24      -6.271 153.109  17.483  1.00156.15           O  \\nATOM   9155  CB  ALA E  24      -4.444 154.952  19.070  1.00 77.70           C  \\nATOM   9156  N   ALA E  25      -5.004 154.059  15.849  1.00167.90           N  \\nATOM   9157  CA  ALA E  25      -5.061 152.982  14.851  1.00167.90           C  \\nATOM   9158  C   ALA E  25      -4.699 153.506  13.451  1.00167.90           C  \\nATOM   9159  O   ALA E  25      -4.265 152.730  12.598  1.00167.90           O  \\nATOM   9160  CB  ALA E  25      -6.439 152.300  14.821  1.00 58.63           C  \\nATOM   9161  N   ARG E  26      -4.842 154.822  13.246  1.00136.36           N  \\nATOM   9162  CA  ARG E  26      -4.561 155.506  11.965  1.00136.36           C  \\nATOM   9163  C   ARG E  26      -3.413 154.958  11.104  1.00136.36           C  \\nATOM   9164  O   ARG E  26      -2.239 155.181  11.414  1.00136.36           O  \\nATOM   9165  CB  ARG E  26      -4.328 157.002  12.203  1.00164.62           C  \\nATOM   9166  CG  ARG E  26      -5.590 157.832  12.334  1.00164.62           C  \\nATOM   9167  CD  ARG E  26      -5.251 159.314  12.392  1.00164.62           C  \\nATOM   9168  NE  ARG E  26      -6.415 160.158  12.123  1.00164.62           N  \\nATOM   9169  CZ  ARG E  26      -6.350 161.406  11.663  1.00164.62           C  \\nATOM   9170  NH1 ARG E  26      -5.174 161.972  11.424  1.00164.62           N  \\nATOM   9171  NH2 ARG E  26      -7.465 162.080  11.416  1.00164.62           N  \\nATOM   9172  N   LYS E  27      -3.777 154.311   9.991  1.00179.64           N  \\nATOM   9173  CA  LYS E  27      -2.842 153.687   9.036  1.00179.64           C  \\nATOM   9174  C   LYS E  27      -1.484 153.276   9.602  1.00179.64           C  \\nATOM   9175  O   LYS E  27      -0.425 153.628   9.071  1.00179.64           O  \\nATOM   9176  CB  LYS E  27      -2.694 154.516   7.751  1.00106.28           C  \\nATOM   9177  CG  LYS E  27      -3.870 154.340   6.785  1.00106.28           C  \\nATOM   9178  CD  LYS E  27      -3.557 154.874   5.388  1.00106.28           C  \\nATOM   9179  CE  LYS E  27      -4.720 154.641   4.413  1.00106.28           C  \\nATOM   9180  NZ  LYS E  27      -4.458 155.175   3.036  1.00106.28           N  \\nATOM   9181  N   SER E  28      -1.553 152.539  10.708  1.00177.31           N  \\nATOM   9182  CA  SER E  28      -0.388 152.027  11.416  1.00177.31           C  \\nATOM   9183  C   SER E  28      -0.064 150.610  10.918  1.00177.31           C  \\nATOM   9184  O   SER E  28      -0.172 149.637  11.674  1.00177.31           O  \\nATOM   9185  CB  SER E  28      -0.680 152.027  12.928  1.00 87.20           C  \\nATOM   9186  OG  SER E  28       0.426 151.581  13.693  1.00 87.20           O  \\nATOM   9187  N   ALA E  29       0.294 150.502   9.634  1.00182.81           N  \\nATOM   9188  CA  ALA E  29       0.650 149.216   9.015  1.00182.81           C  \\nATOM   9189  C   ALA E  29       1.956 148.633   9.586  1.00182.81           C  \\nATOM   9190  O   ALA E  29       2.071 147.411   9.734  1.00182.81           O  \\nATOM   9191  CB  ALA E  29       0.724 149.339   7.467  1.00 79.14           C  \\nATOM   9192  N   PRO E  30       2.970 149.491   9.866  1.00200.00           N  \\nATOM   9193  CA  PRO E  30       4.246 149.012  10.424  1.00200.00           C  \\nATOM   9194  C   PRO E  30       4.284 148.906  11.969  1.00200.00           C  \\nATOM   9195  O   PRO E  30       5.026 149.640  12.633  1.00200.00           O  \\nATOM   9196  CB  PRO E  30       5.246 150.048   9.905  1.00151.78           C  \\nATOM   9197  CG  PRO E  30       4.445 151.315   9.930  1.00151.78           C  \\nATOM   9198  CD  PRO E  30       3.128 150.865   9.335  1.00151.78           C  \\nATOM   9199  N   ALA E  31       3.491 147.988  12.528  1.00163.95           N  \\nATOM   9200  CA  ALA E  31       3.437 147.777  13.980  1.00163.95           C  \\nATOM   9201  C   ALA E  31       4.314 146.592  14.406  1.00163.95           C  \\nATOM   9202  O   ALA E  31       5.190 146.742  15.263  1.00163.95           O  \\nATOM   9203  CB  ALA E  31       1.986 147.579  14.444  1.00 46.45           C  \\nATOM   9204  N   THR E  32       4.069 145.419  13.819  1.00146.03           N  \\nATOM   9205  CA  THR E  32       4.865 144.230  14.128  1.00146.03           C  \\nATOM   9206  C   THR E  32       6.031 144.112  13.141  1.00146.03           C  \\nATOM   9207  O   THR E  32       5.943 143.414  12.125  1.00146.03           O  \\nATOM   9208  CB  THR E  32       4.021 142.909  14.137  1.00121.24           C  \\nATOM   9209  OG1 THR E  32       3.385 142.710  12.867  1.00121.24           O  \\nATOM   9210  CG2 THR E  32       2.968 142.946  15.245  1.00121.24           C  \\nATOM   9211  N   GLY E  33       7.103 144.845  13.436  1.00131.57           N  \\nATOM   9212  CA  GLY E  33       8.288 144.828  12.597  1.00131.57           C  \\nATOM   9213  C   GLY E  33       9.298 143.781  13.033  1.00131.57           C  \\nATOM   9214  O   GLY E  33      10.299 143.560  12.348  1.00131.57           O  \\nATOM   9215  N   GLY E  34       9.033 143.137  14.170  1.00141.43           N  \\nATOM   9216  CA  GLY E  34       9.925 142.111  14.689  1.00141.43           C  \\nATOM   9217  C   GLY E  34       9.829 140.769  13.977  1.00141.43           C  \\nATOM   9218  O   GLY E  34      10.669 139.887  14.184  1.00141.43           O  \\nATOM   9219  N   VAL E  35       8.792 140.605  13.156  1.00191.87           N  \\nATOM   9220  CA  VAL E  35       8.579 139.371  12.397  1.00191.87           C  \\nATOM   9221  C   VAL E  35       9.507 139.402  11.157  1.00191.87           C  \\nATOM   9222  O   VAL E  35       9.272 140.173  10.219  1.00191.87           O  \\nATOM   9223  CB  VAL E  35       7.059 139.229  11.975  1.00 99.07           C  \\nATOM   9224  CG1 VAL E  35       6.739 137.798  11.514  1.00 99.07           C  \\nATOM   9225  CG2 VAL E  35       6.133 139.629  13.133  1.00 99.07           C  \\nATOM   9226  N   LYS E  36      10.592 138.616  11.186  1.00162.54           N  \\nATOM   9227  CA  LYS E  36      11.547 138.565  10.068  1.00162.54           C  \\nATOM   9228  C   LYS E  36      11.201 137.559   8.963  1.00162.54           C  \\nATOM   9229  O   LYS E  36      10.363 136.676   9.154  1.00162.54           O  \\nATOM   9230  CB  LYS E  36      12.988 138.395  10.567  1.00109.10           C  \\nATOM   9231  CG  LYS E  36      13.495 139.613  11.350  1.00109.10           C  \\nATOM   9232  CD  LYS E  36      13.226 140.906  10.583  1.00109.10           C  \\nATOM   9233  CE  LYS E  36      13.305 142.132  11.477  1.00109.10           C  \\nATOM   9234  NZ  LYS E  36      14.690 142.624  11.732  1.00109.10           N  \\nATOM   9235  N   LYS E  37      11.910 137.647   7.840  1.00132.82           N  \\nATOM   9236  CA  LYS E  37      11.606 136.821   6.676  1.00132.82           C  \\nATOM   9237  C   LYS E  37      11.835 135.284   6.653  1.00132.82           C  \\nATOM   9238  O   LYS E  37      10.943 134.547   7.094  1.00132.82           O  \\nATOM   9239  CB  LYS E  37      12.063 137.546   5.398  1.00 78.08           C  \\nATOM   9240  CG  LYS E  37      11.485 138.972   5.244  1.00 78.08           C  \\nATOM   9241  CD  LYS E  37      12.185 139.979   6.172  1.00 78.08           C  \\nATOM   9242  CE  LYS E  37      11.262 141.104   6.644  1.00 78.08           C  \\nATOM   9243  NZ  LYS E  37      11.921 141.926   7.705  1.00 78.08           N  \\nATOM   9244  N   PRO E  38      12.991 134.769   6.152  1.00156.93           N  \\nATOM   9245  CA  PRO E  38      13.100 133.299   6.170  1.00156.93           C  \\nATOM   9246  C   PRO E  38      14.101 132.704   7.177  1.00156.93           C  \\nATOM   9247  O   PRO E  38      14.402 133.326   8.199  1.00156.93           O  \\nATOM   9248  CB  PRO E  38      13.490 132.969   4.718  1.00 47.90           C  \\nATOM   9249  CG  PRO E  38      13.997 134.359   4.124  1.00 47.90           C  \\nATOM   9250  CD  PRO E  38      14.060 135.316   5.302  1.00 47.90           C  \\nATOM   9251  N   HIS E  39      14.617 131.508   6.879  1.00 96.77           N  \\nATOM   9252  CA  HIS E  39      15.568 130.821   7.767  1.00 96.77           C  \\nATOM   9253  C   HIS E  39      16.545 129.873   7.057  1.00 96.77           C  \\nATOM   9254  O   HIS E  39      16.141 129.100   6.185  1.00 96.77           O  \\nATOM   9255  CB  HIS E  39      14.802 130.034   8.830  1.00 75.75           C  \\nATOM   9256  CG  HIS E  39      15.680 129.241   9.746  1.00 75.75           C  \\nATOM   9257  ND1 HIS E  39      16.055 127.941   9.478  1.00 75.75           N  \\nATOM   9258  CD2 HIS E  39      16.246 129.558  10.936  1.00 75.75           C  \\nATOM   9259  CE1 HIS E  39      16.811 127.491  10.464  1.00 75.75           C  \\nATOM   9260  NE2 HIS E  39      16.941 128.453  11.361  1.00 75.75           N  \\nATOM   9261  N   ARG E  40      17.802 129.868   7.514  1.00 46.30           N  \\nATOM   9262  CA  ARG E  40      18.849 129.025   6.922  1.00 46.30           C  \\nATOM   9263  C   ARG E  40      19.920 128.482   7.833  1.00 46.30           C  \\nATOM   9264  O   ARG E  40      20.493 129.214   8.636  1.00 46.30           O  \\nATOM   9265  CB  ARG E  40      19.606 129.783   5.840  1.00 24.00           C  \\nATOM   9266  CG  ARG E  40      19.071 129.548   4.506  1.00 24.00           C  \\nATOM   9267  CD  ARG E  40      20.118 129.518   3.473  1.00 24.00           C  \\nATOM   9268  NE  ARG E  40      19.441 129.151   2.251  1.00 24.00           N  \\nATOM   9269  CZ  ARG E  40      19.842 128.213   1.406  1.00 24.00           C  \\nATOM   9270  NH1 ARG E  40      20.964 127.514   1.612  1.00 24.00           N  \\nATOM   9271  NH2 ARG E  40      19.059 127.909   0.378  1.00 24.00           N  \\nATOM   9272  N   TYR E  41      20.245 127.206   7.661  1.00 26.00           N  \\nATOM   9273  CA  TYR E  41      21.337 126.629   8.432  1.00 26.00           C  \\nATOM   9274  C   TYR E  41      22.635 126.889   7.645  1.00 26.00           C  \\nATOM   9275  O   TYR E  41      22.680 126.754   6.404  1.00 26.00           O  \\nATOM   9276  CB  TYR E  41      21.101 125.139   8.689  1.00 26.16           C  \\nATOM   9277  CG  TYR E  41      20.116 124.878   9.811  1.00 26.16           C  \\nATOM   9278  CD1 TYR E  41      20.417 125.248  11.118  1.00 26.16           C  \\nATOM   9279  CD2 TYR E  41      18.881 124.275   9.569  1.00 26.16           C  \\nATOM   9280  CE1 TYR E  41      19.519 125.030  12.161  1.00 26.16           C  \\nATOM   9281  CE2 TYR E  41      17.973 124.045  10.607  1.00 26.16           C  \\nATOM   9282  CZ  TYR E  41      18.300 124.427  11.902  1.00 26.16           C  \\nATOM   9283  OH  TYR E  41      17.421 124.218  12.953  1.00 26.16           O  \\nATOM   9284  N   ARG E  42      23.673 127.314   8.356  1.00 24.35           N  \\nATOM   9285  CA  ARG E  42      24.941 127.629   7.723  1.00 24.35           C  \\nATOM   9286  C   ARG E  42      25.577 126.382   7.122  1.00 24.35           C  \\nATOM   9287  O   ARG E  42      25.493 125.294   7.686  1.00 24.35           O  \\nATOM   9288  CB  ARG E  42      25.861 128.315   8.721  1.00 53.92           C  \\nATOM   9289  CG  ARG E  42      25.363 129.681   9.091  1.00 53.92           C  \\nATOM   9290  CD  ARG E  42      26.187 130.277  10.191  1.00 53.92           C  \\nATOM   9291  NE  ARG E  42      27.582 130.504   9.804  1.00 53.92           N  \\nATOM   9292  CZ  ARG E  42      28.556 130.841  10.656  1.00 53.92           C  \\nATOM   9293  NH1 ARG E  42      28.298 130.981  11.953  1.00 53.92           N  \\nATOM   9294  NH2 ARG E  42      29.791 131.067  10.214  1.00 53.92           N  \\nATOM   9295  N   PRO E  43      26.244 126.523   5.968  1.00 15.33           N  \\nATOM   9296  CA  PRO E  43      26.848 125.337   5.381  1.00 15.33           C  \\nATOM   9297  C   PRO E  43      27.699 124.537   6.346  1.00 15.33           C  \\nATOM   9298  O   PRO E  43      28.593 125.085   7.004  1.00 15.33           O  \\nATOM   9299  CB  PRO E  43      27.659 125.913   4.211  1.00 16.96           C  \\nATOM   9300  CG  PRO E  43      27.946 127.283   4.618  1.00 16.96           C  \\nATOM   9301  CD  PRO E  43      26.657 127.726   5.220  1.00 16.96           C  \\nATOM   9302  N   GLY E  44      27.326 123.267   6.502  1.00 12.88           N  \\nATOM   9303  CA  GLY E  44      28.077 122.369   7.358  1.00 12.88           C  \\nATOM   9304  C   GLY E  44      27.347 121.918   8.598  1.00 12.88           C  \\nATOM   9305  O   GLY E  44      27.667 120.879   9.183  1.00 12.88           O  \\nATOM   9306  N   THR E  45      26.359 122.699   9.010  1.00 20.22           N  \\nATOM   9307  CA  THR E  45      25.582 122.379  10.196  1.00 20.22           C  \\nATOM   9308  C   THR E  45      24.775 121.108   9.968  1.00 20.22           C  \\nATOM   9309  O   THR E  45      24.794 120.177  10.778  1.00 20.22           O  \\nATOM   9310  CB  THR E  45      24.645 123.535  10.520  1.00 43.22           C  \\nATOM   9311  OG1 THR E  45      25.414 124.736  10.579  1.00 43.22           O  \\nATOM   9312  CG2 THR E  45      23.966 123.328  11.842  1.00 43.22           C  \\nATOM   9313  N   VAL E  46      24.106 121.055   8.825  1.00 22.85           N  \\nATOM   9314  CA  VAL E  46      23.287 119.908   8.466  1.00 22.85           C  \\nATOM   9315  C   VAL E  46      24.194 118.690   8.257  1.00 22.85           C  \\nATOM   9316  O   VAL E  46      23.897 117.606   8.738  1.00 22.85           O  \\nATOM   9317  CB  VAL E  46      22.481 120.198   7.177  1.00 15.66           C  \\nATOM   9318  CG1 VAL E  46      21.552 119.031   6.856  1.00 15.66           C  \\nATOM   9319  CG2 VAL E  46      21.704 121.515   7.315  1.00 15.66           C  \\nATOM   9320  N   ALA E  47      25.332 118.899   7.592  1.00 28.37           N  \\nATOM   9321  CA  ALA E  47      26.303 117.832   7.330  1.00 28.37           C  \\nATOM   9322  C   ALA E  47      26.733 117.116   8.610  1.00 28.37           C  \\nATOM   9323  O   ALA E  47      26.997 115.917   8.584  1.00 28.37           O  \\nATOM   9324  CB  ALA E  47      27.502 118.391   6.617  1.00  6.71           C  \\nATOM   9325  N   LEU E  48      26.838 117.873   9.708  1.00 25.70           N  \\nATOM   9326  CA  LEU E  48      27.203 117.356  11.035  1.00 25.70           C  \\nATOM   9327  C   LEU E  48      26.026 116.644  11.648  1.00 25.70           C  \\nATOM   9328  O   LEU E  48      26.197 115.640  12.316  1.00 25.70           O  \\nATOM   9329  CB  LEU E  48      27.614 118.493  11.954  1.00 31.39           C  \\nATOM   9330  CG  LEU E  48      29.019 119.019  11.710  1.00 31.39           C  \\nATOM   9331  CD1 LEU E  48      29.148 120.419  12.234  1.00 31.39           C  \\nATOM   9332  CD2 LEU E  48      30.025 118.099  12.383  1.00 31.39           C  \\nATOM   9333  N   ARG E  49      24.839 117.221  11.471  1.00 18.12           N  \\nATOM   9334  CA  ARG E  49      23.591 116.647  11.955  1.00 18.12           C  \\nATOM   9335  C   ARG E  49      23.468 115.221  11.368  1.00 18.12           C  \\nATOM   9336  O   ARG E  49      23.176 114.253  12.073  1.00 18.12           O  \\nATOM   9337  CB  ARG E  49      22.438 117.515  11.452  1.00 48.87           C  \\nATOM   9338  CG  ARG E  49      21.296 117.679  12.429  1.00 48.87           C  \\nATOM   9339  CD  ARG E  49      19.913 117.786  11.737  1.00 48.87           C  \\nATOM   9340  NE  ARG E  49      19.699 118.995  10.935  1.00 48.87           N  \\nATOM   9341  CZ  ARG E  49      19.751 120.236  11.405  1.00 48.87           C  \\nATOM   9342  NH1 ARG E  49      20.022 120.470  12.684  1.00 48.87           N  \\nATOM   9343  NH2 ARG E  49      19.524 121.249  10.590  1.00 48.87           N  \\nATOM   9344  N   GLU E  50      23.726 115.116  10.065  1.00 27.71           N  \\nATOM   9345  CA  GLU E  50      23.674 113.859   9.334  1.00 27.71           C  \\nATOM   9346  C   GLU E  50      24.722 112.852   9.832  1.00 27.71           C  \\nATOM   9347  O   GLU E  50      24.441 111.664   9.938  1.00 27.71           O  \\nATOM   9348  CB  GLU E  50      23.844 114.118   7.822  1.00 31.99           C  \\nATOM   9349  CG  GLU E  50      22.671 114.809   7.121  1.00 31.99           C  \\nATOM   9350  CD  GLU E  50      22.956 115.132   5.643  1.00 31.99           C  \\nATOM   9351  OE1 GLU E  50      23.017 114.195   4.813  1.00 31.99           O  \\nATOM   9352  OE2 GLU E  50      23.133 116.327   5.295  1.00 31.99           O  \\nATOM   9353  N   ILE E  51      25.939 113.316  10.095  1.00 21.68           N  \\nATOM   9354  CA  ILE E  51      26.993 112.435  10.592  1.00 21.68           C  \\nATOM   9355  C   ILE E  51      26.514 111.834  11.894  1.00 21.68           C  \\nATOM   9356  O   ILE E  51      26.457 110.612  12.044  1.00 21.68           O  \\nATOM   9357  CB  ILE E  51      28.301 113.200  10.837  1.00  6.79           C  \\nATOM   9358  CG1 ILE E  51      28.864 113.682   9.503  1.00  6.79           C  \\nATOM   9359  CG2 ILE E  51      29.317 112.308  11.490  1.00  6.79           C  \\nATOM   9360  CD1 ILE E  51      30.059 114.582   9.619  1.00  6.79           C  \\nATOM   9361  N   ARG E  52      26.080 112.705  12.797  1.00 19.79           N  \\nATOM   9362  CA  ARG E  52      25.577 112.282  14.090  1.00 19.79           C  \\nATOM   9363  C   ARG E  52      24.455 111.289  13.894  1.00 19.79           C  \\nATOM   9364  O   ARG E  52      24.391 110.274  14.583  1.00 19.79           O  \\nATOM   9365  CB  ARG E  52      25.093 113.484  14.907  1.00 33.55           C  \\nATOM   9366  CG  ARG E  52      26.202 114.447  15.303  1.00 33.55           C  \\nATOM   9367  CD  ARG E  52      25.704 115.540  16.216  1.00 33.55           C  \\nATOM   9368  NE  ARG E  52      26.312 116.845  15.920  1.00 33.55           N  \\nATOM   9369  CZ  ARG E  52      27.490 117.260  16.390  1.00 33.55           C  \\nATOM   9370  NH1 ARG E  52      28.217 116.459  17.187  1.00 33.55           N  \\nATOM   9371  NH2 ARG E  52      27.915 118.500  16.113  1.00 33.55           N  \\nATOM   9372  N   ARG E  53      23.593 111.577  12.929  1.00 21.63           N  \\nATOM   9373  CA  ARG E  53      22.459 110.728  12.629  1.00 21.63           C  \\nATOM   9374  C   ARG E  53      22.826 109.319  12.187  1.00 21.63           C  \\nATOM   9375  O   ARG E  53      22.384 108.337  12.798  1.00 21.63           O  \\nATOM   9376  CB  ARG E  53      21.567 111.373  11.570  1.00 33.63           C  \\nATOM   9377  CG  ARG E  53      20.443 110.456  11.150  1.00 33.63           C  \\nATOM   9378  CD  ARG E  53      19.641 110.948   9.960  1.00 33.63           C  \\nATOM   9379  NE  ARG E  53      18.865 109.840   9.397  1.00 33.63           N  \\nATOM   9380  CZ  ARG E  53      17.931 109.968   8.457  1.00 33.63           C  \\nATOM   9381  NH1 ARG E  53      17.636 111.166   7.953  1.00 33.63           N  \\nATOM   9382  NH2 ARG E  53      17.311 108.879   8.000  1.00 33.63           N  \\nATOM   9383  N   TYR E  54      23.648 109.212  11.142  1.00 19.14           N  \\nATOM   9384  CA  TYR E  54      24.041 107.913  10.601  1.00 19.14           C  \\nATOM   9385  C   TYR E  54      24.989 107.123  11.448  1.00 19.14           C  \\nATOM   9386  O   TYR E  54      25.008 105.900  11.362  1.00 19.14           O  \\nATOM   9387  CB  TYR E  54      24.533 108.055   9.168  1.00 18.72           C  \\nATOM   9388  CG  TYR E  54      23.394 108.446   8.243  1.00 18.72           C  \\nATOM   9389  CD1 TYR E  54      22.329 107.567   8.012  1.00 18.72           C  \\nATOM   9390  CD2 TYR E  54      23.334 109.719   7.659  1.00 18.72           C  \\nATOM   9391  CE1 TYR E  54      21.230 107.942   7.235  1.00 18.72           C  \\nATOM   9392  CE2 TYR E  54      22.243 110.104   6.873  1.00 18.72           C  \\nATOM   9393  CZ  TYR E  54      21.201 109.212   6.669  1.00 18.72           C  \\nATOM   9394  OH  TYR E  54      20.133 109.576   5.894  1.00 18.72           O  \\nATOM   9395  N   GLN E  55      25.793 107.811  12.251  1.00 27.55           N  \\nATOM   9396  CA  GLN E  55      26.697 107.115  13.151  1.00 27.55           C  \\nATOM   9397  C   GLN E  55      25.901 106.402  14.267  1.00 27.55           C  \\nATOM   9398  O   GLN E  55      26.375 105.401  14.818  1.00 27.55           O  \\nATOM   9399  CB  GLN E  55      27.756 108.065  13.715  1.00 31.00           C  \\nATOM   9400  CG  GLN E  55      28.823 108.479  12.681  1.00 31.00           C  \\nATOM   9401  CD  GLN E  55      30.050 109.160  13.302  1.00 31.00           C  \\nATOM   9402  OE1 GLN E  55      29.961 109.762  14.373  1.00 31.00           O  \\nATOM   9403  NE2 GLN E  55      31.191 109.064  12.629  1.00 31.00           N  \\nATOM   9404  N   LYS E  56      24.689 106.899  14.564  1.00 23.85           N  \\nATOM   9405  CA  LYS E  56      23.800 106.317  15.575  1.00 23.85           C  \\nATOM   9406  C   LYS E  56      23.073 105.094  15.014  1.00 23.85           C  \\nATOM   9407  O   LYS E  56      22.744 104.163  15.757  1.00 23.85           O  \\nATOM   9408  CB  LYS E  56      22.715 107.307  16.029  1.00 43.45           C  \\nATOM   9409  CG  LYS E  56      23.110 108.442  16.978  1.00 43.45           C  \\nATOM   9410  CD  LYS E  56      21.836 108.989  17.713  1.00 43.45           C  \\nATOM   9411  CE  LYS E  56      21.703 110.552  17.764  1.00 43.45           C  \\nATOM   9412  NZ  LYS E  56      21.091 111.216  16.539  1.00 43.45           N  \\nATOM   9413  N   SER E  57      22.721 105.125  13.731  1.00 28.47           N  \\nATOM   9414  CA  SER E  57      22.022 103.978  13.158  1.00 28.47           C  \\nATOM   9415  C   SER E  57      22.897 102.867  12.563  1.00 28.47           C  \\nATOM   9416  O   SER E  57      24.145 102.964  12.537  1.00 28.47           O  \\nATOM   9417  CB  SER E  57      20.968 104.435  12.145  1.00 30.41           C  \\nATOM   9418  OG  SER E  57      21.499 105.321  11.185  1.00 30.41           O  \\nATOM   9419  N   THR E  58      22.225 101.813  12.088  1.00 15.13           N  \\nATOM   9420  CA  THR E  58      22.899 100.665  11.489  1.00 15.13           C  \\nATOM   9421  C   THR E  58      22.237 100.185  10.202  1.00 15.13           C  \\nATOM   9422  O   THR E  58      22.698  99.226   9.600  1.00 15.13           O  \\nATOM   9423  CB  THR E  58      22.925  99.478  12.429  1.00 21.48           C  \\nATOM   9424  OG1 THR E  58      21.604  98.960  12.552  1.00 21.48           O  \\nATOM   9425  CG2 THR E  58      23.415  99.883  13.790  1.00 21.48           C  \\nATOM   9426  N   GLU E  59      21.103 100.791   9.858  1.00 16.27           N  \\nATOM   9427  CA  GLU E  59      20.326 100.524   8.631  1.00 16.27           C  \\nATOM   9428  C   GLU E  59      21.299 100.625   7.469  1.00 16.27           C  \\nATOM   9429  O   GLU E  59      22.294 101.358   7.567  1.00 16.27           O  \\nATOM   9430  CB  GLU E  59      19.364 101.691   8.444  1.00 37.49           C  \\nATOM   9431  CG  GLU E  59      20.104 103.008   8.770  1.00 37.49           C  \\nATOM   9432  CD  GLU E  59      19.409 104.266   8.344  1.00 37.49           C  \\nATOM   9433  OE1 GLU E  59      18.875 104.296   7.213  1.00 37.49           O  \\nATOM   9434  OE2 GLU E  59      19.457 105.255   9.123  1.00 37.49           O  \\nATOM   9435  N   LEU E  60      21.035  99.944   6.359  1.00 27.54           N  \\nATOM   9436  CA  LEU E  60      21.958 100.090   5.231  1.00 27.54           C  \\nATOM   9437  C   LEU E  60      21.630 101.405   4.540  1.00 27.54           C  \\nATOM   9438  O   LEU E  60      20.536 101.960   4.715  1.00 27.54           O  \\nATOM   9439  CB  LEU E  60      21.893  98.922   4.250  1.00 12.49           C  \\nATOM   9440  CG  LEU E  60      22.311  97.570   4.814  1.00 12.49           C  \\nATOM   9441  CD1 LEU E  60      22.075  96.496   3.799  1.00 12.49           C  \\nATOM   9442  CD2 LEU E  60      23.767  97.611   5.242  1.00 12.49           C  \\nATOM   9443  N   LEU E  61      22.577 101.894   3.750  1.00 19.03           N  \\nATOM   9444  CA  LEU E  61      22.409 103.162   3.089  1.00 19.03           C  \\nATOM   9445  C   LEU E  61      22.301 103.163   1.565  1.00 19.03           C  \\nATOM   9446  O   LEU E  61      22.061 104.207   0.982  1.00 19.03           O  \\nATOM   9447  CB  LEU E  61      23.494 104.114   3.594  1.00 10.35           C  \\nATOM   9448  CG  LEU E  61      23.630 104.288   5.129  1.00 10.35           C  \\nATOM   9449  CD1 LEU E  61      24.925 105.020   5.467  1.00 10.35           C  \\nATOM   9450  CD2 LEU E  61      22.441 105.033   5.722  1.00 10.35           C  \\nATOM   9451  N   ILE E  62      22.464 102.015   0.913  1.00 24.84           N  \\nATOM   9452  CA  ILE E  62      22.319 101.950  -0.549  1.00 24.84           C  \\nATOM   9453  C   ILE E  62      20.952 101.314  -0.790  1.00 24.84           C  \\nATOM   9454  O   ILE E  62      20.598 100.365  -0.098  1.00 24.84           O  \\nATOM   9455  CB  ILE E  62      23.433 101.074  -1.199  1.00 13.17           C  \\nATOM   9456  CG1 ILE E  62      24.760 101.808  -1.153  1.00 13.17           C  \\nATOM   9457  CG2 ILE E  62      23.116 100.749  -2.647  1.00 13.17           C  \\nATOM   9458  CD1 ILE E  62      25.939 100.887  -1.131  1.00 13.17           C  \\nATOM   9459  N   ARG E  63      20.168 101.859  -1.724  1.00 17.80           N  \\nATOM   9460  CA  ARG E  63      18.849 101.301  -1.999  1.00 17.80           C  \\nATOM   9461  C   ARG E  63      18.991  99.842  -2.381  1.00 17.80           C  \\nATOM   9462  O   ARG E  63      19.732  99.494  -3.290  1.00 17.80           O  \\nATOM   9463  CB  ARG E  63      18.139 102.105  -3.067  1.00 73.98           C  \\nATOM   9464  CG  ARG E  63      17.263 103.208  -2.506  1.00 73.98           C  \\nATOM   9465  CD  ARG E  63      17.147 104.346  -3.506  1.00 73.98           C  \\nATOM   9466  NE  ARG E  63      17.210 103.892  -4.903  1.00 73.98           N  \\nATOM   9467  CZ  ARG E  63      17.794 104.572  -5.893  1.00 73.98           C  \\nATOM   9468  NH1 ARG E  63      18.365 105.735  -5.635  1.00 73.98           N  \\nATOM   9469  NH2 ARG E  63      17.813 104.102  -7.142  1.00 73.98           N  \\nATOM   9470  N   LYS E  64      18.290  98.984  -1.655  1.00 18.59           N  \\nATOM   9471  CA  LYS E  64      18.368  97.543  -1.866  1.00 18.59           C  \\nATOM   9472  C   LYS E  64      18.200  97.019  -3.288  1.00 18.59           C  \\nATOM   9473  O   LYS E  64      19.011  96.227  -3.755  1.00 18.59           O  \\nATOM   9474  CB  LYS E  64      17.462  96.806  -0.869  1.00 59.69           C  \\nATOM   9475  CG  LYS E  64      18.099  96.682   0.517  1.00 59.69           C  \\nATOM   9476  CD  LYS E  64      17.071  96.659   1.631  1.00 59.69           C  \\nATOM   9477  CE  LYS E  64      17.710  96.891   3.009  1.00 59.69           C  \\nATOM   9478  NZ  LYS E  64      18.462  95.706   3.510  1.00 59.69           N  \\nATOM   9479  N   LEU E  65      17.167  97.440  -3.989  1.00 31.10           N  \\nATOM   9480  CA  LEU E  65      17.019  96.948  -5.334  1.00 31.10           C  \\nATOM   9481  C   LEU E  65      18.183  97.362  -6.235  1.00 31.10           C  \\nATOM   9482  O   LEU E  65      18.877  96.503  -6.770  1.00 31.10           O  \\nATOM   9483  CB  LEU E  65      15.665  97.352  -5.928  1.00 23.29           C  \\nATOM   9484  CG  LEU E  65      15.315  97.002  -7.388  1.00 23.29           C  \\nATOM   9485  CD1 LEU E  65      15.633  95.552  -7.722  1.00 23.29           C  \\nATOM   9486  CD2 LEU E  65      13.842  97.273  -7.594  1.00 23.29           C  \\nATOM   9487  N   PRO E  66      18.489  98.662  -6.340  1.00 20.16           N  \\nATOM   9488  CA  PRO E  66      19.605  99.046  -7.219  1.00 20.16           C  \\nATOM   9489  C   PRO E  66      20.874  98.235  -6.976  1.00 20.16           C  \\nATOM   9490  O   PRO E  66      21.545  97.829  -7.938  1.00 20.16           O  \\nATOM   9491  CB  PRO E  66      19.814 100.514  -6.898  1.00 15.14           C  \\nATOM   9492  CG  PRO E  66      18.478 100.950  -6.500  1.00 15.14           C  \\nATOM   9493  CD  PRO E  66      17.946  99.833  -5.648  1.00 15.14           C  \\nATOM   9494  N   PHE E  67      21.191  97.995  -5.693  1.00 17.28           N  \\nATOM   9495  CA  PHE E  67      22.367  97.207  -5.316  1.00 17.28           C  \\nATOM   9496  C   PHE E  67      22.231  95.780  -5.830  1.00 17.28           C  \\nATOM   9497  O   PHE E  67      23.146  95.274  -6.492  1.00 17.28           O  \\nATOM   9498  CB  PHE E  67      22.572  97.196  -3.815  1.00 16.74           C  \\nATOM   9499  CG  PHE E  67      23.798  96.459  -3.392  1.00 16.74           C  \\nATOM   9500  CD1 PHE E  67      25.018  97.114  -3.311  1.00 16.74           C  \\nATOM   9501  CD2 PHE E  67      23.747  95.091  -3.113  1.00 16.74           C  \\nATOM   9502  CE1 PHE E  67      26.177  96.425  -2.960  1.00 16.74           C  \\nATOM   9503  CE2 PHE E  67      24.901  94.383  -2.761  1.00 16.74           C  \\nATOM   9504  CZ  PHE E  67      26.121  95.063  -2.686  1.00 16.74           C  \\nATOM   9505  N   GLN E  68      21.093  95.133  -5.551  1.00 10.24           N  \\nATOM   9506  CA  GLN E  68      20.868  93.775  -6.049  1.00 10.24           C  \\nATOM   9507  C   GLN E  68      21.133  93.671  -7.574  1.00 10.24           C  \\nATOM   9508  O   GLN E  68      21.760  92.727  -8.042  1.00 10.24           O  \\nATOM   9509  CB  GLN E  68      19.473  93.293  -5.720  1.00 43.59           C  \\nATOM   9510  CG  GLN E  68      19.260  91.883  -6.177  1.00 43.59           C  \\nATOM   9511  CD  GLN E  68      18.000  91.274  -5.624  1.00 43.59           C  \\nATOM   9512  OE1 GLN E  68      16.950  91.284  -6.282  1.00 43.59           O  \\nATOM   9513  NE2 GLN E  68      18.086  90.741  -4.400  1.00 43.59           N  \\nATOM   9514  N   ARG E  69      20.723  94.690  -8.324  1.00 13.32           N  \\nATOM   9515  CA  ARG E  69      20.926  94.750  -9.771  1.00 13.32           C  \\nATOM   9516  C   ARG E  69      22.400  94.868 -10.166  1.00 13.32           C  \\nATOM   9517  O   ARG E  69      22.839  94.239 -11.115  1.00 13.32           O  \\nATOM   9518  CB  ARG E  69      20.163  95.932 -10.340  1.00 28.76           C  \\nATOM   9519  CG  ARG E  69      18.960  95.563 -11.141  1.00 28.76           C  \\nATOM   9520  CD  ARG E  69      18.414  96.809 -11.849  1.00 28.76           C  \\nATOM   9521  NE  ARG E  69      17.330  97.447 -11.105  1.00 28.76           N  \\nATOM   9522  CZ  ARG E  69      17.342  98.704 -10.683  1.00 28.76           C  \\nATOM   9523  NH1 ARG E  69      18.395  99.492 -10.922  1.00 28.76           N  \\nATOM   9524  NH2 ARG E  69      16.284  99.168 -10.033  1.00 28.76           N  \\nATOM   9525  N   LEU E  70      23.145  95.733  -9.490  1.00 17.42           N  \\nATOM   9526  CA  LEU E  70      24.562  95.888  -9.782  1.00 17.42           C  \\nATOM   9527  C   LEU E  70      25.245  94.550  -9.569  1.00 17.42           C  \\nATOM   9528  O   LEU E  70      26.055  94.124 -10.406  1.00 17.42           O  \\nATOM   9529  CB  LEU E  70      25.200  96.919  -8.848  1.00 15.96           C  \\nATOM   9530  CG  LEU E  70      26.717  97.159  -8.997  1.00 15.96           C  \\nATOM   9531  CD1 LEU E  70      27.052  97.750 -10.380  1.00 15.96           C  \\nATOM   9532  CD2 LEU E  70      27.215  98.047  -7.851  1.00 15.96           C  \\nATOM   9533  N   VAL E  71      24.943  93.901  -8.436  1.00 12.32           N  \\nATOM   9534  CA  VAL E  71      25.525  92.595  -8.132  1.00 12.32           C  \\nATOM   9535  C   VAL E  71      25.220  91.643  -9.284  1.00 12.32           C  \\nATOM   9536  O   VAL E  71      26.137  91.100  -9.880  1.00 12.32           O  \\nATOM   9537  CB  VAL E  71      25.002  91.995  -6.788  1.00 12.93           C  \\nATOM   9538  CG1 VAL E  71      25.348  90.506  -6.692  1.00 12.93           C  \\nATOM   9539  CG2 VAL E  71      25.598  92.741  -5.579  1.00 12.93           C  \\nATOM   9540  N   ARG E  72      23.944  91.489  -9.638  1.00 15.49           N  \\nATOM   9541  CA  ARG E  72      23.566  90.599 -10.732  1.00 15.49           C  \\nATOM   9542  C   ARG E  72      24.282  90.931 -12.035  1.00 15.49           C  \\nATOM   9543  O   ARG E  72      24.701  90.032 -12.752  1.00 15.49           O  \\nATOM   9544  CB  ARG E  72      22.053  90.578 -10.942  1.00 23.81           C  \\nATOM   9545  CG  ARG E  72      21.318  89.885  -9.825  1.00 23.81           C  \\nATOM   9546  CD  ARG E  72      19.827  89.849 -10.053  1.00 23.81           C  \\nATOM   9547  NE  ARG E  72      19.137  89.401  -8.843  1.00 23.81           N  \\nATOM   9548  CZ  ARG E  72      19.013  88.126  -8.466  1.00 23.81           C  \\nATOM   9549  NH1 ARG E  72      19.525  87.147  -9.211  1.00 23.81           N  \\nATOM   9550  NH2 ARG E  72      18.405  87.833  -7.320  1.00 23.81           N  \\nATOM   9551  N   GLU E  73      24.443  92.215 -12.332  1.00 17.63           N  \\nATOM   9552  CA  GLU E  73      25.119  92.616 -13.552  1.00 17.63           C  \\nATOM   9553  C   GLU E  73      26.558  92.113 -13.559  1.00 17.63           C  \\nATOM   9554  O   GLU E  73      26.974  91.424 -14.475  1.00 17.63           O  \\nATOM   9555  CB  GLU E  73      25.085  94.138 -13.702  1.00 21.24           C  \\nATOM   9556  CG  GLU E  73      25.950  94.656 -14.848  1.00 21.24           C  \\nATOM   9557  CD  GLU E  73      25.892  96.168 -15.020  1.00 21.24           C  \\nATOM   9558  OE1 GLU E  73      24.790  96.748 -14.915  1.00 21.24           O  \\nATOM   9559  OE2 GLU E  73      26.951  96.775 -15.282  1.00 21.24           O  \\nATOM   9560  N   ILE E  74      27.303  92.436 -12.515  1.00 19.79           N  \\nATOM   9561  CA  ILE E  74      28.683  92.003 -12.416  1.00 19.79           C  \\nATOM   9562  C   ILE E  74      28.798  90.483 -12.511  1.00 19.79           C  \\nATOM   9563  O   ILE E  74      29.532  89.967 -13.356  1.00 19.79           O  \\nATOM   9564  CB  ILE E  74      29.316  92.477 -11.077  1.00 12.86           C  \\nATOM   9565  CG1 ILE E  74      29.413  94.000 -11.071  1.00 12.86           C  \\nATOM   9566  CG2 ILE E  74      30.707  91.857 -10.880  1.00 12.86           C  \\nATOM   9567  CD1 ILE E  74      29.735  94.563  -9.740  1.00 12.86           C  \\nATOM   9568  N   ALA E  75      28.062  89.781 -11.648  1.00 17.30           N  \\nATOM   9569  CA  ALA E  75      28.080  88.330 -11.586  1.00 17.30           C  \\nATOM   9570  C   ALA E  75      27.835  87.725 -12.953  1.00 17.30           C  \\nATOM   9571  O   ALA E  75      28.592  86.882 -13.418  1.00 17.30           O  \\nATOM   9572  CB  ALA E  75      27.044  87.858 -10.623  1.00 23.14           C  \\nATOM   9573  N   GLN E  76      26.783  88.186 -13.606  1.00 38.14           N  \\nATOM   9574  CA  GLN E  76      26.411  87.715 -14.922  1.00 38.14           C  \\nATOM   9575  C   GLN E  76      27.529  87.924 -15.923  1.00 38.14           C  \\nATOM   9576  O   GLN E  76      27.619  87.198 -16.909  1.00 38.14           O  \\nATOM   9577  CB  GLN E  76      25.186  88.470 -15.365  1.00 36.55           C  \\nATOM   9578  CG  GLN E  76      24.694  88.144 -16.722  1.00 36.55           C  \\nATOM   9579  CD  GLN E  76      23.663  89.140 -17.150  1.00 36.55           C  \\nATOM   9580  OE1 GLN E  76      23.871  90.353 -17.037  1.00 36.55           O  \\nATOM   9581  NE2 GLN E  76      22.530  88.647 -17.615  1.00 36.55           N  \\nATOM   9582  N   ASP E  77      28.326  88.970 -15.731  1.00 30.23           N  \\nATOM   9583  CA  ASP E  77      29.455  89.204 -16.633  1.00 30.23           C  \\nATOM   9584  C   ASP E  77      30.725  88.320 -16.332  1.00 30.23           C  \\nATOM   9585  O   ASP E  77      31.700  88.338 -17.094  1.00 30.23           O  \\nATOM   9586  CB  ASP E  77      29.732  90.734 -16.829  1.00 58.30           C  \\nATOM   9587  CG  ASP E  77      28.752  91.417 -17.881  1.00 58.30           C  \\nATOM   9588  OD1 ASP E  77      28.366  90.785 -18.904  1.00 58.30           O  \\nATOM   9589  OD2 ASP E  77      28.371  92.598 -17.704  1.00 58.30           O  \\nATOM   9590  N   PHE E  78      30.671  87.497 -15.272  1.00 29.60           N  \\nATOM   9591  CA  PHE E  78      31.752  86.567 -14.911  1.00 29.60           C  \\nATOM   9592  C   PHE E  78      31.237  85.164 -15.284  1.00 29.60           C  \\nATOM   9593  O   PHE E  78      31.973  84.322 -15.819  1.00 29.60           O  \\nATOM   9594  CB  PHE E  78      32.103  86.641 -13.414  1.00 50.46           C  \\nATOM   9595  CG  PHE E  78      33.131  85.599 -12.965  1.00 50.46           C  \\nATOM   9596  CD1 PHE E  78      34.276  85.332 -13.723  1.00 50.46           C  \\nATOM   9597  CD2 PHE E  78      32.949  84.869 -11.783  1.00 50.46           C  \\nATOM   9598  CE1 PHE E  78      35.213  84.355 -13.307  1.00 50.46           C  \\nATOM   9599  CE2 PHE E  78      33.890  83.890 -11.366  1.00 50.46           C  \\nATOM   9600  CZ  PHE E  78      35.011  83.642 -12.130  1.00 50.46           C  \\nATOM   9601  N   LYS E  79      29.959  84.927 -15.020  1.00 28.89           N  \\nATOM   9602  CA  LYS E  79      29.337  83.657 -15.354  1.00 28.89           C  \\nATOM   9603  C   LYS E  79      27.819  83.875 -15.543  1.00 28.89           C  \\nATOM   9604  O   LYS E  79      27.138  84.486 -14.697  1.00 28.89           O  \\nATOM   9605  CB  LYS E  79      29.651  82.626 -14.260  1.00 39.61           C  \\nATOM   9606  CG  LYS E  79      29.960  81.204 -14.756  1.00 39.61           C  \\nATOM   9607  CD  LYS E  79      28.678  80.405 -14.983  1.00 39.61           C  \\nATOM   9608  CE  LYS E  79      28.891  79.161 -15.838  1.00 39.61           C  \\nATOM   9609  NZ  LYS E  79      27.582  78.755 -16.473  1.00 39.61           N  \\nATOM   9610  N   THR E  80      27.310  83.440 -16.695  1.00 24.38           N  \\nATOM   9611  CA  THR E  80      25.892  83.589 -17.024  1.00 24.38           C  \\nATOM   9612  C   THR E  80      25.012  82.531 -16.387  1.00 24.38           C  \\nATOM   9613  O   THR E  80      25.502  81.585 -15.778  1.00 24.38           O  \\nATOM   9614  CB  THR E  80      25.678  83.525 -18.522  1.00 42.15           C  \\nATOM   9615  OG1 THR E  80      26.596  82.576 -19.074  1.00 42.15           O  \\nATOM   9616  CG2 THR E  80      25.891  84.892 -19.157  1.00 42.15           C  \\nATOM   9617  N   ASP E  81      23.705  82.694 -16.545  1.00 44.69           N  \\nATOM   9618  CA  ASP E  81      22.745  81.754 -15.978  1.00 44.69           C  \\nATOM   9619  C   ASP E  81      23.085  81.452 -14.519  1.00 44.69           C  \\nATOM   9620  O   ASP E  81      23.499  80.342 -14.194  1.00 44.69           O  \\nATOM   9621  CB  ASP E  81      22.730  80.451 -16.785  1.00 94.42           C  \\nATOM   9622  CG  ASP E  81      22.517  80.683 -18.263  1.00 94.42           C  \\nATOM   9623  OD1 ASP E  81      21.384  81.031 -18.659  1.00 94.42           O  \\nATOM   9624  OD2 ASP E  81      23.491  80.520 -19.027  1.00 94.42           O  \\nATOM   9625  N   LEU E  82      22.953  82.455 -13.657  1.00 50.42           N  \\nATOM   9626  CA  LEU E  82      23.253  82.296 -12.237  1.00 50.42           C  \\nATOM   9627  C   LEU E  82      22.106  82.717 -11.331  1.00 50.42           C  \\nATOM   9628  O   LEU E  82      21.355  83.624 -11.665  1.00 50.42           O  \\nATOM   9629  CB  LEU E  82      24.466  83.145 -11.860  1.00 31.71           C  \\nATOM   9630  CG  LEU E  82      25.908  82.653 -11.986  1.00 31.71           C  \\nATOM   9631  CD1 LEU E  82      26.836  83.802 -11.676  1.00 31.71           C  \\nATOM   9632  CD2 LEU E  82      26.168  81.523 -11.027  1.00 31.71           C  \\nATOM   9633  N   ARG E  83      21.961  82.044 -10.195  1.00 24.42           N  \\nATOM   9634  CA  ARG E  83      20.939  82.395  -9.215  1.00 24.42           C  \\nATOM   9635  C   ARG E  83      21.603  82.922  -7.933  1.00 24.42           C  \\nATOM   9636  O   ARG E  83      22.789  82.684  -7.697  1.00 24.42           O  \\nATOM   9637  CB  ARG E  83      20.043  81.192  -8.907  1.00 48.97           C  \\nATOM   9638  CG  ARG E  83      19.163  80.810 -10.064  1.00 48.97           C  \\nATOM   9639  CD  ARG E  83      18.117  79.776  -9.711  1.00 48.97           C  \\nATOM   9640  NE  ARG E  83      17.108  79.779 -10.766  1.00 48.97           N  \\nATOM   9641  CZ  ARG E  83      15.789  79.798 -10.569  1.00 48.97           C  \\nATOM   9642  NH1 ARG E  83      15.284  79.790  -9.334  1.00 48.97           N  \\nATOM   9643  NH2 ARG E  83      14.976  79.918 -11.614  1.00 48.97           N  \\nATOM   9644  N   PHE E  84      20.814  83.572  -7.080  1.00 33.16           N  \\nATOM   9645  CA  PHE E  84      21.318  84.151  -5.835  1.00 33.16           C  \\nATOM   9646  C   PHE E  84      20.349  84.062  -4.637  1.00 33.16           C  \\nATOM   9647  O   PHE E  84      19.204  84.522  -4.727  1.00 33.16           O  \\nATOM   9648  CB  PHE E  84      21.590  85.645  -6.035  1.00 32.55           C  \\nATOM   9649  CG  PHE E  84      22.920  85.986  -6.668  1.00 32.55           C  \\nATOM   9650  CD1 PHE E  84      23.098  85.918  -8.052  1.00 32.55           C  \\nATOM   9651  CD2 PHE E  84      23.944  86.537  -5.893  1.00 32.55           C  \\nATOM   9652  CE1 PHE E  84      24.274  86.410  -8.648  1.00 32.55           C  \\nATOM   9653  CE2 PHE E  84      25.108  87.026  -6.474  1.00 32.55           C  \\nATOM   9654  CZ  PHE E  84      25.274  86.966  -7.849  1.00 32.55           C  \\nATOM   9655  N   GLN E  85      20.824  83.534  -3.505  1.00  7.64           N  \\nATOM   9656  CA  GLN E  85      20.025  83.483  -2.280  1.00  7.64           C  \\nATOM   9657  C   GLN E  85      19.757  84.937  -1.906  1.00  7.64           C  \\nATOM   9658  O   GLN E  85      20.577  85.818  -2.184  1.00  7.64           O  \\nATOM   9659  CB  GLN E  85      20.802  82.799  -1.144  1.00 18.63           C  \\nATOM   9660  CG  GLN E  85      21.240  81.352  -1.459  1.00 18.63           C  \\nATOM   9661  CD  GLN E  85      21.635  80.531  -0.214  1.00 18.63           C  \\nATOM   9662  OE1 GLN E  85      22.367  80.997   0.666  1.00 18.63           O  \\nATOM   9663  NE2 GLN E  85      21.190  79.277  -0.177  1.00 18.63           N  \\nATOM   9664  N   SER E  86      18.609  85.222  -1.305  1.00 29.43           N  \\nATOM   9665  CA  SER E  86      18.325  86.614  -0.954  1.00 29.43           C  \\nATOM   9666  C   SER E  86      19.445  87.070  -0.040  1.00 29.43           C  \\nATOM   9667  O   SER E  86      20.002  88.144  -0.213  1.00 29.43           O  \\nATOM   9668  CB  SER E  86      16.977  86.757  -0.246  1.00 44.20           C  \\nATOM   9669  OG  SER E  86      17.067  86.363   1.107  1.00 44.20           O  \\nATOM   9670  N   SER E  87      19.874  86.155   0.821  1.00 19.77           N  \\nATOM   9671  CA  SER E  87      20.921  86.439   1.779  1.00 19.77           C  \\nATOM   9672  C   SER E  87      22.318  86.540   1.191  1.00 19.77           C  \\nATOM   9673  O   SER E  87      23.181  87.173   1.779  1.00 19.77           O  \\nATOM   9674  CB  SER E  87      20.898  85.426   2.915  1.00 23.89           C  \\nATOM   9675  OG  SER E  87      21.324  84.177   2.441  1.00 23.89           O  \\nATOM   9676  N   ALA E  88      22.575  85.898   0.064  1.00 19.03           N  \\nATOM   9677  CA  ALA E  88      23.892  86.031  -0.526  1.00 19.03           C  \\nATOM   9678  C   ALA E  88      24.032  87.510  -0.863  1.00 19.03           C  \\nATOM   9679  O   ALA E  88      25.045  88.135  -0.565  1.00 19.03           O  \\nATOM   9680  CB  ALA E  88      23.979  85.224  -1.752  1.00  7.54           C  \\nATOM   9681  N   VAL E  89      22.968  88.097  -1.402  1.00 13.75           N  \\nATOM   9682  CA  VAL E  89      22.987  89.519  -1.768  1.00 13.75           C  \\nATOM   9683  C   VAL E  89      23.110  90.427  -0.555  1.00 13.75           C  \\nATOM   9684  O   VAL E  89      23.815  91.417  -0.608  1.00 13.75           O  \\nATOM   9685  CB  VAL E  89      21.729  89.925  -2.572  1.00 11.12           C  \\nATOM   9686  CG1 VAL E  89      21.902  91.318  -3.172  1.00 11.12           C  \\nATOM   9687  CG2 VAL E  89      21.442  88.897  -3.648  1.00 11.12           C  \\nATOM   9688  N   MET E  90      22.367  90.131   0.507  1.00 14.56           N  \\nATOM   9689  CA  MET E  90      22.442  90.915   1.729  1.00 14.56           C  \\nATOM   9690  C   MET E  90      23.884  90.846   2.244  1.00 14.56           C  \\nATOM   9691  O   MET E  90      24.478  91.883   2.586  1.00 14.56           O  \\nATOM   9692  CB  MET E  90      21.492  90.385   2.802  1.00 52.83           C  \\nATOM   9693  CG  MET E  90      20.018  90.728   2.625  1.00 52.83           C  \\nATOM   9694  SD  MET E  90      19.013  90.146   4.068  1.00 52.83           S  \\nATOM   9695  CE  MET E  90      18.702  88.350   3.708  1.00 52.83           C  \\nATOM   9696  N   ALA E  91      24.467  89.642   2.266  1.00 17.16           N  \\nATOM   9697  CA  ALA E  91      25.845  89.455   2.722  1.00 17.16           C  \\nATOM   9698  C   ALA E  91      26.775  90.380   1.954  1.00 17.16           C  \\nATOM   9699  O   ALA E  91      27.597  91.066   2.548  1.00 17.16           O  \\nATOM   9700  CB  ALA E  91      26.264  88.027   2.541  1.00 26.01           C  \\nATOM   9701  N   LEU E  92      26.638  90.415   0.635  1.00 16.85           N  \\nATOM   9702  CA  LEU E  92      27.457  91.318  -0.167  1.00 16.85           C  \\nATOM   9703  C   LEU E  92      27.201  92.770   0.212  1.00 16.85           C  \\nATOM   9704  O   LEU E  92      28.145  93.538   0.348  1.00 16.85           O  \\nATOM   9705  CB  LEU E  92      27.190  91.140  -1.661  1.00 12.63           C  \\nATOM   9706  CG  LEU E  92      27.647  89.797  -2.231  1.00 12.63           C  \\nATOM   9707  CD1 LEU E  92      26.854  89.389  -3.438  1.00 12.63           C  \\nATOM   9708  CD2 LEU E  92      29.095  89.920  -2.562  1.00 12.63           C  \\nATOM   9709  N   GLN E  93      25.945  93.165   0.405  1.00 17.17           N  \\nATOM   9710  CA  GLN E  93      25.692  94.563   0.760  1.00 17.17           C  \\nATOM   9711  C   GLN E  93      26.342  94.952   2.060  1.00 17.17           C  \\nATOM   9712  O   GLN E  93      27.003  95.979   2.149  1.00 17.17           O  \\nATOM   9713  CB  GLN E  93      24.211  94.882   0.817  1.00 18.53           C  \\nATOM   9714  CG  GLN E  93      23.937  96.286   0.346  1.00 18.53           C  \\nATOM   9715  CD  GLN E  93      22.475  96.556   0.175  1.00 18.53           C  \\nATOM   9716  OE1 GLN E  93      21.710  95.700  -0.304  1.00 18.53           O  \\nATOM   9717  NE2 GLN E  93      22.063  97.757   0.562  1.00 18.53           N  \\nATOM   9718  N   GLU E  94      26.163  94.107   3.060  1.00 14.49           N  \\nATOM   9719  CA  GLU E  94      26.752  94.314   4.370  1.00 14.49           C  \\nATOM   9720  C   GLU E  94      28.246  94.536   4.272  1.00 14.49           C  \\nATOM   9721  O   GLU E  94      28.759  95.510   4.793  1.00 14.49           O  \\nATOM   9722  CB  GLU E  94      26.473  93.105   5.239  1.00 35.41           C  \\nATOM   9723  CG  GLU E  94      25.030  93.015   5.678  1.00 35.41           C  \\nATOM   9724  CD  GLU E  94      24.653  94.093   6.688  1.00 35.41           C  \\nATOM   9725  OE1 GLU E  94      25.548  94.614   7.402  1.00 35.41           O  \\nATOM   9726  OE2 GLU E  94      23.451  94.421   6.786  1.00 35.41           O  \\nATOM   9727  N   ALA E  95      28.934  93.640   3.575  1.00 10.08           N  \\nATOM   9728  CA  ALA E  95      30.369  93.736   3.387  1.00 10.08           C  \\nATOM   9729  C   ALA E  95      30.733  94.957   2.578  1.00 10.08           C  \\nATOM   9730  O   ALA E  95      31.730  95.611   2.851  1.00 10.08           O  \\nATOM   9731  CB  ALA E  95      30.882  92.496   2.685  1.00  5.00           C  \\nATOM   9732  N   SER E  96      29.928  95.260   1.570  1.00 13.59           N  \\nATOM   9733  CA  SER E  96      30.186  96.393   0.690  1.00 13.59           C  \\nATOM   9734  C   SER E  96      30.199  97.743   1.380  1.00 13.59           C  \\nATOM   9735  O   SER E  96      31.151  98.509   1.245  1.00 13.59           O  \\nATOM   9736  CB  SER E  96      29.189  96.393  -0.469  1.00 29.71           C  \\nATOM   9737  OG  SER E  96      29.379  95.267  -1.321  1.00 29.71           O  \\nATOM   9738  N   GLU E  97      29.155  98.031   2.143  1.00  9.47           N  \\nATOM   9739  CA  GLU E  97      29.083  99.301   2.855  1.00  9.47           C  \\nATOM   9740  C   GLU E  97      30.071  99.356   4.024  1.00  9.47           C  \\nATOM   9741  O   GLU E  97      30.661 100.396   4.263  1.00  9.47           O  \\nATOM   9742  CB  GLU E  97      27.665  99.554   3.354  1.00 21.93           C  \\nATOM   9743  CG  GLU E  97      26.618  99.337   2.287  1.00 21.93           C  \\nATOM   9744  CD  GLU E  97      25.297 100.045   2.570  1.00 21.93           C  \\nATOM   9745  OE1 GLU E  97      25.160 100.705   3.623  1.00 21.93           O  \\nATOM   9746  OE2 GLU E  97      24.375  99.941   1.735  1.00 21.93           O  \\nATOM   9747  N   ALA E  98      30.254  98.247   4.746  1.00  5.00           N  \\nATOM   9748  CA  ALA E  98      31.167  98.234   5.881  1.00  5.00           C  \\nATOM   9749  C   ALA E  98      32.527  98.665   5.392  1.00  5.00           C  \\nATOM   9750  O   ALA E  98      33.195  99.490   6.035  1.00  5.00           O  \\nATOM   9751  CB  ALA E  98      31.244  96.891   6.486  1.00  5.00           C  \\nATOM   9752  N   TYR E  99      32.887  98.164   4.208  1.00 18.26           N  \\nATOM   9753  CA  TYR E  99      34.141  98.494   3.541  1.00 18.26           C  \\nATOM   9754  C   TYR E  99      34.200  99.970   3.132  1.00 18.26           C  \\nATOM   9755  O   TYR E  99      35.174 100.663   3.414  1.00 18.26           O  \\nATOM   9756  CB  TYR E  99      34.320  97.591   2.320  1.00  9.24           C  \\nATOM   9757  CG  TYR E  99      35.395  98.036   1.364  1.00  9.24           C  \\nATOM   9758  CD1 TYR E  99      36.734  97.706   1.573  1.00  9.24           C  \\nATOM   9759  CD2 TYR E  99      35.077  98.850   0.268  1.00  9.24           C  \\nATOM   9760  CE1 TYR E  99      37.747  98.201   0.704  1.00  9.24           C  \\nATOM   9761  CE2 TYR E  99      36.057  99.339  -0.590  1.00  9.24           C  \\nATOM   9762  CZ  TYR E  99      37.386  99.021  -0.375  1.00  9.24           C  \\nATOM   9763  OH  TYR E  99      38.331  99.527  -1.261  1.00  9.24           O  \\nATOM   9764  N   LEU E 100      33.169 100.430   2.433  1.00 17.47           N  \\nATOM   9765  CA  LEU E 100      33.093 101.810   1.976  1.00 17.47           C  \\nATOM   9766  C   LEU E 100      33.101 102.828   3.099  1.00 17.47           C  \\nATOM   9767  O   LEU E 100      33.734 103.871   3.002  1.00 17.47           O  \\nATOM   9768  CB  LEU E 100      31.862 101.996   1.099  1.00 13.86           C  \\nATOM   9769  CG  LEU E 100      32.116 101.518  -0.331  1.00 13.86           C  \\nATOM   9770  CD1 LEU E 100      30.854 101.659  -1.144  1.00 13.86           C  \\nATOM   9771  CD2 LEU E 100      33.238 102.360  -0.961  1.00 13.86           C  \\nATOM   9772  N   VAL E 101      32.405 102.519   4.177  1.00 15.75           N  \\nATOM   9773  CA  VAL E 101      32.357 103.409   5.309  1.00 15.75           C  \\nATOM   9774  C   VAL E 101      33.765 103.570   5.888  1.00 15.75           C  \\nATOM   9775  O   VAL E 101      34.222 104.693   6.078  1.00 15.75           O  \\nATOM   9776  CB  VAL E 101      31.337 102.902   6.364  1.00 10.48           C  \\nATOM   9777  CG1 VAL E 101      31.449 103.702   7.660  1.00 10.48           C  \\nATOM   9778  CG2 VAL E 101      29.925 103.022   5.805  1.00 10.48           C  \\nATOM   9779  N   ALA E 102      34.470 102.460   6.118  1.00 30.71           N  \\nATOM   9780  CA  ALA E 102      35.835 102.514   6.652  1.00 30.71           C  \\nATOM   9781  C   ALA E 102      36.757 103.244   5.674  1.00 30.71           C  \\nATOM   9782  O   ALA E 102      37.620 104.011   6.088  1.00 30.71           O  \\nATOM   9783  CB  ALA E 102      36.357 101.125   6.926  1.00 10.84           C  \\nATOM   9784  N   LEU E 103      36.602 102.989   4.378  1.00 16.86           N  \\nATOM   9785  CA  LEU E 103      37.405 103.691   3.375  1.00 16.86           C  \\nATOM   9786  C   LEU E 103      37.272 105.201   3.590  1.00 16.86           C  \\nATOM   9787  O   LEU E 103      38.254 105.922   3.563  1.00 16.86           O  \\nATOM   9788  CB  LEU E 103      36.929 103.352   1.966  1.00  5.00           C  \\nATOM   9789  CG  LEU E 103      37.936 103.728   0.893  1.00  5.00           C  \\nATOM   9790  CD1 LEU E 103      39.249 103.046   1.185  1.00  5.00           C  \\nATOM   9791  CD2 LEU E 103      37.436 103.301  -0.453  1.00  5.00           C  \\nATOM   9792  N   PHE E 104      36.045 105.675   3.804  1.00 21.69           N  \\nATOM   9793  CA  PHE E 104      35.805 107.095   4.035  1.00 21.69           C  \\nATOM   9794  C   PHE E 104      36.475 107.634   5.301  1.00 21.69           C  \\nATOM   9795  O   PHE E 104      36.975 108.749   5.295  1.00 21.69           O  \\nATOM   9796  CB  PHE E 104      34.307 107.408   4.003  1.00  6.31           C  \\nATOM   9797  CG  PHE E 104      33.700 107.361   2.618  1.00  6.31           C  \\nATOM   9798  CD1 PHE E 104      34.199 108.168   1.600  1.00  6.31           C  \\nATOM   9799  CD2 PHE E 104      32.635 106.512   2.341  1.00  6.31           C  \\nATOM   9800  CE1 PHE E 104      33.654 108.137   0.319  1.00  6.31           C  \\nATOM   9801  CE2 PHE E 104      32.078 106.462   1.077  1.00  6.31           C  \\nATOM   9802  CZ  PHE E 104      32.584 107.277   0.050  1.00  6.31           C  \\nATOM   9803  N   GLU E 105      36.481 106.860   6.381  1.00 16.41           N  \\nATOM   9804  CA  GLU E 105      37.156 107.299   7.589  1.00 16.41           C  \\nATOM   9805  C   GLU E 105      38.610 107.610   7.230  1.00 16.41           C  \\nATOM   9806  O   GLU E 105      39.107 108.679   7.561  1.00 16.41           O  \\nATOM   9807  CB  GLU E 105      37.130 106.224   8.668  1.00 35.72           C  \\nATOM   9808  CG  GLU E 105      35.794 105.545   8.855  1.00 35.72           C  \\nATOM   9809  CD  GLU E 105      35.713 104.717  10.126  1.00 35.72           C  \\nATOM   9810  OE1 GLU E 105      36.782 104.430  10.710  1.00 35.72           O  \\nATOM   9811  OE2 GLU E 105      34.579 104.376  10.561  1.00 35.72           O  \\nATOM   9812  N   ASP E 106      39.284 106.706   6.510  1.00 20.74           N  \\nATOM   9813  CA  ASP E 106      40.691 106.909   6.118  1.00 20.74           C  \\nATOM   9814  C   ASP E 106      40.843 108.108   5.213  1.00 20.74           C  \\nATOM   9815  O   ASP E 106      41.689 108.960   5.456  1.00 20.74           O  \\nATOM   9816  CB  ASP E 106      41.264 105.668   5.434  1.00 14.24           C  \\nATOM   9817  CG  ASP E 106      41.362 104.477   6.373  1.00 14.24           C  \\nATOM   9818  OD1 ASP E 106      41.285 104.659   7.610  1.00 14.24           O  \\nATOM   9819  OD2 ASP E 106      41.510 103.335   5.874  1.00 14.24           O  \\nATOM   9820  N   THR E 107      40.026 108.148   4.159  1.00  9.09           N  \\nATOM   9821  CA  THR E 107      39.988 109.239   3.178  1.00  9.09           C  \\nATOM   9822  C   THR E 107      39.905 110.555   3.915  1.00  9.09           C  \\nATOM   9823  O   THR E 107      40.681 111.453   3.662  1.00  9.09           O  \\nATOM   9824  CB  THR E 107      38.749 109.114   2.287  1.00 11.61           C  \\nATOM   9825  OG1 THR E 107      38.901 107.991   1.416  1.00 11.61           O  \\nATOM   9826  CG2 THR E 107      38.549 110.326   1.450  1.00 11.61           C  \\nATOM   9827  N   ASN E 108      38.988 110.637   4.872  1.00 12.16           N  \\nATOM   9828  CA  ASN E 108      38.782 111.823   5.690  1.00 12.16           C  \\nATOM   9829  C   ASN E 108      40.106 112.236   6.301  1.00 12.16           C  \\nATOM   9830  O   ASN E 108      40.504 113.403   6.200  1.00 12.16           O  \\nATOM   9831  CB  ASN E 108      37.789 111.484   6.803  1.00 25.35           C  \\nATOM   9832  CG  ASN E 108      37.092 112.700   7.369  1.00 25.35           C  \\nATOM   9833  OD1 ASN E 108      36.873 113.691   6.662  1.00 25.35           O  \\nATOM   9834  ND2 ASN E 108      36.688 112.614   8.637  1.00 25.35           N  \\nATOM   9835  N   LEU E 109      40.768 111.276   6.966  1.00 13.14           N  \\nATOM   9836  CA  LEU E 109      42.066 111.509   7.595  1.00 13.14           C  \\nATOM   9837  C   LEU E 109      43.088 112.053   6.594  1.00 13.14           C  \\nATOM   9838  O   LEU E 109      43.820 112.978   6.901  1.00 13.14           O  \\nATOM   9839  CB  LEU E 109      42.572 110.250   8.251  1.00  5.00           C  \\nATOM   9840  CG  LEU E 109      41.842 109.734   9.487  1.00  5.00           C  \\nATOM   9841  CD1 LEU E 109      42.650 108.620  10.105  1.00  5.00           C  \\nATOM   9842  CD2 LEU E 109      41.717 110.813  10.511  1.00  5.00           C  \\nATOM   9843  N   CYS E 110      43.148 111.503   5.394  1.00 14.04           N  \\nATOM   9844  CA  CYS E 110      44.069 112.069   4.426  1.00 14.04           C  \\nATOM   9845  C   CYS E 110      43.762 113.547   4.150  1.00 14.04           C  \\nATOM   9846  O   CYS E 110      44.644 114.394   4.285  1.00 14.04           O  \\nATOM   9847  CB  CYS E 110      44.069 111.268   3.132  1.00 16.17           C  \\nATOM   9848  SG  CYS E 110      44.754 109.641   3.421  1.00 16.17           S  \\nATOM   9849  N   ALA E 111      42.503 113.866   3.825  1.00 16.19           N  \\nATOM   9850  CA  ALA E 111      42.102 115.246   3.543  1.00 16.19           C  \\nATOM   9851  C   ALA E 111      42.547 116.141   4.670  1.00 16.19           C  \\nATOM   9852  O   ALA E 111      43.186 117.155   4.445  1.00 16.19           O  \\nATOM   9853  CB  ALA E 111      40.608 115.350   3.359  1.00  7.47           C  \\nATOM   9854  N   ILE E 112      42.247 115.736   5.892  1.00 22.10           N  \\nATOM   9855  CA  ILE E 112      42.626 116.524   7.051  1.00 22.10           C  \\nATOM   9856  C   ILE E 112      44.125 116.722   7.120  1.00 22.10           C  \\nATOM   9857  O   ILE E 112      44.581 117.750   7.574  1.00 22.10           O  \\nATOM   9858  CB  ILE E 112      42.110 115.886   8.345  1.00 18.41           C  \\nATOM   9859  CG1 ILE E 112      40.595 116.008   8.408  1.00 18.41           C  \\nATOM   9860  CG2 ILE E 112      42.725 116.536   9.549  1.00 18.41           C  \\nATOM   9861  CD1 ILE E 112      39.989 115.283   9.610  1.00 18.41           C  \\nATOM   9862  N   HIS E 113      44.881 115.724   6.684  1.00 18.03           N  \\nATOM   9863  CA  HIS E 113      46.339 115.785   6.669  1.00 18.03           C  \\nATOM   9864  C   HIS E 113      46.838 116.900   5.759  1.00 18.03           C  \\nATOM   9865  O   HIS E 113      47.892 117.476   6.005  1.00 18.03           O  \\nATOM   9866  CB  HIS E 113      46.904 114.460   6.170  1.00 25.32           C  \\nATOM   9867  CG  HIS E 113      48.364 114.302   6.429  1.00 25.32           C  \\nATOM   9868  ND1 HIS E 113      49.309 114.391   5.428  1.00 25.32           N  \\nATOM   9869  CD2 HIS E 113      49.047 114.114   7.585  1.00 25.32           C  \\nATOM   9870  CE1 HIS E 113      50.513 114.272   5.957  1.00 25.32           C  \\nATOM   9871  NE2 HIS E 113      50.382 114.102   7.264  1.00 25.32           N  \\nATOM   9872  N   ALA E 114      46.131 117.096   4.648  1.00 19.45           N  \\nATOM   9873  CA  ALA E 114      46.423 118.152   3.676  1.00 19.45           C  \\nATOM   9874  C   ALA E 114      45.856 119.484   4.169  1.00 19.45           C  \\nATOM   9875  O   ALA E 114      45.801 120.468   3.423  1.00 19.45           O  \\nATOM   9876  CB  ALA E 114      45.803 117.807   2.324  1.00  8.08           C  \\nATOM   9877  N   LYS E 115      45.392 119.489   5.416  1.00 32.88           N  \\nATOM   9878  CA  LYS E 115      44.816 120.665   6.030  1.00 32.88           C  \\nATOM   9879  C   LYS E 115      43.560 121.122   5.291  1.00 32.88           C  \\nATOM   9880  O   LYS E 115      43.289 122.318   5.215  1.00 32.88           O  \\nATOM   9881  CB  LYS E 115      45.857 121.771   6.106  1.00 49.66           C  \\nATOM   9882  CG  LYS E 115      47.104 121.320   6.842  1.00 49.66           C  \\nATOM   9883  CD  LYS E 115      48.192 122.361   6.845  1.00 49.66           C  \\nATOM   9884  CE  LYS E 115      48.902 122.346   8.188  1.00 49.66           C  \\nATOM   9885  NZ  LYS E 115      49.845 123.497   8.368  1.00 49.66           N  \\nATOM   9886  N   ARG E 116      42.826 120.161   4.713  1.00 29.09           N  \\nATOM   9887  CA  ARG E 116      41.558 120.410   4.016  1.00 29.09           C  \\nATOM   9888  C   ARG E 116      40.439 119.796   4.854  1.00 29.09           C  \\nATOM   9889  O   ARG E 116      40.709 119.202   5.902  1.00 29.09           O  \\nATOM   9890  CB  ARG E 116      41.543 119.789   2.617  1.00 23.96           C  \\nATOM   9891  CG  ARG E 116      42.475 120.470   1.628  1.00 23.96           C  \\nATOM   9892  CD  ARG E 116      42.342 119.908   0.205  1.00 23.96           C  \\nATOM   9893  NE  ARG E 116      43.222 118.771  -0.074  1.00 23.96           N  \\nATOM   9894  CZ  ARG E 116      42.895 117.492   0.111  1.00 23.96           C  \\nATOM   9895  NH1 ARG E 116      41.694 117.142   0.577  1.00 23.96           N  \\nATOM   9896  NH2 ARG E 116      43.798 116.558  -0.142  1.00 23.96           N  \\nATOM   9897  N   VAL E 117      39.190 119.949   4.393  1.00 21.02           N  \\nATOM   9898  CA  VAL E 117      37.970 119.443   5.067  1.00 21.02           C  \\nATOM   9899  C   VAL E 117      37.138 118.670   4.027  1.00 21.02           C  \\nATOM   9900  O   VAL E 117      36.291 117.843   4.358  1.00 21.02           O  \\nATOM   9901  CB  VAL E 117      37.116 120.633   5.624  1.00 26.46           C  \\nATOM   9902  CG1 VAL E 117      35.859 120.143   6.281  1.00 26.46           C  \\nATOM   9903  CG2 VAL E 117      37.901 121.412   6.635  1.00 26.46           C  \\nATOM   9904  N   THR E 118      37.377 118.985   2.762  1.00 20.40           N  \\nATOM   9905  CA  THR E 118      36.699 118.346   1.651  1.00 20.40           C  \\nATOM   9906  C   THR E 118      37.449 117.125   1.143  1.00 20.40           C  \\nATOM   9907  O   THR E 118      38.523 117.260   0.561  1.00 20.40           O  \\nATOM   9908  CB  THR E 118      36.596 119.311   0.472  1.00 19.98           C  \\nATOM   9909  OG1 THR E 118      36.050 120.551   0.921  1.00 19.98           O  \\nATOM   9910  CG2 THR E 118      35.701 118.735  -0.602  1.00 19.98           C  \\nATOM   9911  N   ILE E 119      36.882 115.938   1.301  1.00 13.88           N  \\nATOM   9912  CA  ILE E 119      37.586 114.767   0.794  1.00 13.88           C  \\nATOM   9913  C   ILE E 119      37.598 114.850  -0.739  1.00 13.88           C  \\nATOM   9914  O   ILE E 119      36.663 115.380  -1.323  1.00 13.88           O  \\nATOM   9915  CB  ILE E 119      36.944 113.437   1.271  1.00 12.22           C  \\nATOM   9916  CG1 ILE E 119      35.576 113.222   0.608  1.00 12.22           C  \\nATOM   9917  CG2 ILE E 119      36.859 113.410   2.799  1.00 12.22           C  \\nATOM   9918  CD1 ILE E 119      34.862 111.938   1.049  1.00 12.22           C  \\nATOM   9919  N   MET E 120      38.704 114.441  -1.358  1.00 26.11           N  \\nATOM   9920  CA  MET E 120      38.862 114.445  -2.812  1.00 26.11           C  \\nATOM   9921  C   MET E 120      39.393 113.074  -3.229  1.00 26.11           C  \\nATOM   9922  O   MET E 120      39.913 112.339  -2.396  1.00 26.11           O  \\nATOM   9923  CB  MET E 120      39.887 115.488  -3.256  1.00 26.39           C  \\nATOM   9924  CG  MET E 120      39.857 116.818  -2.530  1.00 26.39           C  \\nATOM   9925  SD  MET E 120      40.863 118.061  -3.385  1.00 26.39           S  \\nATOM   9926  CE  MET E 120      39.969 119.541  -2.845  1.00 26.39           C  \\nATOM   9927  N   PRO E 121      39.279 112.717  -4.529  1.00 23.87           N  \\nATOM   9928  CA  PRO E 121      39.751 111.434  -5.072  1.00 23.87           C  \\nATOM   9929  C   PRO E 121      41.207 111.173  -4.652  1.00 23.87           C  \\nATOM   9930  O   PRO E 121      41.588 110.073  -4.276  1.00 23.87           O  \\nATOM   9931  CB  PRO E 121      39.619 111.658  -6.576  1.00 15.50           C  \\nATOM   9932  CG  PRO E 121      38.365 112.475  -6.669  1.00 15.50           C  \\nATOM   9933  CD  PRO E 121      38.629 113.509  -5.591  1.00 15.50           C  \\nATOM   9934  N   LYS E 122      41.996 112.231  -4.735  1.00 18.52           N  \\nATOM   9935  CA  LYS E 122      43.400 112.283  -4.342  1.00 18.52           C  \\nATOM   9936  C   LYS E 122      43.535 111.602  -2.946  1.00 18.52           C  \\nATOM   9937  O   LYS E 122      44.406 110.776  -2.732  1.00 18.52           O  \\nATOM   9938  CB  LYS E 122      43.745 113.783  -4.267  1.00 44.76           C  \\nATOM   9939  CG  LYS E 122      45.179 114.205  -4.299  1.00 44.76           C  \\nATOM   9940  CD  LYS E 122      45.289 115.703  -3.975  1.00 44.76           C  \\nATOM   9941  CE  LYS E 122      44.524 116.575  -4.981  1.00 44.76           C  \\nATOM   9942  NZ  LYS E 122      44.589 118.056  -4.699  1.00 44.76           N  \\nATOM   9943  N   ASP E 123      42.639 111.917  -2.016  1.00 24.10           N  \\nATOM   9944  CA  ASP E 123      42.669 111.317  -0.678  1.00 24.10           C  \\nATOM   9945  C   ASP E 123      42.318 109.836  -0.742  1.00 24.10           C  \\nATOM   9946  O   ASP E 123      43.013 109.007  -0.172  1.00 24.10           O  \\nATOM   9947  CB  ASP E 123      41.680 112.016   0.245  1.00 32.41           C  \\nATOM   9948  CG  ASP E 123      41.933 113.490   0.346  1.00 32.41           C  \\nATOM   9949  OD1 ASP E 123      42.889 113.874   1.031  1.00 32.41           O  \\nATOM   9950  OD2 ASP E 123      41.188 114.267  -0.262  1.00 32.41           O  \\nATOM   9951  N   ILE E 124      41.214 109.519  -1.416  1.00 31.41           N  \\nATOM   9952  CA  ILE E 124      40.776 108.136  -1.586  1.00 31.41           C  \\nATOM   9953  C   ILE E 124      41.927 107.287  -2.112  1.00 31.41           C  \\nATOM   9954  O   ILE E 124      42.209 106.233  -1.570  1.00 31.41           O  \\nATOM   9955  CB  ILE E 124      39.621 108.027  -2.602  1.00 36.45           C  \\nATOM   9956  CG1 ILE E 124      38.346 108.657  -2.030  1.00 36.45           C  \\nATOM   9957  CG2 ILE E 124      39.417 106.571  -3.031  1.00 36.45           C  \\nATOM   9958  CD1 ILE E 124      37.101 108.355  -2.844  1.00 36.45           C  \\nATOM   9959  N   GLN E 125      42.598 107.766  -3.158  1.00 23.28           N  \\nATOM   9960  CA  GLN E 125      43.718 107.056  -3.767  1.00 23.28           C  \\nATOM   9961  C   GLN E 125      44.929 106.894  -2.852  1.00 23.28           C  \\nATOM   9962  O   GLN E 125      45.614 105.880  -2.914  1.00 23.28           O  \\nATOM   9963  CB  GLN E 125      44.101 107.723  -5.076  1.00 31.66           C  \\nATOM   9964  CG  GLN E 125      42.997 107.627  -6.115  1.00 31.66           C  \\nATOM   9965  CD  GLN E 125      43.102 108.692  -7.202  1.00 31.66           C  \\nATOM   9966  OE1 GLN E 125      44.125 109.362  -7.336  1.00 31.66           O  \\nATOM   9967  NE2 GLN E 125      42.026 108.868  -7.972  1.00 31.66           N  \\nATOM   9968  N   LEU E 126      45.188 107.879  -1.997  1.00 16.70           N  \\nATOM   9969  CA  LEU E 126      46.315 107.793  -1.077  1.00 16.70           C  \\nATOM   9970  C   LEU E 126      45.981 106.756  -0.013  1.00 16.70           C  \\nATOM   9971  O   LEU E 126      46.833 105.967   0.398  1.00 16.70           O  \\nATOM   9972  CB  LEU E 126      46.634 109.165  -0.432  1.00  8.01           C  \\nATOM   9973  CG  LEU E 126      47.706 109.082   0.661  1.00  8.01           C  \\nATOM   9974  CD1 LEU E 126      49.007 108.742   0.010  1.00  8.01           C  \\nATOM   9975  CD2 LEU E 126      47.836 110.345   1.484  1.00  8.01           C  \\nATOM   9976  N   ALA E 127      44.733 106.763   0.444  1.00 15.14           N  \\nATOM   9977  CA  ALA E 127      44.294 105.815   1.458  1.00 15.14           C  \\nATOM   9978  C   ALA E 127      44.559 104.399   0.977  1.00 15.14           C  \\nATOM   9979  O   ALA E 127      45.236 103.643   1.647  1.00 15.14           O  \\nATOM   9980  CB  ALA E 127      42.814 106.012   1.769  1.00 32.30           C  \\nATOM   9981  N   ARG E 128      44.064 104.072  -0.216  1.00 22.16           N  \\nATOM   9982  CA  ARG E 128      44.234 102.750  -0.818  1.00 22.16           C  \\nATOM   9983  C   ARG E 128      45.689 102.432  -1.109  1.00 22.16           C  \\nATOM   9984  O   ARG E 128      46.106 101.305  -0.911  1.00 22.16           O  \\nATOM   9985  CB  ARG E 128      43.400 102.615  -2.090  1.00 27.57           C  \\nATOM   9986  CG  ARG E 128      41.974 103.110  -1.935  1.00 27.57           C  \\nATOM   9987  CD  ARG E 128      40.992 102.209  -2.633  1.00 27.57           C  \\nATOM   9988  NE  ARG E 128      41.306 102.021  -4.046  1.00 27.57           N  \\nATOM   9989  CZ  ARG E 128      41.062 100.898  -4.712  1.00 27.57           C  \\nATOM   9990  NH1 ARG E 128      40.497  99.864  -4.100  1.00 27.57           N  \\nATOM   9991  NH2 ARG E 128      41.419 100.790  -5.980  1.00 27.57           N  \\nATOM   9992  N   ARG E 129      46.455 103.401  -1.611  1.00 20.42           N  \\nATOM   9993  CA  ARG E 129      47.880 103.184  -1.877  1.00 20.42           C  \\nATOM   9994  C   ARG E 129      48.544 102.668  -0.594  1.00 20.42           C  \\nATOM   9995  O   ARG E 129      49.173 101.615  -0.598  1.00 20.42           O  \\nATOM   9996  CB  ARG E 129      48.549 104.488  -2.340  1.00 84.01           C  \\nATOM   9997  CG  ARG E 129      50.083 104.450  -2.498  1.00 84.01           C  \\nATOM   9998  CD  ARG E 129      50.568 104.424  -3.966  1.00 84.01           C  \\nATOM   9999  NE  ARG E 129      49.581 104.903  -4.946  1.00 84.01           N  \\nATOM  10000  CZ  ARG E 129      49.363 106.182  -5.263  1.00 84.01           C  \\nATOM  10001  NH1 ARG E 129      50.064 107.148  -4.682  1.00 84.01           N  \\nATOM  10002  NH2 ARG E 129      48.423 106.498  -6.148  1.00 84.01           N  \\nATOM  10003  N   ILE E 130      48.345 103.369   0.518  1.00 28.10           N  \\nATOM  10004  CA  ILE E 130      48.943 102.956   1.775  1.00 28.10           C  \\nATOM  10005  C   ILE E 130      48.405 101.609   2.244  1.00 28.10           C  \\nATOM  10006  O   ILE E 130      49.183 100.755   2.672  1.00 28.10           O  \\nATOM  10007  CB  ILE E 130      48.776 104.050   2.846  1.00 25.00           C  \\nATOM  10008  CG1 ILE E 130      49.569 105.294   2.417  1.00 25.00           C  \\nATOM  10009  CG2 ILE E 130      49.227 103.561   4.221  1.00 25.00           C  \\nATOM  10010  CD1 ILE E 130      49.143 106.557   3.150  1.00 25.00           C  \\nATOM  10011  N   ARG E 131      47.090 101.421   2.145  1.00 39.55           N  \\nATOM  10012  CA  ARG E 131      46.413 100.181   2.541  1.00 39.55           C  \\nATOM  10013  C   ARG E 131      46.888  98.946   1.782  1.00 39.55           C  \\nATOM  10014  O   ARG E 131      46.661  97.825   2.221  1.00 39.55           O  \\nATOM  10015  CB  ARG E 131      44.917 100.298   2.289  1.00 16.53           C  \\nATOM  10016  CG  ARG E 131      44.105 101.089   3.284  1.00 16.53           C  \\nATOM  10017  CD  ARG E 131      42.710 101.273   2.684  1.00 16.53           C  \\nATOM  10018  NE  ARG E 131      41.660 101.437   3.677  1.00 16.53           N  \\nATOM  10019  CZ  ARG E 131      40.490 100.825   3.585  1.00 16.53           C  \\nATOM  10020  NH1 ARG E 131      40.262 100.022   2.548  1.00 16.53           N  \\nATOM  10021  NH2 ARG E 131      39.544 101.029   4.501  1.00 16.53           N  \\nATOM  10022  N   GLY E 132      47.412  99.146   0.581  1.00 32.31           N  \\nATOM  10023  CA  GLY E 132      47.893  98.026  -0.205  1.00 32.31           C  \\nATOM  10024  C   GLY E 132      46.838  97.445  -1.132  1.00 32.31           C  \\nATOM  10025  O   GLY E 132      46.650  96.227  -1.169  1.00 32.31           O  \\nATOM  10026  N   GLU E 133      46.124  98.314  -1.850  1.00 47.32           N  \\nATOM  10027  CA  GLU E 133      45.075  97.903  -2.791  1.00 47.32           C  \\nATOM  10028  C   GLU E 133      45.418  98.377  -4.201  1.00 47.32           C  \\nATOM  10029  O   GLU E 133      44.846  97.922  -5.192  1.00 47.32           O  \\nATOM  10030  CB  GLU E 133      43.703  98.458  -2.340  1.00 16.09           C  \\nATOM  10031  CG  GLU E 133      43.218  97.879  -0.986  1.00 16.09           C  \\nATOM  10032  CD  GLU E 133      41.939  98.523  -0.420  1.00 16.09           C  \\nATOM  10033  OE1 GLU E 133      41.174  99.168  -1.186  1.00 16.09           O  \\nATOM  10034  OE2 GLU E 133      41.706  98.373   0.810  1.00 16.09           O  \\nATOM  10035  N   ARG E 134      46.398  99.266  -4.282  1.00123.79           N  \\nATOM  10036  CA  ARG E 134      46.845  99.829  -5.547  1.00123.79           C  \\nATOM  10037  C   ARG E 134      48.100 100.635  -5.195  1.00123.79           C  \\nATOM  10038  O   ARG E 134      48.283 101.766  -5.657  1.00123.79           O  \\nATOM  10039  CB  ARG E 134      45.742 100.741  -6.092  1.00182.72           C  \\nATOM  10040  CG  ARG E 134      45.895 101.136  -7.537  1.00182.72           C  \\nATOM  10041  CD  ARG E 134      44.722 101.990  -7.979  1.00182.72           C  \\nATOM  10042  NE  ARG E 134      44.882 102.441  -9.358  1.00182.72           N  \\nATOM  10043  CZ  ARG E 134      43.982 103.154 -10.031  1.00182.72           C  \\nATOM  10044  NH1 ARG E 134      42.835 103.508  -9.458  1.00182.72           N  \\nATOM  10045  NH2 ARG E 134      44.239 103.521 -11.281  1.00182.72           N  \\nATOM  10046  N   ALA E 135      48.956 100.021  -4.373  1.00181.34           N  \\nATOM  10047  CA  ALA E 135      50.203 100.609  -3.857  1.00181.34           C  \\nATOM  10048  C   ALA E 135      51.401 100.780  -4.822  1.00181.34           C  \\nATOM  10049  O   ALA E 135      52.556 100.481  -4.397  1.00 49.58           O  \\nATOM  10050  CB  ALA E 135      50.634  99.837  -2.588  1.00 49.58           C  \\nATOM  10051  OXT ALA E 135      51.183 101.276  -5.962  1.00 49.58           O  \\nTER   10052      ALA E 135                                                      \\nATOM  10053  N   LYS F  16       8.938  85.187 -27.137  1.00192.20           N  \\nATOM  10054  CA  LYS F  16      10.295  85.240 -26.507  1.00192.20           C  \\nATOM  10055  C   LYS F  16      10.236  84.666 -25.086  1.00192.20           C  \\nATOM  10056  O   LYS F  16       9.232  84.821 -24.386  1.00192.20           O  \\nATOM  10057  CB  LYS F  16      10.803  86.685 -26.457  1.00 64.20           C  \\nATOM  10058  CG  LYS F  16      12.318  86.845 -26.499  1.00 64.20           C  \\nATOM  10059  CD  LYS F  16      12.709  88.281 -26.205  1.00 64.20           C  \\nATOM  10060  CE  LYS F  16      13.946  88.675 -26.969  1.00 64.20           C  \\nATOM  10061  NZ  LYS F  16      14.242  90.087 -26.732  1.00 64.20           N  \\nATOM  10062  N   ARG F  17      11.319  84.011 -24.669  1.00147.11           N  \\nATOM  10063  CA  ARG F  17      11.402  83.405 -23.345  1.00147.11           C  \\nATOM  10064  C   ARG F  17      11.407  84.459 -22.252  1.00147.11           C  \\nATOM  10065  O   ARG F  17      10.349  84.889 -21.793  1.00147.11           O  \\nATOM  10066  CB  ARG F  17      12.654  82.526 -23.241  1.00124.37           C  \\nATOM  10067  CG  ARG F  17      12.781  81.749 -21.941  1.00124.37           C  \\nATOM  10068  CD  ARG F  17      13.802  80.647 -22.076  1.00124.37           C  \\nATOM  10069  NE  ARG F  17      13.458  79.772 -23.194  1.00124.37           N  \\nATOM  10070  CZ  ARG F  17      14.285  79.452 -24.188  1.00124.37           C  \\nATOM  10071  NH1 ARG F  17      15.527  79.925 -24.216  1.00124.37           N  \\nATOM  10072  NH2 ARG F  17      13.851  78.694 -25.186  1.00124.37           N  \\nATOM  10073  N   HIS F  18      12.596  84.913 -21.878  1.00 88.38           N  \\nATOM  10074  CA  HIS F  18      12.732  85.899 -20.817  1.00 88.38           C  \\nATOM  10075  C   HIS F  18      13.943  86.792 -21.084  1.00 88.38           C  \\nATOM  10076  O   HIS F  18      14.383  86.959 -22.226  1.00 88.38           O  \\nATOM  10077  CB  HIS F  18      12.974  85.185 -19.464  1.00179.56           C  \\nATOM  10078  CG  HIS F  18      11.799  84.421 -18.925  1.00179.56           C  \\nATOM  10079  ND1 HIS F  18      11.467  83.154 -19.356  1.00179.56           N  \\nATOM  10080  CD2 HIS F  18      10.929  84.713 -17.927  1.00179.56           C  \\nATOM  10081  CE1 HIS F  18      10.449  82.697 -18.649  1.00179.56           C  \\nATOM  10082  NE2 HIS F  18      10.104  83.624 -17.774  1.00179.56           N  \\nATOM  10083  N   ARG F  19      14.447  87.358 -19.986  1.00143.68           N  \\nATOM  10084  CA  ARG F  19      15.629  88.205 -19.924  1.00143.68           C  \\nATOM  10085  C   ARG F  19      15.569  89.650 -20.394  1.00143.68           C  \\nATOM  10086  O   ARG F  19      15.128  89.950 -21.507  1.00143.68           O  \\nATOM  10087  CB  ARG F  19      16.820  87.501 -20.577  1.00166.80           C  \\nATOM  10088  CG  ARG F  19      18.168  87.948 -20.041  1.00166.80           C  \\nATOM  10089  CD  ARG F  19      19.066  88.449 -21.158  1.00166.80           C  \\nATOM  10090  NE  ARG F  19      20.465  88.532 -20.741  1.00166.80           N  \\nATOM  10091  CZ  ARG F  19      21.396  87.631 -21.054  1.00166.80           C  \\nATOM  10092  NH1 ARG F  19      21.079  86.572 -21.790  1.00166.80           N  \\nATOM  10093  NH2 ARG F  19      22.648  87.786 -20.635  1.00166.80           N  \\nATOM  10094  N   LYS F  20      16.011  90.532 -19.498  1.00 42.55           N  \\nATOM  10095  CA  LYS F  20      16.121  91.971 -19.748  1.00 42.55           C  \\nATOM  10096  C   LYS F  20      17.638  92.213 -19.648  1.00 42.55           C  \\nATOM  10097  O   LYS F  20      18.330  91.530 -18.876  1.00 42.55           O  \\nATOM  10098  CB  LYS F  20      15.387  92.784 -18.665  1.00 52.35           C  \\nATOM  10099  CG  LYS F  20      14.811  94.141 -19.145  1.00 52.35           C  \\nATOM  10100  CD  LYS F  20      15.869  95.140 -19.650  1.00 52.35           C  \\nATOM  10101  CE  LYS F  20      15.245  96.412 -20.251  1.00 52.35           C  \\nATOM  10102  NZ  LYS F  20      15.884  97.662 -19.745  1.00 52.35           N  \\nATOM  10103  N   VAL F  21      18.174  93.121 -20.461  1.00 29.96           N  \\nATOM  10104  CA  VAL F  21      19.609  93.380 -20.407  1.00 29.96           C  \\nATOM  10105  C   VAL F  21      19.939  94.271 -19.245  1.00 29.96           C  \\nATOM  10106  O   VAL F  21      19.278  95.290 -19.006  1.00 29.96           O  \\nATOM  10107  CB  VAL F  21      20.187  93.989 -21.704  1.00 26.17           C  \\nATOM  10108  CG1 VAL F  21      19.914  93.078 -22.839  1.00 26.17           C  \\nATOM  10109  CG2 VAL F  21      19.596  95.373 -21.982  1.00 26.17           C  \\nATOM  10110  N   LEU F  22      20.951  93.849 -18.504  1.00 30.71           N  \\nATOM  10111  CA  LEU F  22      21.403  94.592 -17.350  1.00 30.71           C  \\nATOM  10112  C   LEU F  22      22.598  95.402 -17.767  1.00 30.71           C  \\nATOM  10113  O   LEU F  22      23.573  94.844 -18.264  1.00 30.71           O  \\nATOM  10114  CB  LEU F  22      21.800  93.629 -16.245  1.00 19.20           C  \\nATOM  10115  CG  LEU F  22      20.620  92.847 -15.686  1.00 19.20           C  \\nATOM  10116  CD1 LEU F  22      21.092  91.500 -15.181  1.00 19.20           C  \\nATOM  10117  CD2 LEU F  22      19.954  93.647 -14.588  1.00 19.20           C  \\nATOM  10118  N   ARG F  23      22.491  96.720 -17.636  1.00 29.57           N  \\nATOM  10119  CA  ARG F  23      23.598  97.596 -17.984  1.00 29.57           C  \\nATOM  10120  C   ARG F  23      23.549  98.913 -17.259  1.00 29.57           C  \\nATOM  10121  O   ARG F  23      22.479  99.403 -16.915  1.00 29.57           O  \\nATOM  10122  CB  ARG F  23      23.699  97.823 -19.492  1.00 15.25           C  \\nATOM  10123  CG  ARG F  23      22.531  98.487 -20.130  1.00 15.25           C  \\nATOM  10124  CD  ARG F  23      22.723  98.396 -21.612  1.00 15.25           C  \\nATOM  10125  NE  ARG F  23      22.447  99.656 -22.304  1.00 15.25           N  \\nATOM  10126  CZ  ARG F  23      21.224 100.136 -22.544  1.00 15.25           C  \\nATOM  10127  NH1 ARG F  23      20.126  99.480 -22.145  1.00 15.25           N  \\nATOM  10128  NH2 ARG F  23      21.099 101.257 -23.231  1.00 15.25           N  \\nATOM  10129  N   ASP F  24      24.738  99.428 -16.954  1.00 17.59           N  \\nATOM  10130  CA  ASP F  24      24.906 100.702 -16.259  1.00 17.59           C  \\nATOM  10131  C   ASP F  24      24.298 100.748 -14.875  1.00 17.59           C  \\nATOM  10132  O   ASP F  24      24.037 101.818 -14.361  1.00 17.59           O  \\nATOM  10133  CB  ASP F  24      24.331 101.828 -17.106  1.00 44.09           C  \\nATOM  10134  CG  ASP F  24      25.037 103.123 -16.881  1.00 44.09           C  \\nATOM  10135  OD1 ASP F  24      26.277 103.141 -17.034  1.00 44.09           O  \\nATOM  10136  OD2 ASP F  24      24.360 104.119 -16.552  1.00 44.09           O  \\nATOM  10137  N   ASN F  25      24.087  99.598 -14.252  1.00 19.05           N  \\nATOM  10138  CA  ASN F  25      23.514  99.584 -12.922  1.00 19.05           C  \\nATOM  10139  C   ASN F  25      24.426 100.194 -11.876  1.00 19.05           C  \\nATOM  10140  O   ASN F  25      24.012 100.413 -10.741  1.00 19.05           O  \\nATOM  10141  CB  ASN F  25      23.085  98.183 -12.531  1.00 20.91           C  \\nATOM  10142  CG  ASN F  25      21.805  97.767 -13.230  1.00 20.91           C  \\nATOM  10143  OD1 ASN F  25      20.694  98.173 -12.845  1.00 20.91           O  \\nATOM  10144  ND2 ASN F  25      21.954  97.002 -14.300  1.00 20.91           N  \\nATOM  10145  N   ILE F  26      25.655 100.506 -12.266  1.00 33.36           N  \\nATOM  10146  CA  ILE F  26      26.603 101.125 -11.358  1.00 33.36           C  \\nATOM  10147  C   ILE F  26      26.011 102.472 -10.938  1.00 33.36           C  \\nATOM  10148  O   ILE F  26      26.311 102.961  -9.860  1.00 33.36           O  \\nATOM  10149  CB  ILE F  26      27.984 101.342 -12.053  1.00 13.03           C  \\nATOM  10150  CG1 ILE F  26      29.161 100.888 -11.159  1.00 13.03           C  \\nATOM  10151  CG2 ILE F  26      28.138 102.788 -12.525  1.00 13.03           C  \\nATOM  10152  CD1 ILE F  26      29.403 101.657  -9.887  1.00 13.03           C  \\nATOM  10153  N   GLN F  27      25.131 103.053 -11.753  1.00 28.86           N  \\nATOM  10154  CA  GLN F  27      24.549 104.351 -11.411  1.00 28.86           C  \\nATOM  10155  C   GLN F  27      23.457 104.271 -10.347  1.00 28.86           C  \\nATOM  10156  O   GLN F  27      22.930 105.305  -9.919  1.00 28.86           O  \\nATOM  10157  CB  GLN F  27      24.037 105.070 -12.653  1.00 32.34           C  \\nATOM  10158  CG  GLN F  27      25.091 105.316 -13.736  1.00 32.34           C  \\nATOM  10159  CD  GLN F  27      26.225 106.240 -13.303  1.00 32.34           C  \\nATOM  10160  OE1 GLN F  27      25.995 107.280 -12.680  1.00 32.34           O  \\nATOM  10161  NE2 GLN F  27      27.458 105.873 -13.656  1.00 32.34           N  \\nATOM  10162  N   GLY F  28      23.143 103.045  -9.908  1.00 26.28           N  \\nATOM  10163  CA  GLY F  28      22.154 102.821  -8.859  1.00 26.28           C  \\nATOM  10164  C   GLY F  28      22.779 103.227  -7.533  1.00 26.28           C  \\nATOM  10165  O   GLY F  28      22.143 103.228  -6.463  1.00 26.28           O  \\nATOM  10166  N   ILE F  29      24.082 103.478  -7.599  1.00 22.58           N  \\nATOM  10167  CA  ILE F  29      24.832 103.924  -6.455  1.00 22.58           C  \\nATOM  10168  C   ILE F  29      24.662 105.408  -6.624  1.00 22.58           C  \\nATOM  10169  O   ILE F  29      25.413 106.073  -7.337  1.00 22.58           O  \\nATOM  10170  CB  ILE F  29      26.313 103.526  -6.555  1.00 30.31           C  \\nATOM  10171  CG1 ILE F  29      26.434 102.018  -6.845  1.00 30.31           C  \\nATOM  10172  CG2 ILE F  29      27.042 103.912  -5.275  1.00 30.31           C  \\nATOM  10173  CD1 ILE F  29      25.647 101.129  -5.908  1.00 30.31           C  \\nATOM  10174  N   THR F  30      23.566 105.885  -6.057  1.00 21.16           N  \\nATOM  10175  CA  THR F  30      23.193 107.276  -6.124  1.00 21.16           C  \\nATOM  10176  C   THR F  30      24.086 108.232  -5.342  1.00 21.16           C  \\nATOM  10177  O   THR F  30      24.708 107.856  -4.339  1.00 21.16           O  \\nATOM  10178  CB  THR F  30      21.716 107.433  -5.689  1.00 29.66           C  \\nATOM  10179  OG1 THR F  30      21.512 106.908  -4.365  1.00 29.66           O  \\nATOM  10180  CG2 THR F  30      20.845 106.673  -6.649  1.00 29.66           C  \\nATOM  10181  N   LYS F  31      24.147 109.472  -5.829  1.00 26.39           N  \\nATOM  10182  CA  LYS F  31      24.905 110.536  -5.182  1.00 26.39           C  \\nATOM  10183  C   LYS F  31      24.515 110.551  -3.680  1.00 26.39           C  \\nATOM  10184  O   LYS F  31      25.391 110.462  -2.816  1.00 26.39           O  \\nATOM  10185  CB  LYS F  31      24.604 111.863  -5.882  1.00 24.79           C  \\nATOM  10186  CG  LYS F  31      25.421 113.035  -5.415  1.00 24.79           C  \\nATOM  10187  CD  LYS F  31      24.990 114.293  -6.125  1.00 24.79           C  \\nATOM  10188  CE  LYS F  31      25.504 115.531  -5.397  1.00 24.79           C  \\nATOM  10189  NZ  LYS F  31      24.964 116.787  -6.019  1.00 24.79           N  \\nATOM  10190  N   PRO F  32      23.194 110.623  -3.351  1.00 26.78           N  \\nATOM  10191  CA  PRO F  32      22.777 110.621  -1.944  1.00 26.78           C  \\nATOM  10192  C   PRO F  32      23.159 109.351  -1.178  1.00 26.78           C  \\nATOM  10193  O   PRO F  32      23.494 109.426  -0.011  1.00 26.78           O  \\nATOM  10194  CB  PRO F  32      21.258 110.789  -2.037  1.00 24.44           C  \\nATOM  10195  CG  PRO F  32      20.914 110.372  -3.420  1.00 24.44           C  \\nATOM  10196  CD  PRO F  32      22.034 110.972  -4.193  1.00 24.44           C  \\nATOM  10197  N   ALA F  33      23.110 108.185  -1.808  1.00 17.28           N  \\nATOM  10198  CA  ALA F  33      23.504 106.983  -1.089  1.00 17.28           C  \\nATOM  10199  C   ALA F  33      24.979 107.052  -0.693  1.00 17.28           C  \\nATOM  10200  O   ALA F  33      25.338 106.752   0.446  1.00 17.28           O  \\nATOM  10201  CB  ALA F  33      23.220 105.764  -1.907  1.00  5.00           C  \\nATOM  10202  N   ILE F  34      25.834 107.472  -1.621  1.00  6.09           N  \\nATOM  10203  CA  ILE F  34      27.271 107.616  -1.326  1.00  6.09           C  \\nATOM  10204  C   ILE F  34      27.508 108.706  -0.267  1.00  6.09           C  \\nATOM  10205  O   ILE F  34      28.433 108.605   0.549  1.00  6.09           O  \\nATOM  10206  CB  ILE F  34      28.054 108.069  -2.569  1.00  8.45           C  \\nATOM  10207  CG1 ILE F  34      28.041 106.979  -3.647  1.00  8.45           C  \\nATOM  10208  CG2 ILE F  34      29.450 108.574  -2.169  1.00  8.45           C  \\nATOM  10209  CD1 ILE F  34      28.477 107.478  -4.992  1.00  8.45           C  \\nATOM  10210  N   ARG F  35      26.740 109.799  -0.345  1.00 17.00           N  \\nATOM  10211  CA  ARG F  35      26.884 110.890   0.627  1.00 17.00           C  \\nATOM  10212  C   ARG F  35      26.536 110.379   2.030  1.00 17.00           C  \\nATOM  10213  O   ARG F  35      27.162 110.752   3.014  1.00 17.00           O  \\nATOM  10214  CB  ARG F  35      26.045 112.112   0.220  1.00 62.74           C  \\nATOM  10215  CG  ARG F  35      26.516 113.417   0.867  1.00 62.74           C  \\nATOM  10216  CD  ARG F  35      25.937 114.664   0.219  1.00 62.74           C  \\nATOM  10217  NE  ARG F  35      24.487 114.649   0.316  1.00 62.74           N  \\nATOM  10218  CZ  ARG F  35      23.671 114.785  -0.724  1.00 62.74           C  \\nATOM  10219  NH1 ARG F  35      24.162 114.965  -1.945  1.00 62.74           N  \\nATOM  10220  NH2 ARG F  35      22.363 114.656  -0.555  1.00 62.74           N  \\nATOM  10221  N   ARG F  36      25.571 109.471   2.108  1.00 12.74           N  \\nATOM  10222  CA  ARG F  36      25.188 108.885   3.382  1.00 12.74           C  \\nATOM  10223  C   ARG F  36      26.345 108.071   3.926  1.00 12.74           C  \\nATOM  10224  O   ARG F  36      26.689 108.186   5.099  1.00 12.74           O  \\nATOM  10225  CB  ARG F  36      23.968 107.969   3.220  1.00 20.32           C  \\nATOM  10226  CG  ARG F  36      22.630 108.678   3.176  1.00 20.32           C  \\nATOM  10227  CD  ARG F  36      21.492 107.688   3.281  1.00 20.32           C  \\nATOM  10228  NE  ARG F  36      21.263 106.880   2.079  1.00 20.32           N  \\nATOM  10229  CZ  ARG F  36      20.668 107.308   0.959  1.00 20.32           C  \\nATOM  10230  NH1 ARG F  36      20.245 108.561   0.839  1.00 20.32           N  \\nATOM  10231  NH2 ARG F  36      20.446 106.447  -0.034  1.00 20.32           N  \\nATOM  10232  N   LEU F  37      26.915 107.214   3.078  1.00 18.40           N  \\nATOM  10233  CA  LEU F  37      28.053 106.378   3.467  1.00 18.40           C  \\nATOM  10234  C   LEU F  37      29.188 107.218   4.073  1.00 18.40           C  \\nATOM  10235  O   LEU F  37      29.695 106.897   5.152  1.00 18.40           O  \\nATOM  10236  CB  LEU F  37      28.544 105.580   2.258  1.00  5.00           C  \\nATOM  10237  CG  LEU F  37      27.663 104.375   1.937  1.00  5.00           C  \\nATOM  10238  CD1 LEU F  37      27.677 103.991   0.476  1.00  5.00           C  \\nATOM  10239  CD2 LEU F  37      28.134 103.262   2.806  1.00  5.00           C  \\nATOM  10240  N   ALA F  38      29.536 108.321   3.399  1.00 17.35           N  \\nATOM  10241  CA  ALA F  38      30.571 109.260   3.858  1.00 17.35           C  \\nATOM  10242  C   ALA F  38      30.269 109.797   5.263  1.00 17.35           C  \\nATOM  10243  O   ALA F  38      31.163 109.915   6.108  1.00 17.35           O  \\nATOM  10244  CB  ALA F  38      30.700 110.412   2.873  1.00  5.00           C  \\nATOM  10245  N   ARG F  39      29.015 110.174   5.476  1.00 14.06           N  \\nATOM  10246  CA  ARG F  39      28.547 110.679   6.760  1.00 14.06           C  \\nATOM  10247  C   ARG F  39      28.796 109.703   7.889  1.00 14.06           C  \\nATOM  10248  O   ARG F  39      29.216 110.108   8.970  1.00 14.06           O  \\nATOM  10249  CB  ARG F  39      27.054 110.955   6.693  1.00 11.94           C  \\nATOM  10250  CG  ARG F  39      26.694 112.033   5.730  1.00 11.94           C  \\nATOM  10251  CD  ARG F  39      27.337 113.331   6.113  1.00 11.94           C  \\nATOM  10252  NE  ARG F  39      26.728 114.409   5.371  1.00 11.94           N  \\nATOM  10253  CZ  ARG F  39      27.388 115.259   4.607  1.00 11.94           C  \\nATOM  10254  NH1 ARG F  39      28.696 115.166   4.476  1.00 11.94           N  \\nATOM  10255  NH2 ARG F  39      26.731 116.238   4.007  1.00 11.94           N  \\nATOM  10256  N   ARG F  40      28.425 108.442   7.687  1.00 14.83           N  \\nATOM  10257  CA  ARG F  40      28.655 107.433   8.715  1.00 14.83           C  \\nATOM  10258  C   ARG F  40      30.163 107.347   8.875  1.00 14.83           C  \\nATOM  10259  O   ARG F  40      30.676 107.161   9.984  1.00 14.83           O  \\nATOM  10260  CB  ARG F  40      28.054 106.083   8.307  1.00 13.76           C  \\nATOM  10261  CG  ARG F  40      28.108 105.022   9.397  1.00 13.76           C  \\nATOM  10262  CD  ARG F  40      27.288 103.820   9.005  1.00 13.76           C  \\nATOM  10263  NE  ARG F  40      25.898 103.918   9.441  1.00 13.76           N  \\nATOM  10264  CZ  ARG F  40      24.872 103.312   8.839  1.00 13.76           C  \\nATOM  10265  NH1 ARG F  40      25.055 102.568   7.756  1.00 13.76           N  \\nATOM  10266  NH2 ARG F  40      23.645 103.434   9.314  1.00 13.76           N  \\nATOM  10267  N   GLY F  41      30.855 107.521   7.748  1.00  7.01           N  \\nATOM  10268  CA  GLY F  41      32.298 107.545   7.731  1.00  7.01           C  \\nATOM  10269  C   GLY F  41      32.832 108.824   8.361  1.00  7.01           C  \\nATOM  10270  O   GLY F  41      34.038 109.050   8.388  1.00  7.01           O  \\nATOM  10271  N   GLY F  42      31.946 109.672   8.872  1.00 23.78           N  \\nATOM  10272  CA  GLY F  42      32.367 110.892   9.546  1.00 23.78           C  \\nATOM  10273  C   GLY F  42      32.914 112.007   8.686  1.00 23.78           C  \\nATOM  10274  O   GLY F  42      33.626 112.879   9.188  1.00 23.78           O  \\nATOM  10275  N   VAL F  43      32.597 111.962   7.396  1.00  9.78           N  \\nATOM  10276  CA  VAL F  43      33.038 112.956   6.439  1.00  9.78           C  \\nATOM  10277  C   VAL F  43      32.069 114.131   6.384  1.00  9.78           C  \\nATOM  10278  O   VAL F  43      30.918 113.966   6.012  1.00  9.78           O  \\nATOM  10279  CB  VAL F  43      33.133 112.341   5.052  1.00  5.96           C  \\nATOM  10280  CG1 VAL F  43      33.586 113.366   4.051  1.00  5.96           C  \\nATOM  10281  CG2 VAL F  43      34.060 111.180   5.073  1.00  5.96           C  \\nATOM  10282  N   LYS F  44      32.582 115.331   6.647  1.00 19.53           N  \\nATOM  10283  CA  LYS F  44      31.785 116.558   6.654  1.00 19.53           C  \\nATOM  10284  C   LYS F  44      31.575 117.260   5.293  1.00 19.53           C  \\nATOM  10285  O   LYS F  44      30.504 117.824   5.027  1.00 19.53           O  \\nATOM  10286  CB  LYS F  44      32.406 117.533   7.641  1.00 25.19           C  \\nATOM  10287  CG  LYS F  44      31.707 118.849   7.711  1.00 25.19           C  \\nATOM  10288  CD  LYS F  44      32.438 119.818   8.586  1.00 25.19           C  \\nATOM  10289  CE  LYS F  44      31.564 121.005   8.818  1.00 25.19           C  \\nATOM  10290  NZ  LYS F  44      32.210 121.925   9.759  1.00 25.19           N  \\nATOM  10291  N   ARG F  45      32.598 117.264   4.444  1.00 19.67           N  \\nATOM  10292  CA  ARG F  45      32.486 117.902   3.141  1.00 19.67           C  \\nATOM  10293  C   ARG F  45      33.031 116.981   2.039  1.00 19.67           C  \\nATOM  10294  O   ARG F  45      34.018 116.260   2.250  1.00 19.67           O  \\nATOM  10295  CB  ARG F  45      33.221 119.233   3.165  1.00 20.29           C  \\nATOM  10296  CG  ARG F  45      32.677 120.257   2.221  1.00 20.29           C  \\nATOM  10297  CD  ARG F  45      33.425 121.547   2.382  1.00 20.29           C  \\nATOM  10298  NE  ARG F  45      32.822 122.577   1.556  1.00 20.29           N  \\nATOM  10299  CZ  ARG F  45      33.331 123.040   0.413  1.00 20.29           C  \\nATOM  10300  NH1 ARG F  45      34.480 122.582  -0.061  1.00 20.29           N  \\nATOM  10301  NH2 ARG F  45      32.624 123.907  -0.312  1.00 20.29           N  \\nATOM  10302  N   ILE F  46      32.424 117.067   0.849  1.00 31.51           N  \\nATOM  10303  CA  ILE F  46      32.767 116.215  -0.291  1.00 31.51           C  \\nATOM  10304  C   ILE F  46      32.960 116.882  -1.661  1.00 31.51           C  \\nATOM  10305  O   ILE F  46      32.056 117.574  -2.144  1.00 31.51           O  \\nATOM  10306  CB  ILE F  46      31.625 115.212  -0.499  1.00 10.31           C  \\nATOM  10307  CG1 ILE F  46      31.251 114.533   0.808  1.00 10.31           C  \\nATOM  10308  CG2 ILE F  46      31.991 114.182  -1.514  1.00 10.31           C  \\nATOM  10309  CD1 ILE F  46      30.068 113.649   0.686  1.00 10.31           C  \\nATOM  10310  N   SER F  47      34.087 116.594  -2.328  1.00 28.14           N  \\nATOM  10311  CA  SER F  47      34.370 117.113  -3.680  1.00 28.14           C  \\nATOM  10312  C   SER F  47      33.459 116.469  -4.749  1.00 28.14           C  \\nATOM  10313  O   SER F  47      33.251 115.258  -4.750  1.00 28.14           O  \\nATOM  10314  CB  SER F  47      35.826 116.828  -4.052  1.00 13.08           C  \\nATOM  10315  OG  SER F  47      35.989 116.693  -5.469  1.00 13.08           O  \\nATOM  10316  N   GLY F  48      33.023 117.247  -5.732  1.00 17.12           N  \\nATOM  10317  CA  GLY F  48      32.154 116.695  -6.757  1.00 17.12           C  \\nATOM  10318  C   GLY F  48      32.665 115.480  -7.525  1.00 17.12           C  \\nATOM  10319  O   GLY F  48      31.878 114.750  -8.166  1.00 17.12           O  \\nATOM  10320  N   LEU F  49      33.974 115.231  -7.439  1.00 19.24           N  \\nATOM  10321  CA  LEU F  49      34.600 114.109  -8.138  1.00 19.24           C  \\nATOM  10322  C   LEU F  49      34.626 112.781  -7.362  1.00 19.24           C  \\nATOM  10323  O   LEU F  49      35.056 111.736  -7.869  1.00 19.24           O  \\nATOM  10324  CB  LEU F  49      36.010 114.516  -8.521  1.00 19.82           C  \\nATOM  10325  CG  LEU F  49      36.051 115.550  -9.633  1.00 19.82           C  \\nATOM  10326  CD1 LEU F  49      37.473 115.903  -9.906  1.00 19.82           C  \\nATOM  10327  CD2 LEU F  49      35.417 114.964 -10.888  1.00 19.82           C  \\nATOM  10328  N   ILE F  50      34.150 112.841  -6.130  1.00 18.75           N  \\nATOM  10329  CA  ILE F  50      34.114 111.700  -5.259  1.00 18.75           C  \\nATOM  10330  C   ILE F  50      33.115 110.643  -5.698  1.00 18.75           C  \\nATOM  10331  O   ILE F  50      33.383 109.450  -5.575  1.00 18.75           O  \\nATOM  10332  CB  ILE F  50      33.758 112.150  -3.841  1.00 16.04           C  \\nATOM  10333  CG1 ILE F  50      34.962 112.831  -3.173  1.00 16.04           C  \\nATOM  10334  CG2 ILE F  50      33.275 110.987  -3.015  1.00 16.04           C  \\nATOM  10335  CD1 ILE F  50      36.081 111.915  -2.753  1.00 16.04           C  \\nATOM  10336  N   TYR F  51      31.988 111.060  -6.263  1.00 11.41           N  \\nATOM  10337  CA  TYR F  51      30.965 110.087  -6.626  1.00 11.41           C  \\nATOM  10338  C   TYR F  51      31.409 109.103  -7.657  1.00 11.41           C  \\nATOM  10339  O   TYR F  51      31.166 107.907  -7.507  1.00 11.41           O  \\nATOM  10340  CB  TYR F  51      29.643 110.763  -6.985  1.00 12.99           C  \\nATOM  10341  CG  TYR F  51      29.258 111.819  -5.971  1.00 12.99           C  \\nATOM  10342  CD1 TYR F  51      28.882 111.480  -4.670  1.00 12.99           C  \\nATOM  10343  CD2 TYR F  51      29.364 113.173  -6.297  1.00 12.99           C  \\nATOM  10344  CE1 TYR F  51      28.631 112.486  -3.713  1.00 12.99           C  \\nATOM  10345  CE2 TYR F  51      29.118 114.178  -5.368  1.00 12.99           C  \\nATOM  10346  CZ  TYR F  51      28.757 113.844  -4.080  1.00 12.99           C  \\nATOM  10347  OH  TYR F  51      28.547 114.885  -3.186  1.00 12.99           O  \\nATOM  10348  N   GLU F  52      32.125 109.581  -8.670  1.00 19.85           N  \\nATOM  10349  CA  GLU F  52      32.604 108.652  -9.681  1.00 19.85           C  \\nATOM  10350  C   GLU F  52      33.736 107.771  -9.166  1.00 19.85           C  \\nATOM  10351  O   GLU F  52      33.735 106.576  -9.447  1.00 19.85           O  \\nATOM  10352  CB  GLU F  52      32.943 109.340 -11.002  1.00 66.51           C  \\nATOM  10353  CG  GLU F  52      31.711 109.523 -11.923  1.00 66.51           C  \\nATOM  10354  CD  GLU F  52      30.912 108.228 -12.197  1.00 66.51           C  \\nATOM  10355  OE1 GLU F  52      31.514 107.129 -12.261  1.00 66.51           O  \\nATOM  10356  OE2 GLU F  52      29.674 108.311 -12.368  1.00 66.51           O  \\nATOM  10357  N   GLU F  53      34.648 108.335  -8.365  1.00 14.28           N  \\nATOM  10358  CA  GLU F  53      35.742 107.559  -7.775  1.00 14.28           C  \\nATOM  10359  C   GLU F  53      35.179 106.403  -6.973  1.00 14.28           C  \\nATOM  10360  O   GLU F  53      35.589 105.245  -7.150  1.00 14.28           O  \\nATOM  10361  CB  GLU F  53      36.584 108.391  -6.815  1.00 34.19           C  \\nATOM  10362  CG  GLU F  53      37.735 109.135  -7.453  1.00 34.19           C  \\nATOM  10363  CD  GLU F  53      38.864 108.248  -7.967  1.00 34.19           C  \\nATOM  10364  OE1 GLU F  53      39.244 107.266  -7.283  1.00 34.19           O  \\nATOM  10365  OE2 GLU F  53      39.391 108.560  -9.059  1.00 34.19           O  \\nATOM  10366  N   THR F  54      34.256 106.731  -6.070  1.00 12.11           N  \\nATOM  10367  CA  THR F  54      33.626 105.747  -5.216  1.00 12.11           C  \\nATOM  10368  C   THR F  54      32.982 104.652  -6.048  1.00 12.11           C  \\nATOM  10369  O   THR F  54      33.121 103.470  -5.737  1.00 12.11           O  \\nATOM  10370  CB  THR F  54      32.576 106.379  -4.315  1.00 10.89           C  \\nATOM  10371  OG1 THR F  54      33.048 107.651  -3.860  1.00 10.89           O  \\nATOM  10372  CG2 THR F  54      32.321 105.498  -3.103  1.00 10.89           C  \\nATOM  10373  N   ARG F  55      32.285 105.018  -7.113  1.00 15.61           N  \\nATOM  10374  CA  ARG F  55      31.683 103.990  -7.936  1.00 15.61           C  \\nATOM  10375  C   ARG F  55      32.784 103.032  -8.414  1.00 15.61           C  \\nATOM  10376  O   ARG F  55      32.719 101.830  -8.176  1.00 15.61           O  \\nATOM  10377  CB  ARG F  55      30.882 104.614  -9.094  1.00 17.08           C  \\nATOM  10378  CG  ARG F  55      29.606 105.292  -8.603  1.00 17.08           C  \\nATOM  10379  CD  ARG F  55      28.696 105.737  -9.726  1.00 17.08           C  \\nATOM  10380  NE  ARG F  55      27.645 106.602  -9.182  1.00 17.08           N  \\nATOM  10381  CZ  ARG F  55      27.609 107.927  -9.315  1.00 17.08           C  \\nATOM  10382  NH1 ARG F  55      28.557 108.568  -9.989  1.00 17.08           N  \\nATOM  10383  NH2 ARG F  55      26.661 108.611  -8.702  1.00 17.08           N  \\nATOM  10384  N   GLY F  56      33.835 103.575  -9.002  1.00 16.80           N  \\nATOM  10385  CA  GLY F  56      34.915 102.727  -9.461  1.00 16.80           C  \\nATOM  10386  C   GLY F  56      35.466 101.806  -8.384  1.00 16.80           C  \\nATOM  10387  O   GLY F  56      35.603 100.607  -8.605  1.00 16.80           O  \\nATOM  10388  N   VAL F  57      35.766 102.362  -7.216  1.00 14.74           N  \\nATOM  10389  CA  VAL F  57      36.301 101.603  -6.104  1.00 14.74           C  \\nATOM  10390  C   VAL F  57      35.385 100.441  -5.725  1.00 14.74           C  \\nATOM  10391  O   VAL F  57      35.830  99.315  -5.500  1.00 14.74           O  \\nATOM  10392  CB  VAL F  57      36.509 102.515  -4.909  1.00  7.90           C  \\nATOM  10393  CG1 VAL F  57      36.617 101.687  -3.626  1.00  7.90           C  \\nATOM  10394  CG2 VAL F  57      37.747 103.342  -5.119  1.00  7.90           C  \\nATOM  10395  N   LEU F  58      34.098 100.720  -5.649  1.00 15.55           N  \\nATOM  10396  CA  LEU F  58      33.129  99.698  -5.337  1.00 15.55           C  \\nATOM  10397  C   LEU F  58      33.045  98.638  -6.439  1.00 15.55           C  \\nATOM  10398  O   LEU F  58      33.009  97.451  -6.143  1.00 15.55           O  \\nATOM  10399  CB  LEU F  58      31.767 100.342  -5.137  1.00 11.46           C  \\nATOM  10400  CG  LEU F  58      30.646  99.372  -4.809  1.00 11.46           C  \\nATOM  10401  CD1 LEU F  58      30.972  98.671  -3.495  1.00 11.46           C  \\nATOM  10402  CD2 LEU F  58      29.315 100.102  -4.749  1.00 11.46           C  \\nATOM  10403  N   LYS F  59      33.008  99.038  -7.706  1.00 16.41           N  \\nATOM  10404  CA  LYS F  59      32.926  98.033  -8.772  1.00 16.41           C  \\nATOM  10405  C   LYS F  59      33.981  96.960  -8.583  1.00 16.41           C  \\nATOM  10406  O   LYS F  59      33.679  95.769  -8.581  1.00 16.41           O  \\nATOM  10407  CB  LYS F  59      33.067  98.629 -10.162  1.00 33.67           C  \\nATOM  10408  CG  LYS F  59      32.253  97.825 -11.150  1.00 33.67           C  \\nATOM  10409  CD  LYS F  59      32.350  98.307 -12.580  1.00 33.67           C  \\nATOM  10410  CE  LYS F  59      33.504  97.629 -13.297  1.00 33.67           C  \\nATOM  10411  NZ  LYS F  59      33.556  97.985 -14.747  1.00 33.67           N  \\nATOM  10412  N   VAL F  60      35.202  97.404  -8.316  1.00 12.00           N  \\nATOM  10413  CA  VAL F  60      36.321  96.513  -8.097  1.00 12.00           C  \\nATOM  10414  C   VAL F  60      36.153  95.674  -6.841  1.00 12.00           C  \\nATOM  10415  O   VAL F  60      36.506  94.496  -6.819  1.00 12.00           O  \\nATOM  10416  CB  VAL F  60      37.599  97.294  -7.942  1.00 14.82           C  \\nATOM  10417  CG1 VAL F  60      38.712  96.354  -7.607  1.00 14.82           C  \\nATOM  10418  CG2 VAL F  60      37.912  98.037  -9.217  1.00 14.82           C  \\nATOM  10419  N   PHE F  61      35.679  96.291  -5.770  1.00  6.74           N  \\nATOM  10420  CA  PHE F  61      35.506  95.543  -4.556  1.00  6.74           C  \\nATOM  10421  C   PHE F  61      34.592  94.386  -4.847  1.00  6.74           C  \\nATOM  10422  O   PHE F  61      34.901  93.248  -4.533  1.00  6.74           O  \\nATOM  10423  CB  PHE F  61      34.897  96.399  -3.457  1.00  8.94           C  \\nATOM  10424  CG  PHE F  61      34.672  95.638  -2.160  1.00  8.94           C  \\nATOM  10425  CD1 PHE F  61      35.725  95.470  -1.234  1.00  8.94           C  \\nATOM  10426  CD2 PHE F  61      33.428  95.075  -1.870  1.00  8.94           C  \\nATOM  10427  CE1 PHE F  61      35.523  94.749  -0.046  1.00  8.94           C  \\nATOM  10428  CE2 PHE F  61      33.229  94.365  -0.704  1.00  8.94           C  \\nATOM  10429  CZ  PHE F  61      34.266  94.197   0.216  1.00  8.94           C  \\nATOM  10430  N   LEU F  62      33.480  94.690  -5.496  1.00 10.92           N  \\nATOM  10431  CA  LEU F  62      32.486  93.699  -5.836  1.00 10.92           C  \\nATOM  10432  C   LEU F  62      32.956  92.624  -6.796  1.00 10.92           C  \\nATOM  10433  O   LEU F  62      32.675  91.460  -6.591  1.00 10.92           O  \\nATOM  10434  CB  LEU F  62      31.238  94.391  -6.386  1.00 14.47           C  \\nATOM  10435  CG  LEU F  62      30.276  94.927  -5.323  1.00 14.47           C  \\nATOM  10436  CD1 LEU F  62      29.194  95.726  -5.989  1.00 14.47           C  \\nATOM  10437  CD2 LEU F  62      29.654  93.778  -4.529  1.00 14.47           C  \\nATOM  10438  N   GLU F  63      33.618  93.005  -7.876  1.00 16.06           N  \\nATOM  10439  CA  GLU F  63      34.106  92.006  -8.820  1.00 16.06           C  \\nATOM  10440  C   GLU F  63      34.983  90.979  -8.098  1.00 16.06           C  \\nATOM  10441  O   GLU F  63      34.899  89.775  -8.340  1.00 16.06           O  \\nATOM  10442  CB  GLU F  63      34.975  92.644  -9.883  1.00 50.87           C  \\nATOM  10443  CG  GLU F  63      34.388  93.817 -10.585  1.00 50.87           C  \\nATOM  10444  CD  GLU F  63      35.439  94.532 -11.412  1.00 50.87           C  \\nATOM  10445  OE1 GLU F  63      36.645  94.404 -11.085  1.00 50.87           O  \\nATOM  10446  OE2 GLU F  63      35.067  95.215 -12.389  1.00 50.87           O  \\nATOM  10447  N   ASN F  64      35.843  91.466  -7.216  1.00 15.51           N  \\nATOM  10448  CA  ASN F  64      36.726  90.574  -6.508  1.00 15.51           C  \\nATOM  10449  C   ASN F  64      35.964  89.585  -5.630  1.00 15.51           C  \\nATOM  10450  O   ASN F  64      36.136  88.373  -5.791  1.00 15.51           O  \\nATOM  10451  CB  ASN F  64      37.794  91.376  -5.753  1.00 20.15           C  \\nATOM  10452  CG  ASN F  64      38.692  92.233  -6.698  1.00 20.15           C  \\nATOM  10453  OD1 ASN F  64      38.579  92.195  -7.936  1.00 20.15           O  \\nATOM  10454  ND2 ASN F  64      39.567  93.022  -6.096  1.00 20.15           N  \\nATOM  10455  N   VAL F  65      35.057  90.072  -4.780  1.00 25.05           N  \\nATOM  10456  CA  VAL F  65      34.286  89.165  -3.927  1.00 25.05           C  \\nATOM  10457  C   VAL F  65      33.416  88.266  -4.782  1.00 25.05           C  \\nATOM  10458  O   VAL F  65      33.416  87.069  -4.598  1.00 25.05           O  \\nATOM  10459  CB  VAL F  65      33.383  89.883  -2.883  1.00 16.86           C  \\nATOM  10460  CG1 VAL F  65      33.152  88.971  -1.687  1.00 16.86           C  \\nATOM  10461  CG2 VAL F  65      34.015  91.134  -2.401  1.00 16.86           C  \\nATOM  10462  N   ILE F  66      32.698  88.829  -5.743  1.00 18.02           N  \\nATOM  10463  CA  ILE F  66      31.850  88.013  -6.600  1.00 18.02           C  \\nATOM  10464  C   ILE F  66      32.668  86.959  -7.334  1.00 18.02           C  \\nATOM  10465  O   ILE F  66      32.261  85.827  -7.358  1.00 18.02           O  \\nATOM  10466  CB  ILE F  66      31.010  88.858  -7.606  1.00 15.13           C  \\nATOM  10467  CG1 ILE F  66      29.954  89.678  -6.856  1.00 15.13           C  \\nATOM  10468  CG2 ILE F  66      30.309  87.948  -8.603  1.00 15.13           C  \\nATOM  10469  CD1 ILE F  66      29.204  90.662  -7.721  1.00 15.13           C  \\nATOM  10470  N   ARG F  67      33.820  87.306  -7.905  1.00 21.75           N  \\nATOM  10471  CA  ARG F  67      34.646  86.318  -8.592  1.00 21.75           C  \\nATOM  10472  C   ARG F  67      34.938  85.120  -7.696  1.00 21.75           C  \\nATOM  10473  O   ARG F  67      34.674  83.973  -8.053  1.00 21.75           O  \\nATOM  10474  CB  ARG F  67      35.983  86.894  -9.039  1.00 59.86           C  \\nATOM  10475  CG  ARG F  67      36.930  85.787  -9.512  1.00 59.86           C  \\nATOM  10476  CD  ARG F  67      38.190  86.310 -10.128  1.00 59.86           C  \\nATOM  10477  NE  ARG F  67      37.873  87.272 -11.175  1.00 59.86           N  \\nATOM  10478  CZ  ARG F  67      38.083  88.581 -11.060  1.00 59.86           C  \\nATOM  10479  NH1 ARG F  67      38.623  89.071  -9.942  1.00 59.86           N  \\nATOM  10480  NH2 ARG F  67      37.712  89.405 -12.036  1.00 59.86           N  \\nATOM  10481  N   ASP F  68      35.520  85.375  -6.542  1.00 20.87           N  \\nATOM  10482  CA  ASP F  68      35.806  84.272  -5.657  1.00 20.87           C  \\nATOM  10483  C   ASP F  68      34.538  83.508  -5.310  1.00 20.87           C  \\nATOM  10484  O   ASP F  68      34.480  82.300  -5.491  1.00 20.87           O  \\nATOM  10485  CB  ASP F  68      36.488  84.761  -4.383  1.00 38.39           C  \\nATOM  10486  CG  ASP F  68      37.870  85.310  -4.642  1.00 38.39           C  \\nATOM  10487  OD1 ASP F  68      38.397  85.136  -5.772  1.00 38.39           O  \\nATOM  10488  OD2 ASP F  68      38.419  85.923  -3.705  1.00 38.39           O  \\nATOM  10489  N   ALA F  69      33.507  84.220  -4.868  1.00 21.97           N  \\nATOM  10490  CA  ALA F  69      32.251  83.589  -4.483  1.00 21.97           C  \\nATOM  10491  C   ALA F  69      31.738  82.668  -5.587  1.00 21.97           C  \\nATOM  10492  O   ALA F  69      31.536  81.474  -5.365  1.00 21.97           O  \\nATOM  10493  CB  ALA F  69      31.226  84.645  -4.114  1.00  8.49           C  \\nATOM  10494  N   VAL F  70      31.635  83.198  -6.799  1.00 21.13           N  \\nATOM  10495  CA  VAL F  70      31.189  82.419  -7.942  1.00 21.13           C  \\nATOM  10496  C   VAL F  70      32.165  81.275  -8.235  1.00 21.13           C  \\nATOM  10497  O   VAL F  70      31.753  80.216  -8.675  1.00 21.13           O  \\nATOM  10498  CB  VAL F  70      30.973  83.302  -9.185  1.00  7.36           C  \\nATOM  10499  CG1 VAL F  70      30.952  82.437 -10.455  1.00  7.36           C  \\nATOM  10500  CG2 VAL F  70      29.656  84.095  -9.041  1.00  7.36           C  \\nATOM  10501  N   THR F  71      33.454  81.472  -7.984  1.00 22.82           N  \\nATOM  10502  CA  THR F  71      34.395  80.376  -8.177  1.00 22.82           C  \\nATOM  10503  C   THR F  71      34.030  79.252  -7.191  1.00 22.82           C  \\nATOM  10504  O   THR F  71      33.956  78.085  -7.565  1.00 22.82           O  \\nATOM  10505  CB  THR F  71      35.867  80.825  -8.001  1.00  9.91           C  \\nATOM  10506  OG1 THR F  71      36.155  81.885  -8.930  1.00  9.91           O  \\nATOM  10507  CG2 THR F  71      36.813  79.653  -8.283  1.00  9.91           C  \\nATOM  10508  N   TYR F  72      33.726  79.625  -5.954  1.00 29.23           N  \\nATOM  10509  CA  TYR F  72      33.321  78.661  -4.939  1.00 29.23           C  \\nATOM  10510  C   TYR F  72      32.083  77.894  -5.370  1.00 29.23           C  \\nATOM  10511  O   TYR F  72      31.938  76.710  -5.052  1.00 29.23           O  \\nATOM  10512  CB  TYR F  72      33.069  79.356  -3.607  1.00 23.24           C  \\nATOM  10513  CG  TYR F  72      34.317  79.440  -2.768  1.00 23.24           C  \\nATOM  10514  CD1 TYR F  72      34.936  78.284  -2.275  1.00 23.24           C  \\nATOM  10515  CD2 TYR F  72      34.893  80.673  -2.451  1.00 23.24           C  \\nATOM  10516  CE1 TYR F  72      36.095  78.362  -1.482  1.00 23.24           C  \\nATOM  10517  CE2 TYR F  72      36.062  80.751  -1.653  1.00 23.24           C  \\nATOM  10518  CZ  TYR F  72      36.641  79.601  -1.178  1.00 23.24           C  \\nATOM  10519  OH  TYR F  72      37.733  79.698  -0.366  1.00 23.24           O  \\nATOM  10520  N   THR F  73      31.189  78.596  -6.068  1.00 20.62           N  \\nATOM  10521  CA  THR F  73      29.952  78.030  -6.596  1.00 20.62           C  \\nATOM  10522  C   THR F  73      30.203  76.986  -7.672  1.00 20.62           C  \\nATOM  10523  O   THR F  73      29.734  75.859  -7.574  1.00 20.62           O  \\nATOM  10524  CB  THR F  73      29.123  79.114  -7.241  1.00 16.30           C  \\nATOM  10525  OG1 THR F  73      28.995  80.184  -6.320  1.00 16.30           O  \\nATOM  10526  CG2 THR F  73      27.747  78.603  -7.582  1.00 16.30           C  \\nATOM  10527  N   GLU F  74      30.869  77.409  -8.745  1.00 31.33           N  \\nATOM  10528  CA  GLU F  74      31.185  76.526  -9.855  1.00 31.33           C  \\nATOM  10529  C   GLU F  74      31.865  75.274  -9.321  1.00 31.33           C  \\nATOM  10530  O   GLU F  74      31.587  74.170  -9.776  1.00 31.33           O  \\nATOM  10531  CB  GLU F  74      32.066  77.240 -10.902  1.00 86.20           C  \\nATOM  10532  CG  GLU F  74      31.373  78.443 -11.579  1.00 86.20           C  \\nATOM  10533  CD  GLU F  74      32.071  78.973 -12.841  1.00 86.20           C  \\nATOM  10534  OE1 GLU F  74      32.941  79.874 -12.733  1.00 86.20           O  \\nATOM  10535  OE2 GLU F  74      31.705  78.523 -13.953  1.00 86.20           O  \\nATOM  10536  N   HIS F  75      32.716  75.425  -8.317  1.00 30.33           N  \\nATOM  10537  CA  HIS F  75      33.376  74.259  -7.780  1.00 30.33           C  \\nATOM  10538  C   HIS F  75      32.425  73.237  -7.150  1.00 30.33           C  \\nATOM  10539  O   HIS F  75      32.651  72.020  -7.193  1.00 30.33           O  \\nATOM  10540  CB  HIS F  75      34.434  74.641  -6.772  1.00 25.29           C  \\nATOM  10541  CG  HIS F  75      35.260  73.473  -6.359  1.00 25.29           C  \\nATOM  10542  ND1 HIS F  75      34.936  72.684  -5.277  1.00 25.29           N  \\nATOM  10543  CD2 HIS F  75      36.315  72.873  -6.957  1.00 25.29           C  \\nATOM  10544  CE1 HIS F  75      35.753  71.646  -5.225  1.00 25.29           C  \\nATOM  10545  NE2 HIS F  75      36.599  71.738  -6.235  1.00 25.29           N  \\nATOM  10546  N   ALA F  76      31.365  73.741  -6.546  1.00 28.06           N  \\nATOM  10547  CA  ALA F  76      30.389  72.892  -5.897  1.00 28.06           C  \\nATOM  10548  C   ALA F  76      29.377  72.338  -6.899  1.00 28.06           C  \\nATOM  10549  O   ALA F  76      28.419  71.661  -6.518  1.00 28.06           O  \\nATOM  10550  CB  ALA F  76      29.691  73.681  -4.811  1.00 22.80           C  \\nATOM  10551  N   LYS F  77      29.608  72.615  -8.180  1.00 34.56           N  \\nATOM  10552  CA  LYS F  77      28.724  72.164  -9.250  1.00 34.56           C  \\nATOM  10553  C   LYS F  77      27.300  72.707  -9.078  1.00 34.56           C  \\nATOM  10554  O   LYS F  77      26.308  72.037  -9.406  1.00 34.56           O  \\nATOM  10555  CB  LYS F  77      28.739  70.631  -9.360  1.00 49.98           C  \\nATOM  10556  CG  LYS F  77      29.948  70.081 -10.102  1.00 49.98           C  \\nATOM  10557  CD  LYS F  77      29.953  68.564 -10.114  1.00 49.98           C  \\nATOM  10558  CE  LYS F  77      31.141  68.014 -10.897  1.00 49.98           C  \\nATOM  10559  NZ  LYS F  77      31.320  66.540 -10.693  1.00 49.98           N  \\nATOM  10560  N   ARG F  78      27.219  73.934  -8.565  1.00 17.81           N  \\nATOM  10561  CA  ARG F  78      25.941  74.614  -8.347  1.00 17.81           C  \\nATOM  10562  C   ARG F  78      25.702  75.772  -9.312  1.00 17.81           C  \\nATOM  10563  O   ARG F  78      26.627  76.234  -9.993  1.00 17.81           O  \\nATOM  10564  CB  ARG F  78      25.852  75.147  -6.922  1.00 22.05           C  \\nATOM  10565  CG  ARG F  78      25.536  74.104  -5.893  1.00 22.05           C  \\nATOM  10566  CD  ARG F  78      25.201  74.750  -4.563  1.00 22.05           C  \\nATOM  10567  NE  ARG F  78      26.374  74.929  -3.707  1.00 22.05           N  \\nATOM  10568  CZ  ARG F  78      26.977  76.092  -3.473  1.00 22.05           C  \\nATOM  10569  NH1 ARG F  78      26.531  77.217  -4.035  1.00 22.05           N  \\nATOM  10570  NH2 ARG F  78      28.013  76.121  -2.648  1.00 22.05           N  \\nATOM  10571  N   LYS F  79      24.449  76.222  -9.370  1.00 31.69           N  \\nATOM  10572  CA  LYS F  79      24.035  77.335 -10.220  1.00 31.69           C  \\nATOM  10573  C   LYS F  79      23.505  78.411  -9.315  1.00 31.69           C  \\nATOM  10574  O   LYS F  79      23.065  79.445  -9.773  1.00 31.69           O  \\nATOM  10575  CB  LYS F  79      22.919  76.928 -11.186  1.00 81.44           C  \\nATOM  10576  CG  LYS F  79      23.325  75.963 -12.279  1.00 81.44           C  \\nATOM  10577  CD  LYS F  79      22.236  75.869 -13.332  1.00 81.44           C  \\nATOM  10578  CE  LYS F  79      22.587  74.882 -14.434  1.00 81.44           C  \\nATOM  10579  NZ  LYS F  79      21.545  74.884 -15.504  1.00 81.44           N  \\nATOM  10580  N   THR F  80      23.550  78.165  -8.018  1.00 28.05           N  \\nATOM  10581  CA  THR F  80      23.051  79.123  -7.055  1.00 28.05           C  \\nATOM  10582  C   THR F  80      24.127  79.575  -6.068  1.00 28.05           C  \\nATOM  10583  O   THR F  80      24.715  78.755  -5.343  1.00 28.05           O  \\nATOM  10584  CB  THR F  80      21.876  78.530  -6.298  1.00 26.98           C  \\nATOM  10585  OG1 THR F  80      20.908  78.072  -7.246  1.00 26.98           O  \\nATOM  10586  CG2 THR F  80      21.242  79.571  -5.407  1.00 26.98           C  \\nATOM  10587  N   VAL F  81      24.383  80.884  -6.053  1.00 14.37           N  \\nATOM  10588  CA  VAL F  81      25.380  81.472  -5.168  1.00 14.37           C  \\nATOM  10589  C   VAL F  81      24.719  81.582  -3.792  1.00 14.37           C  \\nATOM  10590  O   VAL F  81      23.635  82.179  -3.660  1.00 14.37           O  \\nATOM  10591  CB  VAL F  81      25.811  82.887  -5.659  1.00 10.18           C  \\nATOM  10592  CG1 VAL F  81      27.047  83.351  -4.914  1.00 10.18           C  \\nATOM  10593  CG2 VAL F  81      26.044  82.906  -7.172  1.00 10.18           C  \\nATOM  10594  N   THR F  82      25.333  80.929  -2.798  1.00 20.85           N  \\nATOM  10595  CA  THR F  82      24.840  80.925  -1.419  1.00 20.85           C  \\nATOM  10596  C   THR F  82      25.514  81.991  -0.552  1.00 20.85           C  \\nATOM  10597  O   THR F  82      26.508  82.607  -0.936  1.00 20.85           O  \\nATOM  10598  CB  THR F  82      25.055  79.529  -0.723  1.00 36.11           C  \\nATOM  10599  OG1 THR F  82      26.443  79.302  -0.479  1.00 36.11           O  \\nATOM  10600  CG2 THR F  82      24.539  78.392  -1.585  1.00 36.11           C  \\nATOM  10601  N   ALA F  83      24.969  82.219   0.629  1.00 29.25           N  \\nATOM  10602  CA  ALA F  83      25.594  83.163   1.525  1.00 29.25           C  \\nATOM  10603  C   ALA F  83      26.947  82.559   1.864  1.00 29.25           C  \\nATOM  10604  O   ALA F  83      27.937  83.274   1.951  1.00 29.25           O  \\nATOM  10605  CB  ALA F  83      24.789  83.309   2.758  1.00 28.82           C  \\nATOM  10606  N   MET F  84      26.999  81.230   2.013  1.00 17.92           N  \\nATOM  10607  CA  MET F  84      28.256  80.552   2.333  1.00 17.92           C  \\nATOM  10608  C   MET F  84      29.314  80.901   1.320  1.00 17.92           C  \\nATOM  10609  O   MET F  84      30.454  81.148   1.666  1.00 17.92           O  \\nATOM  10610  CB  MET F  84      28.091  79.039   2.404  1.00 34.94           C  \\nATOM  10611  CG  MET F  84      27.548  78.576   3.735  1.00 34.94           C  \\nATOM  10612  SD  MET F  84      27.998  79.750   5.058  1.00 34.94           S  \\nATOM  10613  CE  MET F  84      29.520  79.033   5.711  1.00 34.94           C  \\nATOM  10614  N   ASP F  85      28.931  80.936   0.060  1.00 12.46           N  \\nATOM  10615  CA  ASP F  85      29.880  81.296  -0.969  1.00 12.46           C  \\nATOM  10616  C   ASP F  85      30.466  82.656  -0.674  1.00 12.46           C  \\nATOM  10617  O   ASP F  85      31.678  82.798  -0.553  1.00 12.46           O  \\nATOM  10618  CB  ASP F  85      29.206  81.323  -2.337  1.00 35.98           C  \\nATOM  10619  CG  ASP F  85      28.776  79.954  -2.791  1.00 35.98           C  \\nATOM  10620  OD1 ASP F  85      29.359  78.957  -2.321  1.00 35.98           O  \\nATOM  10621  OD2 ASP F  85      27.840  79.860  -3.604  1.00 35.98           O  \\nATOM  10622  N   VAL F  86      29.585  83.642  -0.515  1.00 14.24           N  \\nATOM  10623  CA  VAL F  86      29.994  85.008  -0.242  1.00 14.24           C  \\nATOM  10624  C   VAL F  86      30.855  85.098   0.992  1.00 14.24           C  \\nATOM  10625  O   VAL F  86      31.909  85.719   0.972  1.00 14.24           O  \\nATOM  10626  CB  VAL F  86      28.788  85.910  -0.115  1.00  5.00           C  \\nATOM  10627  CG1 VAL F  86      29.223  87.334   0.150  1.00  5.00           C  \\nATOM  10628  CG2 VAL F  86      27.992  85.818  -1.414  1.00  5.00           C  \\nATOM  10629  N   VAL F  87      30.428  84.418   2.048  1.00 13.35           N  \\nATOM  10630  CA  VAL F  87      31.153  84.388   3.309  1.00 13.35           C  \\nATOM  10631  C   VAL F  87      32.570  83.835   3.160  1.00 13.35           C  \\nATOM  10632  O   VAL F  87      33.500  84.369   3.760  1.00 13.35           O  \\nATOM  10633  CB  VAL F  87      30.352  83.609   4.351  1.00  6.92           C  \\nATOM  10634  CG1 VAL F  87      31.215  83.265   5.582  1.00  6.92           C  \\nATOM  10635  CG2 VAL F  87      29.155  84.433   4.746  1.00  6.92           C  \\nATOM  10636  N   TYR F  88      32.727  82.767   2.381  1.00 17.93           N  \\nATOM  10637  CA  TYR F  88      34.041  82.187   2.129  1.00 17.93           C  \\nATOM  10638  C   TYR F  88      34.837  83.110   1.248  1.00 17.93           C  \\nATOM  10639  O   TYR F  88      36.016  83.278   1.477  1.00 17.93           O  \\nATOM  10640  CB  TYR F  88      33.959  80.849   1.424  1.00 32.87           C  \\nATOM  10641  CG  TYR F  88      33.232  79.803   2.190  1.00 32.87           C  \\nATOM  10642  CD1 TYR F  88      33.338  79.728   3.560  1.00 32.87           C  \\nATOM  10643  CD2 TYR F  88      32.461  78.861   1.532  1.00 32.87           C  \\nATOM  10644  CE1 TYR F  88      32.699  78.731   4.263  1.00 32.87           C  \\nATOM  10645  CE2 TYR F  88      31.815  77.859   2.215  1.00 32.87           C  \\nATOM  10646  CZ  TYR F  88      31.941  77.789   3.582  1.00 32.87           C  \\nATOM  10647  OH  TYR F  88      31.355  76.735   4.257  1.00 32.87           O  \\nATOM  10648  N   ALA F  89      34.222  83.667   0.210  1.00 19.95           N  \\nATOM  10649  CA  ALA F  89      34.940  84.578  -0.671  1.00 19.95           C  \\nATOM  10650  C   ALA F  89      35.503  85.754   0.153  1.00 19.95           C  \\nATOM  10651  O   ALA F  89      36.664  86.164  -0.027  1.00 19.95           O  \\nATOM  10652  CB  ALA F  89      34.048  85.056  -1.794  1.00  5.00           C  \\nATOM  10653  N   LEU F  90      34.704  86.261   1.089  1.00 20.33           N  \\nATOM  10654  CA  LEU F  90      35.149  87.340   1.964  1.00 20.33           C  \\nATOM  10655  C   LEU F  90      36.272  86.949   2.944  1.00 20.33           C  \\nATOM  10656  O   LEU F  90      37.111  87.766   3.263  1.00 20.33           O  \\nATOM  10657  CB  LEU F  90      33.971  87.953   2.720  1.00  7.70           C  \\nATOM  10658  CG  LEU F  90      32.977  88.731   1.856  1.00  7.70           C  \\nATOM  10659  CD1 LEU F  90      31.718  88.930   2.687  1.00  7.70           C  \\nATOM  10660  CD2 LEU F  90      33.545  90.094   1.348  1.00  7.70           C  \\nATOM  10661  N   LYS F  91      36.258  85.744   3.497  1.00 25.51           N  \\nATOM  10662  CA  LYS F  91      37.345  85.348   4.398  1.00 25.51           C  \\nATOM  10663  C   LYS F  91      38.688  85.324   3.624  1.00 25.51           C  \\nATOM  10664  O   LYS F  91      39.724  85.687   4.184  1.00 25.51           O  \\nATOM  10665  CB  LYS F  91      37.035  84.003   5.071  1.00 38.17           C  \\nATOM  10666  CG  LYS F  91      37.857  83.745   6.297  1.00 38.17           C  \\nATOM  10667  CD  LYS F  91      37.574  82.387   6.847  1.00 38.17           C  \\nATOM  10668  CE  LYS F  91      36.389  82.424   7.793  1.00 38.17           C  \\nATOM  10669  NZ  LYS F  91      35.946  81.033   8.205  1.00 38.17           N  \\nATOM  10670  N   ARG F  92      38.655  84.894   2.354  1.00 25.71           N  \\nATOM  10671  CA  ARG F  92      39.823  84.871   1.459  1.00 25.71           C  \\nATOM  10672  C   ARG F  92      40.434  86.259   1.358  1.00 25.71           C  \\nATOM  10673  O   ARG F  92      41.637  86.400   1.507  1.00 25.71           O  \\nATOM  10674  CB  ARG F  92      39.425  84.517   0.046  1.00 35.24           C  \\nATOM  10675  CG  ARG F  92      38.868  83.161  -0.142  1.00 35.24           C  \\nATOM  10676  CD  ARG F  92      39.275  82.666  -1.514  1.00 35.24           C  \\nATOM  10677  NE  ARG F  92      40.707  82.415  -1.527  1.00 35.24           N  \\nATOM  10678  CZ  ARG F  92      41.610  83.169  -2.141  1.00 35.24           C  \\nATOM  10679  NH1 ARG F  92      41.258  84.252  -2.828  1.00 35.24           N  \\nATOM  10680  NH2 ARG F  92      42.884  82.841  -2.020  1.00 35.24           N  \\nATOM  10681  N   GLN F  93      39.616  87.239   0.948  1.00 14.71           N  \\nATOM  10682  CA  GLN F  93      39.996  88.656   0.851  1.00 14.71           C  \\nATOM  10683  C   GLN F  93      40.392  89.308   2.200  1.00 14.71           C  \\nATOM  10684  O   GLN F  93      40.841  90.453   2.230  1.00 14.71           O  \\nATOM  10685  CB  GLN F  93      38.831  89.463   0.296  1.00 88.86           C  \\nATOM  10686  CG  GLN F  93      38.506  89.244  -1.152  1.00 88.86           C  \\nATOM  10687  CD  GLN F  93      37.791  90.454  -1.731  1.00 88.86           C  \\nATOM  10688  OE1 GLN F  93      37.823  91.551  -1.149  1.00 88.86           O  \\nATOM  10689  NE2 GLN F  93      37.159  90.273  -2.884  1.00 88.86           N  \\nATOM  10690  N   GLY F  94      40.219  88.592   3.304  1.00 22.16           N  \\nATOM  10691  CA  GLY F  94      40.545  89.136   4.607  1.00 22.16           C  \\nATOM  10692  C   GLY F  94      39.457  90.085   5.110  1.00 22.16           C  \\nATOM  10693  O   GLY F  94      39.735  91.020   5.850  1.00 22.16           O  \\nATOM  10694  N   ARG F  95      38.209  89.840   4.736  1.00 50.81           N  \\nATOM  10695  CA  ARG F  95      37.117  90.706   5.139  1.00 50.81           C  \\nATOM  10696  C   ARG F  95      36.016  90.009   5.957  1.00 50.81           C  \\nATOM  10697  O   ARG F  95      34.869  90.459   5.970  1.00 50.81           O  \\nATOM  10698  CB  ARG F  95      36.539  91.370   3.896  1.00 47.90           C  \\nATOM  10699  CG  ARG F  95      36.556  92.862   3.938  1.00 47.90           C  \\nATOM  10700  CD  ARG F  95      37.154  93.385   2.695  1.00 47.90           C  \\nATOM  10701  NE  ARG F  95      38.312  94.188   3.032  1.00 47.90           N  \\nATOM  10702  CZ  ARG F  95      39.368  94.359   2.240  1.00 47.90           C  \\nATOM  10703  NH1 ARG F  95      39.418  93.781   1.038  1.00 47.90           N  \\nATOM  10704  NH2 ARG F  95      40.406  95.080   2.665  1.00 47.90           N  \\nATOM  10705  N   THR F  96      36.402  88.950   6.675  1.00 17.64           N  \\nATOM  10706  CA  THR F  96      35.532  88.140   7.541  1.00 17.64           C  \\nATOM  10707  C   THR F  96      34.236  88.792   7.977  1.00 17.64           C  \\nATOM  10708  O   THR F  96      34.232  89.808   8.658  1.00 17.64           O  \\nATOM  10709  CB  THR F  96      36.266  87.735   8.809  1.00 18.61           C  \\nATOM  10710  OG1 THR F  96      37.531  87.189   8.450  1.00 18.61           O  \\nATOM  10711  CG2 THR F  96      35.483  86.702   9.579  1.00 18.61           C  \\nATOM  10712  N   LEU F  97      33.130  88.153   7.621  1.00 15.87           N  \\nATOM  10713  CA  LEU F  97      31.829  88.664   7.959  1.00 15.87           C  \\nATOM  10714  C   LEU F  97      31.092  87.769   8.926  1.00 15.87           C  \\nATOM  10715  O   LEU F  97      31.007  86.566   8.726  1.00 15.87           O  \\nATOM  10716  CB  LEU F  97      31.011  88.815   6.688  1.00 15.04           C  \\nATOM  10717  CG  LEU F  97      29.565  89.279   6.853  1.00 15.04           C  \\nATOM  10718  CD1 LEU F  97      29.495  90.679   7.455  1.00 15.04           C  \\nATOM  10719  CD2 LEU F  97      28.886  89.206   5.495  1.00 15.04           C  \\nATOM  10720  N   TYR F  98      30.569  88.368   9.988  1.00 15.85           N  \\nATOM  10721  CA  TYR F  98      29.774  87.650  10.977  1.00 15.85           C  \\nATOM  10722  C   TYR F  98      28.304  87.952  10.699  1.00 15.85           C  \\nATOM  10723  O   TYR F  98      27.949  89.056  10.274  1.00 15.85           O  \\nATOM  10724  CB  TYR F  98      30.063  88.137  12.390  1.00 14.74           C  \\nATOM  10725  CG  TYR F  98      31.330  87.659  13.041  1.00 14.74           C  \\nATOM  10726  CD1 TYR F  98      32.201  86.786  12.408  1.00 14.74           C  \\nATOM  10727  CD2 TYR F  98      31.656  88.105  14.313  1.00 14.74           C  \\nATOM  10728  CE1 TYR F  98      33.367  86.377  13.040  1.00 14.74           C  \\nATOM  10729  CE2 TYR F  98      32.801  87.711  14.950  1.00 14.74           C  \\nATOM  10730  CZ  TYR F  98      33.657  86.849  14.325  1.00 14.74           C  \\nATOM  10731  OH  TYR F  98      34.790  86.458  15.014  1.00 14.74           O  \\nATOM  10732  N   GLY F  99      27.453  86.972  10.961  1.00 23.29           N  \\nATOM  10733  CA  GLY F  99      26.036  87.174  10.764  1.00 23.29           C  \\nATOM  10734  C   GLY F  99      25.327  86.389   9.682  1.00 23.29           C  \\nATOM  10735  O   GLY F  99      24.111  86.452   9.629  1.00 23.29           O  \\nATOM  10736  N   PHE F 100      26.047  85.664   8.828  1.00 20.24           N  \\nATOM  10737  CA  PHE F 100      25.402  84.903   7.756  1.00 20.24           C  \\nATOM  10738  C   PHE F 100      25.776  83.428   7.694  1.00 20.24           C  \\nATOM  10739  O   PHE F 100      25.895  82.840   6.612  1.00 20.24           O  \\nATOM  10740  CB  PHE F 100      25.673  85.572   6.420  1.00 19.66           C  \\nATOM  10741  CG  PHE F 100      24.962  86.876   6.249  1.00 19.66           C  \\nATOM  10742  CD1 PHE F 100      25.384  88.013   6.931  1.00 19.66           C  \\nATOM  10743  CD2 PHE F 100      23.870  86.983   5.391  1.00 19.66           C  \\nATOM  10744  CE1 PHE F 100      24.731  89.241   6.758  1.00 19.66           C  \\nATOM  10745  CE2 PHE F 100      23.210  88.208   5.210  1.00 19.66           C  \\nATOM  10746  CZ  PHE F 100      23.645  89.333   5.899  1.00 19.66           C  \\nATOM  10747  N   GLY F 101      25.861  82.812   8.862  1.00 43.20           N  \\nATOM  10748  CA  GLY F 101      26.226  81.416   8.928  1.00 43.20           C  \\nATOM  10749  C   GLY F 101      27.724  81.225   8.788  1.00 43.20           C  \\nATOM  10750  O   GLY F 101      28.178  80.529   7.880  1.00 43.20           O  \\nATOM  10751  N   GLY F 102      28.497  81.861   9.669  1.00101.87           N  \\nATOM  10752  CA  GLY F 102      29.943  81.719   9.627  1.00101.87           C  \\nATOM  10753  C   GLY F 102      30.393  80.398  10.228  1.00101.87           C  \\nATOM  10754  O   GLY F 102      30.789  79.492   9.462  1.00110.04           O  \\nATOM  10755  OXT GLY F 102      30.338  80.254  11.468  1.00110.04           O  \\nTER   10756      GLY F 102                                                      \\nATOM  10757  N   ALA G  12      59.110  44.806 -13.305  1.00155.15           N  \\nATOM  10758  CA  ALA G  12      59.180  45.823 -14.401  1.00155.15           C  \\nATOM  10759  C   ALA G  12      60.110  46.972 -14.003  1.00155.15           C  \\nATOM  10760  O   ALA G  12      60.036  47.459 -12.872  1.00155.15           O  \\nATOM  10761  CB  ALA G  12      57.773  46.362 -14.714  1.00 37.06           C  \\nATOM  10762  N   LYS G  13      60.988  47.394 -14.919  1.00178.91           N  \\nATOM  10763  CA  LYS G  13      61.920  48.495 -14.640  1.00178.91           C  \\nATOM  10764  C   LYS G  13      61.202  49.812 -14.378  1.00178.91           C  \\nATOM  10765  O   LYS G  13      60.710  50.474 -15.298  1.00178.91           O  \\nATOM  10766  CB  LYS G  13      62.971  48.658 -15.748  1.00102.98           C  \\nATOM  10767  CG  LYS G  13      64.284  47.935 -15.444  1.00102.98           C  \\nATOM  10768  CD  LYS G  13      64.857  48.395 -14.104  1.00102.98           C  \\nATOM  10769  CE  LYS G  13      65.900  47.429 -13.570  1.00102.98           C  \\nATOM  10770  NZ  LYS G  13      66.288  47.786 -12.178  1.00102.98           N  \\nATOM  10771  N   ALA G  14      61.171  50.177 -13.100  1.00156.14           N  \\nATOM  10772  CA  ALA G  14      60.506  51.380 -12.630  1.00156.14           C  \\nATOM  10773  C   ALA G  14      61.080  52.691 -13.108  1.00156.14           C  \\nATOM  10774  O   ALA G  14      62.293  52.852 -13.251  1.00156.14           O  \\nATOM  10775  CB  ALA G  14      60.462  51.387 -11.122  1.00 51.77           C  \\nATOM  10776  N   LYS G  15      60.172  53.625 -13.349  1.00151.22           N  \\nATOM  10777  CA  LYS G  15      60.520  54.971 -13.753  1.00151.22           C  \\nATOM  10778  C   LYS G  15      59.468  55.870 -13.145  1.00151.22           C  \\nATOM  10779  O   LYS G  15      58.300  55.845 -13.536  1.00151.22           O  \\nATOM  10780  CB  LYS G  15      60.621  55.123 -15.274  1.00110.09           C  \\nATOM  10781  CG  LYS G  15      62.073  55.048 -15.752  1.00110.09           C  \\nATOM  10782  CD  LYS G  15      62.212  55.012 -17.260  1.00110.09           C  \\nATOM  10783  CE  LYS G  15      63.585  54.477 -17.643  1.00110.09           C  \\nATOM  10784  NZ  LYS G  15      63.731  54.267 -19.107  1.00110.09           N  \\nATOM  10785  N   THR G  16      59.899  56.537 -12.078  1.00 91.26           N  \\nATOM  10786  CA  THR G  16      59.108  57.469 -11.285  1.00 91.26           C  \\nATOM  10787  C   THR G  16      57.915  58.128 -11.959  1.00 91.26           C  \\nATOM  10788  O   THR G  16      57.852  58.268 -13.186  1.00 91.26           O  \\nATOM  10789  CB  THR G  16      59.985  58.617 -10.775  1.00 39.60           C  \\nATOM  10790  OG1 THR G  16      60.606  59.252 -11.897  1.00 39.60           O  \\nATOM  10791  CG2 THR G  16      61.055  58.114  -9.813  1.00 39.60           C  \\nATOM  10792  N   ARG G  17      57.032  58.649 -11.111  1.00 46.55           N  \\nATOM  10793  CA  ARG G  17      55.832  59.334 -11.550  1.00 46.55           C  \\nATOM  10794  C   ARG G  17      56.196  60.606 -12.308  1.00 46.55           C  \\nATOM  10795  O   ARG G  17      55.643  60.881 -13.375  1.00 46.55           O  \\nATOM  10796  CB  ARG G  17      54.996  59.664 -10.337  1.00 36.08           C  \\nATOM  10797  CG  ARG G  17      54.737  58.466  -9.445  1.00 36.08           C  \\nATOM  10798  CD  ARG G  17      53.461  58.670  -8.648  1.00 36.08           C  \\nATOM  10799  NE  ARG G  17      53.685  58.646  -7.211  1.00 36.08           N  \\nATOM  10800  CZ  ARG G  17      52.787  59.046  -6.326  1.00 36.08           C  \\nATOM  10801  NH1 ARG G  17      51.602  59.502  -6.755  1.00 36.08           N  \\nATOM  10802  NH2 ARG G  17      53.059  58.933  -5.026  1.00 36.08           N  \\nATOM  10803  N   SER G  18      57.156  61.361 -11.770  1.00 27.07           N  \\nATOM  10804  CA  SER G  18      57.629  62.601 -12.402  1.00 27.07           C  \\nATOM  10805  C   SER G  18      57.907  62.355 -13.879  1.00 27.07           C  \\nATOM  10806  O   SER G  18      57.440  63.090 -14.733  1.00 27.07           O  \\nATOM  10807  CB  SER G  18      58.891  63.115 -11.706  1.00 24.03           C  \\nATOM  10808  OG  SER G  18      58.660  63.370 -10.325  1.00 24.03           O  \\nATOM  10809  N   SER G  19      58.640  61.286 -14.155  1.00 40.89           N  \\nATOM  10810  CA  SER G  19      58.983  60.870 -15.505  1.00 40.89           C  \\nATOM  10811  C   SER G  19      57.726  60.788 -16.406  1.00 40.89           C  \\nATOM  10812  O   SER G  19      57.716  61.317 -17.534  1.00 40.89           O  \\nATOM  10813  CB  SER G  19      59.680  59.502 -15.422  1.00107.02           C  \\nATOM  10814  OG  SER G  19      60.075  59.011 -16.689  1.00107.02           O  \\nATOM  10815  N   ARG G  20      56.682  60.123 -15.901  1.00 57.92           N  \\nATOM  10816  CA  ARG G  20      55.421  59.947 -16.633  1.00 57.92           C  \\nATOM  10817  C   ARG G  20      54.663  61.238 -16.881  1.00 57.92           C  \\nATOM  10818  O   ARG G  20      54.100  61.431 -17.963  1.00 57.92           O  \\nATOM  10819  CB  ARG G  20      54.506  58.951 -15.914  1.00 97.69           C  \\nATOM  10820  CG  ARG G  20      55.094  57.573 -15.821  1.00 97.69           C  \\nATOM  10821  CD  ARG G  20      54.123  56.538 -15.310  1.00 97.69           C  \\nATOM  10822  NE  ARG G  20      54.828  55.266 -15.202  1.00 97.69           N  \\nATOM  10823  CZ  ARG G  20      54.970  54.569 -14.078  1.00 97.69           C  \\nATOM  10824  NH1 ARG G  20      54.437  55.001 -12.940  1.00 97.69           N  \\nATOM  10825  NH2 ARG G  20      55.702  53.461 -14.081  1.00 97.69           N  \\nATOM  10826  N   ALA G  21      54.605  62.085 -15.852  1.00 32.31           N  \\nATOM  10827  CA  ALA G  21      53.928  63.380 -15.933  1.00 32.31           C  \\nATOM  10828  C   ALA G  21      54.804  64.353 -16.717  1.00 32.31           C  \\nATOM  10829  O   ALA G  21      54.401  65.468 -17.055  1.00 32.31           O  \\nATOM  10830  CB  ALA G  21      53.652  63.900 -14.552  1.00 17.02           C  \\nATOM  10831  N   GLY G  22      56.031  63.916 -16.958  1.00 42.95           N  \\nATOM  10832  CA  GLY G  22      56.961  64.688 -17.741  1.00 42.95           C  \\nATOM  10833  C   GLY G  22      57.470  65.930 -17.083  1.00 42.95           C  \\nATOM  10834  O   GLY G  22      57.655  66.944 -17.757  1.00 42.95           O  \\nATOM  10835  N   LEU G  23      57.722  65.865 -15.782  1.00 25.18           N  \\nATOM  10836  CA  LEU G  23      58.237  67.035 -15.103  1.00 25.18           C  \\nATOM  10837  C   LEU G  23      59.405  66.740 -14.212  1.00 25.18           C  \\nATOM  10838  O   LEU G  23      59.636  65.594 -13.855  1.00 25.18           O  \\nATOM  10839  CB  LEU G  23      57.140  67.788 -14.346  1.00 29.77           C  \\nATOM  10840  CG  LEU G  23      55.839  67.099 -13.956  1.00 29.77           C  \\nATOM  10841  CD1 LEU G  23      55.703  67.008 -12.446  1.00 29.77           C  \\nATOM  10842  CD2 LEU G  23      54.724  67.921 -14.544  1.00 29.77           C  \\nATOM  10843  N   GLN G  24      60.152  67.792 -13.886  1.00 46.00           N  \\nATOM  10844  CA  GLN G  24      61.337  67.718 -13.042  1.00 46.00           C  \\nATOM  10845  C   GLN G  24      61.018  67.609 -11.562  1.00 46.00           C  \\nATOM  10846  O   GLN G  24      61.731  66.939 -10.818  1.00 46.00           O  \\nATOM  10847  CB  GLN G  24      62.226  68.945 -13.270  1.00 58.58           C  \\nATOM  10848  CG  GLN G  24      62.524  69.251 -14.736  1.00 58.58           C  \\nATOM  10849  CD  GLN G  24      63.025  68.038 -15.491  1.00 58.58           C  \\nATOM  10850  OE1 GLN G  24      63.996  67.402 -15.078  1.00 58.58           O  \\nATOM  10851  NE2 GLN G  24      62.348  67.691 -16.588  1.00 58.58           N  \\nATOM  10852  N   PHE G  25      59.980  68.304 -11.123  1.00 37.41           N  \\nATOM  10853  CA  PHE G  25      59.602  68.267  -9.724  1.00 37.41           C  \\nATOM  10854  C   PHE G  25      59.137  66.890  -9.260  1.00 37.41           C  \\nATOM  10855  O   PHE G  25      58.513  66.150 -10.013  1.00 37.41           O  \\nATOM  10856  CB  PHE G  25      58.597  69.372  -9.412  1.00 21.77           C  \\nATOM  10857  CG  PHE G  25      59.250  70.664  -9.027  1.00 21.77           C  \\nATOM  10858  CD1 PHE G  25      60.177  71.265  -9.872  1.00 21.77           C  \\nATOM  10859  CD2 PHE G  25      58.969  71.265  -7.797  1.00 21.77           C  \\nATOM  10860  CE1 PHE G  25      60.824  72.448  -9.503  1.00 21.77           C  \\nATOM  10861  CE2 PHE G  25      59.604  72.447  -7.411  1.00 21.77           C  \\nATOM  10862  CZ  PHE G  25      60.539  73.042  -8.271  1.00 21.77           C  \\nATOM  10863  N   PRO G  26      59.468  66.522  -8.011  1.00 41.25           N  \\nATOM  10864  CA  PRO G  26      59.150  65.253  -7.348  1.00 41.25           C  \\nATOM  10865  C   PRO G  26      57.696  65.000  -6.935  1.00 41.25           C  \\nATOM  10866  O   PRO G  26      57.274  65.328  -5.828  1.00 41.25           O  \\nATOM  10867  CB  PRO G  26      60.064  65.287  -6.138  1.00 33.78           C  \\nATOM  10868  CG  PRO G  26      59.981  66.720  -5.758  1.00 33.78           C  \\nATOM  10869  CD  PRO G  26      60.176  67.415  -7.077  1.00 33.78           C  \\nATOM  10870  N   VAL G  27      56.982  64.297  -7.802  1.00 31.86           N  \\nATOM  10871  CA  VAL G  27      55.593  63.934  -7.586  1.00 31.86           C  \\nATOM  10872  C   VAL G  27      55.411  63.048  -6.353  1.00 31.86           C  \\nATOM  10873  O   VAL G  27      54.514  63.286  -5.529  1.00 31.86           O  \\nATOM  10874  CB  VAL G  27      55.095  63.196  -8.798  1.00 17.80           C  \\nATOM  10875  CG1 VAL G  27      53.627  62.876  -8.671  1.00 17.80           C  \\nATOM  10876  CG2 VAL G  27      55.370  64.033 -10.022  1.00 17.80           C  \\nATOM  10877  N   GLY G  28      56.275  62.040  -6.219  1.00 38.83           N  \\nATOM  10878  CA  GLY G  28      56.205  61.137  -5.080  1.00 38.83           C  \\nATOM  10879  C   GLY G  28      56.327  61.894  -3.774  1.00 38.83           C  \\nATOM  10880  O   GLY G  28      55.737  61.511  -2.758  1.00 38.83           O  \\nATOM  10881  N   ARG G  29      57.052  63.007  -3.817  1.00 30.79           N  \\nATOM  10882  CA  ARG G  29      57.244  63.842  -2.633  1.00 30.79           C  \\nATOM  10883  C   ARG G  29      56.055  64.745  -2.354  1.00 30.79           C  \\nATOM  10884  O   ARG G  29      55.603  64.836  -1.213  1.00 30.79           O  \\nATOM  10885  CB  ARG G  29      58.504  64.694  -2.752  1.00 35.73           C  \\nATOM  10886  CG  ARG G  29      58.792  65.495  -1.512  1.00 35.73           C  \\nATOM  10887  CD  ARG G  29      60.009  66.350  -1.700  1.00 35.73           C  \\nATOM  10888  NE  ARG G  29      61.247  65.596  -1.556  1.00 35.73           N  \\nATOM  10889  CZ  ARG G  29      62.436  66.150  -1.318  1.00 35.73           C  \\nATOM  10890  NH1 ARG G  29      62.562  67.471  -1.215  1.00 35.73           N  \\nATOM  10891  NH2 ARG G  29      63.486  65.379  -1.069  1.00 35.73           N  \\nATOM  10892  N   VAL G  30      55.576  65.451  -3.374  1.00 19.38           N  \\nATOM  10893  CA  VAL G  30      54.426  66.327  -3.188  1.00 19.38           C  \\nATOM  10894  C   VAL G  30      53.281  65.488  -2.620  1.00 19.38           C  \\nATOM  10895  O   VAL G  30      52.552  65.936  -1.723  1.00 19.38           O  \\nATOM  10896  CB  VAL G  30      54.020  67.015  -4.492  1.00 15.55           C  \\nATOM  10897  CG1 VAL G  30      52.766  67.811  -4.300  1.00 15.55           C  \\nATOM  10898  CG2 VAL G  30      55.117  67.939  -4.944  1.00 15.55           C  \\nATOM  10899  N   HIS G  31      53.182  64.236  -3.068  1.00 26.40           N  \\nATOM  10900  CA  HIS G  31      52.156  63.330  -2.559  1.00 26.40           C  \\nATOM  10901  C   HIS G  31      52.353  63.041  -1.055  1.00 26.40           C  \\nATOM  10902  O   HIS G  31      51.427  63.189  -0.251  1.00 26.40           O  \\nATOM  10903  CB  HIS G  31      52.178  62.014  -3.346  1.00 50.15           C  \\nATOM  10904  CG  HIS G  31      50.874  61.274  -3.326  1.00 50.15           C  \\nATOM  10905  ND1 HIS G  31      49.989  61.344  -2.271  1.00 50.15           N  \\nATOM  10906  CD2 HIS G  31      50.294  60.469  -4.247  1.00 50.15           C  \\nATOM  10907  CE1 HIS G  31      48.921  60.616  -2.544  1.00 50.15           C  \\nATOM  10908  NE2 HIS G  31      49.082  60.075  -3.736  1.00 50.15           N  \\nATOM  10909  N   ARG G  32      53.560  62.609  -0.691  1.00 35.25           N  \\nATOM  10910  CA  ARG G  32      53.888  62.299   0.693  1.00 35.25           C  \\nATOM  10911  C   ARG G  32      53.646  63.501   1.603  1.00 35.25           C  \\nATOM  10912  O   ARG G  32      53.193  63.353   2.743  1.00 35.25           O  \\nATOM  10913  CB  ARG G  32      55.344  61.852   0.785  1.00 44.13           C  \\nATOM  10914  CG  ARG G  32      55.626  60.906   1.930  1.00 44.13           C  \\nATOM  10915  CD  ARG G  32      57.106  60.899   2.245  1.00 44.13           C  \\nATOM  10916  NE  ARG G  32      57.512  62.196   2.775  1.00 44.13           N  \\nATOM  10917  CZ  ARG G  32      58.486  62.959   2.274  1.00 44.13           C  \\nATOM  10918  NH1 ARG G  32      59.188  62.564   1.218  1.00 44.13           N  \\nATOM  10919  NH2 ARG G  32      58.726  64.153   2.808  1.00 44.13           N  \\nATOM  10920  N   LEU G  33      53.947  64.692   1.084  1.00 40.03           N  \\nATOM  10921  CA  LEU G  33      53.761  65.940   1.819  1.00 40.03           C  \\nATOM  10922  C   LEU G  33      52.297  66.240   2.045  1.00 40.03           C  \\nATOM  10923  O   LEU G  33      51.905  66.524   3.164  1.00 40.03           O  \\nATOM  10924  CB  LEU G  33      54.453  67.103   1.105  1.00 22.88           C  \\nATOM  10925  CG  LEU G  33      55.986  67.125   1.263  1.00 22.88           C  \\nATOM  10926  CD1 LEU G  33      56.584  68.314   0.499  1.00 22.88           C  \\nATOM  10927  CD2 LEU G  33      56.384  67.194   2.746  1.00 22.88           C  \\nATOM  10928  N   LEU G  34      51.490  66.159   0.993  1.00 33.22           N  \\nATOM  10929  CA  LEU G  34      50.053  66.404   1.122  1.00 33.22           C  \\nATOM  10930  C   LEU G  34      49.341  65.491   2.130  1.00 33.22           C  \\nATOM  10931  O   LEU G  34      48.488  65.961   2.892  1.00 33.22           O  \\nATOM  10932  CB  LEU G  34      49.359  66.317  -0.238  1.00 27.27           C  \\nATOM  10933  CG  LEU G  34      49.628  67.482  -1.195  1.00 27.27           C  \\nATOM  10934  CD1 LEU G  34      49.160  67.131  -2.621  1.00 27.27           C  \\nATOM  10935  CD2 LEU G  34      48.952  68.760  -0.644  1.00 27.27           C  \\nATOM  10936  N   ARG G  35      49.659  64.192   2.116  1.00 51.87           N  \\nATOM  10937  CA  ARG G  35      49.056  63.239   3.060  1.00 51.87           C  \\nATOM  10938  C   ARG G  35      49.376  63.708   4.476  1.00 51.87           C  \\nATOM  10939  O   ARG G  35      48.495  64.124   5.240  1.00 51.87           O  \\nATOM  10940  CB  ARG G  35      49.675  61.853   2.909  1.00 65.61           C  \\nATOM  10941  CG  ARG G  35      49.854  61.353   1.514  1.00 65.61           C  \\nATOM  10942  CD  ARG G  35      50.641  60.047   1.569  1.00 65.61           C  \\nATOM  10943  NE  ARG G  35      50.316  59.132   0.475  1.00 65.61           N  \\nATOM  10944  CZ  ARG G  35      49.078  58.764   0.135  1.00 65.61           C  \\nATOM  10945  NH1 ARG G  35      48.015  59.228   0.795  1.00 65.61           N  \\nATOM  10946  NH2 ARG G  35      48.897  57.914  -0.867  1.00 65.61           N  \\nATOM  10947  N   LYS G  36      50.676  63.746   4.754  1.00 44.11           N  \\nATOM  10948  CA  LYS G  36      51.211  64.134   6.051  1.00 44.11           C  \\nATOM  10949  C   LYS G  36      51.054  65.614   6.366  1.00 44.11           C  \\nATOM  10950  O   LYS G  36      51.586  66.101   7.366  1.00 44.11           O  \\nATOM  10951  CB  LYS G  36      52.683  63.701   6.152  1.00102.46           C  \\nATOM  10952  CG  LYS G  36      52.859  62.202   5.944  1.00102.46           C  \\nATOM  10953  CD  LYS G  36      54.279  61.706   6.135  1.00102.46           C  \\nATOM  10954  CE  LYS G  36      54.304  60.178   6.056  1.00102.46           C  \\nATOM  10955  NZ  LYS G  36      55.653  59.590   6.260  1.00102.46           N  \\nATOM  10956  N   GLY G  37      50.296  66.315   5.526  1.00 52.26           N  \\nATOM  10957  CA  GLY G  37      50.075  67.728   5.736  1.00 52.26           C  \\nATOM  10958  C   GLY G  37      48.845  67.991   6.567  1.00 52.26           C  \\nATOM  10959  O   GLY G  37      48.709  69.076   7.126  1.00 52.26           O  \\nATOM  10960  N   ASN G  38      47.979  66.987   6.695  1.00 50.23           N  \\nATOM  10961  CA  ASN G  38      46.735  67.123   7.449  1.00 50.23           C  \\nATOM  10962  C   ASN G  38      45.854  68.135   6.758  1.00 50.23           C  \\nATOM  10963  O   ASN G  38      45.409  69.115   7.367  1.00 50.23           O  \\nATOM  10964  CB  ASN G  38      46.979  67.572   8.893  1.00 49.13           C  \\nATOM  10965  CG  ASN G  38      47.389  66.442   9.794  1.00 49.13           C  \\nATOM  10966  OD1 ASN G  38      47.977  66.673  10.843  1.00 49.13           O  \\nATOM  10967  ND2 ASN G  38      47.092  65.208   9.390  1.00 49.13           N  \\nATOM  10968  N   TYR G  39      45.706  67.952   5.453  1.00 33.53           N  \\nATOM  10969  CA  TYR G  39      44.876  68.829   4.637  1.00 33.53           C  \\nATOM  10970  C   TYR G  39      43.532  68.149   4.404  1.00 33.53           C  \\nATOM  10971  O   TYR G  39      42.481  68.816   4.295  1.00 33.53           O  \\nATOM  10972  CB  TYR G  39      45.567  69.110   3.305  1.00 30.05           C  \\nATOM  10973  CG  TYR G  39      46.884  69.817   3.468  1.00 30.05           C  \\nATOM  10974  CD1 TYR G  39      46.937  71.139   3.890  1.00 30.05           C  \\nATOM  10975  CD2 TYR G  39      48.077  69.165   3.200  1.00 30.05           C  \\nATOM  10976  CE1 TYR G  39      48.147  71.795   4.035  1.00 30.05           C  \\nATOM  10977  CE2 TYR G  39      49.293  69.809   3.341  1.00 30.05           C  \\nATOM  10978  CZ  TYR G  39      49.327  71.127   3.754  1.00 30.05           C  \\nATOM  10979  OH  TYR G  39      50.544  71.782   3.840  1.00 30.05           O  \\nATOM  10980  N   ALA G  40      43.590  66.813   4.376  1.00 42.83           N  \\nATOM  10981  CA  ALA G  40      42.428  65.968   4.157  1.00 42.83           C  \\nATOM  10982  C   ALA G  40      42.645  64.513   4.588  1.00 42.83           C  \\nATOM  10983  O   ALA G  40      43.739  64.139   5.026  1.00 42.83           O  \\nATOM  10984  CB  ALA G  40      42.036  66.024   2.723  1.00 18.09           C  \\nATOM  10985  N   GLU G  41      41.589  63.707   4.450  1.00 49.84           N  \\nATOM  10986  CA  GLU G  41      41.601  62.297   4.826  1.00 49.84           C  \\nATOM  10987  C   GLU G  41      42.359  61.515   3.776  1.00 49.84           C  \\nATOM  10988  O   GLU G  41      43.302  60.792   4.081  1.00 49.84           O  \\nATOM  10989  CB  GLU G  41      40.172  61.746   4.895  1.00167.51           C  \\nATOM  10990  CG  GLU G  41      39.341  62.249   6.051  1.00167.51           C  \\nATOM  10991  CD  GLU G  41      39.877  61.790   7.391  1.00167.51           C  \\nATOM  10992  OE1 GLU G  41      40.268  60.607   7.507  1.00167.51           O  \\nATOM  10993  OE2 GLU G  41      39.914  62.622   8.323  1.00167.51           O  \\nATOM  10994  N   ARG G  42      41.924  61.666   2.530  1.00 35.89           N  \\nATOM  10995  CA  ARG G  42      42.520  60.965   1.409  1.00 35.89           C  \\nATOM  10996  C   ARG G  42      42.999  61.958   0.369  1.00 35.89           C  \\nATOM  10997  O   ARG G  42      42.644  63.130   0.411  1.00 35.89           O  \\nATOM  10998  CB  ARG G  42      41.509  59.996   0.809  1.00 62.08           C  \\nATOM  10999  CG  ARG G  42      41.064  58.928   1.787  1.00 62.08           C  \\nATOM  11000  CD  ARG G  42      39.572  58.705   1.713  1.00 62.08           C  \\nATOM  11001  NE  ARG G  42      39.250  57.345   1.295  1.00 62.08           N  \\nATOM  11002  CZ  ARG G  42      38.999  56.984   0.038  1.00 62.08           C  \\nATOM  11003  NH1 ARG G  42      39.030  57.882  -0.948  1.00 62.08           N  \\nATOM  11004  NH2 ARG G  42      38.700  55.718  -0.226  1.00 62.08           N  \\nATOM  11005  N   VAL G  43      43.861  61.488  -0.527  1.00 25.79           N  \\nATOM  11006  CA  VAL G  43      44.428  62.316  -1.577  1.00 25.79           C  \\nATOM  11007  C   VAL G  43      44.461  61.558  -2.898  1.00 25.79           C  \\nATOM  11008  O   VAL G  43      45.056  60.478  -3.007  1.00 25.79           O  \\nATOM  11009  CB  VAL G  43      45.874  62.750  -1.229  1.00 23.57           C  \\nATOM  11010  CG1 VAL G  43      46.426  63.691  -2.310  1.00 23.57           C  \\nATOM  11011  CG2 VAL G  43      45.930  63.416   0.139  1.00 23.57           C  \\nATOM  11012  N   GLY G  44      43.872  62.182  -3.911  1.00 25.68           N  \\nATOM  11013  CA  GLY G  44      43.821  61.592  -5.231  1.00 25.68           C  \\nATOM  11014  C   GLY G  44      45.174  61.392  -5.882  1.00 25.68           C  \\nATOM  11015  O   GLY G  44      46.158  62.077  -5.595  1.00 25.68           O  \\nATOM  11016  N   ALA G  45      45.215  60.431  -6.784  1.00 34.26           N  \\nATOM  11017  CA  ALA G  45      46.427  60.105  -7.498  1.00 34.26           C  \\nATOM  11018  C   ALA G  45      46.949  61.292  -8.311  1.00 34.26           C  \\nATOM  11019  O   ALA G  45      48.158  61.496  -8.421  1.00 34.26           O  \\nATOM  11020  CB  ALA G  45      46.163  58.900  -8.409  1.00 19.85           C  \\nATOM  11021  N   GLY G  46      46.030  62.101  -8.828  1.00 35.16           N  \\nATOM  11022  CA  GLY G  46      46.412  63.231  -9.653  1.00 35.16           C  \\nATOM  11023  C   GLY G  46      46.749  64.531  -8.967  1.00 35.16           C  \\nATOM  11024  O   GLY G  46      47.476  65.326  -9.525  1.00 35.16           O  \\nATOM  11025  N   ALA G  47      46.257  64.739  -7.753  1.00 30.74           N  \\nATOM  11026  CA  ALA G  47      46.507  65.978  -7.027  1.00 30.74           C  \\nATOM  11027  C   ALA G  47      47.971  66.314  -6.943  1.00 30.74           C  \\nATOM  11028  O   ALA G  47      48.365  67.380  -7.387  1.00 30.74           O  \\nATOM  11029  CB  ALA G  47      45.910  65.925  -5.639  1.00 42.46           C  \\nATOM  11030  N   PRO G  48      48.814  65.396  -6.412  1.00 34.81           N  \\nATOM  11031  CA  PRO G  48      50.248  65.709  -6.322  1.00 34.81           C  \\nATOM  11032  C   PRO G  48      50.862  65.960  -7.678  1.00 34.81           C  \\nATOM  11033  O   PRO G  48      51.760  66.772  -7.808  1.00 34.81           O  \\nATOM  11034  CB  PRO G  48      50.839  64.466  -5.668  1.00 24.41           C  \\nATOM  11035  CG  PRO G  48      49.908  63.386  -6.084  1.00 24.41           C  \\nATOM  11036  CD  PRO G  48      48.556  64.031  -5.919  1.00 24.41           C  \\nATOM  11037  N   VAL G  49      50.353  65.286  -8.699  1.00 32.01           N  \\nATOM  11038  CA  VAL G  49      50.874  65.477 -10.039  1.00 32.01           C  \\nATOM  11039  C   VAL G  49      50.555  66.892 -10.515  1.00 32.01           C  \\nATOM  11040  O   VAL G  49      51.436  67.628 -10.970  1.00 32.01           O  \\nATOM  11041  CB  VAL G  49      50.289  64.438 -11.010  1.00 16.66           C  \\nATOM  11042  CG1 VAL G  49      50.724  64.761 -12.436  1.00 16.66           C  \\nATOM  11043  CG2 VAL G  49      50.769  63.055 -10.629  1.00 16.66           C  \\nATOM  11044  N   TYR G  50      49.291  67.268 -10.362  1.00 34.70           N  \\nATOM  11045  CA  TYR G  50      48.785  68.585 -10.735  1.00 34.70           C  \\nATOM  11046  C   TYR G  50      49.571  69.671 -10.010  1.00 34.70           C  \\nATOM  11047  O   TYR G  50      50.064  70.629 -10.605  1.00 34.70           O  \\nATOM  11048  CB  TYR G  50      47.309  68.692 -10.319  1.00 34.15           C  \\nATOM  11049  CG  TYR G  50      46.542  69.785 -11.026  1.00 34.15           C  \\nATOM  11050  CD1 TYR G  50      46.819  71.132 -10.795  1.00 34.15           C  \\nATOM  11051  CD2 TYR G  50      45.569  69.469 -11.968  1.00 34.15           C  \\nATOM  11052  CE1 TYR G  50      46.143  72.131 -11.493  1.00 34.15           C  \\nATOM  11053  CE2 TYR G  50      44.895  70.453 -12.671  1.00 34.15           C  \\nATOM  11054  CZ  TYR G  50      45.183  71.779 -12.433  1.00 34.15           C  \\nATOM  11055  OH  TYR G  50      44.502  72.747 -13.142  1.00 34.15           O  \\nATOM  11056  N   LEU G  51      49.648  69.518  -8.700  1.00 27.65           N  \\nATOM  11057  CA  LEU G  51      50.339  70.461  -7.860  1.00 27.65           C  \\nATOM  11058  C   LEU G  51      51.800  70.585  -8.254  1.00 27.65           C  \\nATOM  11059  O   LEU G  51      52.301  71.688  -8.339  1.00 27.65           O  \\nATOM  11060  CB  LEU G  51      50.193  70.055  -6.394  1.00 14.84           C  \\nATOM  11061  CG  LEU G  51      50.963  70.890  -5.363  1.00 14.84           C  \\nATOM  11062  CD1 LEU G  51      50.774  72.398  -5.625  1.00 14.84           C  \\nATOM  11063  CD2 LEU G  51      50.557  70.487  -3.938  1.00 14.84           C  \\nATOM  11064  N   ALA G  52      52.468  69.460  -8.512  1.00 16.58           N  \\nATOM  11065  CA  ALA G  52      53.882  69.422  -8.895  1.00 16.58           C  \\nATOM  11066  C   ALA G  52      54.114  70.246 -10.149  1.00 16.58           C  \\nATOM  11067  O   ALA G  52      55.054  71.062 -10.218  1.00 16.58           O  \\nATOM  11068  CB  ALA G  52      54.301  67.991  -9.121  1.00 12.08           C  \\nATOM  11069  N   ALA G  53      53.231  70.043 -11.126  1.00 23.58           N  \\nATOM  11070  CA  ALA G  53      53.264  70.767 -12.396  1.00 23.58           C  \\nATOM  11071  C   ALA G  53      53.225  72.252 -12.140  1.00 23.58           C  \\nATOM  11072  O   ALA G  53      54.031  72.981 -12.695  1.00 23.58           O  \\nATOM  11073  CB  ALA G  53      52.104  70.369 -13.255  1.00 24.26           C  \\nATOM  11074  N   VAL G  54      52.298  72.685 -11.284  1.00 20.76           N  \\nATOM  11075  CA  VAL G  54      52.144  74.093 -10.902  1.00 20.76           C  \\nATOM  11076  C   VAL G  54      53.370  74.703 -10.201  1.00 20.76           C  \\nATOM  11077  O   VAL G  54      53.805  75.800 -10.540  1.00 20.76           O  \\nATOM  11078  CB  VAL G  54      50.901  74.266 -10.009  1.00 26.53           C  \\nATOM  11079  CG1 VAL G  54      50.881  75.663  -9.343  1.00 26.53           C  \\nATOM  11080  CG2 VAL G  54      49.633  74.006 -10.846  1.00 26.53           C  \\nATOM  11081  N   LEU G  55      53.912  73.996  -9.215  1.00 23.53           N  \\nATOM  11082  CA  LEU G  55      55.091  74.445  -8.475  1.00 23.53           C  \\nATOM  11083  C   LEU G  55      56.250  74.645  -9.415  1.00 23.53           C  \\nATOM  11084  O   LEU G  55      56.896  75.694  -9.412  1.00 23.53           O  \\nATOM  11085  CB  LEU G  55      55.485  73.393  -7.465  1.00 11.87           C  \\nATOM  11086  CG  LEU G  55      54.460  73.258  -6.363  1.00 11.87           C  \\nATOM  11087  CD1 LEU G  55      54.879  72.145  -5.394  1.00 11.87           C  \\nATOM  11088  CD2 LEU G  55      54.348  74.641  -5.663  1.00 11.87           C  \\nATOM  11089  N   GLU G  56      56.502  73.616 -10.219  1.00 30.13           N  \\nATOM  11090  CA  GLU G  56      57.562  73.654 -11.193  1.00 30.13           C  \\nATOM  11091  C   GLU G  56      57.366  74.834 -12.125  1.00 30.13           C  \\nATOM  11092  O   GLU G  56      58.279  75.631 -12.298  1.00 30.13           O  \\nATOM  11093  CB  GLU G  56      57.566  72.383 -12.005  1.00 31.34           C  \\nATOM  11094  CG  GLU G  56      58.614  72.415 -13.083  1.00 31.34           C  \\nATOM  11095  CD  GLU G  56      58.751  71.099 -13.795  1.00 31.34           C  \\nATOM  11096  OE1 GLU G  56      58.920  70.077 -13.108  1.00 31.34           O  \\nATOM  11097  OE2 GLU G  56      58.701  71.098 -15.042  1.00 31.34           O  \\nATOM  11098  N   TYR G  57      56.182  74.944 -12.728  1.00 22.08           N  \\nATOM  11099  CA  TYR G  57      55.891  76.052 -13.638  1.00 22.08           C  \\nATOM  11100  C   TYR G  57      56.196  77.422 -13.053  1.00 22.08           C  \\nATOM  11101  O   TYR G  57      56.821  78.243 -13.715  1.00 22.08           O  \\nATOM  11102  CB  TYR G  57      54.441  76.046 -14.109  1.00 26.52           C  \\nATOM  11103  CG  TYR G  57      54.011  77.399 -14.641  1.00 26.52           C  \\nATOM  11104  CD1 TYR G  57      54.557  77.917 -15.815  1.00 26.52           C  \\nATOM  11105  CD2 TYR G  57      53.083  78.173 -13.953  1.00 26.52           C  \\nATOM  11106  CE1 TYR G  57      54.191  79.167 -16.290  1.00 26.52           C  \\nATOM  11107  CE2 TYR G  57      52.703  79.430 -14.422  1.00 26.52           C  \\nATOM  11108  CZ  TYR G  57      53.260  79.915 -15.589  1.00 26.52           C  \\nATOM  11109  OH  TYR G  57      52.872  81.141 -16.054  1.00 26.52           O  \\nATOM  11110  N   LEU G  58      55.696  77.708 -11.856  1.00 30.86           N  \\nATOM  11111  CA  LEU G  58      55.985  79.002 -11.246  1.00 30.86           C  \\nATOM  11112  C   LEU G  58      57.478  79.155 -10.945  1.00 30.86           C  \\nATOM  11113  O   LEU G  58      58.026  80.247 -11.059  1.00 30.86           O  \\nATOM  11114  CB  LEU G  58      55.144  79.226  -9.994  1.00 18.28           C  \\nATOM  11115  CG  LEU G  58      53.657  79.504 -10.239  1.00 18.28           C  \\nATOM  11116  CD1 LEU G  58      52.960  79.562  -8.905  1.00 18.28           C  \\nATOM  11117  CD2 LEU G  58      53.458  80.798 -11.047  1.00 18.28           C  \\nATOM  11118  N   THR G  59      58.134  78.065 -10.564  1.00 34.68           N  \\nATOM  11119  CA  THR G  59      59.570  78.096 -10.307  1.00 34.68           C  \\nATOM  11120  C   THR G  59      60.293  78.559 -11.582  1.00 34.68           C  \\nATOM  11121  O   THR G  59      61.177  79.415 -11.545  1.00 34.68           O  \\nATOM  11122  CB  THR G  59      60.071  76.709  -9.867  1.00 41.58           C  \\nATOM  11123  OG1 THR G  59      59.343  76.290  -8.707  1.00 41.58           O  \\nATOM  11124  CG2 THR G  59      61.526  76.755  -9.508  1.00 41.58           C  \\nATOM  11125  N   ALA G  60      59.888  78.014 -12.719  1.00 32.08           N  \\nATOM  11126  CA  ALA G  60      60.469  78.404 -14.000  1.00 32.08           C  \\nATOM  11127  C   ALA G  60      60.195  79.867 -14.273  1.00 32.08           C  \\nATOM  11128  O   ALA G  60      61.056  80.571 -14.750  1.00 32.08           O  \\nATOM  11129  CB  ALA G  60      59.890  77.570 -15.115  1.00 46.88           C  \\nATOM  11130  N   GLU G  61      58.978  80.315 -13.987  1.00 27.65           N  \\nATOM  11131  CA  GLU G  61      58.602  81.707 -14.208  1.00 27.65           C  \\nATOM  11132  C   GLU G  61      59.584  82.619 -13.517  1.00 27.65           C  \\nATOM  11133  O   GLU G  61      60.265  83.382 -14.168  1.00 27.65           O  \\nATOM  11134  CB  GLU G  61      57.187  81.965 -13.722  1.00 46.19           C  \\nATOM  11135  CG  GLU G  61      56.522  83.150 -14.392  1.00 46.19           C  \\nATOM  11136  CD  GLU G  61      56.426  83.009 -15.901  1.00 46.19           C  \\nATOM  11137  OE1 GLU G  61      56.002  81.923 -16.376  1.00 46.19           O  \\nATOM  11138  OE2 GLU G  61      56.764  83.996 -16.599  1.00 46.19           O  \\nATOM  11139  N   ILE G  62      59.733  82.486 -12.211  1.00 23.70           N  \\nATOM  11140  CA  ILE G  62      60.693  83.320 -11.490  1.00 23.70           C  \\nATOM  11141  C   ILE G  62      62.111  83.179 -12.011  1.00 23.70           C  \\nATOM  11142  O   ILE G  62      62.740  84.184 -12.294  1.00 23.70           O  \\nATOM  11143  CB  ILE G  62      60.696  83.044  -9.967  1.00 26.61           C  \\nATOM  11144  CG1 ILE G  62      59.372  83.498  -9.383  1.00 26.61           C  \\nATOM  11145  CG2 ILE G  62      61.840  83.785  -9.268  1.00 26.61           C  \\nATOM  11146  CD1 ILE G  62      59.345  83.476  -7.899  1.00 26.61           C  \\nATOM  11147  N   LEU G  63      62.619  81.952 -12.146  1.00 15.59           N  \\nATOM  11148  CA  LEU G  63      64.001  81.746 -12.633  1.00 15.59           C  \\nATOM  11149  C   LEU G  63      64.238  82.404 -13.974  1.00 15.59           C  \\nATOM  11150  O   LEU G  63      65.265  83.016 -14.185  1.00 15.59           O  \\nATOM  11151  CB  LEU G  63      64.380  80.266 -12.680  1.00  9.68           C  \\nATOM  11152  CG  LEU G  63      64.414  79.611 -11.292  1.00  9.68           C  \\nATOM  11153  CD1 LEU G  63      64.733  78.145 -11.440  1.00  9.68           C  \\nATOM  11154  CD2 LEU G  63      65.427  80.276 -10.355  1.00  9.68           C  \\nATOM  11155  N   GLU G  64      63.259  82.308 -14.858  1.00 24.00           N  \\nATOM  11156  CA  GLU G  64      63.323  82.936 -16.163  1.00 24.00           C  \\nATOM  11157  C   GLU G  64      63.645  84.409 -15.919  1.00 24.00           C  \\nATOM  11158  O   GLU G  64      64.765  84.875 -16.148  1.00 24.00           O  \\nATOM  11159  CB  GLU G  64      61.953  82.812 -16.835  1.00 81.17           C  \\nATOM  11160  CG  GLU G  64      61.802  83.589 -18.109  1.00 81.17           C  \\nATOM  11161  CD  GLU G  64      62.661  83.035 -19.213  1.00 81.17           C  \\nATOM  11162  OE1 GLU G  64      62.264  82.022 -19.821  1.00 81.17           O  \\nATOM  11163  OE2 GLU G  64      63.741  83.602 -19.472  1.00 81.17           O  \\nATOM  11164  N   LEU G  65      62.693  85.090 -15.294  1.00 28.28           N  \\nATOM  11165  CA  LEU G  65      62.796  86.504 -15.002  1.00 28.28           C  \\nATOM  11166  C   LEU G  65      64.052  86.957 -14.287  1.00 28.28           C  \\nATOM  11167  O   LEU G  65      64.608  87.995 -14.641  1.00 28.28           O  \\nATOM  11168  CB  LEU G  65      61.552  86.957 -14.252  1.00 33.43           C  \\nATOM  11169  CG  LEU G  65      60.274  86.748 -15.075  1.00 33.43           C  \\nATOM  11170  CD1 LEU G  65      59.077  87.304 -14.326  1.00 33.43           C  \\nATOM  11171  CD2 LEU G  65      60.405  87.422 -16.439  1.00 33.43           C  \\nATOM  11172  N   ALA G  66      64.479  86.207 -13.268  1.00 23.39           N  \\nATOM  11173  CA  ALA G  66      65.695  86.530 -12.511  1.00 23.39           C  \\nATOM  11174  C   ALA G  66      66.945  86.237 -13.344  1.00 23.39           C  \\nATOM  11175  O   ALA G  66      67.949  86.950 -13.235  1.00 23.39           O  \\nATOM  11176  CB  ALA G  66      65.736  85.761 -11.205  1.00  5.00           C  \\nATOM  11177  N   GLY G  67      66.880  85.184 -14.165  1.00 35.89           N  \\nATOM  11178  CA  GLY G  67      67.987  84.828 -15.037  1.00 35.89           C  \\nATOM  11179  C   GLY G  67      68.246  86.041 -15.902  1.00 35.89           C  \\nATOM  11180  O   GLY G  67      69.399  86.477 -16.055  1.00 35.89           O  \\nATOM  11181  N   ASN G  68      67.153  86.610 -16.429  1.00 27.46           N  \\nATOM  11182  CA  ASN G  68      67.214  87.821 -17.257  1.00 27.46           C  \\nATOM  11183  C   ASN G  68      67.828  89.013 -16.503  1.00 27.46           C  \\nATOM  11184  O   ASN G  68      68.706  89.699 -17.017  1.00 27.46           O  \\nATOM  11185  CB  ASN G  68      65.834  88.164 -17.807  1.00 43.30           C  \\nATOM  11186  CG  ASN G  68      65.423  87.242 -18.938  1.00 43.30           C  \\nATOM  11187  OD1 ASN G  68      66.274  86.733 -19.674  1.00 43.30           O  \\nATOM  11188  ND2 ASN G  68      64.121  87.008 -19.077  1.00 43.30           N  \\nATOM  11189  N   ALA G  69      67.374  89.248 -15.278  1.00 32.99           N  \\nATOM  11190  CA  ALA G  69      67.927  90.316 -14.455  1.00 32.99           C  \\nATOM  11191  C   ALA G  69      69.447  90.187 -14.360  1.00 32.99           C  \\nATOM  11192  O   ALA G  69      70.152  91.180 -14.500  1.00 32.99           O  \\nATOM  11193  CB  ALA G  69      67.309  90.292 -13.054  1.00 21.08           C  \\nATOM  11194  N   ALA G  70      69.949  88.976 -14.107  1.00 32.35           N  \\nATOM  11195  CA  ALA G  70      71.393  88.744 -14.009  1.00 32.35           C  \\nATOM  11196  C   ALA G  70      72.074  89.211 -15.278  1.00 32.35           C  \\nATOM  11197  O   ALA G  70      72.962  90.050 -15.227  1.00 32.35           O  \\nATOM  11198  CB  ALA G  70      71.689  87.281 -13.765  1.00 18.75           C  \\nATOM  11199  N   ARG G  71      71.626  88.689 -16.415  1.00 56.07           N  \\nATOM  11200  CA  ARG G  71      72.165  89.064 -17.715  1.00 56.07           C  \\nATOM  11201  C   ARG G  71      72.210  90.597 -17.883  1.00 56.07           C  \\nATOM  11202  O   ARG G  71      73.165  91.139 -18.441  1.00 56.07           O  \\nATOM  11203  CB  ARG G  71      71.306  88.445 -18.808  1.00 71.76           C  \\nATOM  11204  CG  ARG G  71      71.870  88.578 -20.173  1.00 71.76           C  \\nATOM  11205  CD  ARG G  71      70.903  88.039 -21.177  1.00 71.76           C  \\nATOM  11206  NE  ARG G  71      71.493  88.015 -22.513  1.00 71.76           N  \\nATOM  11207  CZ  ARG G  71      70.861  88.390 -23.625  1.00 71.76           C  \\nATOM  11208  NH1 ARG G  71      69.612  88.832 -23.562  1.00 71.76           N  \\nATOM  11209  NH2 ARG G  71      71.461  88.286 -24.808  1.00 71.76           N  \\nATOM  11210  N   ASP G  72      71.172  91.288 -17.413  1.00 44.90           N  \\nATOM  11211  CA  ASP G  72      71.104  92.748 -17.496  1.00 44.90           C  \\nATOM  11212  C   ASP G  72      72.178  93.420 -16.672  1.00 44.90           C  \\nATOM  11213  O   ASP G  72      72.663  94.485 -17.034  1.00 44.90           O  \\nATOM  11214  CB  ASP G  72      69.738  93.252 -17.040  1.00 56.77           C  \\nATOM  11215  CG  ASP G  72      68.624  92.846 -17.977  1.00 56.77           C  \\nATOM  11216  OD1 ASP G  72      68.909  92.396 -19.111  1.00 56.77           O  \\nATOM  11217  OD2 ASP G  72      67.453  92.974 -17.569  1.00 56.77           O  \\nATOM  11218  N   ASN G  73      72.454  92.870 -15.499  1.00 49.16           N  \\nATOM  11219  CA  ASN G  73      73.506  93.418 -14.653  1.00 49.16           C  \\nATOM  11220  C   ASN G  73      74.850  92.862 -15.088  1.00 49.16           C  \\nATOM  11221  O   ASN G  73      75.864  93.113 -14.442  1.00 49.16           O  \\nATOM  11222  CB  ASN G  73      73.266  93.075 -13.186  1.00105.63           C  \\nATOM  11223  CG  ASN G  73      72.346  94.053 -12.509  1.00105.63           C  \\nATOM  11224  OD1 ASN G  73      72.462  95.267 -12.702  1.00105.63           O  \\nATOM  11225  ND2 ASN G  73      71.422  93.537 -11.709  1.00105.63           N  \\nATOM  11226  N   LYS G  74      74.840  92.110 -16.189  1.00 48.20           N  \\nATOM  11227  CA  LYS G  74      76.032  91.476 -16.746  1.00 48.20           C  \\nATOM  11228  C   LYS G  74      76.608  90.515 -15.707  1.00 48.20           C  \\nATOM  11229  O   LYS G  74      77.746  90.673 -15.278  1.00 48.20           O  \\nATOM  11230  CB  LYS G  74      77.075  92.525 -17.142  1.00 82.49           C  \\nATOM  11231  CG  LYS G  74      76.544  93.671 -17.992  1.00 82.49           C  \\nATOM  11232  CD  LYS G  74      77.581  94.785 -18.074  1.00 82.49           C  \\nATOM  11233  CE  LYS G  74      76.981  96.102 -18.543  1.00 82.49           C  \\nATOM  11234  NZ  LYS G  74      78.013  97.178 -18.513  1.00 82.49           N  \\nATOM  11235  N   LYS G  75      75.790  89.555 -15.267  1.00 45.76           N  \\nATOM  11236  CA  LYS G  75      76.191  88.557 -14.265  1.00 45.76           C  \\nATOM  11237  C   LYS G  75      75.716  87.132 -14.611  1.00 45.76           C  \\nATOM  11238  O   LYS G  75      74.635  86.930 -15.181  1.00 45.76           O  \\nATOM  11239  CB  LYS G  75      75.644  88.943 -12.884  1.00 40.81           C  \\nATOM  11240  CG  LYS G  75      75.548  90.449 -12.631  1.00 40.81           C  \\nATOM  11241  CD  LYS G  75      76.653  91.009 -11.733  1.00 40.81           C  \\nATOM  11242  CE  LYS G  75      76.422  90.640 -10.274  1.00 40.81           C  \\nATOM  11243  NZ  LYS G  75      77.476  91.201  -9.410  1.00 40.81           N  \\nATOM  11244  N   THR G  76      76.533  86.152 -14.238  1.00 53.62           N  \\nATOM  11245  CA  THR G  76      76.251  84.736 -14.481  1.00 53.62           C  \\nATOM  11246  C   THR G  76      75.372  84.105 -13.387  1.00 53.62           C  \\nATOM  11247  O   THR G  76      74.405  83.401 -13.688  1.00 53.62           O  \\nATOM  11248  CB  THR G  76      77.572  83.928 -14.534  1.00 84.47           C  \\nATOM  11249  OG1 THR G  76      78.471  84.530 -15.474  1.00 84.47           O  \\nATOM  11250  CG2 THR G  76      77.309  82.474 -14.922  1.00 84.47           C  \\nATOM  11251  N   ARG G  77      75.764  84.316 -12.127  1.00 41.80           N  \\nATOM  11252  CA  ARG G  77      75.060  83.773 -10.969  1.00 41.80           C  \\nATOM  11253  C   ARG G  77      74.000  84.677 -10.384  1.00 41.80           C  \\nATOM  11254  O   ARG G  77      74.298  85.796  -9.939  1.00 41.80           O  \\nATOM  11255  CB  ARG G  77      76.033  83.366  -9.857  1.00 62.04           C  \\nATOM  11256  CG  ARG G  77      76.258  81.871  -9.813  1.00 62.04           C  \\nATOM  11257  CD  ARG G  77      76.873  81.400  -8.514  1.00 62.04           C  \\nATOM  11258  NE  ARG G  77      78.329  81.454  -8.526  1.00 62.04           N  \\nATOM  11259  CZ  ARG G  77      79.032  82.330  -7.822  1.00 62.04           C  \\nATOM  11260  NH1 ARG G  77      78.399  83.211  -7.063  1.00 62.04           N  \\nATOM  11261  NH2 ARG G  77      80.357  82.316  -7.856  1.00 62.04           N  \\nATOM  11262  N   ILE G  78      72.783  84.116 -10.341  1.00 35.39           N  \\nATOM  11263  CA  ILE G  78      71.563  84.736  -9.820  1.00 35.39           C  \\nATOM  11264  C   ILE G  78      71.631  84.870  -8.315  1.00 35.39           C  \\nATOM  11265  O   ILE G  78      71.813  83.873  -7.621  1.00 35.39           O  \\nATOM  11266  CB  ILE G  78      70.342  83.837 -10.046  1.00 18.12           C  \\nATOM  11267  CG1 ILE G  78      70.084  83.602 -11.526  1.00 18.12           C  \\nATOM  11268  CG2 ILE G  78      69.127  84.442  -9.399  1.00 18.12           C  \\nATOM  11269  CD1 ILE G  78      68.802  82.767 -11.832  1.00 18.12           C  \\nATOM  11270  N   ILE G  79      71.413  86.081  -7.815  1.00 43.09           N  \\nATOM  11271  CA  ILE G  79      71.424  86.322  -6.378  1.00 43.09           C  \\nATOM  11272  C   ILE G  79      70.082  86.887  -5.950  1.00 43.09           C  \\nATOM  11273  O   ILE G  79      69.231  87.190  -6.782  1.00 43.09           O  \\nATOM  11274  CB  ILE G  79      72.545  87.298  -5.955  1.00 11.11           C  \\nATOM  11275  CG1 ILE G  79      72.442  88.613  -6.729  1.00 11.11           C  \\nATOM  11276  CG2 ILE G  79      73.908  86.651  -6.165  1.00 11.11           C  \\nATOM  11277  CD1 ILE G  79      73.287  89.702  -6.141  1.00 11.11           C  \\nATOM  11278  N   PRO G  80      69.851  86.985  -4.638  1.00 31.82           N  \\nATOM  11279  CA  PRO G  80      68.589  87.521  -4.135  1.00 31.82           C  \\nATOM  11280  C   PRO G  80      68.093  88.792  -4.844  1.00 31.82           C  \\nATOM  11281  O   PRO G  80      66.935  88.846  -5.246  1.00 31.82           O  \\nATOM  11282  CB  PRO G  80      68.908  87.752  -2.665  1.00 14.81           C  \\nATOM  11283  CG  PRO G  80      69.760  86.557  -2.349  1.00 14.81           C  \\nATOM  11284  CD  PRO G  80      70.683  86.480  -3.530  1.00 14.81           C  \\nATOM  11285  N   ARG G  81      68.973  89.781  -5.054  1.00 28.27           N  \\nATOM  11286  CA  ARG G  81      68.597  91.040  -5.731  1.00 28.27           C  \\nATOM  11287  C   ARG G  81      67.963  90.779  -7.093  1.00 28.27           C  \\nATOM  11288  O   ARG G  81      67.044  91.467  -7.522  1.00 28.27           O  \\nATOM  11289  CB  ARG G  81      69.813  91.978  -5.897  1.00 33.83           C  \\nATOM  11290  CG  ARG G  81      69.478  93.364  -6.478  1.00 33.83           C  \\nATOM  11291  CD  ARG G  81      68.238  93.920  -5.790  1.00 33.83           C  \\nATOM  11292  NE  ARG G  81      67.924  95.360  -5.848  1.00 33.83           N  \\nATOM  11293  CZ  ARG G  81      68.399  96.249  -6.722  1.00 33.83           C  \\nATOM  11294  NH1 ARG G  81      69.265  95.888  -7.676  1.00 33.83           N  \\nATOM  11295  NH2 ARG G  81      67.952  97.512  -6.680  1.00 33.83           N  \\nATOM  11296  N   HIS G  82      68.423  89.725  -7.734  1.00 30.62           N  \\nATOM  11297  CA  HIS G  82      67.922  89.368  -9.033  1.00 30.62           C  \\nATOM  11298  C   HIS G  82      66.502  88.877  -8.917  1.00 30.62           C  \\nATOM  11299  O   HIS G  82      65.631  89.329  -9.649  1.00 30.62           O  \\nATOM  11300  CB  HIS G  82      68.842  88.329  -9.647  1.00 35.67           C  \\nATOM  11301  CG  HIS G  82      70.231  88.840  -9.869  1.00 35.67           C  \\nATOM  11302  ND1 HIS G  82      71.011  88.440 -10.929  1.00 35.67           N  \\nATOM  11303  CD2 HIS G  82      70.943  89.781  -9.211  1.00 35.67           C  \\nATOM  11304  CE1 HIS G  82      72.141  89.117 -10.915  1.00 35.67           C  \\nATOM  11305  NE2 HIS G  82      72.124  89.936  -9.882  1.00 35.67           N  \\nATOM  11306  N   LEU G  83      66.259  87.996  -7.952  1.00 34.03           N  \\nATOM  11307  CA  LEU G  83      64.923  87.456  -7.696  1.00 34.03           C  \\nATOM  11308  C   LEU G  83      63.926  88.602  -7.365  1.00 34.03           C  \\nATOM  11309  O   LEU G  83      62.822  88.641  -7.907  1.00 34.03           O  \\nATOM  11310  CB  LEU G  83      65.013  86.388  -6.579  1.00 12.72           C  \\nATOM  11311  CG  LEU G  83      65.829  85.110  -6.923  1.00 12.72           C  \\nATOM  11312  CD1 LEU G  83      66.148  84.282  -5.682  1.00 12.72           C  \\nATOM  11313  CD2 LEU G  83      65.077  84.270  -7.994  1.00 12.72           C  \\nATOM  11314  N   GLN G  84      64.368  89.566  -6.552  1.00 23.67           N  \\nATOM  11315  CA  GLN G  84      63.576  90.744  -6.168  1.00 23.67           C  \\nATOM  11316  C   GLN G  84      63.258  91.607  -7.373  1.00 23.67           C  \\nATOM  11317  O   GLN G  84      62.100  91.935  -7.604  1.00 23.67           O  \\nATOM  11318  CB  GLN G  84      64.346  91.596  -5.169  1.00 25.33           C  \\nATOM  11319  CG  GLN G  84      63.751  92.966  -4.899  1.00 25.33           C  \\nATOM  11320  CD  GLN G  84      62.568  92.917  -3.947  1.00 25.33           C  \\nATOM  11321  OE1 GLN G  84      61.948  91.865  -3.764  1.00 25.33           O  \\nATOM  11322  NE2 GLN G  84      62.242  94.056  -3.338  1.00 25.33           N  \\nATOM  11323  N   LEU G  85      64.282  92.019  -8.118  1.00 19.86           N  \\nATOM  11324  CA  LEU G  85      64.067  92.817  -9.318  1.00 19.86           C  \\nATOM  11325  C   LEU G  85      63.092  92.095 -10.223  1.00 19.86           C  \\nATOM  11326  O   LEU G  85      62.146  92.693 -10.701  1.00 19.86           O  \\nATOM  11327  CB  LEU G  85      65.370  93.032 -10.080  1.00 24.32           C  \\nATOM  11328  CG  LEU G  85      66.449  93.875  -9.400  1.00 24.32           C  \\nATOM  11329  CD1 LEU G  85      67.697  93.880 -10.245  1.00 24.32           C  \\nATOM  11330  CD2 LEU G  85      65.956  95.275  -9.155  1.00 24.32           C  \\nATOM  11331  N   ALA G  86      63.308  90.806 -10.451  1.00 31.36           N  \\nATOM  11332  CA  ALA G  86      62.409  90.019 -11.297  1.00 31.36           C  \\nATOM  11333  C   ALA G  86      60.941  90.125 -10.850  1.00 31.36           C  \\nATOM  11334  O   ALA G  86      60.050  90.425 -11.663  1.00 31.36           O  \\nATOM  11335  CB  ALA G  86      62.839  88.556 -11.293  1.00 40.57           C  \\nATOM  11336  N   VAL G  87      60.725  89.856  -9.557  1.00 25.69           N  \\nATOM  11337  CA  VAL G  87      59.415  89.869  -8.908  1.00 25.69           C  \\nATOM  11338  C   VAL G  87      58.682  91.203  -8.833  1.00 25.69           C  \\nATOM  11339  O   VAL G  87      57.587  91.337  -9.373  1.00 25.69           O  \\nATOM  11340  CB  VAL G  87      59.497  89.179  -7.490  1.00  9.27           C  \\nATOM  11341  CG1 VAL G  87      58.379  89.608  -6.573  1.00  9.27           C  \\nATOM  11342  CG2 VAL G  87      59.405  87.693  -7.649  1.00  9.27           C  \\nATOM  11343  N   ARG G  88      59.292  92.215  -8.244  1.00 19.87           N  \\nATOM  11344  CA  ARG G  88      58.578  93.482  -8.121  1.00 19.87           C  \\nATOM  11345  C   ARG G  88      58.428  94.206  -9.467  1.00 19.87           C  \\nATOM  11346  O   ARG G  88      57.701  95.179  -9.596  1.00 19.87           O  \\nATOM  11347  CB  ARG G  88      59.238  94.346  -7.052  1.00 21.18           C  \\nATOM  11348  CG  ARG G  88      60.002  93.500  -6.071  1.00 21.18           C  \\nATOM  11349  CD  ARG G  88      59.375  93.289  -4.689  1.00 21.18           C  \\nATOM  11350  NE  ARG G  88      58.146  92.490  -4.564  1.00 21.18           N  \\nATOM  11351  CZ  ARG G  88      57.905  91.612  -3.581  1.00 21.18           C  \\nATOM  11352  NH1 ARG G  88      58.806  91.352  -2.637  1.00 21.18           N  \\nATOM  11353  NH2 ARG G  88      56.680  91.130  -3.438  1.00 21.18           N  \\nATOM  11354  N   ASN G  89      59.092  93.682 -10.482  1.00 20.39           N  \\nATOM  11355  CA  ASN G  89      59.013  94.243 -11.815  1.00 20.39           C  \\nATOM  11356  C   ASN G  89      57.954  93.601 -12.695  1.00 20.39           C  \\nATOM  11357  O   ASN G  89      57.816  93.997 -13.864  1.00 20.39           O  \\nATOM  11358  CB  ASN G  89      60.353  94.117 -12.515  1.00 36.68           C  \\nATOM  11359  CG  ASN G  89      61.239  95.277 -12.249  1.00 36.68           C  \\nATOM  11360  OD1 ASN G  89      60.905  96.181 -11.481  1.00 36.68           O  \\nATOM  11361  ND2 ASN G  89      62.377  95.283 -12.899  1.00 36.68           N  \\nATOM  11362  N   ASP G  90      57.273  92.578 -12.164  1.00 45.29           N  \\nATOM  11363  CA  ASP G  90      56.213  91.848 -12.877  1.00 45.29           C  \\nATOM  11364  C   ASP G  90      54.910  92.035 -12.088  1.00 45.29           C  \\nATOM  11365  O   ASP G  90      54.815  91.632 -10.924  1.00 45.29           O  \\nATOM  11366  CB  ASP G  90      56.572  90.350 -12.989  1.00 30.78           C  \\nATOM  11367  CG  ASP G  90      55.538  89.547 -13.776  1.00 30.78           C  \\nATOM  11368  OD1 ASP G  90      55.487  89.682 -15.020  1.00 30.78           O  \\nATOM  11369  OD2 ASP G  90      54.783  88.780 -13.143  1.00 30.78           O  \\nATOM  11370  N   GLU G  91      53.908  92.646 -12.716  1.00 33.91           N  \\nATOM  11371  CA  GLU G  91      52.645  92.891 -12.035  1.00 33.91           C  \\nATOM  11372  C   GLU G  91      52.108  91.668 -11.286  1.00 33.91           C  \\nATOM  11373  O   GLU G  91      51.934  91.722 -10.075  1.00 33.91           O  \\nATOM  11374  CB  GLU G  91      51.593  93.461 -13.000  1.00141.14           C  \\nATOM  11375  CG  GLU G  91      51.888  94.887 -13.504  1.00141.14           C  \\nATOM  11376  CD  GLU G  91      51.765  95.981 -12.427  1.00141.14           C  \\nATOM  11377  OE1 GLU G  91      52.473  95.914 -11.395  1.00141.14           O  \\nATOM  11378  OE2 GLU G  91      50.969  96.928 -12.630  1.00141.14           O  \\nATOM  11379  N   GLU G  92      52.009  90.526 -11.965  1.00 25.44           N  \\nATOM  11380  CA  GLU G  92      51.454  89.322 -11.344  1.00 25.44           C  \\nATOM  11381  C   GLU G  92      52.254  88.631 -10.247  1.00 25.44           C  \\nATOM  11382  O   GLU G  92      51.714  88.319  -9.195  1.00 25.44           O  \\nATOM  11383  CB  GLU G  92      50.994  88.352 -12.419  1.00 31.91           C  \\nATOM  11384  CG  GLU G  92      49.873  88.939 -13.277  1.00 31.91           C  \\nATOM  11385  CD  GLU G  92      49.419  88.005 -14.370  1.00 31.91           C  \\nATOM  11386  OE1 GLU G  92      49.747  86.815 -14.281  1.00 31.91           O  \\nATOM  11387  OE2 GLU G  92      48.730  88.453 -15.314  1.00 31.91           O  \\nATOM  11388  N   LEU G  93      53.535  88.377 -10.476  1.00 13.21           N  \\nATOM  11389  CA  LEU G  93      54.367  87.760  -9.439  1.00 13.21           C  \\nATOM  11390  C   LEU G  93      54.442  88.665  -8.210  1.00 13.21           C  \\nATOM  11391  O   LEU G  93      54.528  88.174  -7.098  1.00 13.21           O  \\nATOM  11392  CB  LEU G  93      55.788  87.481  -9.959  1.00 31.43           C  \\nATOM  11393  CG  LEU G  93      56.084  86.297 -10.896  1.00 31.43           C  \\nATOM  11394  CD1 LEU G  93      57.567  86.291 -11.268  1.00 31.43           C  \\nATOM  11395  CD2 LEU G  93      55.732  84.996 -10.212  1.00 31.43           C  \\nATOM  11396  N   ASN G  94      54.442  89.983  -8.425  1.00 21.92           N  \\nATOM  11397  CA  ASN G  94      54.485  90.963  -7.339  1.00 21.92           C  \\nATOM  11398  C   ASN G  94      53.235  90.889  -6.469  1.00 21.92           C  \\nATOM  11399  O   ASN G  94      53.317  91.026  -5.255  1.00 21.92           O  \\nATOM  11400  CB  ASN G  94      54.633  92.376  -7.887  1.00 24.89           C  \\nATOM  11401  CG  ASN G  94      54.714  93.404  -6.789  1.00 24.89           C  \\nATOM  11402  OD1 ASN G  94      55.390  93.193  -5.780  1.00 24.89           O  \\nATOM  11403  ND2 ASN G  94      54.005  94.504  -6.956  1.00 24.89           N  \\nATOM  11404  N   LYS G  95      52.072  90.768  -7.099  1.00 15.91           N  \\nATOM  11405  CA  LYS G  95      50.833  90.634  -6.366  1.00 15.91           C  \\nATOM  11406  C   LYS G  95      50.909  89.311  -5.596  1.00 15.91           C  \\nATOM  11407  O   LYS G  95      50.714  89.276  -4.386  1.00 15.91           O  \\nATOM  11408  CB  LYS G  95      49.646  90.637  -7.326  1.00 48.08           C  \\nATOM  11409  CG  LYS G  95      48.282  90.476  -6.663  1.00 48.08           C  \\nATOM  11410  CD  LYS G  95      47.176  90.526  -7.708  1.00 48.08           C  \\nATOM  11411  CE  LYS G  95      45.885  89.829  -7.262  1.00 48.08           C  \\nATOM  11412  NZ  LYS G  95      44.902  89.640  -8.409  1.00 48.08           N  \\nATOM  11413  N   LEU G  96      51.282  88.234  -6.278  1.00 25.95           N  \\nATOM  11414  CA  LEU G  96      51.375  86.928  -5.634  1.00 25.95           C  \\nATOM  11415  C   LEU G  96      52.288  86.926  -4.439  1.00 25.95           C  \\nATOM  11416  O   LEU G  96      52.160  86.072  -3.568  1.00 25.95           O  \\nATOM  11417  CB  LEU G  96      51.863  85.870  -6.619  1.00 14.64           C  \\nATOM  11418  CG  LEU G  96      52.151  84.449  -6.124  1.00 14.64           C  \\nATOM  11419  CD1 LEU G  96      50.887  83.863  -5.591  1.00 14.64           C  \\nATOM  11420  CD2 LEU G  96      52.715  83.567  -7.242  1.00 14.64           C  \\nATOM  11421  N   LEU G  97      53.218  87.870  -4.397  1.00 23.05           N  \\nATOM  11422  CA  LEU G  97      54.164  87.940  -3.291  1.00 23.05           C  \\nATOM  11423  C   LEU G  97      54.121  89.269  -2.520  1.00 23.05           C  \\nATOM  11424  O   LEU G  97      55.059  89.640  -1.824  1.00 23.05           O  \\nATOM  11425  CB  LEU G  97      55.572  87.617  -3.823  1.00 12.64           C  \\nATOM  11426  CG  LEU G  97      55.750  86.189  -4.378  1.00 12.64           C  \\nATOM  11427  CD1 LEU G  97      57.161  86.012  -4.914  1.00 12.64           C  \\nATOM  11428  CD2 LEU G  97      55.443  85.137  -3.278  1.00 12.64           C  \\nATOM  11429  N   GLY G  98      52.981  89.933  -2.578  1.00  7.68           N  \\nATOM  11430  CA  GLY G  98      52.834  91.202  -1.912  1.00  7.68           C  \\nATOM  11431  C   GLY G  98      53.091  91.230  -0.419  1.00  7.68           C  \\nATOM  11432  O   GLY G  98      53.431  92.286   0.112  1.00  7.68           O  \\nATOM  11433  N   ARG G  99      52.884  90.132   0.297  1.00 22.70           N  \\nATOM  11434  CA  ARG G  99      53.128  90.177   1.732  1.00 22.70           C  \\nATOM  11435  C   ARG G  99      54.367  89.363   2.031  1.00 22.70           C  \\nATOM  11436  O   ARG G  99      54.616  88.953   3.160  1.00 22.70           O  \\nATOM  11437  CB  ARG G  99      51.899  89.714   2.519  1.00103.13           C  \\nATOM  11438  CG  ARG G  99      50.743  90.713   2.439  1.00103.13           C  \\nATOM  11439  CD  ARG G  99      49.416  90.136   2.944  1.00103.13           C  \\nATOM  11440  NE  ARG G  99      48.261  90.909   2.454  1.00103.13           N  \\nATOM  11441  CZ  ARG G  99      46.972  90.566   2.592  1.00103.13           C  \\nATOM  11442  NH1 ARG G  99      46.620  89.445   3.217  1.00103.13           N  \\nATOM  11443  NH2 ARG G  99      46.023  91.349   2.087  1.00103.13           N  \\nATOM  11444  N   VAL G 100      55.188  89.214   1.003  1.00 23.39           N  \\nATOM  11445  CA  VAL G 100      56.423  88.461   1.099  1.00 23.39           C  \\nATOM  11446  C   VAL G 100      57.648  89.334   0.883  1.00 23.39           C  \\nATOM  11447  O   VAL G 100      57.748  90.043  -0.127  1.00 23.39           O  \\nATOM  11448  CB  VAL G 100      56.463  87.290   0.066  1.00 17.83           C  \\nATOM  11449  CG1 VAL G 100      57.839  86.628   0.071  1.00 17.83           C  \\nATOM  11450  CG2 VAL G 100      55.367  86.259   0.389  1.00 17.83           C  \\nATOM  11451  N   THR G 101      58.567  89.273   1.847  1.00 11.33           N  \\nATOM  11452  CA  THR G 101      59.812  90.011   1.754  1.00 11.33           C  \\nATOM  11453  C   THR G 101      61.022  89.089   1.525  1.00 11.33           C  \\nATOM  11454  O   THR G 101      61.244  88.094   2.215  1.00 11.33           O  \\nATOM  11455  CB  THR G 101      60.009  91.049   2.904  1.00 19.35           C  \\nATOM  11456  OG1 THR G 101      61.356  90.983   3.387  1.00 19.35           O  \\nATOM  11457  CG2 THR G 101      59.004  90.862   4.020  1.00 19.35           C  \\nATOM  11458  N   ILE G 102      61.715  89.362   0.429  1.00 21.05           N  \\nATOM  11459  CA  ILE G 102      62.868  88.583   0.018  1.00 21.05           C  \\nATOM  11460  C   ILE G 102      64.139  89.128   0.653  1.00 21.05           C  \\nATOM  11461  O   ILE G 102      64.549  90.254   0.381  1.00 21.05           O  \\nATOM  11462  CB  ILE G 102      62.972  88.635  -1.500  1.00 10.21           C  \\nATOM  11463  CG1 ILE G 102      61.866  87.808  -2.124  1.00 10.21           C  \\nATOM  11464  CG2 ILE G 102      64.271  88.122  -1.967  1.00 10.21           C  \\nATOM  11465  CD1 ILE G 102      61.902  87.864  -3.610  1.00 10.21           C  \\nATOM  11466  N   ALA G 103      64.751  88.336   1.527  1.00 29.47           N  \\nATOM  11467  CA  ALA G 103      65.972  88.753   2.193  1.00 29.47           C  \\nATOM  11468  C   ALA G 103      67.057  89.087   1.173  1.00 29.47           C  \\nATOM  11469  O   ALA G 103      67.125  88.487   0.093  1.00 29.47           O  \\nATOM  11470  CB  ALA G 103      66.440  87.688   3.135  1.00 16.64           C  \\nATOM  11471  N   GLN G 104      67.860  90.089   1.521  1.00 38.53           N  \\nATOM  11472  CA  GLN G 104      68.946  90.593   0.688  1.00 38.53           C  \\nATOM  11473  C   GLN G 104      68.523  90.968  -0.729  1.00 38.53           C  \\nATOM  11474  O   GLN G 104      69.317  90.858  -1.662  1.00 38.53           O  \\nATOM  11475  CB  GLN G 104      70.148  89.638   0.691  1.00 49.57           C  \\nATOM  11476  CG  GLN G 104      71.063  89.805   1.914  1.00 49.57           C  \\nATOM  11477  CD  GLN G 104      71.760  91.186   1.986  1.00 49.57           C  \\nATOM  11478  OE1 GLN G 104      72.717  91.454   1.239  1.00 49.57           O  \\nATOM  11479  NE2 GLN G 104      71.313  92.040   2.921  1.00 49.57           N  \\nATOM  11480  N   GLY G 105      67.278  91.430  -0.872  1.00 25.06           N  \\nATOM  11481  CA  GLY G 105      66.754  91.846  -2.168  1.00 25.06           C  \\nATOM  11482  C   GLY G 105      66.735  93.362  -2.391  1.00 25.06           C  \\nATOM  11483  O   GLY G 105      66.747  93.822  -3.532  1.00 25.06           O  \\nATOM  11484  N   GLY G 106      66.688  94.148  -1.311  1.00 21.90           N  \\nATOM  11485  CA  GLY G 106      66.677  95.599  -1.429  1.00 21.90           C  \\nATOM  11486  C   GLY G 106      65.434  96.091  -2.125  1.00 21.90           C  \\nATOM  11487  O   GLY G 106      64.491  95.330  -2.287  1.00 21.90           O  \\nATOM  11488  N   VAL G 107      65.432  97.341  -2.585  1.00 36.17           N  \\nATOM  11489  CA  VAL G 107      64.249  97.886  -3.260  1.00 36.17           C  \\nATOM  11490  C   VAL G 107      64.549  98.243  -4.706  1.00 36.17           C  \\nATOM  11491  O   VAL G 107      65.683  98.122  -5.165  1.00 36.17           O  \\nATOM  11492  CB  VAL G 107      63.649  99.140  -2.528  1.00 24.30           C  \\nATOM  11493  CG1 VAL G 107      63.576  98.928  -1.023  1.00 24.30           C  \\nATOM  11494  CG2 VAL G 107      64.436 100.381  -2.840  1.00 24.30           C  \\nATOM  11495  N   LEU G 108      63.499  98.619  -5.426  1.00 23.56           N  \\nATOM  11496  CA  LEU G 108      63.588  99.015  -6.827  1.00 23.56           C  \\nATOM  11497  C   LEU G 108      63.890 100.493  -6.923  1.00 23.56           C  \\nATOM  11498  O   LEU G 108      63.306 101.288  -6.178  1.00 23.56           O  \\nATOM  11499  CB  LEU G 108      62.243  98.824  -7.522  1.00  8.97           C  \\nATOM  11500  CG  LEU G 108      61.790  97.472  -8.019  1.00  8.97           C  \\nATOM  11501  CD1 LEU G 108      60.489  97.685  -8.807  1.00  8.97           C  \\nATOM  11502  CD2 LEU G 108      62.820  96.887  -8.930  1.00  8.97           C  \\nATOM  11503  N   PRO G 109      64.830 100.887  -7.803  1.00 44.27           N  \\nATOM  11504  CA  PRO G 109      65.100 102.320  -7.903  1.00 44.27           C  \\nATOM  11505  C   PRO G 109      63.805 103.047  -8.307  1.00 44.27           C  \\nATOM  11506  O   PRO G 109      63.089 102.617  -9.221  1.00 52.17           O  \\nATOM  11507  CB  PRO G 109      66.207 102.393  -8.970  1.00 52.14           C  \\nATOM  11508  CG  PRO G 109      66.181 101.058  -9.652  1.00 52.14           C  \\nATOM  11509  CD  PRO G 109      65.856 100.122  -8.530  1.00 52.14           C  \\nATOM  11510  N   ASN G 110      63.476 104.078  -7.528  1.00 17.90           N  \\nATOM  11511  CA  ASN G 110      62.280 104.895  -7.703  1.00 17.90           C  \\nATOM  11512  C   ASN G 110      62.353 106.145  -6.814  1.00 17.90           C  \\nATOM  11513  O   ASN G 110      62.500 106.020  -5.582  1.00 17.90           O  \\nATOM  11514  CB  ASN G 110      61.032 104.072  -7.335  1.00 73.16           C  \\nATOM  11515  CG  ASN G 110      59.800 104.935  -7.097  1.00 73.16           C  \\nATOM  11516  OD1 ASN G 110      59.194 105.459  -8.038  1.00 73.16           O  \\nATOM  11517  ND2 ASN G 110      59.431 105.094  -5.827  1.00 73.16           N  \\nATOM  11518  N   ILE G 111      62.306 107.330  -7.442  1.00 34.95           N  \\nATOM  11519  CA  ILE G 111      62.324 108.607  -6.702  1.00 34.95           C  \\nATOM  11520  C   ILE G 111      61.146 109.477  -7.107  1.00 34.95           C  \\nATOM  11521  O   ILE G 111      61.029 109.865  -8.273  1.00 34.95           O  \\nATOM  11522  CB  ILE G 111      63.595 109.488  -6.951  1.00 37.55           C  \\nATOM  11523  CG1 ILE G 111      64.890 108.735  -6.620  1.00 37.55           C  \\nATOM  11524  CG2 ILE G 111      63.511 110.760  -6.086  1.00 37.55           C  \\nATOM  11525  CD1 ILE G 111      66.147 109.498  -6.984  1.00 37.55           C  \\nATOM  11526  N   GLN G 112      60.322 109.839  -6.125  1.00 32.33           N  \\nATOM  11527  CA  GLN G 112      59.157 110.683  -6.365  1.00 32.33           C  \\nATOM  11528  C   GLN G 112      59.584 111.918  -7.141  1.00 32.33           C  \\nATOM  11529  O   GLN G 112      60.405 112.695  -6.667  1.00 32.33           O  \\nATOM  11530  CB  GLN G 112      58.516 111.103  -5.037  1.00 37.18           C  \\nATOM  11531  CG  GLN G 112      57.906 109.957  -4.245  1.00 37.18           C  \\nATOM  11532  CD  GLN G 112      56.950 109.107  -5.076  1.00 37.18           C  \\nATOM  11533  OE1 GLN G 112      55.933 109.598  -5.585  1.00 37.18           O  \\nATOM  11534  NE2 GLN G 112      57.286 107.827  -5.233  1.00 37.18           N  \\nATOM  11535  N   SER G 113      59.001 112.099  -8.322  1.00 36.71           N  \\nATOM  11536  CA  SER G 113      59.322 113.225  -9.197  1.00 36.71           C  \\nATOM  11537  C   SER G 113      59.324 114.608  -8.540  1.00 36.71           C  \\nATOM  11538  O   SER G 113      60.135 115.458  -8.892  1.00 36.71           O  \\nATOM  11539  CB  SER G 113      58.377 113.248 -10.393  1.00 46.70           C  \\nATOM  11540  OG  SER G 113      57.061 113.574  -9.983  1.00 46.70           O  \\nATOM  11541  N   VAL G 114      58.442 114.822  -7.570  1.00 40.62           N  \\nATOM  11542  CA  VAL G 114      58.353 116.105  -6.882  1.00 40.62           C  \\nATOM  11543  C   VAL G 114      59.674 116.420  -6.185  1.00 40.62           C  \\nATOM  11544  O   VAL G 114      59.982 117.574  -5.887  1.00 40.62           O  \\nATOM  11545  CB  VAL G 114      57.221 116.091  -5.841  1.00 47.33           C  \\nATOM  11546  CG1 VAL G 114      56.917 117.504  -5.402  1.00 47.33           C  \\nATOM  11547  CG2 VAL G 114      55.957 115.402  -6.414  1.00 47.33           C  \\nATOM  11548  N   LEU G 115      60.485 115.384  -6.006  1.00 52.74           N  \\nATOM  11549  CA  LEU G 115      61.781 115.484  -5.351  1.00 52.74           C  \\nATOM  11550  C   LEU G 115      62.993 115.692  -6.250  1.00 52.74           C  \\nATOM  11551  O   LEU G 115      64.086 115.940  -5.748  1.00 25.03           O  \\nATOM  11552  CB  LEU G 115      62.019 114.232  -4.524  1.00 25.14           C  \\nATOM  11553  CG  LEU G 115      60.987 113.982  -3.435  1.00 25.14           C  \\nATOM  11554  CD1 LEU G 115      61.319 112.712  -2.666  1.00 25.14           C  \\nATOM  11555  CD2 LEU G 115      60.966 115.165  -2.504  1.00 25.14           C  \\nATOM  11556  N   LEU G 116      62.828 115.575  -7.561  1.00 41.27           N  \\nATOM  11557  CA  LEU G 116      63.958 115.756  -8.467  1.00 41.27           C  \\nATOM  11558  C   LEU G 116      64.381 117.222  -8.550  1.00 41.27           C  \\nATOM  11559  O   LEU G 116      63.609 118.117  -8.196  1.00 41.27           O  \\nATOM  11560  CB  LEU G 116      63.627 115.196  -9.852  1.00 34.03           C  \\nATOM  11561  CG  LEU G 116      63.449 113.670  -9.877  1.00 34.03           C  \\nATOM  11562  CD1 LEU G 116      63.123 113.239 -11.300  1.00 34.03           C  \\nATOM  11563  CD2 LEU G 116      64.691 112.937  -9.339  1.00 34.03           C  \\nATOM  11564  N   PRO G 117      65.646 117.485  -8.934  1.00 77.77           N  \\nATOM  11565  CA  PRO G 117      66.157 118.857  -9.049  1.00 77.77           C  \\nATOM  11566  C   PRO G 117      65.273 119.740  -9.943  1.00 77.77           C  \\nATOM  11567  O   PRO G 117      64.708 119.266 -10.937  1.00 77.77           O  \\nATOM  11568  CB  PRO G 117      67.547 118.642  -9.636  1.00100.50           C  \\nATOM  11569  CG  PRO G 117      67.960 117.354  -9.003  1.00100.50           C  \\nATOM  11570  CD  PRO G 117      66.723 116.512  -9.191  1.00100.50           C  \\nATOM  11571  N   LYS G 118      65.194 121.023  -9.585  1.00119.35           N  \\nATOM  11572  CA  LYS G 118      64.367 122.026 -10.265  1.00119.35           C  \\nATOM  11573  C   LYS G 118      64.731 122.479 -11.678  1.00119.35           C  \\nATOM  11574  O   LYS G 118      63.914 123.118 -12.348  1.00 83.28           O  \\nATOM  11575  CB  LYS G 118      64.237 123.249  -9.363  1.00148.44           C  \\nATOM  11576  CG  LYS G 118      63.675 122.911  -8.001  1.00148.44           C  \\nATOM  11577  CD  LYS G 118      64.003 123.980  -6.989  1.00148.44           C  \\nATOM  11578  CE  LYS G 118      63.553 123.556  -5.606  1.00148.44           C  \\nATOM  11579  NZ  LYS G 118      64.048 124.495  -4.566  1.00148.44           N  \\nATOM  11580  N   LYS G 119      65.953 122.186 -12.119  1.00163.83           N  \\nATOM  11581  CA  LYS G 119      66.405 122.574 -13.457  1.00163.83           C  \\nATOM  11582  C   LYS G 119      67.354 121.545 -14.092  1.00163.83           C  \\nATOM  11583  O   LYS G 119      67.095 120.332 -13.933  1.00153.86           O  \\nATOM  11584  CB  LYS G 119      67.069 123.957 -13.413  1.00153.86           C  \\nATOM  11585  CG  LYS G 119      66.124 125.087 -13.070  1.00153.86           C  \\nATOM  11586  CD  LYS G 119      66.754 126.425 -13.348  1.00153.86           C  \\nATOM  11587  CE  LYS G 119      65.734 127.520 -13.175  1.00153.86           C  \\nATOM  11588  NZ  LYS G 119      66.188 128.785 -13.801  1.00153.86           N  \\nATOM  11589  OXT LYS G 119      68.333 121.950 -14.763  1.00153.86           O  \\nTER   11590      LYS G 119                                                      \\nATOM  11591  N   LYS H  24      82.428  54.051  12.410  1.00170.84           N  \\nATOM  11592  CA  LYS H  24      81.172  53.806  13.176  1.00170.84           C  \\nATOM  11593  C   LYS H  24      80.201  55.004  13.183  1.00170.84           C  \\nATOM  11594  O   LYS H  24      79.193  54.980  12.472  1.00170.84           O  \\nATOM  11595  CB  LYS H  24      81.500  53.348  14.605  1.00108.34           C  \\nATOM  11596  CG  LYS H  24      82.596  54.152  15.290  1.00108.34           C  \\nATOM  11597  CD  LYS H  24      82.510  54.044  16.794  1.00108.34           C  \\nATOM  11598  CE  LYS H  24      83.540  54.933  17.446  1.00108.34           C  \\nATOM  11599  NZ  LYS H  24      83.342  54.971  18.912  1.00108.34           N  \\nATOM  11600  N   LYS H  25      80.507  56.038  13.977  1.00156.61           N  \\nATOM  11601  CA  LYS H  25      79.684  57.258  14.103  1.00156.61           C  \\nATOM  11602  C   LYS H  25      78.196  57.044  14.439  1.00156.61           C  \\nATOM  11603  O   LYS H  25      77.843  56.886  15.611  1.00156.61           O  \\nATOM  11604  CB  LYS H  25      79.829  58.160  12.862  1.00 99.20           C  \\nATOM  11605  CG  LYS H  25      81.110  58.996  12.789  1.00 99.20           C  \\nATOM  11606  CD  LYS H  25      81.131  59.803  11.494  1.00 99.20           C  \\nATOM  11607  CE  LYS H  25      82.360  60.688  11.378  1.00 99.20           C  \\nATOM  11608  NZ  LYS H  25      82.389  61.354  10.044  1.00 99.20           N  \\nATOM  11609  N   ARG H  26      77.341  57.063  13.412  1.00186.32           N  \\nATOM  11610  CA  ARG H  26      75.889  56.885  13.547  1.00186.32           C  \\nATOM  11611  C   ARG H  26      75.165  58.133  14.095  1.00186.32           C  \\nATOM  11612  O   ARG H  26      75.094  58.361  15.305  1.00186.32           O  \\nATOM  11613  CB  ARG H  26      75.573  55.608  14.349  1.00112.48           C  \\nATOM  11614  CG  ARG H  26      74.112  55.383  14.671  1.00112.48           C  \\nATOM  11615  CD  ARG H  26      73.819  53.915  14.941  1.00112.48           C  \\nATOM  11616  NE  ARG H  26      73.553  53.186  13.703  1.00112.48           N  \\nATOM  11617  CZ  ARG H  26      72.488  53.389  12.930  1.00112.48           C  \\nATOM  11618  NH1 ARG H  26      71.580  54.300  13.257  1.00112.48           N  \\nATOM  11619  NH2 ARG H  26      72.325  52.683  11.821  1.00112.48           N  \\nATOM  11620  N   ARG H  27      74.653  58.941  13.163  1.00142.46           N  \\nATOM  11621  CA  ARG H  27      73.934  60.195  13.436  1.00142.46           C  \\nATOM  11622  C   ARG H  27      73.512  60.753  12.062  1.00142.46           C  \\nATOM  11623  O   ARG H  27      74.367  60.942  11.192  1.00142.46           O  \\nATOM  11624  CB  ARG H  27      74.861  61.187  14.156  1.00 89.01           C  \\nATOM  11625  CG  ARG H  27      76.232  61.351  13.495  1.00 89.01           C  \\nATOM  11626  CD  ARG H  27      77.020  62.491  14.101  1.00 89.01           C  \\nATOM  11627  NE  ARG H  27      78.284  62.710  13.400  1.00 89.01           N  \\nATOM  11628  CZ  ARG H  27      78.520  63.704  12.543  1.00 89.01           C  \\nATOM  11629  NH1 ARG H  27      77.576  64.597  12.256  1.00 89.01           N  \\nATOM  11630  NH2 ARG H  27      79.725  63.822  11.997  1.00 89.01           N  \\nATOM  11631  N   LYS H  28      72.218  61.016  11.850  1.00111.25           N  \\nATOM  11632  CA  LYS H  28      71.772  61.502  10.533  1.00111.25           C  \\nATOM  11633  C   LYS H  28      71.082  62.872  10.410  1.00111.25           C  \\nATOM  11634  O   LYS H  28      71.662  63.786   9.817  1.00111.25           O  \\nATOM  11635  CB  LYS H  28      70.950  60.417   9.782  1.00 97.28           C  \\nATOM  11636  CG  LYS H  28      70.935  60.629   8.249  1.00 97.28           C  \\nATOM  11637  CD  LYS H  28      70.382  59.475   7.393  1.00 97.28           C  \\nATOM  11638  CE  LYS H  28      70.830  59.700   5.936  1.00 97.28           C  \\nATOM  11639  NZ  LYS H  28      70.039  59.053   4.854  1.00 97.28           N  \\nATOM  11640  N   THR H  29      69.855  62.992  10.932  1.00 85.41           N  \\nATOM  11641  CA  THR H  29      69.034  64.219  10.876  1.00 85.41           C  \\nATOM  11642  C   THR H  29      68.169  64.154   9.631  1.00 85.41           C  \\nATOM  11643  O   THR H  29      67.046  63.663   9.679  1.00 85.41           O  \\nATOM  11644  CB  THR H  29      69.868  65.560  10.802  1.00132.76           C  \\nATOM  11645  OG1 THR H  29      70.641  65.731  11.994  1.00132.76           O  \\nATOM  11646  CG2 THR H  29      68.955  66.779  10.615  1.00132.76           C  \\nATOM  11647  N   ARG H  30      68.758  64.591   8.515  1.00 50.05           N  \\nATOM  11648  CA  ARG H  30      68.142  64.668   7.190  1.00 50.05           C  \\nATOM  11649  C   ARG H  30      67.327  65.928   6.973  1.00 50.05           C  \\nATOM  11650  O   ARG H  30      66.506  66.317   7.800  1.00 50.05           O  \\nATOM  11651  CB  ARG H  30      67.336  63.423   6.833  1.00 92.86           C  \\nATOM  11652  CG  ARG H  30      68.153  62.401   6.069  1.00 92.86           C  \\nATOM  11653  CD  ARG H  30      67.266  61.323   5.503  1.00 92.86           C  \\nATOM  11654  NE  ARG H  30      66.270  61.892   4.605  1.00 92.86           N  \\nATOM  11655  CZ  ARG H  30      66.378  61.915   3.280  1.00 92.86           C  \\nATOM  11656  NH1 ARG H  30      67.444  61.392   2.683  1.00 92.86           N  \\nATOM  11657  NH2 ARG H  30      65.408  62.453   2.552  1.00 92.86           N  \\nATOM  11658  N   LYS H  31      67.562  66.565   5.834  1.00 59.31           N  \\nATOM  11659  CA  LYS H  31      66.877  67.794   5.498  1.00 59.31           C  \\nATOM  11660  C   LYS H  31      66.448  67.846   4.045  1.00 59.31           C  \\nATOM  11661  O   LYS H  31      67.221  68.278   3.197  1.00 59.31           O  \\nATOM  11662  CB  LYS H  31      67.800  68.979   5.784  1.00 63.91           C  \\nATOM  11663  CG  LYS H  31      67.352  69.869   6.918  1.00 63.91           C  \\nATOM  11664  CD  LYS H  31      66.707  71.140   6.397  1.00 63.91           C  \\nATOM  11665  CE  LYS H  31      66.085  71.934   7.537  1.00 63.91           C  \\nATOM  11666  NZ  LYS H  31      64.930  71.206   8.149  1.00 63.91           N  \\nATOM  11667  N   GLU H  32      65.226  67.410   3.749  1.00 43.81           N  \\nATOM  11668  CA  GLU H  32      64.741  67.490   2.375  1.00 43.81           C  \\nATOM  11669  C   GLU H  32      64.622  68.966   1.998  1.00 43.81           C  \\nATOM  11670  O   GLU H  32      64.391  69.830   2.853  1.00 43.81           O  \\nATOM  11671  CB  GLU H  32      63.397  66.802   2.216  1.00 69.68           C  \\nATOM  11672  CG  GLU H  32      63.460  65.315   2.448  1.00 69.68           C  \\nATOM  11673  CD  GLU H  32      62.180  64.608   2.070  1.00 69.68           C  \\nATOM  11674  OE1 GLU H  32      61.134  65.278   1.957  1.00 69.68           O  \\nATOM  11675  OE2 GLU H  32      62.219  63.374   1.885  1.00 69.68           O  \\nATOM  11676  N   SER H  33      64.785  69.243   0.713  1.00 26.28           N  \\nATOM  11677  CA  SER H  33      64.747  70.596   0.193  1.00 26.28           C  \\nATOM  11678  C   SER H  33      64.474  70.543  -1.292  1.00 26.28           C  \\nATOM  11679  O   SER H  33      64.959  69.655  -1.974  1.00 26.28           O  \\nATOM  11680  CB  SER H  33      66.113  71.232   0.433  1.00 34.90           C  \\nATOM  11681  OG  SER H  33      66.363  72.255  -0.503  1.00 34.90           O  \\nATOM  11682  N   TYR H  34      63.801  71.555  -1.818  1.00 32.25           N  \\nATOM  11683  CA  TYR H  34      63.468  71.599  -3.244  1.00 32.25           C  \\nATOM  11684  C   TYR H  34      64.648  71.980  -4.166  1.00 32.25           C  \\nATOM  11685  O   TYR H  34      64.519  71.964  -5.402  1.00 32.25           O  \\nATOM  11686  CB  TYR H  34      62.276  72.553  -3.466  1.00 31.74           C  \\nATOM  11687  CG  TYR H  34      60.936  72.027  -2.953  1.00 31.74           C  \\nATOM  11688  CD1 TYR H  34      60.212  71.057  -3.674  1.00 31.74           C  \\nATOM  11689  CD2 TYR H  34      60.382  72.505  -1.762  1.00 31.74           C  \\nATOM  11690  CE1 TYR H  34      58.970  70.580  -3.216  1.00 31.74           C  \\nATOM  11691  CE2 TYR H  34      59.137  72.037  -1.301  1.00 31.74           C  \\nATOM  11692  CZ  TYR H  34      58.435  71.077  -2.032  1.00 31.74           C  \\nATOM  11693  OH  TYR H  34      57.196  70.655  -1.593  1.00 31.74           O  \\nATOM  11694  N   ALA H  35      65.813  72.236  -3.567  1.00 33.99           N  \\nATOM  11695  CA  ALA H  35      67.006  72.656  -4.303  1.00 33.99           C  \\nATOM  11696  C   ALA H  35      67.408  71.971  -5.618  1.00 33.99           C  \\nATOM  11697  O   ALA H  35      67.581  72.654  -6.627  1.00 33.99           O  \\nATOM  11698  CB  ALA H  35      68.204  72.761  -3.363  1.00 19.82           C  \\nATOM  11699  N   ILE H  36      67.556  70.651  -5.656  1.00 42.65           N  \\nATOM  11700  CA  ILE H  36      67.965  70.054  -6.933  1.00 42.65           C  \\nATOM  11701  C   ILE H  36      66.957  70.167  -8.070  1.00 42.65           C  \\nATOM  11702  O   ILE H  36      67.348  70.269  -9.225  1.00 42.65           O  \\nATOM  11703  CB  ILE H  36      68.457  68.602  -6.810  1.00 32.26           C  \\nATOM  11704  CG1 ILE H  36      67.347  67.692  -6.332  1.00 32.26           C  \\nATOM  11705  CG2 ILE H  36      69.654  68.542  -5.870  1.00 32.26           C  \\nATOM  11706  CD1 ILE H  36      67.671  66.256  -6.546  1.00 32.26           C  \\nATOM  11707  N   TYR H  37      65.671  70.227  -7.739  1.00 25.08           N  \\nATOM  11708  CA  TYR H  37      64.621  70.342  -8.748  1.00 25.08           C  \\nATOM  11709  C   TYR H  37      64.651  71.770  -9.235  1.00 25.08           C  \\nATOM  11710  O   TYR H  37      64.492  72.018 -10.427  1.00 25.08           O  \\nATOM  11711  CB  TYR H  37      63.285  69.991  -8.140  1.00 32.60           C  \\nATOM  11712  CG  TYR H  37      63.381  68.696  -7.399  1.00 32.60           C  \\nATOM  11713  CD1 TYR H  37      63.433  67.486  -8.081  1.00 32.60           C  \\nATOM  11714  CD2 TYR H  37      63.499  68.677  -6.020  1.00 32.60           C  \\nATOM  11715  CE1 TYR H  37      63.602  66.288  -7.403  1.00 32.60           C  \\nATOM  11716  CE2 TYR H  37      63.674  67.489  -5.328  1.00 32.60           C  \\nATOM  11717  CZ  TYR H  37      63.724  66.295  -6.021  1.00 32.60           C  \\nATOM  11718  OH  TYR H  37      63.881  65.108  -5.322  1.00 32.60           O  \\nATOM  11719  N   VAL H  38      64.899  72.703  -8.311  1.00 28.64           N  \\nATOM  11720  CA  VAL H  38      65.020  74.115  -8.670  1.00 28.64           C  \\nATOM  11721  C   VAL H  38      66.169  74.188  -9.664  1.00 28.64           C  \\nATOM  11722  O   VAL H  38      65.979  74.612 -10.806  1.00 28.64           O  \\nATOM  11723  CB  VAL H  38      65.385  75.012  -7.461  1.00 21.73           C  \\nATOM  11724  CG1 VAL H  38      65.723  76.419  -7.929  1.00 21.73           C  \\nATOM  11725  CG2 VAL H  38      64.247  75.064  -6.464  1.00 21.73           C  \\nATOM  11726  N   TYR H  39      67.348  73.726  -9.238  1.00 36.86           N  \\nATOM  11727  CA  TYR H  39      68.529  73.732 -10.087  1.00 36.86           C  \\nATOM  11728  C   TYR H  39      68.198  73.149 -11.462  1.00 36.86           C  \\nATOM  11729  O   TYR H  39      68.398  73.816 -12.473  1.00 36.86           O  \\nATOM  11730  CB  TYR H  39      69.685  72.961  -9.438  1.00 67.49           C  \\nATOM  11731  CG  TYR H  39      71.031  73.278 -10.062  1.00 67.49           C  \\nATOM  11732  CD1 TYR H  39      71.731  74.438  -9.709  1.00 67.49           C  \\nATOM  11733  CD2 TYR H  39      71.596  72.439 -11.022  1.00 67.49           C  \\nATOM  11734  CE1 TYR H  39      72.960  74.754 -10.298  1.00 67.49           C  \\nATOM  11735  CE2 TYR H  39      72.823  72.747 -11.616  1.00 67.49           C  \\nATOM  11736  CZ  TYR H  39      73.497  73.901 -11.248  1.00 67.49           C  \\nATOM  11737  OH  TYR H  39      74.713  74.192 -11.816  1.00 67.49           O  \\nATOM  11738  N   LYS H  40      67.648  71.937 -11.512  1.00 31.85           N  \\nATOM  11739  CA  LYS H  40      67.295  71.340 -12.797  1.00 31.85           C  \\nATOM  11740  C   LYS H  40      66.504  72.312 -13.680  1.00 31.85           C  \\nATOM  11741  O   LYS H  40      66.787  72.454 -14.873  1.00 31.85           O  \\nATOM  11742  CB  LYS H  40      66.479  70.063 -12.611  1.00 42.34           C  \\nATOM  11743  CG  LYS H  40      67.207  68.948 -11.904  1.00 42.34           C  \\nATOM  11744  CD  LYS H  40      66.361  67.695 -11.907  1.00 42.34           C  \\nATOM  11745  CE  LYS H  40      66.823  66.729 -10.835  1.00 42.34           C  \\nATOM  11746  NZ  LYS H  40      65.803  65.652 -10.614  1.00 42.34           N  \\nATOM  11747  N   VAL H  41      65.526  72.992 -13.088  1.00 27.27           N  \\nATOM  11748  CA  VAL H  41      64.693  73.940 -13.823  1.00 27.27           C  \\nATOM  11749  C   VAL H  41      65.508  75.133 -14.334  1.00 27.27           C  \\nATOM  11750  O   VAL H  41      65.306  75.591 -15.465  1.00 27.27           O  \\nATOM  11751  CB  VAL H  41      63.495  74.419 -12.955  1.00 60.33           C  \\nATOM  11752  CG1 VAL H  41      62.544  75.258 -13.782  1.00 60.33           C  \\nATOM  11753  CG2 VAL H  41      62.741  73.231 -12.385  1.00 60.33           C  \\nATOM  11754  N   LEU H  42      66.421  75.636 -13.505  1.00 37.69           N  \\nATOM  11755  CA  LEU H  42      67.276  76.754 -13.901  1.00 37.69           C  \\nATOM  11756  C   LEU H  42      68.037  76.394 -15.168  1.00 37.69           C  \\nATOM  11757  O   LEU H  42      68.062  77.162 -16.120  1.00 37.69           O  \\nATOM  11758  CB  LEU H  42      68.279  77.091 -12.800  1.00 21.19           C  \\nATOM  11759  CG  LEU H  42      69.293  78.214 -13.076  1.00 21.19           C  \\nATOM  11760  CD1 LEU H  42      68.637  79.443 -13.728  1.00 21.19           C  \\nATOM  11761  CD2 LEU H  42      69.965  78.610 -11.756  1.00 21.19           C  \\nATOM  11762  N   LYS H  43      68.630  75.204 -15.169  1.00 59.02           N  \\nATOM  11763  CA  LYS H  43      69.395  74.703 -16.303  1.00 59.02           C  \\nATOM  11764  C   LYS H  43      68.581  74.471 -17.568  1.00 59.02           C  \\nATOM  11765  O   LYS H  43      69.149  74.270 -18.647  1.00 59.02           O  \\nATOM  11766  CB  LYS H  43      70.157  73.441 -15.900  1.00 39.98           C  \\nATOM  11767  CG  LYS H  43      71.227  73.745 -14.883  1.00 39.98           C  \\nATOM  11768  CD  LYS H  43      71.964  74.986 -15.368  1.00 39.98           C  \\nATOM  11769  CE  LYS H  43      72.855  75.611 -14.331  1.00 39.98           C  \\nATOM  11770  NZ  LYS H  43      73.518  76.762 -14.987  1.00 39.98           N  \\nATOM  11771  N   GLN H  44      67.257  74.462 -17.425  1.00 38.73           N  \\nATOM  11772  CA  GLN H  44      66.351  74.302 -18.561  1.00 38.73           C  \\nATOM  11773  C   GLN H  44      66.012  75.679 -19.191  1.00 38.73           C  \\nATOM  11774  O   GLN H  44      65.881  75.820 -20.412  1.00 38.73           O  \\nATOM  11775  CB  GLN H  44      65.068  73.590 -18.125  1.00 68.52           C  \\nATOM  11776  CG  GLN H  44      64.915  72.176 -18.661  1.00 68.52           C  \\nATOM  11777  CD  GLN H  44      63.542  71.582 -18.363  1.00 68.52           C  \\nATOM  11778  OE1 GLN H  44      63.058  71.644 -17.233  1.00 68.52           O  \\nATOM  11779  NE2 GLN H  44      62.911  71.001 -19.379  1.00 68.52           N  \\nATOM  11780  N   VAL H  45      65.848  76.687 -18.347  1.00 45.52           N  \\nATOM  11781  CA  VAL H  45      65.526  78.018 -18.826  1.00 45.52           C  \\nATOM  11782  C   VAL H  45      66.765  78.761 -19.290  1.00 45.52           C  \\nATOM  11783  O   VAL H  45      66.799  79.298 -20.401  1.00 45.52           O  \\nATOM  11784  CB  VAL H  45      64.836  78.847 -17.732  1.00 52.48           C  \\nATOM  11785  CG1 VAL H  45      64.379  80.156 -18.313  1.00 52.48           C  \\nATOM  11786  CG2 VAL H  45      63.655  78.095 -17.143  1.00 52.48           C  \\nATOM  11787  N   HIS H  46      67.758  78.802 -18.408  1.00 59.38           N  \\nATOM  11788  CA  HIS H  46      69.040  79.461 -18.637  1.00 59.38           C  \\nATOM  11789  C   HIS H  46      70.089  78.431 -18.283  1.00 59.38           C  \\nATOM  11790  O   HIS H  46      70.656  78.449 -17.182  1.00 59.38           O  \\nATOM  11791  CB  HIS H  46      69.176  80.653 -17.716  1.00 42.51           C  \\nATOM  11792  CG  HIS H  46      68.257  81.770 -18.064  1.00 42.51           C  \\nATOM  11793  ND1 HIS H  46      67.047  81.955 -17.438  1.00 42.51           N  \\nATOM  11794  CD2 HIS H  46      68.367  82.758 -18.980  1.00 42.51           C  \\nATOM  11795  CE1 HIS H  46      66.448  83.012 -17.951  1.00 42.51           C  \\nATOM  11796  NE2 HIS H  46      67.228  83.518 -18.888  1.00 42.51           N  \\nATOM  11797  N   PRO H  47      70.427  77.568 -19.254  1.00 54.63           N  \\nATOM  11798  CA  PRO H  47      71.408  76.498 -19.073  1.00 54.63           C  \\nATOM  11799  C   PRO H  47      72.749  76.982 -18.584  1.00 54.63           C  \\nATOM  11800  O   PRO H  47      73.423  76.277 -17.840  1.00 54.63           O  \\nATOM  11801  CB  PRO H  47      71.512  75.887 -20.470  1.00 24.80           C  \\nATOM  11802  CG  PRO H  47      70.200  76.282 -21.137  1.00 24.80           C  \\nATOM  11803  CD  PRO H  47      70.057  77.693 -20.676  1.00 24.80           C  \\nATOM  11804  N   ASP H  48      73.098  78.213 -18.949  1.00 33.94           N  \\nATOM  11805  CA  ASP H  48      74.386  78.786 -18.574  1.00 33.94           C  \\nATOM  11806  C   ASP H  48      74.382  79.766 -17.377  1.00 33.94           C  \\nATOM  11807  O   ASP H  48      75.396  80.421 -17.105  1.00 33.94           O  \\nATOM  11808  CB  ASP H  48      75.048  79.410 -19.814  1.00 71.30           C  \\nATOM  11809  CG  ASP H  48      75.197  78.409 -20.982  1.00 71.30           C  \\nATOM  11810  OD1 ASP H  48      75.797  77.328 -20.800  1.00 71.30           O  \\nATOM  11811  OD2 ASP H  48      74.720  78.701 -22.100  1.00 71.30           O  \\nATOM  11812  N   THR H  49      73.275  79.807 -16.625  1.00 46.35           N  \\nATOM  11813  CA  THR H  49      73.146  80.687 -15.455  1.00 46.35           C  \\nATOM  11814  C   THR H  49      73.260  79.875 -14.164  1.00 46.35           C  \\nATOM  11815  O   THR H  49      72.585  78.876 -14.008  1.00 46.35           O  \\nATOM  11816  CB  THR H  49      71.777  81.411 -15.443  1.00 43.30           C  \\nATOM  11817  OG1 THR H  49      71.601  82.132 -16.664  1.00 43.30           O  \\nATOM  11818  CG2 THR H  49      71.704  82.388 -14.305  1.00 43.30           C  \\nATOM  11819  N   GLY H  50      74.106  80.312 -13.241  1.00 27.19           N  \\nATOM  11820  CA  GLY H  50      74.265  79.605 -11.981  1.00 27.19           C  \\nATOM  11821  C   GLY H  50      73.379  80.228 -10.915  1.00 27.19           C  \\nATOM  11822  O   GLY H  50      72.549  81.064 -11.236  1.00 27.19           O  \\nATOM  11823  N   ILE H  51      73.597  79.905  -9.641  1.00 26.19           N  \\nATOM  11824  CA  ILE H  51      72.753  80.469  -8.581  1.00 26.19           C  \\nATOM  11825  C   ILE H  51      73.359  80.495  -7.166  1.00 26.19           C  \\nATOM  11826  O   ILE H  51      73.766  79.464  -6.623  1.00 26.19           O  \\nATOM  11827  CB  ILE H  51      71.374  79.755  -8.537  1.00 47.65           C  \\nATOM  11828  CG1 ILE H  51      70.401  80.518  -7.636  1.00 47.65           C  \\nATOM  11829  CG2 ILE H  51      71.538  78.310  -8.061  1.00 47.65           C  \\nATOM  11830  CD1 ILE H  51      68.980  80.025  -7.730  1.00 47.65           C  \\nATOM  11831  N   SER H  52      73.329  81.696  -6.579  1.00 28.12           N  \\nATOM  11832  CA  SER H  52      73.829  82.016  -5.244  1.00 28.12           C  \\nATOM  11833  C   SER H  52      73.204  81.051  -4.260  1.00 28.12           C  \\nATOM  11834  O   SER H  52      72.075  80.592  -4.445  1.00 28.12           O  \\nATOM  11835  CB  SER H  52      73.420  83.464  -4.897  1.00 40.74           C  \\nATOM  11836  OG  SER H  52      73.777  83.883  -3.585  1.00 40.74           O  \\nATOM  11837  N   SER H  53      73.922  80.752  -3.194  1.00 38.97           N  \\nATOM  11838  CA  SER H  53      73.398  79.834  -2.210  1.00 38.97           C  \\nATOM  11839  C   SER H  53      72.185  80.431  -1.537  1.00 38.97           C  \\nATOM  11840  O   SER H  53      71.173  79.749  -1.353  1.00 38.97           O  \\nATOM  11841  CB  SER H  53      74.441  79.548  -1.156  1.00 35.09           C  \\nATOM  11842  OG  SER H  53      74.140  78.330  -0.526  1.00 35.09           O  \\nATOM  11843  N   LYS H  54      72.268  81.730  -1.237  1.00 49.51           N  \\nATOM  11844  CA  LYS H  54      71.179  82.456  -0.576  1.00 49.51           C  \\nATOM  11845  C   LYS H  54      69.966  82.583  -1.504  1.00 49.51           C  \\nATOM  11846  O   LYS H  54      68.808  82.573  -1.066  1.00 49.51           O  \\nATOM  11847  CB  LYS H  54      71.668  83.828  -0.120  1.00 46.10           C  \\nATOM  11848  CG  LYS H  54      72.780  83.751   0.918  1.00 46.10           C  \\nATOM  11849  CD  LYS H  54      73.288  85.132   1.298  1.00 46.10           C  \\nATOM  11850  CE  LYS H  54      74.433  85.068   2.284  1.00 46.10           C  \\nATOM  11851  NZ  LYS H  54      74.679  86.435   2.776  1.00 46.10           N  \\nATOM  11852  N   ALA H  55      70.249  82.704  -2.794  1.00 26.70           N  \\nATOM  11853  CA  ALA H  55      69.211  82.772  -3.799  1.00 26.70           C  \\nATOM  11854  C   ALA H  55      68.434  81.446  -3.756  1.00 26.70           C  \\nATOM  11855  O   ALA H  55      67.203  81.422  -3.809  1.00 26.70           O  \\nATOM  11856  CB  ALA H  55      69.846  82.987  -5.175  1.00 28.72           C  \\nATOM  11857  N   MET H  56      69.161  80.336  -3.656  1.00 16.72           N  \\nATOM  11858  CA  MET H  56      68.515  79.027  -3.596  1.00 16.72           C  \\nATOM  11859  C   MET H  56      67.651  78.896  -2.344  1.00 16.72           C  \\nATOM  11860  O   MET H  56      66.581  78.315  -2.383  1.00 16.72           O  \\nATOM  11861  CB  MET H  56      69.554  77.907  -3.677  1.00 25.38           C  \\nATOM  11862  CG  MET H  56      68.963  76.507  -3.748  1.00 25.38           C  \\nATOM  11863  SD  MET H  56      67.937  76.233  -5.182  1.00 25.38           S  \\nATOM  11864  CE  MET H  56      69.160  75.779  -6.384  1.00 25.38           C  \\nATOM  11865  N   SER H  57      68.110  79.460  -1.238  1.00 25.03           N  \\nATOM  11866  CA  SER H  57      67.343  79.420   0.002  1.00 25.03           C  \\nATOM  11867  C   SER H  57      65.983  80.158  -0.141  1.00 25.03           C  \\nATOM  11868  O   SER H  57      64.976  79.806   0.473  1.00 25.03           O  \\nATOM  11869  CB  SER H  57      68.184  80.014   1.134  1.00 33.07           C  \\nATOM  11870  OG  SER H  57      67.569  79.747   2.378  1.00 33.07           O  \\nATOM  11871  N   ILE H  58      65.982  81.205  -0.952  1.00 16.25           N  \\nATOM  11872  CA  ILE H  58      64.789  81.982  -1.219  1.00 16.25           C  \\nATOM  11873  C   ILE H  58      63.873  81.184  -2.112  1.00 16.25           C  \\nATOM  11874  O   ILE H  58      62.722  81.029  -1.797  1.00 16.25           O  \\nATOM  11875  CB  ILE H  58      65.170  83.373  -1.824  1.00 14.66           C  \\nATOM  11876  CG1 ILE H  58      65.804  84.248  -0.718  1.00 14.66           C  \\nATOM  11877  CG2 ILE H  58      63.949  84.059  -2.467  1.00 14.66           C  \\nATOM  11878  CD1 ILE H  58      66.432  85.485  -1.231  1.00 14.66           C  \\nATOM  11879  N   MET H  59      64.386  80.625  -3.201  1.00 25.41           N  \\nATOM  11880  CA  MET H  59      63.540  79.831  -4.086  1.00 25.41           C  \\nATOM  11881  C   MET H  59      62.831  78.712  -3.328  1.00 25.41           C  \\nATOM  11882  O   MET H  59      61.621  78.517  -3.431  1.00 25.41           O  \\nATOM  11883  CB  MET H  59      64.350  79.245  -5.228  1.00 22.33           C  \\nATOM  11884  CG  MET H  59      64.669  80.232  -6.317  1.00 22.33           C  \\nATOM  11885  SD  MET H  59      63.220  81.040  -7.048  1.00 22.33           S  \\nATOM  11886  CE  MET H  59      62.422  79.728  -7.952  1.00 22.33           C  \\nATOM  11887  N   ASN H  60      63.594  77.996  -2.525  1.00 32.03           N  \\nATOM  11888  CA  ASN H  60      63.050  76.902  -1.733  1.00 32.03           C  \\nATOM  11889  C   ASN H  60      61.871  77.403  -0.891  1.00 32.03           C  \\nATOM  11890  O   ASN H  60      60.764  76.913  -1.035  1.00 32.03           O  \\nATOM  11891  CB  ASN H  60      64.169  76.343  -0.858  1.00 24.47           C  \\nATOM  11892  CG  ASN H  60      63.774  75.105  -0.138  1.00 24.47           C  \\nATOM  11893  OD1 ASN H  60      63.377  74.127  -0.754  1.00 24.47           O  \\nATOM  11894  ND2 ASN H  60      63.868  75.133   1.186  1.00 24.47           N  \\nATOM  11895  N   SER H  61      62.110  78.420  -0.064  1.00 29.76           N  \\nATOM  11896  CA  SER H  61      61.074  79.009   0.778  1.00 29.76           C  \\nATOM  11897  C   SER H  61      59.876  79.298  -0.092  1.00 29.76           C  \\nATOM  11898  O   SER H  61      58.751  78.959   0.227  1.00 29.76           O  \\nATOM  11899  CB  SER H  61      61.556  80.330   1.386  1.00 27.03           C  \\nATOM  11900  OG  SER H  61      62.781  80.155   2.068  1.00 27.03           O  \\nATOM  11901  N   PHE H  62      60.141  79.896  -1.229  1.00 13.47           N  \\nATOM  11902  CA  PHE H  62      59.101  80.226  -2.148  1.00 13.47           C  \\nATOM  11903  C   PHE H  62      58.221  79.039  -2.516  1.00 13.47           C  \\nATOM  11904  O   PHE H  62      57.003  79.119  -2.455  1.00 13.47           O  \\nATOM  11905  CB  PHE H  62      59.726  80.808  -3.385  1.00 20.06           C  \\nATOM  11906  CG  PHE H  62      58.780  80.942  -4.498  1.00 20.06           C  \\nATOM  11907  CD1 PHE H  62      57.715  81.818  -4.404  1.00 20.06           C  \\nATOM  11908  CD2 PHE H  62      58.951  80.208  -5.652  1.00 20.06           C  \\nATOM  11909  CE1 PHE H  62      56.828  81.966  -5.463  1.00 20.06           C  \\nATOM  11910  CE2 PHE H  62      58.074  80.348  -6.714  1.00 20.06           C  \\nATOM  11911  CZ  PHE H  62      57.009  81.227  -6.626  1.00 20.06           C  \\nATOM  11912  N   VAL H  63      58.846  77.947  -2.924  1.00 20.17           N  \\nATOM  11913  CA  VAL H  63      58.116  76.749  -3.301  1.00 20.17           C  \\nATOM  11914  C   VAL H  63      57.335  76.184  -2.127  1.00 20.17           C  \\nATOM  11915  O   VAL H  63      56.212  75.718  -2.289  1.00 20.17           O  \\nATOM  11916  CB  VAL H  63      59.053  75.700  -3.869  1.00  5.87           C  \\nATOM  11917  CG1 VAL H  63      58.284  74.456  -4.166  1.00  5.87           C  \\nATOM  11918  CG2 VAL H  63      59.763  76.238  -5.133  1.00  5.87           C  \\nATOM  11919  N   ASN H  64      57.923  76.224  -0.939  1.00 23.79           N  \\nATOM  11920  CA  ASN H  64      57.214  75.760   0.248  1.00 23.79           C  \\nATOM  11921  C   ASN H  64      55.988  76.642   0.442  1.00 23.79           C  \\nATOM  11922  O   ASN H  64      54.872  76.155   0.565  1.00 23.79           O  \\nATOM  11923  CB  ASN H  64      58.090  75.867   1.475  1.00 57.53           C  \\nATOM  11924  CG  ASN H  64      59.202  74.879   1.457  1.00 57.53           C  \\nATOM  11925  OD1 ASN H  64      58.978  73.703   1.197  1.00 57.53           O  \\nATOM  11926  ND2 ASN H  64      60.426  75.344   1.707  1.00 57.53           N  \\nATOM  11927  N   ASP H  65      56.202  77.948   0.397  1.00 26.79           N  \\nATOM  11928  CA  ASP H  65      55.130  78.899   0.567  1.00 26.79           C  \\nATOM  11929  C   ASP H  65      53.979  78.580  -0.393  1.00 26.79           C  \\nATOM  11930  O   ASP H  65      52.885  78.210   0.024  1.00 26.79           O  \\nATOM  11931  CB  ASP H  65      55.652  80.324   0.357  1.00 36.10           C  \\nATOM  11932  CG  ASP H  65      54.615  81.368   0.685  1.00 36.10           C  \\nATOM  11933  OD1 ASP H  65      53.921  81.224   1.712  1.00 36.10           O  \\nATOM  11934  OD2 ASP H  65      54.460  82.321  -0.097  1.00 36.10           O  \\nATOM  11935  N   VAL H  66      54.239  78.630  -1.683  1.00 23.66           N  \\nATOM  11936  CA  VAL H  66      53.185  78.348  -2.629  1.00 23.66           C  \\nATOM  11937  C   VAL H  66      52.582  76.953  -2.402  1.00 23.66           C  \\nATOM  11938  O   VAL H  66      51.369  76.779  -2.500  1.00 23.66           O  \\nATOM  11939  CB  VAL H  66      53.691  78.552  -4.036  1.00 28.19           C  \\nATOM  11940  CG1 VAL H  66      52.563  78.409  -5.020  1.00 28.19           C  \\nATOM  11941  CG2 VAL H  66      54.297  79.939  -4.140  1.00 28.19           C  \\nATOM  11942  N   PHE H  67      53.404  75.971  -2.029  1.00 23.40           N  \\nATOM  11943  CA  PHE H  67      52.865  74.649  -1.743  1.00 23.40           C  \\nATOM  11944  C   PHE H  67      51.816  74.777  -0.645  1.00 23.40           C  \\nATOM  11945  O   PHE H  67      50.661  74.428  -0.847  1.00 23.40           O  \\nATOM  11946  CB  PHE H  67      53.960  73.680  -1.278  1.00 18.81           C  \\nATOM  11947  CG  PHE H  67      53.431  72.312  -0.855  1.00 18.81           C  \\nATOM  11948  CD1 PHE H  67      53.010  72.076   0.455  1.00 18.81           C  \\nATOM  11949  CD2 PHE H  67      53.322  71.276  -1.770  1.00 18.81           C  \\nATOM  11950  CE1 PHE H  67      52.487  70.832   0.839  1.00 18.81           C  \\nATOM  11951  CE2 PHE H  67      52.800  70.030  -1.391  1.00 18.81           C  \\nATOM  11952  CZ  PHE H  67      52.384  69.812  -0.094  1.00 18.81           C  \\nATOM  11953  N   GLU H  68      52.221  75.340   0.496  1.00 27.75           N  \\nATOM  11954  CA  GLU H  68      51.349  75.488   1.667  1.00 27.75           C  \\nATOM  11955  C   GLU H  68      50.090  76.283   1.396  1.00 27.75           C  \\nATOM  11956  O   GLU H  68      49.000  75.875   1.789  1.00 27.75           O  \\nATOM  11957  CB  GLU H  68      52.123  76.040   2.871  1.00 54.84           C  \\nATOM  11958  CG  GLU H  68      53.311  75.144   3.281  1.00 54.84           C  \\nATOM  11959  CD  GLU H  68      54.006  75.523   4.617  1.00 54.84           C  \\nATOM  11960  OE1 GLU H  68      54.261  76.727   4.891  1.00 54.84           O  \\nATOM  11961  OE2 GLU H  68      54.331  74.586   5.391  1.00 54.84           O  \\nATOM  11962  N   ARG H  69      50.222  77.365   0.643  1.00 21.66           N  \\nATOM  11963  CA  ARG H  69      49.074  78.192   0.310  1.00 21.66           C  \\nATOM  11964  C   ARG H  69      48.062  77.441  -0.553  1.00 21.66           C  \\nATOM  11965  O   ARG H  69      46.850  77.444  -0.283  1.00 21.66           O  \\nATOM  11966  CB  ARG H  69      49.530  79.473  -0.372  1.00 17.19           C  \\nATOM  11967  CG  ARG H  69      50.352  80.370   0.529  1.00 17.19           C  \\nATOM  11968  CD  ARG H  69      50.159  81.820   0.138  1.00 17.19           C  \\nATOM  11969  NE  ARG H  69      51.360  82.417  -0.424  1.00 17.19           N  \\nATOM  11970  CZ  ARG H  69      51.357  83.433  -1.289  1.00 17.19           C  \\nATOM  11971  NH1 ARG H  69      50.212  83.980  -1.712  1.00 17.19           N  \\nATOM  11972  NH2 ARG H  69      52.514  83.931  -1.727  1.00 17.19           N  \\nATOM  11973  N   ILE H  70      48.567  76.747  -1.564  1.00 20.72           N  \\nATOM  11974  CA  ILE H  70      47.696  75.996  -2.433  1.00 20.72           C  \\nATOM  11975  C   ILE H  70      47.006  74.856  -1.730  1.00 20.72           C  \\nATOM  11976  O   ILE H  70      45.795  74.712  -1.850  1.00 20.72           O  \\nATOM  11977  CB  ILE H  70      48.425  75.470  -3.654  1.00 19.61           C  \\nATOM  11978  CG1 ILE H  70      48.709  76.637  -4.611  1.00 19.61           C  \\nATOM  11979  CG2 ILE H  70      47.585  74.383  -4.326  1.00 19.61           C  \\nATOM  11980  CD1 ILE H  70      49.005  76.228  -6.028  1.00 19.61           C  \\nATOM  11981  N   ALA H  71      47.772  74.036  -1.011  1.00 22.39           N  \\nATOM  11982  CA  ALA H  71      47.197  72.904  -0.295  1.00 22.39           C  \\nATOM  11983  C   ALA H  71      46.180  73.414   0.706  1.00 22.39           C  \\nATOM  11984  O   ALA H  71      45.106  72.835   0.836  1.00 22.39           O  \\nATOM  11985  CB  ALA H  71      48.267  72.105   0.400  1.00  8.44           C  \\nATOM  11986  N   GLY H  72      46.513  74.508   1.398  1.00 31.09           N  \\nATOM  11987  CA  GLY H  72      45.600  75.085   2.367  1.00 31.09           C  \\nATOM  11988  C   GLY H  72      44.259  75.452   1.744  1.00 31.09           C  \\nATOM  11989  O   GLY H  72      43.210  75.119   2.296  1.00 31.09           O  \\nATOM  11990  N   GLU H  73      44.280  76.127   0.591  1.00 21.31           N  \\nATOM  11991  CA  GLU H  73      43.040  76.509  -0.070  1.00 21.31           C  \\nATOM  11992  C   GLU H  73      42.224  75.279  -0.451  1.00 21.31           C  \\nATOM  11993  O   GLU H  73      41.036  75.218  -0.158  1.00 21.31           O  \\nATOM  11994  CB  GLU H  73      43.316  77.388  -1.291  1.00 45.11           C  \\nATOM  11995  CG  GLU H  73      42.105  78.222  -1.741  1.00 45.11           C  \\nATOM  11996  CD  GLU H  73      41.620  79.216  -0.674  1.00 45.11           C  \\nATOM  11997  OE1 GLU H  73      42.310  80.252  -0.459  1.00 45.11           O  \\nATOM  11998  OE2 GLU H  73      40.543  78.957  -0.071  1.00 45.11           O  \\nATOM  11999  N   ALA H  74      42.870  74.298  -1.082  1.00 21.07           N  \\nATOM  12000  CA  ALA H  74      42.238  73.037  -1.482  1.00 21.07           C  \\nATOM  12001  C   ALA H  74      41.666  72.270  -0.278  1.00 21.07           C  \\nATOM  12002  O   ALA H  74      40.669  71.547  -0.401  1.00 21.07           O  \\nATOM  12003  CB  ALA H  74      43.228  72.183  -2.198  1.00 17.97           C  \\nATOM  12004  N   SER H  75      42.347  72.361   0.862  1.00 19.21           N  \\nATOM  12005  CA  SER H  75      41.866  71.757   2.088  1.00 19.21           C  \\nATOM  12006  C   SER H  75      40.486  72.357   2.337  1.00 19.21           C  \\nATOM  12007  O   SER H  75      39.486  71.644   2.432  1.00 19.21           O  \\nATOM  12008  CB  SER H  75      42.769  72.144   3.250  1.00 16.36           C  \\nATOM  12009  OG  SER H  75      42.274  71.592   4.457  1.00 16.36           O  \\nATOM  12010  N   ARG H  76      40.440  73.683   2.444  1.00 16.36           N  \\nATOM  12011  CA  ARG H  76      39.192  74.394   2.662  1.00 16.36           C  \\nATOM  12012  C   ARG H  76      38.120  73.995   1.652  1.00 16.36           C  \\nATOM  12013  O   ARG H  76      37.053  73.569   2.054  1.00 16.36           O  \\nATOM  12014  CB  ARG H  76      39.446  75.896   2.697  1.00 38.08           C  \\nATOM  12015  CG  ARG H  76      39.983  76.347   4.050  1.00 38.08           C  \\nATOM  12016  CD  ARG H  76      40.575  77.752   4.024  1.00 38.08           C  \\nATOM  12017  NE  ARG H  76      41.992  77.723   4.379  1.00 38.08           N  \\nATOM  12018  CZ  ARG H  76      42.953  78.306   3.667  1.00 38.08           C  \\nATOM  12019  NH1 ARG H  76      42.650  78.991   2.559  1.00 38.08           N  \\nATOM  12020  NH2 ARG H  76      44.226  78.129   4.011  1.00 38.08           N  \\nATOM  12021  N   LEU H  77      38.389  74.090   0.357  1.00 31.08           N  \\nATOM  12022  CA  LEU H  77      37.397  73.664  -0.629  1.00 31.08           C  \\nATOM  12023  C   LEU H  77      36.765  72.319  -0.235  1.00 31.08           C  \\nATOM  12024  O   LEU H  77      35.545  72.214  -0.139  1.00 31.08           O  \\nATOM  12025  CB  LEU H  77      38.030  73.523  -2.000  1.00 19.29           C  \\nATOM  12026  CG  LEU H  77      38.343  74.820  -2.737  1.00 19.29           C  \\nATOM  12027  CD1 LEU H  77      39.290  74.530  -3.892  1.00 19.29           C  \\nATOM  12028  CD2 LEU H  77      37.058  75.458  -3.263  1.00 19.29           C  \\nATOM  12029  N   ALA H  78      37.584  71.301   0.043  1.00 23.77           N  \\nATOM  12030  CA  ALA H  78      37.041  69.996   0.435  1.00 23.77           C  \\nATOM  12031  C   ALA H  78      36.050  70.049   1.605  1.00 23.77           C  \\nATOM  12032  O   ALA H  78      34.973  69.487   1.501  1.00 23.77           O  \\nATOM  12033  CB  ALA H  78      38.155  69.014   0.724  1.00  6.30           C  \\nATOM  12034  N   HIS H  79      36.410  70.697   2.717  1.00 32.00           N  \\nATOM  12035  CA  HIS H  79      35.508  70.805   3.888  1.00 32.00           C  \\nATOM  12036  C   HIS H  79      34.181  71.483   3.540  1.00 32.00           C  \\nATOM  12037  O   HIS H  79      33.115  71.024   3.953  1.00 32.00           O  \\nATOM  12038  CB  HIS H  79      36.164  71.565   5.037  1.00105.78           C  \\nATOM  12039  CG  HIS H  79      37.254  70.805   5.720  1.00105.78           C  \\nATOM  12040  ND1 HIS H  79      38.405  70.407   5.072  1.00105.78           N  \\nATOM  12041  CD2 HIS H  79      37.383  70.392   7.003  1.00105.78           C  \\nATOM  12042  CE1 HIS H  79      39.196  69.782   5.926  1.00105.78           C  \\nATOM  12043  NE2 HIS H  79      38.599  69.760   7.105  1.00105.78           N  \\nATOM  12044  N   TYR H  80      34.258  72.577   2.785  1.00 26.59           N  \\nATOM  12045  CA  TYR H  80      33.076  73.327   2.362  1.00 26.59           C  \\nATOM  12046  C   TYR H  80      32.072  72.391   1.730  1.00 26.59           C  \\nATOM  12047  O   TYR H  80      30.884  72.433   2.033  1.00 26.59           O  \\nATOM  12048  CB  TYR H  80      33.478  74.408   1.356  1.00 36.67           C  \\nATOM  12049  CG  TYR H  80      34.364  75.462   1.974  1.00 36.67           C  \\nATOM  12050  CD1 TYR H  80      34.571  75.493   3.367  1.00 36.67           C  \\nATOM  12051  CD2 TYR H  80      34.968  76.456   1.188  1.00 36.67           C  \\nATOM  12052  CE1 TYR H  80      35.343  76.479   3.958  1.00 36.67           C  \\nATOM  12053  CE2 TYR H  80      35.748  77.457   1.776  1.00 36.67           C  \\nATOM  12054  CZ  TYR H  80      35.927  77.459   3.164  1.00 36.67           C  \\nATOM  12055  OH  TYR H  80      36.674  78.448   3.770  1.00 36.67           O  \\nATOM  12056  N   ASN H  81      32.586  71.514   0.880  1.00 27.08           N  \\nATOM  12057  CA  ASN H  81      31.779  70.542   0.188  1.00 27.08           C  \\nATOM  12058  C   ASN H  81      31.637  69.204   0.867  1.00 27.08           C  \\nATOM  12059  O   ASN H  81      31.168  68.248   0.257  1.00 27.08           O  \\nATOM  12060  CB  ASN H  81      32.309  70.403  -1.211  1.00 45.15           C  \\nATOM  12061  CG  ASN H  81      32.291  71.714  -1.919  1.00 45.15           C  \\nATOM  12062  OD1 ASN H  81      31.319  72.044  -2.598  1.00 45.15           O  \\nATOM  12063  ND2 ASN H  81      33.289  72.539  -1.658  1.00 45.15           N  \\nATOM  12064  N   LYS H  82      32.014  69.138   2.140  1.00 48.07           N  \\nATOM  12065  CA  LYS H  82      31.895  67.912   2.918  1.00 48.07           C  \\nATOM  12066  C   LYS H  82      32.514  66.719   2.194  1.00 48.07           C  \\nATOM  12067  O   LYS H  82      31.878  65.676   2.088  1.00 48.07           O  \\nATOM  12068  CB  LYS H  82      30.407  67.631   3.214  1.00 71.73           C  \\nATOM  12069  CG  LYS H  82      29.603  68.864   3.661  1.00 71.73           C  \\nATOM  12070  CD  LYS H  82      28.135  68.548   3.940  1.00 71.73           C  \\nATOM  12071  CE  LYS H  82      27.388  68.093   2.680  1.00 71.73           C  \\nATOM  12072  NZ  LYS H  82      25.966  67.667   2.942  1.00 71.73           N  \\nATOM  12073  N   ARG H  83      33.699  66.907   1.611  1.00 43.13           N  \\nATOM  12074  CA  ARG H  83      34.406  65.829   0.902  1.00 43.13           C  \\nATOM  12075  C   ARG H  83      35.653  65.372   1.649  1.00 43.13           C  \\nATOM  12076  O   ARG H  83      36.359  66.184   2.263  1.00 43.13           O  \\nATOM  12077  CB  ARG H  83      34.802  66.232  -0.522  1.00 59.74           C  \\nATOM  12078  CG  ARG H  83      33.805  65.827  -1.588  1.00 59.74           C  \\nATOM  12079  CD  ARG H  83      32.789  66.916  -1.789  1.00 59.74           C  \\nATOM  12080  NE  ARG H  83      31.421  66.425  -1.972  1.00 59.74           N  \\nATOM  12081  CZ  ARG H  83      31.005  65.724  -3.023  1.00 59.74           C  \\nATOM  12082  NH1 ARG H  83      31.859  65.415  -3.992  1.00 59.74           N  \\nATOM  12083  NH2 ARG H  83      29.729  65.371  -3.135  1.00 59.74           N  \\nATOM  12084  N   SER H  84      35.918  64.067   1.597  1.00 49.65           N  \\nATOM  12085  CA  SER H  84      37.076  63.476   2.275  1.00 49.65           C  \\nATOM  12086  C   SER H  84      38.390  63.574   1.508  1.00 49.65           C  \\nATOM  12087  O   SER H  84      39.457  63.555   2.114  1.00 49.65           O  \\nATOM  12088  CB  SER H  84      36.805  62.005   2.635  1.00 52.10           C  \\nATOM  12089  OG  SER H  84      36.106  61.885   3.866  1.00 52.10           O  \\nATOM  12090  N   THR H  85      38.324  63.688   0.185  1.00 39.29           N  \\nATOM  12091  CA  THR H  85      39.545  63.741  -0.603  1.00 39.29           C  \\nATOM  12092  C   THR H  85      39.842  65.006  -1.439  1.00 39.29           C  \\nATOM  12093  O   THR H  85      38.943  65.630  -2.021  1.00 39.29           O  \\nATOM  12094  CB  THR H  85      39.664  62.479  -1.541  1.00 41.14           C  \\nATOM  12095  OG1 THR H  85      39.097  62.764  -2.820  1.00 41.14           O  \\nATOM  12096  CG2 THR H  85      38.905  61.302  -0.974  1.00 41.14           C  \\nATOM  12097  N   ILE H  86      41.126  65.365  -1.470  1.00 23.49           N  \\nATOM  12098  CA  ILE H  86      41.654  66.478  -2.258  1.00 23.49           C  \\nATOM  12099  C   ILE H  86      42.167  65.879  -3.583  1.00 23.49           C  \\nATOM  12100  O   ILE H  86      43.167  65.156  -3.612  1.00 23.49           O  \\nATOM  12101  CB  ILE H  86      42.838  67.165  -1.541  1.00 27.76           C  \\nATOM  12102  CG1 ILE H  86      42.336  67.939  -0.313  1.00 27.76           C  \\nATOM  12103  CG2 ILE H  86      43.601  68.065  -2.517  1.00 27.76           C  \\nATOM  12104  CD1 ILE H  86      43.439  68.600   0.536  1.00 27.76           C  \\nATOM  12105  N   THR H  87      41.426  66.116  -4.658  1.00 33.91           N  \\nATOM  12106  CA  THR H  87      41.774  65.613  -5.972  1.00 33.91           C  \\nATOM  12107  C   THR H  87      42.380  66.753  -6.766  1.00 33.91           C  \\nATOM  12108  O   THR H  87      42.486  67.868  -6.278  1.00 33.91           O  \\nATOM  12109  CB  THR H  87      40.535  65.175  -6.697  1.00 27.22           C  \\nATOM  12110  OG1 THR H  87      39.843  66.338  -7.160  1.00 27.22           O  \\nATOM  12111  CG2 THR H  87      39.629  64.412  -5.755  1.00 27.22           C  \\nATOM  12112  N   SER H  88      42.719  66.501  -8.019  1.00 24.64           N  \\nATOM  12113  CA  SER H  88      43.306  67.544  -8.830  1.00 24.64           C  \\nATOM  12114  C   SER H  88      42.285  68.676  -9.109  1.00 24.64           C  \\nATOM  12115  O   SER H  88      42.654  69.810  -9.415  1.00 24.64           O  \\nATOM  12116  CB  SER H  88      43.816  66.929 -10.116  1.00 40.60           C  \\nATOM  12117  OG  SER H  88      42.770  66.194 -10.717  1.00 40.60           O  \\nATOM  12118  N   ARG H  89      41.001  68.396  -8.918  1.00 31.36           N  \\nATOM  12119  CA  ARG H  89      39.981  69.419  -9.155  1.00 31.36           C  \\nATOM  12120  C   ARG H  89      40.193  70.492  -8.087  1.00 31.36           C  \\nATOM  12121  O   ARG H  89      40.213  71.691  -8.366  1.00 31.36           O  \\nATOM  12122  CB  ARG H  89      38.582  68.810  -9.021  1.00 44.80           C  \\nATOM  12123  CG  ARG H  89      37.607  69.300 -10.064  1.00 44.80           C  \\nATOM  12124  CD  ARG H  89      36.209  69.206  -9.558  1.00 44.80           C  \\nATOM  12125  NE  ARG H  89      35.411  70.259 -10.163  1.00 44.80           N  \\nATOM  12126  CZ  ARG H  89      34.199  70.612  -9.747  1.00 44.80           C  \\nATOM  12127  NH1 ARG H  89      33.638  69.991  -8.716  1.00 44.80           N  \\nATOM  12128  NH2 ARG H  89      33.547  71.582 -10.374  1.00 44.80           N  \\nATOM  12129  N   GLU H  90      40.392  70.020  -6.862  1.00 14.46           N  \\nATOM  12130  CA  GLU H  90      40.659  70.880  -5.717  1.00 14.46           C  \\nATOM  12131  C   GLU H  90      41.915  71.716  -5.980  1.00 14.46           C  \\nATOM  12132  O   GLU H  90      41.934  72.926  -5.735  1.00 14.46           O  \\nATOM  12133  CB  GLU H  90      40.831  70.041  -4.452  1.00 37.26           C  \\nATOM  12134  CG  GLU H  90      39.517  69.626  -3.803  1.00 37.26           C  \\nATOM  12135  CD  GLU H  90      38.637  68.727  -4.684  1.00 37.26           C  \\nATOM  12136  OE1 GLU H  90      39.107  67.641  -5.072  1.00 37.26           O  \\nATOM  12137  OE2 GLU H  90      37.466  69.088  -4.964  1.00 37.26           O  \\nATOM  12138  N   ILE H  91      42.954  71.081  -6.510  1.00 13.90           N  \\nATOM  12139  CA  ILE H  91      44.165  71.820  -6.829  1.00 13.90           C  \\nATOM  12140  C   ILE H  91      43.838  72.916  -7.839  1.00 13.90           C  \\nATOM  12141  O   ILE H  91      44.169  74.068  -7.628  1.00 13.90           O  \\nATOM  12142  CB  ILE H  91      45.298  70.897  -7.364  1.00 12.86           C  \\nATOM  12143  CG1 ILE H  91      45.630  69.826  -6.310  1.00 12.86           C  \\nATOM  12144  CG2 ILE H  91      46.563  71.720  -7.694  1.00 12.86           C  \\nATOM  12145  CD1 ILE H  91      45.861  70.358  -4.906  1.00 12.86           C  \\nATOM  12146  N   GLN H  92      43.087  72.574  -8.877  1.00 20.84           N  \\nATOM  12147  CA  GLN H  92      42.732  73.538  -9.912  1.00 20.84           C  \\nATOM  12148  C   GLN H  92      42.042  74.783  -9.392  1.00 20.84           C  \\nATOM  12149  O   GLN H  92      42.568  75.882  -9.510  1.00 20.84           O  \\nATOM  12150  CB  GLN H  92      41.871  72.887 -10.986  1.00 28.65           C  \\nATOM  12151  CG  GLN H  92      41.729  73.754 -12.203  1.00 28.65           C  \\nATOM  12152  CD  GLN H  92      41.087  73.030 -13.365  1.00 28.65           C  \\nATOM  12153  OE1 GLN H  92      39.863  72.892 -13.419  1.00 28.65           O  \\nATOM  12154  NE2 GLN H  92      41.912  72.544 -14.295  1.00 28.65           N  \\nATOM  12155  N   THR H  93      40.878  74.621  -8.787  1.00 19.60           N  \\nATOM  12156  CA  THR H  93      40.191  75.787  -8.304  1.00 19.60           C  \\nATOM  12157  C   THR H  93      41.059  76.490  -7.265  1.00 19.60           C  \\nATOM  12158  O   THR H  93      41.214  77.712  -7.344  1.00 19.60           O  \\nATOM  12159  CB  THR H  93      38.796  75.455  -7.824  1.00 38.84           C  \\nATOM  12160  OG1 THR H  93      38.856  74.240  -7.100  1.00 38.84           O  \\nATOM  12161  CG2 THR H  93      37.863  75.230  -9.020  1.00 38.84           C  \\nATOM  12162  N   ALA H  94      41.733  75.737  -6.388  1.00 20.62           N  \\nATOM  12163  CA  ALA H  94      42.615  76.358  -5.393  1.00 20.62           C  \\nATOM  12164  C   ALA H  94      43.561  77.291  -6.117  1.00 20.62           C  \\nATOM  12165  O   ALA H  94      43.790  78.412  -5.675  1.00 20.62           O  \\nATOM  12166  CB  ALA H  94      43.419  75.329  -4.628  1.00  6.37           C  \\nATOM  12167  N   VAL H  95      44.094  76.832  -7.246  1.00 16.65           N  \\nATOM  12168  CA  VAL H  95      45.001  77.644  -8.059  1.00 16.65           C  \\nATOM  12169  C   VAL H  95      44.274  78.875  -8.611  1.00 16.65           C  \\nATOM  12170  O   VAL H  95      44.775  79.990  -8.487  1.00 16.65           O  \\nATOM  12171  CB  VAL H  95      45.620  76.810  -9.219  1.00 11.22           C  \\nATOM  12172  CG1 VAL H  95      46.127  77.709 -10.325  1.00 11.22           C  \\nATOM  12173  CG2 VAL H  95      46.765  75.956  -8.699  1.00 11.22           C  \\nATOM  12174  N   ARG H  96      43.084  78.666  -9.188  1.00 34.91           N  \\nATOM  12175  CA  ARG H  96      42.282  79.749  -9.769  1.00 34.91           C  \\nATOM  12176  C   ARG H  96      42.074  80.865  -8.778  1.00 34.91           C  \\nATOM  12177  O   ARG H  96      42.141  82.041  -9.126  1.00 34.91           O  \\nATOM  12178  CB  ARG H  96      40.949  79.232 -10.292  1.00 49.65           C  \\nATOM  12179  CG  ARG H  96      41.073  78.599 -11.660  1.00 49.65           C  \\nATOM  12180  CD  ARG H  96      39.719  78.283 -12.292  1.00 49.65           C  \\nATOM  12181  NE  ARG H  96      39.866  77.548 -13.558  1.00 49.65           N  \\nATOM  12182  CZ  ARG H  96      39.188  76.441 -13.880  1.00 49.65           C  \\nATOM  12183  NH1 ARG H  96      38.294  75.937 -13.037  1.00 49.65           N  \\nATOM  12184  NH2 ARG H  96      39.465  75.787 -15.006  1.00 49.65           N  \\nATOM  12185  N   LEU H  97      41.850  80.483  -7.533  1.00 20.13           N  \\nATOM  12186  CA  LEU H  97      41.687  81.446  -6.463  1.00 20.13           C  \\nATOM  12187  C   LEU H  97      43.015  82.121  -6.088  1.00 20.13           C  \\nATOM  12188  O   LEU H  97      43.121  83.342  -6.084  1.00 20.13           O  \\nATOM  12189  CB  LEU H  97      41.117  80.754  -5.232  1.00 20.91           C  \\nATOM  12190  CG  LEU H  97      39.729  80.144  -5.419  1.00 20.91           C  \\nATOM  12191  CD1 LEU H  97      39.307  79.429  -4.154  1.00 20.91           C  \\nATOM  12192  CD2 LEU H  97      38.725  81.227  -5.774  1.00 20.91           C  \\nATOM  12193  N   LEU H  98      44.043  81.325  -5.825  1.00 32.52           N  \\nATOM  12194  CA  LEU H  98      45.335  81.861  -5.418  1.00 32.52           C  \\nATOM  12195  C   LEU H  98      46.194  82.650  -6.393  1.00 32.52           C  \\nATOM  12196  O   LEU H  98      46.883  83.584  -5.989  1.00 32.52           O  \\nATOM  12197  CB  LEU H  98      46.180  80.746  -4.802  1.00 53.60           C  \\nATOM  12198  CG  LEU H  98      45.723  80.235  -3.436  1.00 53.60           C  \\nATOM  12199  CD1 LEU H  98      46.421  78.942  -3.140  1.00 53.60           C  \\nATOM  12200  CD2 LEU H  98      46.006  81.253  -2.340  1.00 53.60           C  \\nATOM  12201  N   LEU H  99      46.189  82.285  -7.662  1.00 30.01           N  \\nATOM  12202  CA  LEU H  99      47.055  82.979  -8.605  1.00 30.01           C  \\nATOM  12203  C   LEU H  99      46.445  84.047  -9.526  1.00 30.01           C  \\nATOM  12204  O   LEU H  99      45.287  83.929  -9.969  1.00 30.01           O  \\nATOM  12205  CB  LEU H  99      47.843  81.954  -9.416  1.00  8.34           C  \\nATOM  12206  CG  LEU H  99      48.511  80.822  -8.604  1.00  8.34           C  \\nATOM  12207  CD1 LEU H  99      49.457  80.020  -9.496  1.00  8.34           C  \\nATOM  12208  CD2 LEU H  99      49.256  81.366  -7.437  1.00  8.34           C  \\nATOM  12209  N   PRO H 100      47.183  85.167  -9.723  1.00 38.48           N  \\nATOM  12210  CA  PRO H 100      46.722  86.260 -10.582  1.00 38.48           C  \\nATOM  12211  C   PRO H 100      46.576  85.939 -12.066  1.00 38.48           C  \\nATOM  12212  O   PRO H 100      47.460  85.348 -12.691  1.00 38.48           O  \\nATOM  12213  CB  PRO H 100      47.739  87.380 -10.308  1.00 21.03           C  \\nATOM  12214  CG  PRO H 100      48.906  86.699  -9.682  1.00 21.03           C  \\nATOM  12215  CD  PRO H 100      48.265  85.648  -8.839  1.00 21.03           C  \\nATOM  12216  N   GLY H 101      45.387  86.257 -12.572  1.00 34.40           N  \\nATOM  12217  CA  GLY H 101      45.032  86.061 -13.967  1.00 34.40           C  \\nATOM  12218  C   GLY H 101      45.890  85.200 -14.872  1.00 34.40           C  \\nATOM  12219  O   GLY H 101      45.644  84.005 -14.997  1.00 34.40           O  \\nATOM  12220  N   GLU H 102      46.891  85.789 -15.520  1.00 25.81           N  \\nATOM  12221  CA  GLU H 102      47.732  85.015 -16.433  1.00 25.81           C  \\nATOM  12222  C   GLU H 102      48.420  83.857 -15.737  1.00 25.81           C  \\nATOM  12223  O   GLU H 102      48.206  82.713 -16.092  1.00 25.81           O  \\nATOM  12224  CB  GLU H 102      48.742  85.914 -17.136  1.00 82.06           C  \\nATOM  12225  CG  GLU H 102      48.578  85.933 -18.646  1.00 82.06           C  \\nATOM  12226  CD  GLU H 102      47.133  86.118 -19.092  1.00 82.06           C  \\nATOM  12227  OE1 GLU H 102      46.338  86.770 -18.369  1.00 82.06           O  \\nATOM  12228  OE2 GLU H 102      46.794  85.603 -20.179  1.00 82.06           O  \\nATOM  12229  N   LEU H 103      49.223  84.165 -14.731  1.00 21.99           N  \\nATOM  12230  CA  LEU H 103      49.929  83.182 -13.944  1.00 21.99           C  \\nATOM  12231  C   LEU H 103      49.011  81.977 -13.723  1.00 21.99           C  \\nATOM  12232  O   LEU H 103      49.384  80.838 -14.015  1.00 21.99           O  \\nATOM  12233  CB  LEU H 103      50.313  83.821 -12.604  1.00 17.31           C  \\nATOM  12234  CG  LEU H 103      51.772  83.902 -12.154  1.00 17.31           C  \\nATOM  12235  CD1 LEU H 103      52.746  84.144 -13.317  1.00 17.31           C  \\nATOM  12236  CD2 LEU H 103      51.869  84.986 -11.117  1.00 17.31           C  \\nATOM  12237  N   ALA H 104      47.769  82.247 -13.327  1.00 35.80           N  \\nATOM  12238  CA  ALA H 104      46.802  81.178 -13.075  1.00 35.80           C  \\nATOM  12239  C   ALA H 104      46.387  80.432 -14.345  1.00 35.80           C  \\nATOM  12240  O   ALA H 104      46.338  79.202 -14.374  1.00 35.80           O  \\nATOM  12241  CB  ALA H 104      45.582  81.726 -12.359  1.00 30.72           C  \\nATOM  12242  N   LYS H 105      46.059  81.186 -15.387  1.00 37.60           N  \\nATOM  12243  CA  LYS H 105      45.663  80.620 -16.668  1.00 37.60           C  \\nATOM  12244  C   LYS H 105      46.662  79.542 -17.097  1.00 37.60           C  \\nATOM  12245  O   LYS H 105      46.288  78.388 -17.319  1.00 37.60           O  \\nATOM  12246  CB  LYS H 105      45.589  81.750 -17.689  1.00 71.72           C  \\nATOM  12247  CG  LYS H 105      45.458  81.329 -19.117  1.00 71.72           C  \\nATOM  12248  CD  LYS H 105      45.321  82.562 -19.969  1.00 71.72           C  \\nATOM  12249  CE  LYS H 105      45.512  82.276 -21.450  1.00 71.72           C  \\nATOM  12250  NZ  LYS H 105      45.242  83.507 -22.266  1.00 71.72           N  \\nATOM  12251  N   HIS H 106      47.942  79.909 -17.092  1.00 41.27           N  \\nATOM  12252  CA  HIS H 106      49.027  79.008 -17.485  1.00 41.27           C  \\nATOM  12253  C   HIS H 106      49.222  77.872 -16.514  1.00 41.27           C  \\nATOM  12254  O   HIS H 106      49.417  76.733 -16.925  1.00 41.27           O  \\nATOM  12255  CB  HIS H 106      50.344  79.755 -17.652  1.00 30.19           C  \\nATOM  12256  CG  HIS H 106      50.311  80.784 -18.732  1.00 30.19           C  \\nATOM  12257  ND1 HIS H 106      51.431  81.476 -19.133  1.00 30.19           N  \\nATOM  12258  CD2 HIS H 106      49.290  81.251 -19.490  1.00 30.19           C  \\nATOM  12259  CE1 HIS H 106      51.105  82.324 -20.091  1.00 30.19           C  \\nATOM  12260  NE2 HIS H 106      49.810  82.208 -20.326  1.00 30.19           N  \\nATOM  12261  N   ALA H 107      49.206  78.177 -15.225  1.00 28.41           N  \\nATOM  12262  CA  ALA H 107      49.361  77.139 -14.230  1.00 28.41           C  \\nATOM  12263  C   ALA H 107      48.247  76.074 -14.395  1.00 28.41           C  \\nATOM  12264  O   ALA H 107      48.489  74.882 -14.202  1.00 28.41           O  \\nATOM  12265  CB  ALA H 107      49.378  77.758 -12.829  1.00 13.59           C  \\nATOM  12266  N   VAL H 108      47.046  76.484 -14.806  1.00 17.28           N  \\nATOM  12267  CA  VAL H 108      45.956  75.523 -15.021  1.00 17.28           C  \\nATOM  12268  C   VAL H 108      46.289  74.585 -16.172  1.00 17.28           C  \\nATOM  12269  O   VAL H 108      46.181  73.371 -16.032  1.00 17.28           O  \\nATOM  12270  CB  VAL H 108      44.582  76.222 -15.285  1.00 17.89           C  \\nATOM  12271  CG1 VAL H 108      43.589  75.259 -15.880  1.00 17.89           C  \\nATOM  12272  CG2 VAL H 108      44.010  76.742 -13.975  1.00 17.89           C  \\nATOM  12273  N   SER H 109      46.690  75.154 -17.308  1.00 36.24           N  \\nATOM  12274  CA  SER H 109      47.048  74.361 -18.474  1.00 36.24           C  \\nATOM  12275  C   SER H 109      48.213  73.419 -18.148  1.00 36.24           C  \\nATOM  12276  O   SER H 109      48.146  72.234 -18.455  1.00 36.24           O  \\nATOM  12277  CB  SER H 109      47.403  75.269 -19.631  1.00 31.11           C  \\nATOM  12278  OG  SER H 109      48.798  75.437 -19.700  1.00 31.11           O  \\nATOM  12279  N   GLU H 110      49.281  73.940 -17.538  1.00 22.70           N  \\nATOM  12280  CA  GLU H 110      50.426  73.106 -17.130  1.00 22.70           C  \\nATOM  12281  C   GLU H 110      49.935  71.955 -16.257  1.00 22.70           C  \\nATOM  12282  O   GLU H 110      50.313  70.806 -16.464  1.00 22.70           O  \\nATOM  12283  CB  GLU H 110      51.439  73.916 -16.329  1.00 40.78           C  \\nATOM  12284  CG  GLU H 110      52.223  74.903 -17.153  1.00 40.78           C  \\nATOM  12285  CD  GLU H 110      53.084  74.240 -18.221  1.00 40.78           C  \\nATOM  12286  OE1 GLU H 110      53.931  73.387 -17.875  1.00 40.78           O  \\nATOM  12287  OE2 GLU H 110      52.924  74.577 -19.412  1.00 40.78           O  \\nATOM  12288  N   GLY H 111      49.079  72.287 -15.287  1.00 30.27           N  \\nATOM  12289  CA  GLY H 111      48.509  71.305 -14.384  1.00 30.27           C  \\nATOM  12290  C   GLY H 111      47.806  70.217 -15.150  1.00 30.27           C  \\nATOM  12291  O   GLY H 111      48.184  69.058 -15.038  1.00 30.27           O  \\nATOM  12292  N   THR H 112      46.800  70.589 -15.940  1.00 31.38           N  \\nATOM  12293  CA  THR H 112      46.046  69.631 -16.746  1.00 31.38           C  \\nATOM  12294  C   THR H 112      46.971  68.814 -17.663  1.00 31.38           C  \\nATOM  12295  O   THR H 112      46.809  67.604 -17.790  1.00 31.38           O  \\nATOM  12296  CB  THR H 112      44.925  70.323 -17.567  1.00 39.79           C  \\nATOM  12297  OG1 THR H 112      45.273  71.691 -17.797  1.00 39.79           O  \\nATOM  12298  CG2 THR H 112      43.604  70.285 -16.818  1.00 39.79           C  \\nATOM  12299  N   LYS H 113      47.979  69.463 -18.245  1.00 23.38           N  \\nATOM  12300  CA  LYS H 113      48.937  68.783 -19.110  1.00 23.38           C  \\nATOM  12301  C   LYS H 113      49.656  67.642 -18.380  1.00 23.38           C  \\nATOM  12302  O   LYS H 113      49.718  66.523 -18.874  1.00 23.38           O  \\nATOM  12303  CB  LYS H 113      49.952  69.779 -19.653  1.00 74.85           C  \\nATOM  12304  CG  LYS H 113      50.163  69.655 -21.139  1.00 74.85           C  \\nATOM  12305  CD  LYS H 113      51.126  70.704 -21.646  1.00 74.85           C  \\nATOM  12306  CE  LYS H 113      52.525  70.488 -21.084  1.00 74.85           C  \\nATOM  12307  NZ  LYS H 113      53.462  71.553 -21.556  1.00 74.85           N  \\nATOM  12308  N   ALA H 114      50.196  67.932 -17.204  1.00 46.27           N  \\nATOM  12309  CA  ALA H 114      50.882  66.923 -16.412  1.00 46.27           C  \\nATOM  12310  C   ALA H 114      49.959  65.754 -16.102  1.00 46.27           C  \\nATOM  12311  O   ALA H 114      50.252  64.622 -16.447  1.00 46.27           O  \\nATOM  12312  CB  ALA H 114      51.389  67.524 -15.125  1.00 55.16           C  \\nATOM  12313  N   VAL H 115      48.816  66.025 -15.493  1.00 48.14           N  \\nATOM  12314  CA  VAL H 115      47.917  64.933 -15.162  1.00 48.14           C  \\nATOM  12315  C   VAL H 115      47.521  64.107 -16.380  1.00 48.14           C  \\nATOM  12316  O   VAL H 115      47.588  62.880 -16.342  1.00 48.14           O  \\nATOM  12317  CB  VAL H 115      46.670  65.409 -14.398  1.00 26.84           C  \\nATOM  12318  CG1 VAL H 115      45.641  64.296 -14.371  1.00 26.84           C  \\nATOM  12319  CG2 VAL H 115      47.049  65.801 -12.952  1.00 26.84           C  \\nATOM  12320  N   THR H 116      47.131  64.766 -17.465  1.00 51.83           N  \\nATOM  12321  CA  THR H 116      46.762  64.048 -18.680  1.00 51.83           C  \\nATOM  12322  C   THR H 116      47.924  63.170 -19.142  1.00 51.83           C  \\nATOM  12323  O   THR H 116      47.768  61.963 -19.261  1.00 51.83           O  \\nATOM  12324  CB  THR H 116      46.370  65.012 -19.810  1.00 35.63           C  \\nATOM  12325  OG1 THR H 116      45.088  65.595 -19.528  1.00 35.63           O  \\nATOM  12326  CG2 THR H 116      46.325  64.291 -21.127  1.00 35.63           C  \\nATOM  12327  N   LYS H 117      49.099  63.764 -19.336  1.00 36.81           N  \\nATOM  12328  CA  LYS H 117      50.283  63.032 -19.776  1.00 36.81           C  \\nATOM  12329  C   LYS H 117      50.606  61.828 -18.865  1.00 36.81           C  \\nATOM  12330  O   LYS H 117      51.206  60.842 -19.293  1.00 36.81           O  \\nATOM  12331  CB  LYS H 117      51.471  63.997 -19.854  1.00 65.44           C  \\nATOM  12332  CG  LYS H 117      52.744  63.402 -20.424  1.00 65.44           C  \\nATOM  12333  CD  LYS H 117      53.786  64.481 -20.696  1.00 65.44           C  \\nATOM  12334  CE  LYS H 117      55.016  63.911 -21.401  1.00 65.44           C  \\nATOM  12335  NZ  LYS H 117      55.778  62.954 -20.548  1.00 65.44           N  \\nATOM  12336  N   TYR H 118      50.245  61.937 -17.596  1.00 56.25           N  \\nATOM  12337  CA  TYR H 118      50.469  60.870 -16.636  1.00 56.25           C  \\nATOM  12338  C   TYR H 118      49.554  59.686 -16.914  1.00 56.25           C  \\nATOM  12339  O   TYR H 118      50.006  58.538 -16.940  1.00 56.25           O  \\nATOM  12340  CB  TYR H 118      50.196  61.405 -15.237  1.00 42.54           C  \\nATOM  12341  CG  TYR H 118      50.417  60.447 -14.086  1.00 42.54           C  \\nATOM  12342  CD1 TYR H 118      51.701  60.011 -13.756  1.00 42.54           C  \\nATOM  12343  CD2 TYR H 118      49.363  60.089 -13.241  1.00 42.54           C  \\nATOM  12344  CE1 TYR H 118      51.939  59.252 -12.604  1.00 42.54           C  \\nATOM  12345  CE2 TYR H 118      49.587  59.339 -12.091  1.00 42.54           C  \\nATOM  12346  CZ  TYR H 118      50.882  58.928 -11.773  1.00 42.54           C  \\nATOM  12347  OH  TYR H 118      51.135  58.250 -10.599  1.00 42.54           O  \\nATOM  12348  N   THR H 119      48.259  59.964 -17.057  1.00 49.36           N  \\nATOM  12349  CA  THR H 119      47.272  58.918 -17.320  1.00 49.36           C  \\nATOM  12350  C   THR H 119      47.491  58.310 -18.693  1.00 49.36           C  \\nATOM  12351  O   THR H 119      47.487  57.088 -18.855  1.00 49.36           O  \\nATOM  12352  CB  THR H 119      45.861  59.470 -17.265  1.00 66.31           C  \\nATOM  12353  OG1 THR H 119      45.778  60.407 -16.186  1.00 66.31           O  \\nATOM  12354  CG2 THR H 119      44.852  58.326 -17.053  1.00 66.31           C  \\nATOM  12355  N   SER H 120      47.664  59.188 -19.675  1.00105.20           N  \\nATOM  12356  CA  SER H 120      47.917  58.792 -21.048  1.00105.20           C  \\nATOM  12357  C   SER H 120      49.365  58.307 -21.082  1.00105.20           C  \\nATOM  12358  O   SER H 120      50.293  59.105 -21.254  1.00105.20           O  \\nATOM  12359  CB  SER H 120      47.722  59.985 -21.999  1.00 92.09           C  \\nATOM  12360  OG  SER H 120      46.396  60.497 -21.948  1.00 92.09           O  \\nATOM  12361  N   ALA H 121      49.517  57.006 -20.820  1.00 79.13           N  \\nATOM  12362  CA  ALA H 121      50.781  56.263 -20.783  1.00 79.13           C  \\nATOM  12363  C   ALA H 121      51.187  55.786 -19.390  1.00 79.13           C  \\nATOM  12364  O   ALA H 121      51.266  56.566 -18.436  1.00 79.13           O  \\nATOM  12365  CB  ALA H 121      51.929  57.036 -21.435  1.00115.59           C  \\nATOM  12366  N   LYS H 122      51.460  54.487 -19.303  1.00145.74           N  \\nATOM  12367  CA  LYS H 122      51.879  53.839 -18.068  1.00145.74           C  \\nATOM  12368  C   LYS H 122      52.287  52.400 -18.437  1.00145.74           C  \\nATOM  12369  O   LYS H 122      53.340  52.250 -19.093  1.00113.58           O  \\nATOM  12370  CB  LYS H 122      50.739  53.885 -17.028  1.00113.58           C  \\nATOM  12371  CG  LYS H 122      51.196  53.769 -15.576  1.00113.58           C  \\nATOM  12372  CD  LYS H 122      51.490  52.318 -15.192  1.00113.58           C  \\nATOM  12373  CE  LYS H 122      52.716  52.162 -14.281  1.00113.58           C  \\nATOM  12374  NZ  LYS H 122      52.547  52.651 -12.874  1.00113.58           N  \\nATOM  12375  OXT LYS H 122      51.549  51.443 -18.126  1.00113.58           O  \\nTER   12376      LYS H 122                                                      \\nHETATM12377 MN    MN I 147      75.436 135.124  -0.612  1.00 99.79          MN  \\nHETATM12378 MN    MN I 500      11.975 113.527 -10.909  1.00 63.71          MN  \\nHETATM12379 MN    MN I 600       6.117 129.617   7.536  1.00137.05          MN  \\nHETATM12380 MN    MN J 293      64.861 141.219   3.828  1.00109.80          MN  \\nHETATM12381 MN    MN J 300      89.596 109.237   3.400  1.00120.55          MN  \\nHETATM12382 MN    MN J 400      81.121  73.445 -14.719  1.00115.84          MN  \\nHETATM12383  O   HOH I 601      72.565  60.018  -6.320  1.00 21.96           O  \\nHETATM12384  O   HOH I 602      83.057  96.149  -9.118  1.00 12.83           O  \\nHETATM12385  O   HOH I 603      75.260  74.861  19.542  1.00 30.07           O  \\nHETATM12386  O   HOH I 604      90.802 107.070 -10.300  1.00 37.72           O  \\nHETATM12387  O   HOH J   3      10.823 104.968  19.458  1.00  8.50           O  \\nHETATM12388  O   HOH J   4      15.774  67.877  25.008  1.00 16.19           O  \\nHETATM12389  O   HOH J   5      75.384  69.631  28.629  1.00 15.33           O  \\nHETATM12390  O   HOH J  12      87.724 103.773 -19.719  1.00 32.26           O  \\nHETATM12391  O   HOH J  13      23.476  64.105  -7.557  1.00 49.16           O  \\nHETATM12392  O   HOH B  10      57.749  75.590  18.612  1.00 22.60           O  \\nHETATM12393  O   HOH E   6      26.412  91.978 -19.036  1.00  5.00           O  \\nHETATM12394  O   HOH F   7      30.887 124.400   2.610  1.00 19.00           O  \\nHETATM12395  O   HOH F   8      21.286 104.199  -3.703  1.00 13.03           O  \\nMASTER      335    0    6   37   20    0    1    612385   10    0   90          \\nEND                                                                             \\n\",\"pdb\");\n\tviewer_1705745312876235.setBackgroundColor(\"white\");\n\tviewer_1705745312876235.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n\tviewer_1705745312876235.zoomTo();\nviewer_1705745312876235.render();\n});\n</script>",
      "text/html": [
       "<div id=\"3dmolviewer_1705745312876235\"  style=\"position: relative; width: 640px; height: 480px;\">\n",
       "        <p id=\"3dmolwarning_1705745312876235\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n",
       "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n",
       "        </div>\n",
       "<script>\n",
       "\n",
       "var loadScriptAsync = function(uri){\n",
       "  return new Promise((resolve, reject) => {\n",
       "    //this is to ignore the existence of requirejs amd\n",
       "    var savedexports, savedmodule;\n",
       "    if (typeof exports !== 'undefined') savedexports = exports;\n",
       "    else exports = {}\n",
       "    if (typeof module !== 'undefined') savedmodule = module;\n",
       "    else module = {}\n",
       "\n",
       "    var tag = document.createElement('script');\n",
       "    tag.src = uri;\n",
       "    tag.async = true;\n",
       "    tag.onload = () => {\n",
       "        exports = savedexports;\n",
       "        module = savedmodule;\n",
       "        resolve();\n",
       "    };\n",
       "  var firstScriptTag = document.getElementsByTagName('script')[0];\n",
       "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n",
       "});\n",
       "};\n",
       "\n",
       "if(typeof $3Dmolpromise === 'undefined') {\n",
       "$3Dmolpromise = null;\n",
       "  $3Dmolpromise = loadScriptAsync('https://cdnjs.cloudflare.com/ajax/libs/3Dmol/2.0.4/3Dmol-min.js');\n",
       "}\n",
       "\n",
       "var viewer_1705745312876235 = null;\n",
       "var warn = document.getElementById(\"3dmolwarning_1705745312876235\");\n",
       "if(warn) {\n",
       "    warn.parentNode.removeChild(warn);\n",
       "}\n",
       "$3Dmolpromise.then(function() {\n",
       "viewer_1705745312876235 = $3Dmol.createViewer(document.getElementById(\"3dmolviewer_1705745312876235\"),{backgroundColor:\"white\"});\n",
       "viewer_1705745312876235.zoomTo();\n",
       "\tviewer_1705745312876235.addModel(\"HEADER    DNA BINDING PROTEIN/DNA                 03-JUL-97   1AOI              \\nTITLE     COMPLEX BETWEEN NUCLEOSOME CORE PARTICLE (H3,H4,H2A,H2B)              \\nTITLE    2 AND 146 BP LONG DNA FRAGMENT                                         \\nCOMPND    MOL_ID: 1;                                                            \\nCOMPND   2 MOLECULE: PALINDROMIC 146 BP DNA REPEAT 8/9 FROM HUMAN X-            \\nCOMPND   3 CHROMOSOME ALPHA SATELLITE DNA;                                      \\nCOMPND   4 CHAIN: I, J;                                                         \\nCOMPND   5 ENGINEERED: YES;                                                     \\nCOMPND   6 MOL_ID: 2;                                                           \\nCOMPND   7 MOLECULE: HISTONE H3;                                                \\nCOMPND   8 CHAIN: A, E;                                                         \\nCOMPND   9 FRAGMENT: HISTONE H3;                                                \\nCOMPND  10 ENGINEERED: YES;                                                     \\nCOMPND  11 MOL_ID: 3;                                                           \\nCOMPND  12 MOLECULE: HISTONE H4;                                                \\nCOMPND  13 CHAIN: B, F;                                                         \\nCOMPND  14 FRAGMENT: HISTONE H4;                                                \\nCOMPND  15 ENGINEERED: YES;                                                     \\nCOMPND  16 MOL_ID: 4;                                                           \\nCOMPND  17 MOLECULE: HISTONE H2A;                                               \\nCOMPND  18 CHAIN: C, G;                                                         \\nCOMPND  19 FRAGMENT: HISTONE H2A;                                               \\nCOMPND  20 ENGINEERED: YES;                                                     \\nCOMPND  21 MOL_ID: 5;                                                           \\nCOMPND  22 MOLECULE: HISTONE H2B;                                               \\nCOMPND  23 CHAIN: D, H;                                                         \\nCOMPND  24 FRAGMENT: HISTONE H2B;                                               \\nCOMPND  25 ENGINEERED: YES;                                                     \\nCOMPND  26 MUTATION: YES                                                        \\nSOURCE    MOL_ID: 1;                                                            \\nSOURCE   2 SYNTHETIC: YES;                                                      \\nSOURCE   3 MOL_ID: 2;                                                           \\nSOURCE   4 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE   5 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE   6 ORGANISM_TAXID: 8355;                                                \\nSOURCE   7 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE   8 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE   9 MOL_ID: 3;                                                           \\nSOURCE  10 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  11 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  12 ORGANISM_TAXID: 8355;                                                \\nSOURCE  13 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  14 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE  15 OTHER_DETAILS: SYNTHETIC GENE, OPTIMIZED CODON USAGE FOR             \\nSOURCE  16 ESCHERICHIA COLI;                                                    \\nSOURCE  17 MOL_ID: 4;                                                           \\nSOURCE  18 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  19 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  20 ORGANISM_TAXID: 8355;                                                \\nSOURCE  21 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  22 EXPRESSION_SYSTEM_TAXID: 562;                                        \\nSOURCE  23 MOL_ID: 5;                                                           \\nSOURCE  24 ORGANISM_SCIENTIFIC: XENOPUS LAEVIS;                                 \\nSOURCE  25 ORGANISM_COMMON: AFRICAN CLAWED FROG;                                \\nSOURCE  26 ORGANISM_TAXID: 8355;                                                \\nSOURCE  27 EXPRESSION_SYSTEM: ESCHERICHIA COLI;                                 \\nSOURCE  28 EXPRESSION_SYSTEM_TAXID: 562                                         \\nKEYWDS    NUCLEOSOME, CHROMATIN, HISTONE, PROTEIN DNA INTERACTION,              \\nKEYWDS   2 NUCLEOPROTEIN, SUPERCOILED DNA, DNA BINDING PROTEIN/DNA              \\nKEYWDS   3 COMPLEX                                                              \\nEXPDTA    X-RAY DIFFRACTION                                                     \\nAUTHOR    K.LUGER,A.W.MAEDER,R.K.RICHMOND,D.F.SARGENT,T.J.RICHMOND              \\nREVDAT   3   24-FEB-09 1AOI    1       VERSN                                    \\nREVDAT   2   01-APR-03 1AOI    1       JRNL                                     \\nREVDAT   1   30-SEP-98 1AOI    0                                                \\nJRNL        AUTH   K.LUGER,A.W.MADER,R.K.RICHMOND,D.F.SARGENT,                  \\nJRNL        AUTH 2 T.J.RICHMOND                                                 \\nJRNL        TITL   CRYSTAL STRUCTURE OF THE NUCLEOSOME CORE PARTICLE            \\nJRNL        TITL 2 AT 2.8 A RESOLUTION.                                         \\nJRNL        REF    NATURE                        V. 389   251 1997              \\nJRNL        REFN                   ISSN 0028-0836                               \\nJRNL        PMID   9305837                                                      \\nJRNL        DOI    10.1038/38444                                                \\nREMARK   1                                                                      \\nREMARK   2                                                                      \\nREMARK   2 RESOLUTION.    2.80 ANGSTROMS.                                       \\nREMARK   3                                                                      \\nREMARK   3 REFINEMENT.                                                          \\nREMARK   3   PROGRAM     : X-PLOR 3.843                                         \\nREMARK   3   AUTHORS     : BRUNGER                                              \\nREMARK   3                                                                      \\nREMARK   3  DATA USED IN REFINEMENT.                                            \\nREMARK   3   RESOLUTION RANGE HIGH (ANGSTROMS) : 2.80                           \\nREMARK   3   RESOLUTION RANGE LOW  (ANGSTROMS) : 25.00                          \\nREMARK   3   DATA CUTOFF            (SIGMA(F)) : NULL                           \\nREMARK   3   DATA CUTOFF HIGH         (ABS(F)) : NULL                           \\nREMARK   3   DATA CUTOFF LOW          (ABS(F)) : NULL                           \\nREMARK   3   COMPLETENESS (WORKING+TEST)   (%) : NULL                           \\nREMARK   3   NUMBER OF REFLECTIONS             : 51237                          \\nREMARK   3                                                                      \\nREMARK   3  FIT TO DATA USED IN REFINEMENT.                                     \\nREMARK   3   CROSS-VALIDATION METHOD          : THROUGHOUT                      \\nREMARK   3   FREE R VALUE TEST SET SELECTION  : RANDOM                          \\nREMARK   3   R VALUE            (WORKING SET) : 0.224                           \\nREMARK   3   FREE R VALUE                     : 0.302                           \\nREMARK   3   FREE R VALUE TEST SET SIZE   (%) : NULL                            \\nREMARK   3   FREE R VALUE TEST SET COUNT      : NULL                            \\nREMARK   3   ESTIMATED ERROR OF FREE R VALUE  : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  FIT IN THE HIGHEST RESOLUTION BIN.                                  \\nREMARK   3   TOTAL NUMBER OF BINS USED           : NULL                         \\nREMARK   3   BIN RESOLUTION RANGE HIGH       (A) : NULL                         \\nREMARK   3   BIN RESOLUTION RANGE LOW        (A) : NULL                         \\nREMARK   3   BIN COMPLETENESS (WORKING+TEST) (%) : NULL                         \\nREMARK   3   REFLECTIONS IN BIN    (WORKING SET) : NULL                         \\nREMARK   3   BIN R VALUE           (WORKING SET) : NULL                         \\nREMARK   3   BIN FREE R VALUE                    : NULL                         \\nREMARK   3   BIN FREE R VALUE TEST SET SIZE  (%) : NULL                         \\nREMARK   3   BIN FREE R VALUE TEST SET COUNT     : NULL                         \\nREMARK   3   ESTIMATED ERROR OF BIN FREE R VALUE : NULL                         \\nREMARK   3                                                                      \\nREMARK   3  NUMBER OF NON-HYDROGEN ATOMS USED IN REFINEMENT.                    \\nREMARK   3   PROTEIN ATOMS            : 6387                                    \\nREMARK   3   NUCLEIC ACID ATOMS       : 5980                                    \\nREMARK   3   HETEROGEN ATOMS          : 6                                       \\nREMARK   3   SOLVENT ATOMS            : 13                                      \\nREMARK   3                                                                      \\nREMARK   3  B VALUES.                                                           \\nREMARK   3   FROM WILSON PLOT           (A**2) : NULL                           \\nREMARK   3   MEAN B VALUE      (OVERALL, A**2) : NULL                           \\nREMARK   3   OVERALL ANISOTROPIC B VALUE.                                       \\nREMARK   3    B11 (A**2) : NULL                                                 \\nREMARK   3    B22 (A**2) : NULL                                                 \\nREMARK   3    B33 (A**2) : NULL                                                 \\nREMARK   3    B12 (A**2) : NULL                                                 \\nREMARK   3    B13 (A**2) : NULL                                                 \\nREMARK   3    B23 (A**2) : NULL                                                 \\nREMARK   3                                                                      \\nREMARK   3  ESTIMATED COORDINATE ERROR.                                         \\nREMARK   3   ESD FROM LUZZATI PLOT        (A) : NULL                            \\nREMARK   3   ESD FROM SIGMAA              (A) : NULL                            \\nREMARK   3   LOW RESOLUTION CUTOFF        (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  CROSS-VALIDATED ESTIMATED COORDINATE ERROR.                         \\nREMARK   3   ESD FROM C-V LUZZATI PLOT    (A) : NULL                            \\nREMARK   3   ESD FROM C-V SIGMAA          (A) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  RMS DEVIATIONS FROM IDEAL VALUES.                                   \\nREMARK   3   BOND LENGTHS                 (A) : 0.009                           \\nREMARK   3   BOND ANGLES            (DEGREES) : 1.30                            \\nREMARK   3   DIHEDRAL ANGLES        (DEGREES) : NULL                            \\nREMARK   3   IMPROPER ANGLES        (DEGREES) : NULL                            \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL MODEL : RESTRAINED                                \\nREMARK   3                                                                      \\nREMARK   3  ISOTROPIC THERMAL FACTOR RESTRAINTS.    RMS    SIGMA                \\nREMARK   3   MAIN-CHAIN BOND              (A**2) : NULL  ; NULL                 \\nREMARK   3   MAIN-CHAIN ANGLE             (A**2) : NULL  ; NULL                 \\nREMARK   3   SIDE-CHAIN BOND              (A**2) : NULL  ; NULL                 \\nREMARK   3   SIDE-CHAIN ANGLE             (A**2) : NULL  ; NULL                 \\nREMARK   3                                                                      \\nREMARK   3  NCS MODEL : NULL                                                    \\nREMARK   3                                                                      \\nREMARK   3  NCS RESTRAINTS.                         RMS   SIGMA/WEIGHT          \\nREMARK   3   GROUP  1  POSITIONAL            (A) : NULL  ; NULL                 \\nREMARK   3   GROUP  1  B-FACTOR           (A**2) : NULL  ; NULL                 \\nREMARK   3                                                                      \\nREMARK   3  PARAMETER FILE  1  : NULL                                           \\nREMARK   3  TOPOLOGY FILE  1   : NULL                                           \\nREMARK   3                                                                      \\nREMARK   3  OTHER REFINEMENT REMARKS: BULK SOLVENT MODEL USED                   \\nREMARK   4                                                                      \\nREMARK   4 1AOI COMPLIES WITH FORMAT V. 3.15, 01-DEC-08                         \\nREMARK 100                                                                      \\nREMARK 100 THIS ENTRY HAS BEEN PROCESSED BY BNL.                                \\nREMARK 200                                                                      \\nREMARK 200 EXPERIMENTAL DETAILS                                                 \\nREMARK 200  EXPERIMENT TYPE                : X-RAY DIFFRACTION                  \\nREMARK 200  DATE OF DATA COLLECTION        : 15-AUG-95                          \\nREMARK 200  TEMPERATURE           (KELVIN) : 110.0                              \\nREMARK 200  PH                             : NULL                               \\nREMARK 200  NUMBER OF CRYSTALS USED        : 1                                  \\nREMARK 200                                                                      \\nREMARK 200  SYNCHROTRON              (Y/N) : Y                                  \\nREMARK 200  RADIATION SOURCE               : ESRF                               \\nREMARK 200  BEAMLINE                       : ID13                               \\nREMARK 200  X-RAY GENERATOR MODEL          : NULL                               \\nREMARK 200  MONOCHROMATIC OR LAUE    (M/L) : M                                  \\nREMARK 200  WAVELENGTH OR RANGE        (A) : NULL                               \\nREMARK 200  MONOCHROMATOR                  : NULL                               \\nREMARK 200  OPTICS                         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200  DETECTOR TYPE                  : IMAGE PLATE                        \\nREMARK 200  DETECTOR MANUFACTURER          : MARRESEARCH                        \\nREMARK 200  INTENSITY-INTEGRATION SOFTWARE : IN-HOUSE SOFTWARE                  \\nREMARK 200  DATA SCALING SOFTWARE          : IN-HOUSE SOFTWARE                  \\nREMARK 200                                                                      \\nREMARK 200  NUMBER OF UNIQUE REFLECTIONS   : 52487                              \\nREMARK 200  RESOLUTION RANGE HIGH      (A) : 2.800                              \\nREMARK 200  RESOLUTION RANGE LOW       (A) : 25.000                             \\nREMARK 200  REJECTION CRITERIA  (SIGMA(I)) : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 OVERALL.                                                             \\nREMARK 200  COMPLETENESS FOR RANGE     (%) : 99.0                               \\nREMARK 200  DATA REDUNDANCY                : 5.700                              \\nREMARK 200  R MERGE                    (I) : 0.05600                            \\nREMARK 200  R SYM                      (I) : 3.60000                            \\nREMARK 200  <I/SIGMA(I)> FOR THE DATA SET  : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 IN THE HIGHEST RESOLUTION SHELL.                                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE HIGH (A) : 2.80                     \\nREMARK 200  HIGHEST RESOLUTION SHELL, RANGE LOW  (A) : 2.85                     \\nREMARK 200  COMPLETENESS FOR SHELL     (%) : 95.0                               \\nREMARK 200  DATA REDUNDANCY IN SHELL       : 6.30                               \\nREMARK 200  R MERGE FOR SHELL          (I) : 0.13200                            \\nREMARK 200  R SYM FOR SHELL            (I) : NULL                               \\nREMARK 200  <I/SIGMA(I)> FOR SHELL         : NULL                               \\nREMARK 200                                                                      \\nREMARK 200 DIFFRACTION PROTOCOL: SINGLE WAVELENGTH                              \\nREMARK 200 METHOD USED TO DETERMINE THE STRUCTURE: MIR                          \\nREMARK 200 SOFTWARE USED: IN-HOUSE SOFTWARE                                     \\nREMARK 200 STARTING MODEL: NULL                                                 \\nREMARK 200                                                                      \\nREMARK 200 REMARK: NULL                                                         \\nREMARK 280                                                                      \\nREMARK 280 CRYSTAL                                                              \\nREMARK 280 SOLVENT CONTENT, VS   (%): 56.54                                     \\nREMARK 280 MATTHEWS COEFFICIENT, VM (ANGSTROMS**3/DA): 2.83                     \\nREMARK 280                                                                      \\nREMARK 280 CRYSTALLIZATION CONDITIONS: NULL                                     \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY                                            \\nREMARK 290 SYMMETRY OPERATORS FOR SPACE GROUP: P 21 21 21                       \\nREMARK 290                                                                      \\nREMARK 290      SYMOP   SYMMETRY                                                \\nREMARK 290     NNNMMM   OPERATOR                                                \\nREMARK 290       1555   X,Y,Z                                                   \\nREMARK 290       2555   -X+1/2,-Y,Z+1/2                                         \\nREMARK 290       3555   -X,Y+1/2,-Z+1/2                                         \\nREMARK 290       4555   X+1/2,-Y+1/2,-Z                                         \\nREMARK 290                                                                      \\nREMARK 290     WHERE NNN -> OPERATOR NUMBER                                     \\nREMARK 290           MMM -> TRANSLATION VECTOR                                  \\nREMARK 290                                                                      \\nREMARK 290 CRYSTALLOGRAPHIC SYMMETRY TRANSFORMATIONS                            \\nREMARK 290 THE FOLLOWING TRANSFORMATIONS OPERATE ON THE ATOM/HETATM             \\nREMARK 290 RECORDS IN THIS ENTRY TO PRODUCE CRYSTALLOGRAPHICALLY                \\nREMARK 290 RELATED MOLECULES.                                                   \\nREMARK 290   SMTRY1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 290   SMTRY1   2 -1.000000  0.000000  0.000000       53.02000            \\nREMARK 290   SMTRY2   2  0.000000 -1.000000  0.000000        0.00000            \\nREMARK 290   SMTRY3   2  0.000000  0.000000  1.000000       55.06000            \\nREMARK 290   SMTRY1   3 -1.000000  0.000000  0.000000        0.00000            \\nREMARK 290   SMTRY2   3  0.000000  1.000000  0.000000       90.89000            \\nREMARK 290   SMTRY3   3  0.000000  0.000000 -1.000000       55.06000            \\nREMARK 290   SMTRY1   4  1.000000  0.000000  0.000000       53.02000            \\nREMARK 290   SMTRY2   4  0.000000 -1.000000  0.000000       90.89000            \\nREMARK 290   SMTRY3   4  0.000000  0.000000 -1.000000        0.00000            \\nREMARK 290                                                                      \\nREMARK 290 REMARK: NULL                                                         \\nREMARK 300                                                                      \\nREMARK 300 BIOMOLECULE: 1                                                       \\nREMARK 300 SEE REMARK 350 FOR THE AUTHOR PROVIDED AND/OR PROGRAM                \\nREMARK 300 GENERATED ASSEMBLY INFORMATION FOR THE STRUCTURE IN                  \\nREMARK 300 THIS ENTRY. THE REMARK MAY ALSO PROVIDE INFORMATION ON               \\nREMARK 300 BURIED SURFACE AREA.                                                 \\nREMARK 350                                                                      \\nREMARK 350 COORDINATES FOR A COMPLETE MULTIMER REPRESENTING THE KNOWN           \\nREMARK 350 BIOLOGICALLY SIGNIFICANT OLIGOMERIZATION STATE OF THE                \\nREMARK 350 MOLECULE CAN BE GENERATED BY APPLYING BIOMT TRANSFORMATIONS          \\nREMARK 350 GIVEN BELOW.  BOTH NON-CRYSTALLOGRAPHIC AND                          \\nREMARK 350 CRYSTALLOGRAPHIC OPERATIONS ARE GIVEN.                               \\nREMARK 350                                                                      \\nREMARK 350 BIOMOLECULE: 1                                                       \\nREMARK 350 AUTHOR DETERMINED BIOLOGICAL UNIT: DECAMERIC                         \\nREMARK 350 APPLY THE FOLLOWING TO CHAINS: I, J, A, B, C, D, E, F, G, H          \\nREMARK 350   BIOMT1   1  1.000000  0.000000  0.000000        0.00000            \\nREMARK 350   BIOMT2   1  0.000000  1.000000  0.000000        0.00000            \\nREMARK 350   BIOMT3   1  0.000000  0.000000  1.000000        0.00000            \\nREMARK 465                                                                      \\nREMARK 465 MISSING RESIDUES                                                     \\nREMARK 465 THE FOLLOWING RESIDUES WERE NOT LOCATED IN THE                       \\nREMARK 465 EXPERIMENT. (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN               \\nREMARK 465 IDENTIFIER; SSSEQ=SEQUENCE NUMBER; I=INSERTION CODE.)                \\nREMARK 465                                                                      \\nREMARK 465   M RES C SSSEQI                                                     \\nREMARK 465     LEU A    20                                                      \\nREMARK 465     ALA A    21                                                      \\nREMARK 465     THR A    22                                                      \\nREMARK 465     LYS A    23                                                      \\nREMARK 465     ALA A    24                                                      \\nREMARK 465     ALA A    25                                                      \\nREMARK 465     ARG A    26                                                      \\nREMARK 465     LYS A    27                                                      \\nREMARK 465     SER A    28                                                      \\nREMARK 465     ALA A    29                                                      \\nREMARK 465     PRO A    30                                                      \\nREMARK 465     ALA A    31                                                      \\nREMARK 465     THR A    32                                                      \\nREMARK 465     GLY A    33                                                      \\nREMARK 465     GLY A    34                                                      \\nREMARK 465     VAL A    35                                                      \\nREMARK 465     LYS A    36                                                      \\nREMARK 465     LYS A    37                                                      \\nREMARK 465     LYS B    16                                                      \\nREMARK 465     ARG B    17                                                      \\nREMARK 465     HIS B    18                                                      \\nREMARK 465     ARG B    19                                                      \\nREMARK 465     LYS C   119                                                      \\nREMARK 465     GLY G     4                                                      \\nREMARK 465     LYS G     5                                                      \\nREMARK 465     GLN G     6                                                      \\nREMARK 465     GLY G     7                                                      \\nREMARK 465     GLY G     8                                                      \\nREMARK 465     LYS G     9                                                      \\nREMARK 465     THR G    10                                                      \\nREMARK 465     ARG G    11                                                      \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: CLOSE CONTACTS                                             \\nREMARK 500                                                                      \\nREMARK 500 THE FOLLOWING ATOMS THAT ARE RELATED BY CRYSTALLOGRAPHIC             \\nREMARK 500 SYMMETRY ARE IN CLOSE CONTACT.  AN ATOM LOCATED WITHIN 0.15          \\nREMARK 500 ANGSTROMS OF A SYMMETRY RELATED ATOM IS ASSUMED TO BE ON A           \\nREMARK 500 SPECIAL POSITION AND IS, THEREFORE, LISTED IN REMARK 375             \\nREMARK 500 INSTEAD OF REMARK 500.  ATOMS WITH NON-BLANK ALTERNATE               \\nREMARK 500 LOCATION INDICATORS ARE NOT INCLUDED IN THE CALCULATIONS.            \\nREMARK 500                                                                      \\nREMARK 500 DISTANCE CUTOFF:                                                     \\nREMARK 500 2.2 ANGSTROMS FOR CONTACTS NOT INVOLVING HYDROGEN ATOMS              \\nREMARK 500 1.6 ANGSTROMS FOR CONTACTS INVOLVING HYDROGEN ATOMS                  \\nREMARK 500                                                                      \\nREMARK 500  ATM1  RES C  SSEQI   ATM2  RES C  SSEQI  SSYMOP   DISTANCE          \\nREMARK 500   O    VAL D    45     O    HOH E     6     2565     2.17            \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: TORSION ANGLES                                             \\nREMARK 500                                                                      \\nREMARK 500 TORSION ANGLES OUTSIDE THE EXPECTED RAMACHANDRAN REGIONS:            \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500 STANDARD TABLE:                                                      \\nREMARK 500 FORMAT:(10X,I3,1X,A3,1X,A1,I4,A1,4X,F7.2,3X,F7.2)                    \\nREMARK 500                                                                      \\nREMARK 500 EXPECTED VALUES: GJ KLEYWEGT AND TA JONES (1996). PHI/PSI-           \\nREMARK 500 CHOLOGY: RAMACHANDRAN REVISITED. STRUCTURE 4, 1395 - 1400            \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        PSI       PHI                                   \\nREMARK 500    THR A  58       -0.56   -140.04                                   \\nREMARK 500    VAL B  21      -56.84   -168.14                                   \\nREMARK 500    THR B  96      123.60    -28.14                                   \\nREMARK 500    LYS C   9     -153.63   -150.77                                   \\nREMARK 500    THR C  10      166.13    -48.94                                   \\nREMARK 500    ARG C  11      158.27     62.51                                   \\nREMARK 500    ALA C  12      -85.54     77.55                                   \\nREMARK 500    LYS C  13      134.79     73.65                                   \\nREMARK 500    ALA C  14      170.84    -36.88                                   \\nREMARK 500    LYS C  36        0.65    -65.94                                   \\nREMARK 500    ASN C  38       74.42     50.34                                   \\nREMARK 500    VAL C 114        2.88    -68.57                                   \\nREMARK 500    PRO C 117     -177.41    -65.56                                   \\nREMARK 500    LYS D  28     -152.63    -76.88                                   \\nREMARK 500    THR D  29      -63.57   -156.41                                   \\nREMARK 500    ARG D  30      115.48     56.44                                   \\nREMARK 500    ALA E  21      -23.68   -142.38                                   \\nREMARK 500    THR E  22      171.32    -40.96                                   \\nREMARK 500    LYS E  23      -84.48    -42.26                                   \\nREMARK 500    ALA E  25      -21.97    159.76                                   \\nREMARK 500    ARG E  26      107.78    -33.89                                   \\nREMARK 500    LYS E  27       50.96     24.91                                   \\nREMARK 500    LYS E  37      -94.57    -68.87                                   \\nREMARK 500    PRO E  38     -153.92   -109.18                                   \\nREMARK 500    ARG E 134       44.52   -172.12                                   \\nREMARK 500    ARG F  17      -90.19    -66.91                                   \\nREMARK 500    HIS F  18     -155.92   -148.34                                   \\nREMARK 500    ARG F  19      127.24     76.29                                   \\nREMARK 500    THR F  96      120.55    -19.56                                   \\nREMARK 500    THR G  16      161.78    -23.63                                   \\nREMARK 500    LYS H  25      -97.48     53.01                                   \\nREMARK 500    ARG H  26       95.08     75.97                                   \\nREMARK 500    ARG H  27      124.56   -178.79                                   \\nREMARK 500    THR H  29      -85.15     91.54                                   \\nREMARK 500    ARG H  30      132.30     83.76                                   \\nREMARK 500    ALA H 121      127.26    111.53                                   \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 500                                                                      \\nREMARK 500 GEOMETRY AND STEREOCHEMISTRY                                         \\nREMARK 500 SUBTOPIC: PLANAR GROUPS                                              \\nREMARK 500                                                                      \\nREMARK 500 PLANAR GROUPS IN THE FOLLOWING RESIDUES HAVE A TOTAL                 \\nREMARK 500 RMS DISTANCE OF ALL ATOMS FROM THE BEST-FIT PLANE                    \\nREMARK 500 BY MORE THAN AN EXPECTED VALUE OF 6*RMSD, WITH AN                    \\nREMARK 500 RMSD 0.02 ANGSTROMS, OR AT LEAST ONE ATOM HAS                        \\nREMARK 500 AN RMSD GREATER THAN THIS VALUE                                      \\nREMARK 500 (M=MODEL NUMBER; RES=RESIDUE NAME; C=CHAIN IDENTIFIER;               \\nREMARK 500 SSEQ=SEQUENCE NUMBER; I=INSERTION CODE).                             \\nREMARK 500                                                                      \\nREMARK 500  M RES CSSEQI        RMS     TYPE                                    \\nREMARK 500     DT I  96         0.06    SIDE_CHAIN                              \\nREMARK 500     DG I 131         0.07    SIDE_CHAIN                              \\nREMARK 500     DA I 145         0.07    SIDE_CHAIN                              \\nREMARK 500     DA J 147         0.06    SIDE_CHAIN                              \\nREMARK 500     DC J 158         0.06    SIDE_CHAIN                              \\nREMARK 500     DG J 185         0.06    SIDE_CHAIN                              \\nREMARK 500     DG J 214         0.06    SIDE_CHAIN                              \\nREMARK 500                                                                      \\nREMARK 500 REMARK: NULL                                                         \\nREMARK 800                                                                      \\nREMARK 800 SITE                                                                 \\nREMARK 800 SITE_IDENTIFIER: AC1                                                 \\nREMARK 800 EVIDENCE_CODE: SOFTWARE                                              \\nREMARK 800 SITE_DESCRIPTION: BINDING SITE FOR RESIDUE MN J 400                  \\nDBREF  1AOI A   20   135  UNP    P02302   H32_XENLA       20    135             \\nDBREF  1AOI B   16   102  UNP    P62799   H4_XENLA        17    103             \\nDBREF  1AOI C    4   119  UNP    P06897   H2A1_XENLA       4    119             \\nDBREF  1AOI D   24   122  UNP    P02281   H2B1_XENLA      27    125             \\nDBREF  1AOI E   20   135  UNP    P02302   H32_XENLA       21    136             \\nDBREF  1AOI F   16   102  UNP    P62799   H4_XENLA        17    103             \\nDBREF  1AOI G    4   119  UNP    P06897   H2A1_XENLA       4    119             \\nDBREF  1AOI H   24   122  UNP    P02281   H2B1_XENLA      27    125             \\nDBREF  1AOI I    1   146  PDB    1AOI     1AOI             1    146             \\nDBREF  1AOI J  147   292  PDB    1AOI     1AOI           147    292             \\nSEQADV 1AOI ALA A   21  UNP  P02302    VAL    21 CONFLICT                       \\nSEQADV 1AOI ARG A   26  UNP  P02302    LYS    26 CONFLICT                       \\nSEQADV 1AOI SER A   28  UNP  P02302    CYS    28 CONFLICT                       \\nSEQADV 1AOI SER A   86  UNP  P02302    ARG    86 CONFLICT                       \\nSEQADV 1AOI ARG C   99  UNP  P06897    GLY    99 CONFLICT                       \\nSEQADV 1AOI THR D   29  UNP  P02281    SER    32 CONFLICT                       \\nSEQADV 1AOI ALA E   21  UNP  P02302    VAL    21 CONFLICT                       \\nSEQADV 1AOI ARG E   26  UNP  P02302    LYS    26 CONFLICT                       \\nSEQADV 1AOI SER E   28  UNP  P02302    CYS    28 CONFLICT                       \\nSEQADV 1AOI SER E   86  UNP  P02302    ARG    86 CONFLICT                       \\nSEQADV 1AOI ARG G   99  UNP  P06897    GLY    99 CONFLICT                       \\nSEQADV 1AOI THR H   29  UNP  P02281    SER    32 CONFLICT                       \\nSEQRES   1 I  146   DA  DT  DC  DA  DA  DT  DA  DT  DC  DC  DA  DC  DC          \\nSEQRES   2 I  146   DT  DG  DC  DA  DG  DA  DT  DT  DC  DT  DA  DC  DC          \\nSEQRES   3 I  146   DA  DA  DA  DA  DG  DT  DG  DT  DA  DT  DT  DT  DG          \\nSEQRES   4 I  146   DG  DA  DA  DA  DC  DT  DG  DC  DT  DC  DC  DA  DT          \\nSEQRES   5 I  146   DC  DA  DA  DA  DA  DG  DG  DC  DA  DT  DG  DT  DT          \\nSEQRES   6 I  146   DC  DA  DG  DC  DT  DG  DA  DA  DT  DT  DC  DA  DG          \\nSEQRES   7 I  146   DC  DT  DG  DA  DA  DC  DA  DT  DG  DC  DC  DT  DT          \\nSEQRES   8 I  146   DT  DT  DG  DA  DT  DG  DG  DA  DG  DC  DA  DG  DT          \\nSEQRES   9 I  146   DT  DT  DC  DC  DA  DA  DA  DT  DA  DC  DA  DC  DT          \\nSEQRES  10 I  146   DT  DT  DT  DG  DG  DT  DA  DG  DA  DA  DT  DC  DT          \\nSEQRES  11 I  146   DG  DC  DA  DG  DG  DT  DG  DG  DA  DT  DA  DT  DT          \\nSEQRES  12 I  146   DG  DA  DT                                                  \\nSEQRES   1 J  146   DA  DT  DC  DA  DA  DT  DA  DT  DC  DC  DA  DC  DC          \\nSEQRES   2 J  146   DT  DG  DC  DA  DG  DA  DT  DT  DC  DT  DA  DC  DC          \\nSEQRES   3 J  146   DA  DA  DA  DA  DG  DT  DG  DT  DA  DT  DT  DT  DG          \\nSEQRES   4 J  146   DG  DA  DA  DA  DC  DT  DG  DC  DT  DC  DC  DA  DT          \\nSEQRES   5 J  146   DC  DA  DA  DA  DA  DG  DG  DC  DA  DT  DG  DT  DT          \\nSEQRES   6 J  146   DC  DA  DG  DC  DT  DG  DA  DA  DT  DT  DC  DA  DG          \\nSEQRES   7 J  146   DC  DT  DG  DA  DA  DC  DA  DT  DG  DC  DC  DT  DT          \\nSEQRES   8 J  146   DT  DT  DG  DA  DT  DG  DG  DA  DG  DC  DA  DG  DT          \\nSEQRES   9 J  146   DT  DT  DC  DC  DA  DA  DA  DT  DA  DC  DA  DC  DT          \\nSEQRES  10 J  146   DT  DT  DT  DG  DG  DT  DA  DG  DA  DA  DT  DC  DT          \\nSEQRES  11 J  146   DG  DC  DA  DG  DG  DT  DG  DG  DA  DT  DA  DT  DT          \\nSEQRES  12 J  146   DG  DA  DT                                                  \\nSEQRES   1 A  116  LEU ALA THR LYS ALA ALA ARG LYS SER ALA PRO ALA THR          \\nSEQRES   2 A  116  GLY GLY VAL LYS LYS PRO HIS ARG TYR ARG PRO GLY THR          \\nSEQRES   3 A  116  VAL ALA LEU ARG GLU ILE ARG ARG TYR GLN LYS SER THR          \\nSEQRES   4 A  116  GLU LEU LEU ILE ARG LYS LEU PRO PHE GLN ARG LEU VAL          \\nSEQRES   5 A  116  ARG GLU ILE ALA GLN ASP PHE LYS THR ASP LEU ARG PHE          \\nSEQRES   6 A  116  GLN SER SER ALA VAL MET ALA LEU GLN GLU ALA SER GLU          \\nSEQRES   7 A  116  ALA TYR LEU VAL ALA LEU PHE GLU ASP THR ASN LEU CYS          \\nSEQRES   8 A  116  ALA ILE HIS ALA LYS ARG VAL THR ILE MET PRO LYS ASP          \\nSEQRES   9 A  116  ILE GLN LEU ALA ARG ARG ILE ARG GLY GLU ARG ALA              \\nSEQRES   1 B   87  LYS ARG HIS ARG LYS VAL LEU ARG ASP ASN ILE GLN GLY          \\nSEQRES   2 B   87  ILE THR LYS PRO ALA ILE ARG ARG LEU ALA ARG ARG GLY          \\nSEQRES   3 B   87  GLY VAL LYS ARG ILE SER GLY LEU ILE TYR GLU GLU THR          \\nSEQRES   4 B   87  ARG GLY VAL LEU LYS VAL PHE LEU GLU ASN VAL ILE ARG          \\nSEQRES   5 B   87  ASP ALA VAL THR TYR THR GLU HIS ALA LYS ARG LYS THR          \\nSEQRES   6 B   87  VAL THR ALA MET ASP VAL VAL TYR ALA LEU LYS ARG GLN          \\nSEQRES   7 B   87  GLY ARG THR LEU TYR GLY PHE GLY GLY                          \\nSEQRES   1 C  116  GLY LYS GLN GLY GLY LYS THR ARG ALA LYS ALA LYS THR          \\nSEQRES   2 C  116  ARG SER SER ARG ALA GLY LEU GLN PHE PRO VAL GLY ARG          \\nSEQRES   3 C  116  VAL HIS ARG LEU LEU ARG LYS GLY ASN TYR ALA GLU ARG          \\nSEQRES   4 C  116  VAL GLY ALA GLY ALA PRO VAL TYR LEU ALA ALA VAL LEU          \\nSEQRES   5 C  116  GLU TYR LEU THR ALA GLU ILE LEU GLU LEU ALA GLY ASN          \\nSEQRES   6 C  116  ALA ALA ARG ASP ASN LYS LYS THR ARG ILE ILE PRO ARG          \\nSEQRES   7 C  116  HIS LEU GLN LEU ALA VAL ARG ASN ASP GLU GLU LEU ASN          \\nSEQRES   8 C  116  LYS LEU LEU GLY ARG VAL THR ILE ALA GLN GLY GLY VAL          \\nSEQRES   9 C  116  LEU PRO ASN ILE GLN SER VAL LEU LEU PRO LYS LYS              \\nSEQRES   1 D   99  LYS LYS ARG ARG LYS THR ARG LYS GLU SER TYR ALA ILE          \\nSEQRES   2 D   99  TYR VAL TYR LYS VAL LEU LYS GLN VAL HIS PRO ASP THR          \\nSEQRES   3 D   99  GLY ILE SER SER LYS ALA MET SER ILE MET ASN SER PHE          \\nSEQRES   4 D   99  VAL ASN ASP VAL PHE GLU ARG ILE ALA GLY GLU ALA SER          \\nSEQRES   5 D   99  ARG LEU ALA HIS TYR ASN LYS ARG SER THR ILE THR SER          \\nSEQRES   6 D   99  ARG GLU ILE GLN THR ALA VAL ARG LEU LEU LEU PRO GLY          \\nSEQRES   7 D   99  GLU LEU ALA LYS HIS ALA VAL SER GLU GLY THR LYS ALA          \\nSEQRES   8 D   99  VAL THR LYS TYR THR SER ALA LYS                              \\nSEQRES   1 E  116  LEU ALA THR LYS ALA ALA ARG LYS SER ALA PRO ALA THR          \\nSEQRES   2 E  116  GLY GLY VAL LYS LYS PRO HIS ARG TYR ARG PRO GLY THR          \\nSEQRES   3 E  116  VAL ALA LEU ARG GLU ILE ARG ARG TYR GLN LYS SER THR          \\nSEQRES   4 E  116  GLU LEU LEU ILE ARG LYS LEU PRO PHE GLN ARG LEU VAL          \\nSEQRES   5 E  116  ARG GLU ILE ALA GLN ASP PHE LYS THR ASP LEU ARG PHE          \\nSEQRES   6 E  116  GLN SER SER ALA VAL MET ALA LEU GLN GLU ALA SER GLU          \\nSEQRES   7 E  116  ALA TYR LEU VAL ALA LEU PHE GLU ASP THR ASN LEU CYS          \\nSEQRES   8 E  116  ALA ILE HIS ALA LYS ARG VAL THR ILE MET PRO LYS ASP          \\nSEQRES   9 E  116  ILE GLN LEU ALA ARG ARG ILE ARG GLY GLU ARG ALA              \\nSEQRES   1 F   87  LYS ARG HIS ARG LYS VAL LEU ARG ASP ASN ILE GLN GLY          \\nSEQRES   2 F   87  ILE THR LYS PRO ALA ILE ARG ARG LEU ALA ARG ARG GLY          \\nSEQRES   3 F   87  GLY VAL LYS ARG ILE SER GLY LEU ILE TYR GLU GLU THR          \\nSEQRES   4 F   87  ARG GLY VAL LEU LYS VAL PHE LEU GLU ASN VAL ILE ARG          \\nSEQRES   5 F   87  ASP ALA VAL THR TYR THR GLU HIS ALA LYS ARG LYS THR          \\nSEQRES   6 F   87  VAL THR ALA MET ASP VAL VAL TYR ALA LEU LYS ARG GLN          \\nSEQRES   7 F   87  GLY ARG THR LEU TYR GLY PHE GLY GLY                          \\nSEQRES   1 G  116  GLY LYS GLN GLY GLY LYS THR ARG ALA LYS ALA LYS THR          \\nSEQRES   2 G  116  ARG SER SER ARG ALA GLY LEU GLN PHE PRO VAL GLY ARG          \\nSEQRES   3 G  116  VAL HIS ARG LEU LEU ARG LYS GLY ASN TYR ALA GLU ARG          \\nSEQRES   4 G  116  VAL GLY ALA GLY ALA PRO VAL TYR LEU ALA ALA VAL LEU          \\nSEQRES   5 G  116  GLU TYR LEU THR ALA GLU ILE LEU GLU LEU ALA GLY ASN          \\nSEQRES   6 G  116  ALA ALA ARG ASP ASN LYS LYS THR ARG ILE ILE PRO ARG          \\nSEQRES   7 G  116  HIS LEU GLN LEU ALA VAL ARG ASN ASP GLU GLU LEU ASN          \\nSEQRES   8 G  116  LYS LEU LEU GLY ARG VAL THR ILE ALA GLN GLY GLY VAL          \\nSEQRES   9 G  116  LEU PRO ASN ILE GLN SER VAL LEU LEU PRO LYS LYS              \\nSEQRES   1 H   99  LYS LYS ARG ARG LYS THR ARG LYS GLU SER TYR ALA ILE          \\nSEQRES   2 H   99  TYR VAL TYR LYS VAL LEU LYS GLN VAL HIS PRO ASP THR          \\nSEQRES   3 H   99  GLY ILE SER SER LYS ALA MET SER ILE MET ASN SER PHE          \\nSEQRES   4 H   99  VAL ASN ASP VAL PHE GLU ARG ILE ALA GLY GLU ALA SER          \\nSEQRES   5 H   99  ARG LEU ALA HIS TYR ASN LYS ARG SER THR ILE THR SER          \\nSEQRES   6 H   99  ARG GLU ILE GLN THR ALA VAL ARG LEU LEU LEU PRO GLY          \\nSEQRES   7 H   99  GLU LEU ALA LYS HIS ALA VAL SER GLU GLY THR LYS ALA          \\nSEQRES   8 H   99  VAL THR LYS TYR THR SER ALA LYS                              \\nHET     MN  I 147       1                                                       \\nHET     MN  J 293       1                                                       \\nHET     MN  J 300       1                                                       \\nHET     MN  J 400       1                                                       \\nHET     MN  I 500       1                                                       \\nHET     MN  I 600       1                                                       \\nHETNAM      MN MANGANESE (II) ION                                               \\nFORMUL  11   MN    6(MN 2+)                                                     \\nFORMUL  17  HOH   *13(H2 O)                                                     \\nHELIX    1   1 THR A   45  LYS A   56  1                                  12    \\nHELIX    2   2 LYS A   64  PHE A   78  1                                  15    \\nHELIX    3   3 SER A   86  HIS A  113  1                                  28    \\nHELIX    4   4 PRO A  121  ARG A  131  1                                  11    \\nHELIX    5   5 ILE B   26  GLY B   28  5                                   3    \\nHELIX    6   6 LYS B   31  ARG B   40  1                                  10    \\nHELIX    7   7 GLY B   48  HIS B   75  5                                  28    \\nHELIX    8   8 ALA B   83  GLN B   93  1                                  11    \\nHELIX    9   9 LYS C    5  GLY C    7  5                                   3    \\nHELIX   10  10 ARG C   17  ALA C   21  1                                   5    \\nHELIX   11  11 VAL C   27  ARG C   35  1                                   9    \\nHELIX   12  12 ALA C   45  ASP C   72  1                                  28    \\nHELIX   13  13 PRO C   80  ARG C   88  1                                   9    \\nHELIX   14  14 GLU C   91  LEU C   96  1                                   6    \\nHELIX   15  15 SER C  113  LEU C  115  5                                   3    \\nHELIX   16  16 ALA D   35  VAL D   45  1                                  11    \\nHELIX   17  17 SER D   53  ASN D   81  1                                  29    \\nHELIX   18  18 SER D   88  LEU D   98  1                                  11    \\nHELIX   19  19 GLY D  101  THR D  119  1                                  19    \\nHELIX   20  20 THR E   45  LYS E   56  1                                  12    \\nHELIX   21  21 LYS E   64  ASP E   77  1                                  14    \\nHELIX   22  22 SER E   86  ALA E  114  1                                  29    \\nHELIX   23  23 PRO E  121  ARG E  131  1                                  11    \\nHELIX   24  24 ASN F   25  GLY F   28  5                                   4    \\nHELIX   25  25 LYS F   31  ARG F   40  1                                  10    \\nHELIX   26  26 ILE F   50  ALA F   76  1                                  27    \\nHELIX   27  27 ALA F   83  ARG F   92  1                                  10    \\nHELIX   28  28 ARG G   17  ALA G   21  1                                   5    \\nHELIX   29  29 VAL G   27  GLY G   37  1                                  11    \\nHELIX   30  30 ALA G   47  ASN G   73  1                                  27    \\nHELIX   31  31 PRO G   80  ARG G   88  1                                   9    \\nHELIX   32  32 GLU G   91  LEU G   96  1                                   6    \\nHELIX   33  33 SER G  113  LEU G  115  5                                   3    \\nHELIX   34  34 TYR H   34  VAL H   45  5                                  12    \\nHELIX   35  35 SER H   53  TYR H   80  1                                  28    \\nHELIX   36  36 SER H   88  LEU H   98  1                                  11    \\nHELIX   37  37 GLY H  101  THR H  119  1                                  19    \\nSHEET    1   A 2 ARG A  83  PHE A  84  0                                        \\nSHEET    2   A 2 THR B  80  VAL B  81  1  N  VAL B  81   O  ARG A  83           \\nSHEET    1   B 2 THR A 118  ILE A 119  0                                        \\nSHEET    2   B 2 ARG B  45  ILE B  46  1  O  ARG B  45   N  ILE A 119           \\nSHEET    1   C 2 LEU B  97  TYR B  98  0                                        \\nSHEET    2   C 2 THR G 101  ILE G 102  1  O  THR G 101   N  TYR B  98           \\nSHEET    1   D 2 ARG C  42  VAL C  43  0                                        \\nSHEET    2   D 2 THR D  85  ILE D  86  1  N  ILE D  86   O  ARG C  42           \\nSHEET    1   E 2 ARG C  77  ILE C  78  0                                        \\nSHEET    2   E 2 GLY D  50  ILE D  51  1  O  GLY D  50   N  ILE C  78           \\nSHEET    1   F 2 THR C 101  ILE C 102  0                                        \\nSHEET    2   F 2 LEU F  97  TYR F  98  1  N  TYR F  98   O  THR C 101           \\nSHEET    1   G 2 ARG E  83  PHE E  84  0                                        \\nSHEET    2   G 2 THR F  80  VAL F  81  1  N  VAL F  81   O  ARG E  83           \\nSHEET    1   H 2 THR E 118  ILE E 119  0                                        \\nSHEET    2   H 2 ARG F  45  ILE F  46  1  O  ARG F  45   N  ILE E 119           \\nSHEET    1   I 2 ARG G  42  VAL G  43  0                                        \\nSHEET    2   I 2 THR H  85  ILE H  86  1  N  ILE H  86   O  ARG G  42           \\nSHEET    1   J 2 ARG G  77  ILE G  78  0                                        \\nSHEET    2   J 2 GLY H  50  ILE H  51  1  O  GLY H  50   N  ILE G  78           \\nSITE     1 AC1  1  DT J 167                                                     \\nCRYST1  106.040  181.780  110.120  90.00  90.00  90.00 P 21 21 21    8          \\nORIGX1      1.000000  0.000000  0.000000        0.00000                         \\nORIGX2      0.000000  1.000000  0.000000        0.00000                         \\nORIGX3      0.000000  0.000000  1.000000        0.00000                         \\nSCALE1      0.009430  0.000000  0.000000        0.00000                         \\nSCALE2      0.000000  0.005501  0.000000        0.00000                         \\nSCALE3      0.000000  0.000000  0.009081        0.00000                         \\nATOM      1  O5'  DA I   1      25.537 137.838  26.891  1.00170.35           O  \\nATOM      2  C5'  DA I   1      25.358 139.192  27.309  1.00170.35           C  \\nATOM      3  C4'  DA I   1      24.106 139.813  26.732  1.00170.35           C  \\nATOM      4  O4'  DA I   1      24.251 139.999  25.303  1.00170.35           O  \\nATOM      5  C3'  DA I   1      22.837 138.982  26.918  1.00170.35           C  \\nATOM      6  O3'  DA I   1      21.723 139.844  27.145  1.00170.35           O  \\nATOM      7  C2'  DA I   1      22.671 138.294  25.577  1.00170.35           C  \\nATOM      8  C1'  DA I   1      23.178 139.357  24.621  1.00170.35           C  \\nATOM      9  N9   DA I   1      23.690 138.834  23.351  1.00 66.50           N  \\nATOM     10  C8   DA I   1      24.833 138.084  23.152  1.00 66.50           C  \\nATOM     11  N7   DA I   1      25.045 137.760  21.893  1.00 66.50           N  \\nATOM     12  C5   DA I   1      23.973 138.331  21.217  1.00 66.50           C  \\nATOM     13  C6   DA I   1      23.622 138.348  19.863  1.00 66.50           C  \\nATOM     14  N6   DA I   1      24.335 137.759  18.911  1.00 66.50           N  \\nATOM     15  N1   DA I   1      22.498 139.000  19.515  1.00 66.50           N  \\nATOM     16  C2   DA I   1      21.776 139.597  20.476  1.00 66.50           C  \\nATOM     17  N3   DA I   1      21.999 139.653  21.789  1.00 66.50           N  \\nATOM     18  C4   DA I   1      23.128 138.993  22.101  1.00 66.50           C  \\nATOM     19  P    DT I   2      20.372 139.246  27.770  1.00153.90           P  \\nATOM     20  OP1  DT I   2      19.269 140.187  27.450  1.00153.90           O  \\nATOM     21  OP2  DT I   2      20.642 138.887  29.184  1.00153.90           O  \\nATOM     22  O5'  DT I   2      20.132 137.896  26.960  1.00143.36           O  \\nATOM     23  C5'  DT I   2      18.812 137.465  26.669  1.00143.36           C  \\nATOM     24  C4'  DT I   2      18.134 138.494  25.799  1.00143.36           C  \\nATOM     25  O4'  DT I   2      18.881 138.676  24.575  1.00143.36           O  \\nATOM     26  C3'  DT I   2      16.716 138.152  25.378  1.00143.36           C  \\nATOM     27  O3'  DT I   2      15.970 139.359  25.318  1.00143.36           O  \\nATOM     28  C2'  DT I   2      16.894 137.543  24.000  1.00143.36           C  \\nATOM     29  C1'  DT I   2      18.110 138.274  23.447  1.00143.36           C  \\nATOM     30  N1   DT I   2      18.984 137.435  22.594  1.00111.90           N  \\nATOM     31  C2   DT I   2      18.877 137.512  21.215  1.00111.90           C  \\nATOM     32  O2   DT I   2      18.051 138.207  20.637  1.00111.90           O  \\nATOM     33  N3   DT I   2      19.783 136.727  20.535  1.00111.90           N  \\nATOM     34  C4   DT I   2      20.742 135.888  21.077  1.00111.90           C  \\nATOM     35  O4   DT I   2      21.507 135.270  20.340  1.00111.90           O  \\nATOM     36  C5   DT I   2      20.764 135.827  22.514  1.00111.90           C  \\nATOM     37  C7   DT I   2      21.733 134.908  23.184  1.00111.90           C  \\nATOM     38  C6   DT I   2      19.904 136.597  23.192  1.00111.90           C  \\nATOM     39  P    DC I   3      14.379 139.291  25.262  1.00107.76           P  \\nATOM     40  OP1  DC I   3      13.828 140.650  25.481  1.00107.76           O  \\nATOM     41  OP2  DC I   3      13.978 138.173  26.157  1.00107.76           O  \\nATOM     42  O5'  DC I   3      14.089 138.888  23.754  1.00118.45           O  \\nATOM     43  C5'  DC I   3      12.936 138.141  23.418  1.00118.45           C  \\nATOM     44  C4'  DC I   3      12.930 137.834  21.940  1.00118.45           C  \\nATOM     45  O4'  DC I   3      14.256 137.451  21.485  1.00118.45           O  \\nATOM     46  C3'  DC I   3      12.012 136.668  21.591  1.00118.45           C  \\nATOM     47  O3'  DC I   3      11.331 136.941  20.374  1.00118.45           O  \\nATOM     48  C2'  DC I   3      12.968 135.505  21.409  1.00118.45           C  \\nATOM     49  C1'  DC I   3      14.174 136.202  20.809  1.00118.45           C  \\nATOM     50  N1   DC I   3      15.460 135.479  20.962  1.00 75.97           N  \\nATOM     51  C2   DC I   3      16.324 135.391  19.854  1.00 75.97           C  \\nATOM     52  O2   DC I   3      15.992 135.941  18.786  1.00 75.97           O  \\nATOM     53  N3   DC I   3      17.488 134.707  19.977  1.00 75.97           N  \\nATOM     54  C4   DC I   3      17.803 134.126  21.137  1.00 75.97           C  \\nATOM     55  N4   DC I   3      18.956 133.459  21.209  1.00 75.97           N  \\nATOM     56  C5   DC I   3      16.951 134.203  22.277  1.00 75.97           C  \\nATOM     57  C6   DC I   3      15.803 134.887  22.149  1.00 75.97           C  \\nATOM     58  P    DA I   4      10.135 135.984  19.919  1.00160.30           P  \\nATOM     59  OP1  DA I   4       8.961 136.812  19.543  1.00160.30           O  \\nATOM     60  OP2  DA I   4       9.995 134.924  20.951  1.00160.30           O  \\nATOM     61  O5'  DA I   4      10.695 135.303  18.605  1.00 81.02           O  \\nATOM     62  C5'  DA I   4      11.008 136.087  17.464  1.00 81.02           C  \\nATOM     63  C4'  DA I   4      11.360 135.178  16.314  1.00 81.02           C  \\nATOM     64  O4'  DA I   4      12.608 134.502  16.617  1.00 81.02           O  \\nATOM     65  C3'  DA I   4      10.325 134.082  16.068  1.00 81.02           C  \\nATOM     66  O3'  DA I   4      10.124 133.930  14.655  1.00 81.02           O  \\nATOM     67  C2'  DA I   4      10.911 132.865  16.771  1.00 81.02           C  \\nATOM     68  C1'  DA I   4      12.418 133.096  16.719  1.00 81.02           C  \\nATOM     69  N9   DA I   4      13.169 132.630  17.896  1.00 51.15           N  \\nATOM     70  C8   DA I   4      12.795 132.662  19.227  1.00 51.15           C  \\nATOM     71  N7   DA I   4      13.706 132.185  20.050  1.00 51.15           N  \\nATOM     72  C5   DA I   4      14.750 131.810  19.209  1.00 51.15           C  \\nATOM     73  C6   DA I   4      16.022 131.230  19.461  1.00 51.15           C  \\nATOM     74  N6   DA I   4      16.481 130.921  20.684  1.00 51.15           N  \\nATOM     75  N1   DA I   4      16.813 130.977  18.393  1.00 51.15           N  \\nATOM     76  C2   DA I   4      16.358 131.279  17.163  1.00 51.15           C  \\nATOM     77  N3   DA I   4      15.195 131.822  16.799  1.00 51.15           N  \\nATOM     78  C4   DA I   4      14.429 132.070  17.878  1.00 51.15           C  \\nATOM     79  P    DA I   5       9.609 132.531  14.056  1.00 87.05           P  \\nATOM     80  OP1  DA I   5       9.312 132.719  12.606  1.00 87.05           O  \\nATOM     81  OP2  DA I   5       8.566 131.973  14.959  1.00 87.05           O  \\nATOM     82  O5'  DA I   5      10.915 131.637  14.161  1.00 98.96           O  \\nATOM     83  C5'  DA I   5      12.078 132.005  13.433  1.00 98.96           C  \\nATOM     84  C4'  DA I   5      12.698 130.776  12.830  1.00 98.96           C  \\nATOM     85  O4'  DA I   5      13.515 130.138  13.830  1.00 98.96           O  \\nATOM     86  C3'  DA I   5      11.646 129.755  12.416  1.00 98.96           C  \\nATOM     87  O3'  DA I   5      12.047 129.134  11.192  1.00 98.96           O  \\nATOM     88  C2'  DA I   5      11.567 128.817  13.610  1.00 98.96           C  \\nATOM     89  C1'  DA I   5      12.949 128.909  14.244  1.00 98.96           C  \\nATOM     90  N9   DA I   5      12.939 128.919  15.704  1.00 67.55           N  \\nATOM     91  C8   DA I   5      12.001 129.467  16.539  1.00 67.55           C  \\nATOM     92  N7   DA I   5      12.272 129.310  17.816  1.00 67.55           N  \\nATOM     93  C5   DA I   5      13.473 128.613  17.820  1.00 67.55           C  \\nATOM     94  C6   DA I   5      14.305 128.132  18.868  1.00 67.55           C  \\nATOM     95  N6   DA I   5      14.047 128.275  20.168  1.00 67.55           N  \\nATOM     96  N1   DA I   5      15.430 127.486  18.520  1.00 67.55           N  \\nATOM     97  C2   DA I   5      15.706 127.331  17.220  1.00 67.55           C  \\nATOM     98  N3   DA I   5      15.013 127.731  16.151  1.00 67.55           N  \\nATOM     99  C4   DA I   5      13.896 128.371  16.524  1.00 67.55           C  \\nATOM    100  P    DT I   6      11.383 127.747  10.728  1.00 83.50           P  \\nATOM    101  OP1  DT I   6      11.100 127.761   9.264  1.00 83.50           O  \\nATOM    102  OP2  DT I   6      10.304 127.367  11.690  1.00 83.50           O  \\nATOM    103  O5'  DT I   6      12.580 126.733  10.927  1.00 51.12           O  \\nATOM    104  C5'  DT I   6      12.298 125.377  11.121  1.00 51.12           C  \\nATOM    105  C4'  DT I   6      13.441 124.704  11.824  1.00 51.12           C  \\nATOM    106  O4'  DT I   6      13.678 125.269  13.139  1.00 51.12           O  \\nATOM    107  C3'  DT I   6      13.085 123.244  12.038  1.00 51.12           C  \\nATOM    108  O3'  DT I   6      14.152 122.451  11.602  1.00 51.12           O  \\nATOM    109  C2'  DT I   6      12.874 123.121  13.531  1.00 51.12           C  \\nATOM    110  C1'  DT I   6      13.764 124.211  14.071  1.00 51.12           C  \\nATOM    111  N1   DT I   6      13.310 124.691  15.377  1.00 45.37           N  \\nATOM    112  C2   DT I   6      14.170 124.552  16.448  1.00 45.37           C  \\nATOM    113  O2   DT I   6      15.308 124.125  16.342  1.00 45.37           O  \\nATOM    114  N3   DT I   6      13.654 124.944  17.650  1.00 45.37           N  \\nATOM    115  C4   DT I   6      12.414 125.476  17.893  1.00 45.37           C  \\nATOM    116  O4   DT I   6      12.106 125.793  19.036  1.00 45.37           O  \\nATOM    117  C5   DT I   6      11.566 125.618  16.724  1.00 45.37           C  \\nATOM    118  C7   DT I   6      10.190 126.179  16.893  1.00 45.37           C  \\nATOM    119  C6   DT I   6      12.055 125.230  15.534  1.00 45.37           C  \\nATOM    120  P    DA I   7      13.889 120.932  11.248  1.00 74.79           P  \\nATOM    121  OP1  DA I   7      14.268 120.761   9.825  1.00 74.79           O  \\nATOM    122  OP2  DA I   7      12.521 120.577  11.702  1.00 74.79           O  \\nATOM    123  O5'  DA I   7      14.950 120.232  12.187  1.00 52.17           O  \\nATOM    124  C5'  DA I   7      16.221 120.840  12.345  1.00 52.17           C  \\nATOM    125  C4'  DA I   7      16.803 120.492  13.688  1.00 52.17           C  \\nATOM    126  O4'  DA I   7      16.096 121.186  14.740  1.00 52.17           O  \\nATOM    127  C3'  DA I   7      16.673 119.009  13.986  1.00 52.17           C  \\nATOM    128  O3'  DA I   7      17.892 118.529  14.549  1.00 52.17           O  \\nATOM    129  C2'  DA I   7      15.503 118.950  14.952  1.00 52.17           C  \\nATOM    130  C1'  DA I   7      15.645 120.260  15.699  1.00 52.17           C  \\nATOM    131  N9   DA I   7      14.398 120.769  16.264  1.00 49.10           N  \\nATOM    132  C8   DA I   7      13.226 121.025  15.607  1.00 49.10           C  \\nATOM    133  N7   DA I   7      12.265 121.456  16.392  1.00 49.10           N  \\nATOM    134  C5   DA I   7      12.849 121.493  17.653  1.00 49.10           C  \\nATOM    135  C6   DA I   7      12.353 121.853  18.926  1.00 49.10           C  \\nATOM    136  N6   DA I   7      11.110 122.277  19.150  1.00 49.10           N  \\nATOM    137  N1   DA I   7      13.195 121.760  19.977  1.00 49.10           N  \\nATOM    138  C2   DA I   7      14.441 121.340  19.761  1.00 49.10           C  \\nATOM    139  N3   DA I   7      15.024 120.980  18.621  1.00 49.10           N  \\nATOM    140  C4   DA I   7      14.164 121.077  17.589  1.00 49.10           C  \\nATOM    141  P    DT I   8      18.069 116.959  14.813  1.00 86.12           P  \\nATOM    142  OP1  DT I   8      19.483 116.581  14.578  1.00 86.12           O  \\nATOM    143  OP2  DT I   8      16.993 116.242  14.077  1.00 86.12           O  \\nATOM    144  O5'  DT I   8      17.791 116.882  16.375  1.00113.81           O  \\nATOM    145  C5'  DT I   8      18.502 117.743  17.265  1.00113.81           C  \\nATOM    146  C4'  DT I   8      18.194 117.379  18.696  1.00113.81           C  \\nATOM    147  O4'  DT I   8      16.965 118.008  19.130  1.00113.81           O  \\nATOM    148  C3'  DT I   8      18.007 115.876  18.910  1.00113.81           C  \\nATOM    149  O3'  DT I   8      18.613 115.463  20.139  1.00113.81           O  \\nATOM    150  C2'  DT I   8      16.498 115.724  18.965  1.00113.81           C  \\nATOM    151  C1'  DT I   8      16.090 117.019  19.633  1.00113.81           C  \\nATOM    152  N1   DT I   8      14.722 117.444  19.349  1.00 39.29           N  \\nATOM    153  C2   DT I   8      13.987 117.959  20.396  1.00 39.29           C  \\nATOM    154  O2   DT I   8      14.443 118.105  21.524  1.00 39.29           O  \\nATOM    155  N3   DT I   8      12.696 118.307  20.079  1.00 39.29           N  \\nATOM    156  C4   DT I   8      12.089 118.215  18.837  1.00 39.29           C  \\nATOM    157  O4   DT I   8      10.910 118.574  18.694  1.00 39.29           O  \\nATOM    158  C5   DT I   8      12.935 117.680  17.778  1.00 39.29           C  \\nATOM    159  C7   DT I   8      12.373 117.552  16.396  1.00 39.29           C  \\nATOM    160  C6   DT I   8      14.191 117.324  18.087  1.00 39.29           C  \\nATOM    161  P    DC I   9      19.367 114.043  20.220  1.00106.25           P  \\nATOM    162  OP1  DC I   9      20.794 114.287  20.554  1.00106.25           O  \\nATOM    163  OP2  DC I   9      19.014 113.254  19.011  1.00106.25           O  \\nATOM    164  O5'  DC I   9      18.681 113.342  21.464  1.00 79.01           O  \\nATOM    165  C5'  DC I   9      17.286 113.478  21.675  1.00 79.01           C  \\nATOM    166  C4'  DC I   9      17.032 114.198  22.977  1.00 79.01           C  \\nATOM    167  O4'  DC I   9      16.057 115.243  22.765  1.00 79.01           O  \\nATOM    168  C3'  DC I   9      16.463 113.299  24.064  1.00 79.01           C  \\nATOM    169  O3'  DC I   9      17.019 113.654  25.331  1.00 79.01           O  \\nATOM    170  C2'  DC I   9      14.962 113.520  23.966  1.00 79.01           C  \\nATOM    171  C1'  DC I   9      14.808 114.903  23.339  1.00 79.01           C  \\nATOM    172  N1   DC I   9      13.819 114.932  22.252  1.00 51.82           N  \\nATOM    173  C2   DC I   9      12.506 115.293  22.536  1.00 51.82           C  \\nATOM    174  O2   DC I   9      12.212 115.609  23.702  1.00 51.82           O  \\nATOM    175  N3   DC I   9      11.586 115.294  21.536  1.00 51.82           N  \\nATOM    176  C4   DC I   9      11.951 114.957  20.294  1.00 51.82           C  \\nATOM    177  N4   DC I   9      11.014 114.969  19.327  1.00 51.82           N  \\nATOM    178  C5   DC I   9      13.291 114.595  19.980  1.00 51.82           C  \\nATOM    179  C6   DC I   9      14.181 114.600  20.978  1.00 51.82           C  \\nATOM    180  P    DC I  10      17.479 112.498  26.348  1.00106.94           P  \\nATOM    181  OP1  DC I  10      18.638 112.983  27.145  1.00106.94           O  \\nATOM    182  OP2  DC I  10      17.596 111.231  25.571  1.00106.94           O  \\nATOM    183  O5'  DC I  10      16.231 112.375  27.320  1.00121.81           O  \\nATOM    184  C5'  DC I  10      15.124 113.264  27.187  1.00121.81           C  \\nATOM    185  C4'  DC I  10      13.852 112.568  27.603  1.00121.81           C  \\nATOM    186  O4'  DC I  10      12.791 112.874  26.663  1.00121.81           O  \\nATOM    187  C3'  DC I  10      13.959 111.041  27.646  1.00121.81           C  \\nATOM    188  O3'  DC I  10      13.202 110.551  28.757  1.00121.81           O  \\nATOM    189  C2'  DC I  10      13.313 110.618  26.340  1.00121.81           C  \\nATOM    190  C1'  DC I  10      12.227 111.666  26.184  1.00121.81           C  \\nATOM    191  N1   DC I  10      11.794 111.878  24.797  1.00 76.30           N  \\nATOM    192  C2   DC I  10      10.484 112.317  24.549  1.00 76.30           C  \\nATOM    193  O2   DC I  10       9.740 112.574  25.510  1.00 76.30           O  \\nATOM    194  N3   DC I  10      10.065 112.458  23.267  1.00 76.30           N  \\nATOM    195  C4   DC I  10      10.905 112.199  22.259  1.00 76.30           C  \\nATOM    196  N4   DC I  10      10.451 112.339  21.009  1.00 76.30           N  \\nATOM    197  C5   DC I  10      12.249 111.782  22.487  1.00 76.30           C  \\nATOM    198  C6   DC I  10      12.647 111.635  23.759  1.00 76.30           C  \\nATOM    199  P    DA I  11      13.541 109.119  29.408  1.00115.40           P  \\nATOM    200  OP1  DA I  11      14.519 109.334  30.509  1.00115.40           O  \\nATOM    201  OP2  DA I  11      13.866 108.156  28.322  1.00115.40           O  \\nATOM    202  O5'  DA I  11      12.134 108.719  30.046  1.00 77.48           O  \\nATOM    203  C5'  DA I  11      11.439 109.648  30.876  1.00 77.48           C  \\nATOM    204  C4'  DA I  11       9.959 109.658  30.564  1.00 77.48           C  \\nATOM    205  O4'  DA I  11       9.708 110.198  29.243  1.00 77.48           O  \\nATOM    206  C3'  DA I  11       9.225 108.311  30.619  1.00 77.48           C  \\nATOM    207  O3'  DA I  11       7.947 108.503  31.257  1.00 77.48           O  \\nATOM    208  C2'  DA I  11       9.011 107.983  29.154  1.00 77.48           C  \\nATOM    209  C1'  DA I  11       8.757 109.367  28.595  1.00 77.48           C  \\nATOM    210  N9   DA I  11       8.933 109.483  27.147  1.00 78.90           N  \\nATOM    211  C8   DA I  11      10.079 109.297  26.409  1.00 78.90           C  \\nATOM    212  N7   DA I  11       9.909 109.455  25.117  1.00 78.90           N  \\nATOM    213  C5   DA I  11       8.562 109.769  24.993  1.00 78.90           C  \\nATOM    214  C6   DA I  11       7.758 110.054  23.874  1.00 78.90           C  \\nATOM    215  N6   DA I  11       8.217 110.064  22.624  1.00 78.90           N  \\nATOM    216  N1   DA I  11       6.453 110.333  24.089  1.00 78.90           N  \\nATOM    217  C2   DA I  11       5.999 110.325  25.350  1.00 78.90           C  \\nATOM    218  N3   DA I  11       6.655 110.070  26.486  1.00 78.90           N  \\nATOM    219  C4   DA I  11       7.948 109.796  26.235  1.00 78.90           C  \\nATOM    220  P    DC I  12       6.964 107.249  31.520  1.00121.14           P  \\nATOM    221  OP1  DC I  12       6.367 107.434  32.865  1.00121.14           O  \\nATOM    222  OP2  DC I  12       7.724 106.007  31.224  1.00121.14           O  \\nATOM    223  O5'  DC I  12       5.801 107.415  30.430  1.00119.74           O  \\nATOM    224  C5'  DC I  12       4.968 108.587  30.391  1.00119.74           C  \\nATOM    225  C4'  DC I  12       3.790 108.372  29.464  1.00119.74           C  \\nATOM    226  O4'  DC I  12       4.219 108.494  28.081  1.00119.74           O  \\nATOM    227  C3'  DC I  12       3.131 106.992  29.571  1.00119.74           C  \\nATOM    228  O3'  DC I  12       1.714 107.081  29.357  1.00119.74           O  \\nATOM    229  C2'  DC I  12       3.748 106.229  28.417  1.00119.74           C  \\nATOM    230  C1'  DC I  12       3.849 107.316  27.369  1.00119.74           C  \\nATOM    231  N1   DC I  12       4.860 107.046  26.328  1.00 64.88           N  \\nATOM    232  C2   DC I  12       4.544 107.322  24.985  1.00 64.88           C  \\nATOM    233  O2   DC I  12       3.423 107.801  24.716  1.00 64.88           O  \\nATOM    234  N3   DC I  12       5.466 107.056  24.017  1.00 64.88           N  \\nATOM    235  C4   DC I  12       6.655 106.538  24.348  1.00 64.88           C  \\nATOM    236  N4   DC I  12       7.527 106.286  23.366  1.00 64.88           N  \\nATOM    237  C5   DC I  12       7.001 106.254  25.705  1.00 64.88           C  \\nATOM    238  C6   DC I  12       6.084 106.522  26.653  1.00 64.88           C  \\nATOM    239  P    DC I  13       0.814 105.740  29.365  1.00104.25           P  \\nATOM    240  OP1  DC I  13      -0.177 105.851  30.464  1.00104.25           O  \\nATOM    241  OP2  DC I  13       1.729 104.573  29.329  1.00104.25           O  \\nATOM    242  O5'  DC I  13       0.016 105.787  27.984  1.00111.59           O  \\nATOM    243  C5'  DC I  13       0.679 106.078  26.757  1.00111.59           C  \\nATOM    244  C4'  DC I  13      -0.001 105.370  25.607  1.00111.59           C  \\nATOM    245  O4'  DC I  13       0.961 105.230  24.532  1.00111.59           O  \\nATOM    246  C3'  DC I  13      -0.482 103.951  25.927  1.00111.59           C  \\nATOM    247  O3'  DC I  13      -1.689 103.625  25.212  1.00111.59           O  \\nATOM    248  C2'  DC I  13       0.669 103.084  25.461  1.00111.59           C  \\nATOM    249  C1'  DC I  13       1.222 103.856  24.274  1.00111.59           C  \\nATOM    250  N1   DC I  13       2.676 103.686  24.123  1.00 54.47           N  \\nATOM    251  C2   DC I  13       3.256 103.833  22.853  1.00 54.47           C  \\nATOM    252  O2   DC I  13       2.529 104.135  21.889  1.00 54.47           O  \\nATOM    253  N3   DC I  13       4.596 103.644  22.713  1.00 54.47           N  \\nATOM    254  C4   DC I  13       5.343 103.327  23.779  1.00 54.47           C  \\nATOM    255  N4   DC I  13       6.655 103.140  23.597  1.00 54.47           N  \\nATOM    256  C5   DC I  13       4.778 103.187  25.078  1.00 54.47           C  \\nATOM    257  C6   DC I  13       3.454 103.375  25.204  1.00 54.47           C  \\nATOM    258  P    DT I  14      -2.344 102.153  25.363  1.00125.22           P  \\nATOM    259  OP1  DT I  14      -3.808 102.262  25.143  1.00125.22           O  \\nATOM    260  OP2  DT I  14      -1.833 101.511  26.605  1.00125.22           O  \\nATOM    261  O5'  DT I  14      -1.753 101.346  24.130  1.00124.34           O  \\nATOM    262  C5'  DT I  14      -2.111 101.693  22.799  1.00124.34           C  \\nATOM    263  C4'  DT I  14      -1.647 100.615  21.851  1.00124.34           C  \\nATOM    264  O4'  DT I  14      -0.201 100.585  21.823  1.00124.34           O  \\nATOM    265  C3'  DT I  14      -2.085  99.207  22.256  1.00124.34           C  \\nATOM    266  O3'  DT I  14      -2.267  98.432  21.071  1.00124.34           O  \\nATOM    267  C2'  DT I  14      -0.875  98.680  23.002  1.00124.34           C  \\nATOM    268  C1'  DT I  14       0.239  99.280  22.165  1.00124.34           C  \\nATOM    269  N1   DT I  14       1.549  99.397  22.826  1.00 91.68           N  \\nATOM    270  C2   DT I  14       2.660  99.581  22.028  1.00 91.68           C  \\nATOM    271  O2   DT I  14       2.610  99.666  20.807  1.00 91.68           O  \\nATOM    272  N3   DT I  14       3.840  99.664  22.713  1.00 91.68           N  \\nATOM    273  C4   DT I  14       4.021  99.595  24.083  1.00 91.68           C  \\nATOM    274  O4   DT I  14       5.147  99.693  24.558  1.00 91.68           O  \\nATOM    275  C5   DT I  14       2.813  99.408  24.856  1.00 91.68           C  \\nATOM    276  C7   DT I  14       2.903  99.325  26.346  1.00 91.68           C  \\nATOM    277  C6   DT I  14       1.654  99.318  24.196  1.00 91.68           C  \\nATOM    278  P    DG I  15      -3.569  98.662  20.165  1.00141.01           P  \\nATOM    279  OP1  DG I  15      -3.788 100.123  20.002  1.00141.01           O  \\nATOM    280  OP2  DG I  15      -4.639  97.809  20.745  1.00141.01           O  \\nATOM    281  O5'  DG I  15      -3.156  98.075  18.745  1.00150.37           O  \\nATOM    282  C5'  DG I  15      -2.439  98.869  17.800  1.00150.37           C  \\nATOM    283  C4'  DG I  15      -1.445  98.011  17.052  1.00150.37           C  \\nATOM    284  O4'  DG I  15      -0.303  97.721  17.897  1.00150.37           O  \\nATOM    285  C3'  DG I  15      -1.998  96.657  16.610  1.00150.37           C  \\nATOM    286  O3'  DG I  15      -1.475  96.314  15.327  1.00150.37           O  \\nATOM    287  C2'  DG I  15      -1.489  95.705  17.680  1.00150.37           C  \\nATOM    288  C1'  DG I  15      -0.143  96.313  18.041  1.00150.37           C  \\nATOM    289  N9   DG I  15       0.325  96.053  19.402  1.00 92.86           N  \\nATOM    290  C8   DG I  15      -0.424  95.682  20.498  1.00 92.86           C  \\nATOM    291  N7   DG I  15       0.285  95.578  21.591  1.00 92.86           N  \\nATOM    292  C5   DG I  15       1.578  95.895  21.191  1.00 92.86           C  \\nATOM    293  C6   DG I  15       2.782  95.989  21.943  1.00 92.86           C  \\nATOM    294  O6   DG I  15       2.949  95.842  23.163  1.00 92.86           O  \\nATOM    295  N1   DG I  15       3.866  96.313  21.133  1.00 92.86           N  \\nATOM    296  C2   DG I  15       3.800  96.534  19.780  1.00 92.86           C  \\nATOM    297  N2   DG I  15       4.957  96.799  19.162  1.00 92.86           N  \\nATOM    298  N3   DG I  15       2.685  96.490  19.078  1.00 92.86           N  \\nATOM    299  C4   DG I  15       1.621  96.164  19.839  1.00 92.86           C  \\nATOM    300  P    DC I  16      -1.837  94.895  14.667  1.00126.38           P  \\nATOM    301  OP1  DC I  16      -2.490  95.151  13.359  1.00126.38           O  \\nATOM    302  OP2  DC I  16      -2.521  94.042  15.680  1.00126.38           O  \\nATOM    303  O5'  DC I  16      -0.406  94.265  14.377  1.00137.65           O  \\nATOM    304  C5'  DC I  16       0.746  95.101  14.296  1.00137.65           C  \\nATOM    305  C4'  DC I  16       1.968  94.281  13.962  1.00137.65           C  \\nATOM    306  O4'  DC I  16       2.794  94.142  15.141  1.00137.65           O  \\nATOM    307  C3'  DC I  16       1.681  92.864  13.475  1.00137.65           C  \\nATOM    308  O3'  DC I  16       2.576  92.569  12.396  1.00137.65           O  \\nATOM    309  C2'  DC I  16       1.866  92.009  14.719  1.00137.65           C  \\nATOM    310  C1'  DC I  16       2.875  92.783  15.552  1.00137.65           C  \\nATOM    311  N1   DC I  16       2.614  92.747  17.003  1.00 78.10           N  \\nATOM    312  C2   DC I  16       3.575  93.276  17.865  1.00 78.10           C  \\nATOM    313  O2   DC I  16       4.611  93.760  17.378  1.00 78.10           O  \\nATOM    314  N3   DC I  16       3.354  93.256  19.207  1.00 78.10           N  \\nATOM    315  C4   DC I  16       2.218  92.742  19.689  1.00 78.10           C  \\nATOM    316  N4   DC I  16       2.035  92.756  21.014  1.00 78.10           N  \\nATOM    317  C5   DC I  16       1.220  92.194  18.830  1.00 78.10           C  \\nATOM    318  C6   DC I  16       1.459  92.214  17.506  1.00 78.10           C  \\nATOM    319  P    DA I  17       3.113  91.076  12.163  1.00 99.08           P  \\nATOM    320  OP1  DA I  17       3.084  90.769  10.712  1.00 99.08           O  \\nATOM    321  OP2  DA I  17       2.490  90.135  13.130  1.00 99.08           O  \\nATOM    322  O5'  DA I  17       4.639  91.204  12.561  1.00122.04           O  \\nATOM    323  C5'  DA I  17       5.341  92.430  12.396  1.00122.04           C  \\nATOM    324  C4'  DA I  17       6.693  92.290  13.041  1.00122.04           C  \\nATOM    325  O4'  DA I  17       6.451  91.923  14.419  1.00122.04           O  \\nATOM    326  C3'  DA I  17       7.467  91.120  12.445  1.00122.04           C  \\nATOM    327  O3'  DA I  17       8.868  91.320  12.611  1.00122.04           O  \\nATOM    328  C2'  DA I  17       6.984  89.934  13.258  1.00122.04           C  \\nATOM    329  C1'  DA I  17       6.751  90.546  14.628  1.00122.04           C  \\nATOM    330  N9   DA I  17       5.629  89.962  15.358  1.00 88.59           N  \\nATOM    331  C8   DA I  17       4.535  89.291  14.865  1.00 88.59           C  \\nATOM    332  N7   DA I  17       3.684  88.921  15.791  1.00 88.59           N  \\nATOM    333  C5   DA I  17       4.263  89.370  16.972  1.00 88.59           C  \\nATOM    334  C6   DA I  17       3.855  89.298  18.313  1.00 88.59           C  \\nATOM    335  N6   DA I  17       2.713  88.748  18.705  1.00 88.59           N  \\nATOM    336  N1   DA I  17       4.667  89.830  19.248  1.00 88.59           N  \\nATOM    337  C2   DA I  17       5.803  90.411  18.851  1.00 88.59           C  \\nATOM    338  N3   DA I  17       6.290  90.555  17.623  1.00 88.59           N  \\nATOM    339  C4   DA I  17       5.463  90.004  16.719  1.00 88.59           C  \\nATOM    340  P    DG I  18       9.888  90.166  12.173  1.00 81.03           P  \\nATOM    341  OP1  DG I  18      11.066  90.842  11.585  1.00 81.03           O  \\nATOM    342  OP2  DG I  18       9.142  89.158  11.372  1.00 81.03           O  \\nATOM    343  O5'  DG I  18      10.288  89.457  13.540  1.00 78.56           O  \\nATOM    344  C5'  DG I  18      10.697  90.206  14.667  1.00 78.56           C  \\nATOM    345  C4'  DG I  18      10.813  89.303  15.872  1.00 78.56           C  \\nATOM    346  O4'  DG I  18       9.508  88.917  16.371  1.00 78.56           O  \\nATOM    347  C3'  DG I  18      11.583  87.996  15.654  1.00 78.56           C  \\nATOM    348  O3'  DG I  18      12.331  87.704  16.842  1.00 78.56           O  \\nATOM    349  C2'  DG I  18      10.469  86.968  15.540  1.00 78.56           C  \\nATOM    350  C1'  DG I  18       9.516  87.516  16.580  1.00 78.56           C  \\nATOM    351  N9   DG I  18       8.140  87.029  16.563  1.00 76.83           N  \\nATOM    352  C8   DG I  18       7.433  86.494  15.512  1.00 76.83           C  \\nATOM    353  N7   DG I  18       6.227  86.121  15.848  1.00 76.83           N  \\nATOM    354  C5   DG I  18       6.136  86.437  17.198  1.00 76.83           C  \\nATOM    355  C6   DG I  18       5.069  86.260  18.121  1.00 76.83           C  \\nATOM    356  O6   DG I  18       3.950  85.759  17.927  1.00 76.83           O  \\nATOM    357  N1   DG I  18       5.410  86.733  19.386  1.00 76.83           N  \\nATOM    358  C2   DG I  18       6.615  87.302  19.722  1.00 76.83           C  \\nATOM    359  N2   DG I  18       6.738  87.716  20.989  1.00 76.83           N  \\nATOM    360  N3   DG I  18       7.614  87.457  18.880  1.00 76.83           N  \\nATOM    361  C4   DG I  18       7.306  87.008  17.645  1.00 76.83           C  \\nATOM    362  P    DA I  19      13.927  87.540  16.780  1.00 58.59           P  \\nATOM    363  OP1  DA I  19      14.588  88.759  16.222  1.00 58.59           O  \\nATOM    364  OP2  DA I  19      14.200  86.205  16.169  1.00 58.59           O  \\nATOM    365  O5'  DA I  19      14.297  87.474  18.320  1.00 68.39           O  \\nATOM    366  C5'  DA I  19      14.018  86.309  19.075  1.00 68.39           C  \\nATOM    367  C4'  DA I  19      13.206  86.660  20.297  1.00 68.39           C  \\nATOM    368  O4'  DA I  19      11.799  86.633  19.949  1.00 68.39           O  \\nATOM    369  C3'  DA I  19      13.398  85.616  21.391  1.00 68.39           C  \\nATOM    370  O3'  DA I  19      13.546  86.218  22.672  1.00 68.39           O  \\nATOM    371  C2'  DA I  19      12.183  84.717  21.275  1.00 68.39           C  \\nATOM    372  C1'  DA I  19      11.118  85.608  20.663  1.00 68.39           C  \\nATOM    373  N9   DA I  19      10.253  84.889  19.723  1.00 77.32           N  \\nATOM    374  C8   DA I  19      10.555  84.463  18.455  1.00 77.32           C  \\nATOM    375  N7   DA I  19       9.565  83.847  17.852  1.00 77.32           N  \\nATOM    376  C5   DA I  19       8.539  83.865  18.790  1.00 77.32           C  \\nATOM    377  C6   DA I  19       7.205  83.374  18.766  1.00 77.32           C  \\nATOM    378  N6   DA I  19       6.652  82.751  17.722  1.00 77.32           N  \\nATOM    379  N1   DA I  19       6.451  83.555  19.871  1.00 77.32           N  \\nATOM    380  C2   DA I  19       6.994  84.188  20.917  1.00 77.32           C  \\nATOM    381  N3   DA I  19       8.219  84.696  21.058  1.00 77.32           N  \\nATOM    382  C4   DA I  19       8.951  84.499  19.948  1.00 77.32           C  \\nATOM    383  P    DT I  20      14.460  85.492  23.778  1.00105.51           P  \\nATOM    384  OP1  DT I  20      14.871  86.502  24.789  1.00105.51           O  \\nATOM    385  OP2  DT I  20      15.501  84.729  23.049  1.00105.51           O  \\nATOM    386  O5'  DT I  20      13.447  84.464  24.452  1.00114.59           O  \\nATOM    387  C5'  DT I  20      12.263  84.947  25.080  1.00114.59           C  \\nATOM    388  C4'  DT I  20      11.269  83.832  25.314  1.00114.59           C  \\nATOM    389  O4'  DT I  20      10.515  83.500  24.118  1.00114.59           O  \\nATOM    390  C3'  DT I  20      11.805  82.511  25.878  1.00114.59           C  \\nATOM    391  O3'  DT I  20      11.043  82.163  27.051  1.00114.59           O  \\nATOM    392  C2'  DT I  20      11.567  81.524  24.742  1.00114.59           C  \\nATOM    393  C1'  DT I  20      10.316  82.098  24.103  1.00114.59           C  \\nATOM    394  N1   DT I  20      10.002  81.663  22.715  1.00 90.06           N  \\nATOM    395  C2   DT I  20       8.671  81.422  22.414  1.00 90.06           C  \\nATOM    396  O2   DT I  20       7.769  81.578  23.220  1.00 90.06           O  \\nATOM    397  N3   DT I  20       8.435  80.985  21.128  1.00 90.06           N  \\nATOM    398  C4   DT I  20       9.370  80.777  20.131  1.00 90.06           C  \\nATOM    399  O4   DT I  20       9.002  80.376  19.025  1.00 90.06           O  \\nATOM    400  C5   DT I  20      10.748  81.059  20.508  1.00 90.06           C  \\nATOM    401  C7   DT I  20      11.832  80.861  19.493  1.00 90.06           C  \\nATOM    402  C6   DT I  20      10.989  81.485  21.763  1.00 90.06           C  \\nATOM    403  P    DT I  21      11.154  80.688  27.691  1.00126.32           P  \\nATOM    404  OP1  DT I  21      10.943  80.800  29.162  1.00126.32           O  \\nATOM    405  OP2  DT I  21      12.389  80.041  27.181  1.00126.32           O  \\nATOM    406  O5'  DT I  21       9.899  79.947  27.051  1.00163.70           O  \\nATOM    407  C5'  DT I  21       8.621  80.585  27.034  1.00163.70           C  \\nATOM    408  C4'  DT I  21       7.527  79.570  26.804  1.00163.70           C  \\nATOM    409  O4'  DT I  21       7.376  79.291  25.393  1.00163.70           O  \\nATOM    410  C3'  DT I  21       7.773  78.226  27.486  1.00163.70           C  \\nATOM    411  O3'  DT I  21       6.562  77.732  28.072  1.00163.70           O  \\nATOM    412  C2'  DT I  21       8.257  77.339  26.350  1.00163.70           C  \\nATOM    413  C1'  DT I  21       7.510  77.898  25.152  1.00163.70           C  \\nATOM    414  N1   DT I  21       8.201  77.739  23.859  1.00 99.19           N  \\nATOM    415  C2   DT I  21       7.427  77.570  22.728  1.00 99.19           C  \\nATOM    416  O2   DT I  21       6.206  77.504  22.755  1.00 99.19           O  \\nATOM    417  N3   DT I  21       8.136  77.477  21.555  1.00 99.19           N  \\nATOM    418  C4   DT I  21       9.515  77.536  21.403  1.00 99.19           C  \\nATOM    419  O4   DT I  21      10.013  77.467  20.276  1.00 99.19           O  \\nATOM    420  C5   DT I  21      10.265  77.687  22.639  1.00 99.19           C  \\nATOM    421  C7   DT I  21      11.759  77.740  22.583  1.00 99.19           C  \\nATOM    422  C6   DT I  21       9.579  77.776  23.786  1.00 99.19           C  \\nATOM    423  P    DC I  22       6.608  76.434  29.020  1.00136.78           P  \\nATOM    424  OP1  DC I  22       5.224  76.149  29.481  1.00136.78           O  \\nATOM    425  OP2  DC I  22       7.697  76.612  30.024  1.00136.78           O  \\nATOM    426  O5'  DC I  22       7.054  75.292  28.004  1.00140.75           O  \\nATOM    427  C5'  DC I  22       6.977  73.922  28.363  1.00140.75           C  \\nATOM    428  C4'  DC I  22       5.903  73.236  27.554  1.00140.75           C  \\nATOM    429  O4'  DC I  22       5.877  73.783  26.208  1.00140.75           O  \\nATOM    430  C3'  DC I  22       6.117  71.730  27.404  1.00140.75           C  \\nATOM    431  O3'  DC I  22       4.886  71.032  27.586  1.00140.75           O  \\nATOM    432  C2'  DC I  22       6.632  71.580  25.985  1.00140.75           C  \\nATOM    433  C1'  DC I  22       5.957  72.730  25.261  1.00140.75           C  \\nATOM    434  N1   DC I  22       6.722  73.202  24.093  1.00101.08           N  \\nATOM    435  C2   DC I  22       6.027  73.618  22.940  1.00101.08           C  \\nATOM    436  O2   DC I  22       4.785  73.677  22.967  1.00101.08           O  \\nATOM    437  N3   DC I  22       6.733  73.951  21.832  1.00101.08           N  \\nATOM    438  C4   DC I  22       8.071  73.906  21.852  1.00101.08           C  \\nATOM    439  N4   DC I  22       8.721  74.214  20.729  1.00101.08           N  \\nATOM    440  C5   DC I  22       8.797  73.537  23.023  1.00101.08           C  \\nATOM    441  C6   DC I  22       8.091  73.200  24.109  1.00101.08           C  \\nATOM    442  P    DT I  23       4.647  69.641  26.828  1.00129.19           P  \\nATOM    443  OP1  DT I  23       3.556  68.917  27.525  1.00129.19           O  \\nATOM    444  OP2  DT I  23       5.967  68.979  26.639  1.00129.19           O  \\nATOM    445  O5'  DT I  23       4.118  70.099  25.398  1.00186.42           O  \\nATOM    446  C5'  DT I  23       2.793  69.789  24.974  1.00186.42           C  \\nATOM    447  C4'  DT I  23       2.812  68.525  24.150  1.00186.42           C  \\nATOM    448  O4'  DT I  23       3.551  68.786  22.929  1.00186.42           O  \\nATOM    449  C3'  DT I  23       3.545  67.385  24.859  1.00186.42           C  \\nATOM    450  O3'  DT I  23       2.896  66.128  24.646  1.00186.42           O  \\nATOM    451  C2'  DT I  23       4.936  67.417  24.252  1.00186.42           C  \\nATOM    452  C1'  DT I  23       4.694  67.943  22.845  1.00186.42           C  \\nATOM    453  N1   DT I  23       5.829  68.743  22.319  1.00147.51           N  \\nATOM    454  C2   DT I  23       5.844  69.121  20.983  1.00147.51           C  \\nATOM    455  O2   DT I  23       4.940  68.864  20.195  1.00147.51           O  \\nATOM    456  N3   DT I  23       6.972  69.821  20.604  1.00147.51           N  \\nATOM    457  C4   DT I  23       8.044  70.183  21.403  1.00147.51           C  \\nATOM    458  O4   DT I  23       8.982  70.815  20.917  1.00147.51           O  \\nATOM    459  C5   DT I  23       7.951  69.766  22.788  1.00147.51           C  \\nATOM    460  C7   DT I  23       9.062  70.109  23.730  1.00147.51           C  \\nATOM    461  C6   DT I  23       6.866  69.082  23.168  1.00147.51           C  \\nATOM    462  P    DA I  24       3.720  64.764  24.850  1.00165.21           P  \\nATOM    463  OP1  DA I  24       2.745  63.647  24.950  1.00165.21           O  \\nATOM    464  OP2  DA I  24       4.711  64.972  25.939  1.00165.21           O  \\nATOM    465  O5'  DA I  24       4.515  64.631  23.477  1.00147.31           O  \\nATOM    466  C5'  DA I  24       3.838  64.796  22.230  1.00147.31           C  \\nATOM    467  C4'  DA I  24       4.669  64.224  21.106  1.00147.31           C  \\nATOM    468  O4'  DA I  24       5.723  65.149  20.741  1.00147.31           O  \\nATOM    469  C3'  DA I  24       5.352  62.909  21.473  1.00147.31           C  \\nATOM    470  O3'  DA I  24       5.216  61.949  20.411  1.00147.31           O  \\nATOM    471  C2'  DA I  24       6.787  63.317  21.766  1.00147.31           C  \\nATOM    472  C1'  DA I  24       7.001  64.540  20.886  1.00147.31           C  \\nATOM    473  N9   DA I  24       7.916  65.528  21.474  1.00172.68           N  \\nATOM    474  C8   DA I  24       8.090  65.795  22.814  1.00172.68           C  \\nATOM    475  N7   DA I  24       8.993  66.716  23.061  1.00172.68           N  \\nATOM    476  C5   DA I  24       9.444  67.087  21.801  1.00172.68           C  \\nATOM    477  C6   DA I  24      10.411  68.025  21.380  1.00172.68           C  \\nATOM    478  N6   DA I  24      11.125  68.785  22.218  1.00172.68           N  \\nATOM    479  N1   DA I  24      10.622  68.155  20.051  1.00172.68           N  \\nATOM    480  C2   DA I  24       9.909  67.391  19.211  1.00172.68           C  \\nATOM    481  N3   DA I  24       8.977  66.476  19.483  1.00172.68           N  \\nATOM    482  C4   DA I  24       8.788  66.368  20.811  1.00172.68           C  \\nATOM    483  P    DC I  25       6.450  60.996  20.018  1.00158.27           P  \\nATOM    484  OP1  DC I  25       5.942  59.910  19.140  1.00158.27           O  \\nATOM    485  OP2  DC I  25       7.226  60.647  21.240  1.00158.27           O  \\nATOM    486  O5'  DC I  25       7.328  61.975  19.129  1.00113.15           O  \\nATOM    487  C5'  DC I  25       6.902  62.340  17.821  1.00113.15           C  \\nATOM    488  C4'  DC I  25       7.865  61.754  16.824  1.00113.15           C  \\nATOM    489  O4'  DC I  25       9.040  62.594  16.813  1.00113.15           O  \\nATOM    490  C3'  DC I  25       8.344  60.384  17.293  1.00113.15           C  \\nATOM    491  O3'  DC I  25       8.695  59.567  16.179  1.00113.15           O  \\nATOM    492  C2'  DC I  25       9.540  60.715  18.160  1.00113.15           C  \\nATOM    493  C1'  DC I  25      10.112  61.955  17.493  1.00113.15           C  \\nATOM    494  N1   DC I  25      10.671  62.913  18.457  1.00101.19           N  \\nATOM    495  C2   DC I  25      11.388  64.007  17.979  1.00101.19           C  \\nATOM    496  O2   DC I  25      11.494  64.162  16.748  1.00101.19           O  \\nATOM    497  N3   DC I  25      11.948  64.866  18.867  1.00101.19           N  \\nATOM    498  C4   DC I  25      11.811  64.657  20.179  1.00101.19           C  \\nATOM    499  N4   DC I  25      12.415  65.501  21.014  1.00101.19           N  \\nATOM    500  C5   DC I  25      11.058  63.566  20.690  1.00101.19           C  \\nATOM    501  C6   DC I  25      10.507  62.728  19.803  1.00101.19           C  \\nATOM    502  P    DC I  26       9.667  58.307  16.389  1.00113.18           P  \\nATOM    503  OP1  DC I  26       8.977  57.107  15.857  1.00113.18           O  \\nATOM    504  OP2  DC I  26      10.157  58.306  17.795  1.00113.18           O  \\nATOM    505  O5'  DC I  26      10.887  58.644  15.424  1.00 99.13           O  \\nATOM    506  C5'  DC I  26      11.056  59.966  14.906  1.00 99.13           C  \\nATOM    507  C4'  DC I  26      12.524  60.281  14.754  1.00 99.13           C  \\nATOM    508  O4'  DC I  26      12.984  61.154  15.815  1.00 99.13           O  \\nATOM    509  C3'  DC I  26      13.426  59.054  14.813  1.00 99.13           C  \\nATOM    510  O3'  DC I  26      14.501  59.285  13.925  1.00 99.13           O  \\nATOM    511  C2'  DC I  26      13.941  59.066  16.241  1.00 99.13           C  \\nATOM    512  C1'  DC I  26      14.089  60.554  16.478  1.00 99.13           C  \\nATOM    513  N1   DC I  26      14.062  60.985  17.884  1.00 92.40           N  \\nATOM    514  C2   DC I  26      14.545  62.267  18.200  1.00 92.40           C  \\nATOM    515  O2   DC I  26      15.014  62.974  17.285  1.00 92.40           O  \\nATOM    516  N3   DC I  26      14.488  62.699  19.487  1.00 92.40           N  \\nATOM    517  C4   DC I  26      13.972  61.908  20.434  1.00 92.40           C  \\nATOM    518  N4   DC I  26      13.890  62.391  21.673  1.00 92.40           N  \\nATOM    519  C5   DC I  26      13.505  60.589  20.145  1.00 92.40           C  \\nATOM    520  C6   DC I  26      13.569  60.172  18.868  1.00 92.40           C  \\nATOM    521  P    DA I  27      15.095  58.079  13.067  1.00120.75           P  \\nATOM    522  OP1  DA I  27      14.285  57.973  11.824  1.00120.75           O  \\nATOM    523  OP2  DA I  27      15.225  56.904  13.964  1.00120.75           O  \\nATOM    524  O5'  DA I  27      16.548  58.615  12.690  1.00109.52           O  \\nATOM    525  C5'  DA I  27      16.740  59.972  12.272  1.00109.52           C  \\nATOM    526  C4'  DA I  27      18.049  60.510  12.803  1.00109.52           C  \\nATOM    527  O4'  DA I  27      17.969  60.769  14.226  1.00109.52           O  \\nATOM    528  C3'  DA I  27      19.241  59.582  12.606  1.00109.52           C  \\nATOM    529  O3'  DA I  27      20.359  60.379  12.266  1.00109.52           O  \\nATOM    530  C2'  DA I  27      19.436  58.958  13.978  1.00109.52           C  \\nATOM    531  C1'  DA I  27      18.988  60.062  14.926  1.00109.52           C  \\nATOM    532  N9   DA I  27      18.417  59.583  16.194  1.00108.29           N  \\nATOM    533  C8   DA I  27      17.881  58.341  16.435  1.00108.29           C  \\nATOM    534  N7   DA I  27      17.409  58.190  17.651  1.00108.29           N  \\nATOM    535  C5   DA I  27      17.655  59.411  18.261  1.00108.29           C  \\nATOM    536  C6   DA I  27      17.377  59.894  19.557  1.00108.29           C  \\nATOM    537  N6   DA I  27      16.763  59.178  20.498  1.00108.29           N  \\nATOM    538  N1   DA I  27      17.751  61.155  19.850  1.00108.29           N  \\nATOM    539  C2   DA I  27      18.358  61.879  18.898  1.00108.29           C  \\nATOM    540  N3   DA I  27      18.670  61.541  17.642  1.00108.29           N  \\nATOM    541  C4   DA I  27      18.286  60.279  17.381  1.00108.29           C  \\nATOM    542  P    DA I  28      21.563  59.758  11.411  1.00119.93           P  \\nATOM    543  OP1  DA I  28      21.216  59.808   9.968  1.00119.93           O  \\nATOM    544  OP2  DA I  28      21.962  58.470  12.031  1.00119.93           O  \\nATOM    545  O5'  DA I  28      22.701  60.828  11.679  1.00 78.84           O  \\nATOM    546  C5'  DA I  28      22.332  62.144  12.072  1.00 78.84           C  \\nATOM    547  C4'  DA I  28      22.784  62.423  13.486  1.00 78.84           C  \\nATOM    548  O4'  DA I  28      22.049  61.656  14.484  1.00 78.84           O  \\nATOM    549  C3'  DA I  28      24.265  62.141  13.728  1.00 78.84           C  \\nATOM    550  O3'  DA I  28      24.852  63.280  14.339  1.00 78.84           O  \\nATOM    551  C2'  DA I  28      24.259  60.972  14.698  1.00 78.84           C  \\nATOM    552  C1'  DA I  28      22.975  61.221  15.468  1.00 78.84           C  \\nATOM    553  N9   DA I  28      22.434  60.052  16.172  1.00 82.33           N  \\nATOM    554  C8   DA I  28      22.463  58.738  15.776  1.00 82.33           C  \\nATOM    555  N7   DA I  28      21.965  57.903  16.662  1.00 82.33           N  \\nATOM    556  C5   DA I  28      21.562  58.723  17.706  1.00 82.33           C  \\nATOM    557  C6   DA I  28      20.963  58.448  18.960  1.00 82.33           C  \\nATOM    558  N6   DA I  28      20.660  57.228  19.395  1.00 82.33           N  \\nATOM    559  N1   DA I  28      20.688  59.492  19.765  1.00 82.33           N  \\nATOM    560  C2   DA I  28      21.001  60.724  19.341  1.00 82.33           C  \\nATOM    561  N3   DA I  28      21.569  61.111  18.192  1.00 82.33           N  \\nATOM    562  C4   DA I  28      21.829  60.052  17.410  1.00 82.33           C  \\nATOM    563  P    DA I  29      26.400  63.591  14.103  1.00114.27           P  \\nATOM    564  OP1  DA I  29      26.512  65.025  13.724  1.00114.27           O  \\nATOM    565  OP2  DA I  29      26.930  62.535  13.201  1.00114.27           O  \\nATOM    566  O5'  DA I  29      27.025  63.367  15.543  1.00 60.34           O  \\nATOM    567  C5'  DA I  29      26.294  62.644  16.502  1.00 60.34           C  \\nATOM    568  C4'  DA I  29      26.061  63.493  17.723  1.00 60.34           C  \\nATOM    569  O4'  DA I  29      25.053  62.838  18.516  1.00 60.34           O  \\nATOM    570  C3'  DA I  29      27.295  63.578  18.605  1.00 60.34           C  \\nATOM    571  O3'  DA I  29      27.341  64.809  19.316  1.00 60.34           O  \\nATOM    572  C2'  DA I  29      27.153  62.384  19.534  1.00 60.34           C  \\nATOM    573  C1'  DA I  29      25.650  62.115  19.592  1.00 60.34           C  \\nATOM    574  N9   DA I  29      25.291  60.698  19.424  1.00 64.40           N  \\nATOM    575  C8   DA I  29      25.639  59.865  18.380  1.00 64.40           C  \\nATOM    576  N7   DA I  29      25.125  58.662  18.469  1.00 64.40           N  \\nATOM    577  C5   DA I  29      24.400  58.695  19.655  1.00 64.40           C  \\nATOM    578  C6   DA I  29      23.606  57.738  20.301  1.00 64.40           C  \\nATOM    579  N6   DA I  29      23.394  56.512  19.827  1.00 64.40           N  \\nATOM    580  N1   DA I  29      23.024  58.089  21.465  1.00 64.40           N  \\nATOM    581  C2   DA I  29      23.231  59.317  21.941  1.00 64.40           C  \\nATOM    582  N3   DA I  29      23.948  60.309  21.427  1.00 64.40           N  \\nATOM    583  C4   DA I  29      24.511  59.934  20.265  1.00 64.40           C  \\nATOM    584  P    DA I  30      28.615  65.141  20.233  1.00 65.58           P  \\nATOM    585  OP1  DA I  30      28.470  66.541  20.735  1.00 65.58           O  \\nATOM    586  OP2  DA I  30      29.860  64.708  19.536  1.00 65.58           O  \\nATOM    587  O5'  DA I  30      28.424  64.178  21.464  1.00 43.90           O  \\nATOM    588  C5'  DA I  30      27.349  64.393  22.334  1.00 43.90           C  \\nATOM    589  C4'  DA I  30      27.453  63.427  23.475  1.00 43.90           C  \\nATOM    590  O4'  DA I  30      26.976  62.128  23.047  1.00 43.90           O  \\nATOM    591  C3'  DA I  30      28.892  63.243  23.947  1.00 43.90           C  \\nATOM    592  O3'  DA I  30      28.867  63.290  25.373  1.00 43.90           O  \\nATOM    593  C2'  DA I  30      29.285  61.888  23.373  1.00 43.90           C  \\nATOM    594  C1'  DA I  30      27.954  61.140  23.315  1.00 43.90           C  \\nATOM    595  N9   DA I  30      27.821  60.079  22.302  1.00 64.74           N  \\nATOM    596  C8   DA I  30      28.370  60.013  21.042  1.00 64.74           C  \\nATOM    597  N7   DA I  30      28.093  58.901  20.399  1.00 64.74           N  \\nATOM    598  C5   DA I  30      27.303  58.184  21.291  1.00 64.74           C  \\nATOM    599  C6   DA I  30      26.698  56.902  21.222  1.00 64.74           C  \\nATOM    600  N6   DA I  30      26.814  56.073  20.182  1.00 64.74           N  \\nATOM    601  N1   DA I  30      25.966  56.495  22.283  1.00 64.74           N  \\nATOM    602  C2   DA I  30      25.858  57.309  23.337  1.00 64.74           C  \\nATOM    603  N3   DA I  30      26.386  58.520  23.530  1.00 64.74           N  \\nATOM    604  C4   DA I  30      27.109  58.905  22.459  1.00 64.74           C  \\nATOM    605  P    DG I  31      30.215  63.124  26.224  1.00 63.08           P  \\nATOM    606  OP1  DG I  31      30.311  64.256  27.187  1.00 63.08           O  \\nATOM    607  OP2  DG I  31      31.348  62.853  25.297  1.00 63.08           O  \\nATOM    608  O5'  DG I  31      29.884  61.808  27.054  1.00 76.79           O  \\nATOM    609  C5'  DG I  31      28.530  61.519  27.428  1.00 76.79           C  \\nATOM    610  C4'  DG I  31      28.379  60.063  27.803  1.00 76.79           C  \\nATOM    611  O4'  DG I  31      28.172  59.215  26.644  1.00 76.79           O  \\nATOM    612  C3'  DG I  31      29.592  59.503  28.535  1.00 76.79           C  \\nATOM    613  O3'  DG I  31      29.187  58.826  29.703  1.00 76.79           O  \\nATOM    614  C2'  DG I  31      30.218  58.534  27.547  1.00 76.79           C  \\nATOM    615  C1'  DG I  31      29.040  58.091  26.703  1.00 76.79           C  \\nATOM    616  N9   DG I  31      29.413  57.732  25.336  1.00 90.91           N  \\nATOM    617  C8   DG I  31      29.986  58.555  24.396  1.00 90.91           C  \\nATOM    618  N7   DG I  31      30.228  57.952  23.262  1.00 90.91           N  \\nATOM    619  C5   DG I  31      29.786  56.651  23.461  1.00 90.91           C  \\nATOM    620  C6   DG I  31      29.791  55.529  22.580  1.00 90.91           C  \\nATOM    621  O6   DG I  31      30.204  55.461  21.412  1.00 90.91           O  \\nATOM    622  N1   DG I  31      29.245  54.406  23.189  1.00 90.91           N  \\nATOM    623  C2   DG I  31      28.757  54.362  24.471  1.00 90.91           C  \\nATOM    624  N2   DG I  31      28.268  53.178  24.859  1.00 90.91           N  \\nATOM    625  N3   DG I  31      28.746  55.393  25.301  1.00 90.91           N  \\nATOM    626  C4   DG I  31      29.273  56.498  24.735  1.00 90.91           C  \\nATOM    627  P    DT I  32      30.300  58.267  30.696  1.00 67.38           P  \\nATOM    628  OP1  DT I  32      29.819  58.513  32.076  1.00 67.38           O  \\nATOM    629  OP2  DT I  32      31.628  58.787  30.275  1.00 67.38           O  \\nATOM    630  O5'  DT I  32      30.242  56.711  30.396  1.00115.84           O  \\nATOM    631  C5'  DT I  32      29.011  56.012  30.519  1.00115.84           C  \\nATOM    632  C4'  DT I  32      29.258  54.525  30.485  1.00115.84           C  \\nATOM    633  O4'  DT I  32      29.426  54.087  29.117  1.00115.84           O  \\nATOM    634  C3'  DT I  32      30.518  54.096  31.236  1.00115.84           C  \\nATOM    635  O3'  DT I  32      30.260  52.906  31.981  1.00115.84           O  \\nATOM    636  C2'  DT I  32      31.528  53.855  30.128  1.00115.84           C  \\nATOM    637  C1'  DT I  32      30.654  53.393  28.973  1.00115.84           C  \\nATOM    638  N1   DT I  32      31.190  53.713  27.639  1.00 94.85           N  \\nATOM    639  C2   DT I  32      30.973  52.827  26.602  1.00 94.85           C  \\nATOM    640  O2   DT I  32      30.386  51.762  26.737  1.00 94.85           O  \\nATOM    641  N3   DT I  32      31.477  53.236  25.392  1.00 94.85           N  \\nATOM    642  C4   DT I  32      32.164  54.405  25.124  1.00 94.85           C  \\nATOM    643  O4   DT I  32      32.531  54.646  23.979  1.00 94.85           O  \\nATOM    644  C5   DT I  32      32.383  55.267  26.262  1.00 94.85           C  \\nATOM    645  C7   DT I  32      33.158  56.534  26.077  1.00 94.85           C  \\nATOM    646  C6   DT I  32      31.886  54.887  27.443  1.00 94.85           C  \\nATOM    647  P    DG I  33      31.445  52.210  32.805  1.00112.46           P  \\nATOM    648  OP1  DG I  33      30.842  51.593  34.013  1.00112.46           O  \\nATOM    649  OP2  DG I  33      32.552  53.193  32.957  1.00112.46           O  \\nATOM    650  O5'  DG I  33      31.920  51.054  31.819  1.00121.33           O  \\nATOM    651  C5'  DG I  33      30.973  50.141  31.269  1.00121.33           C  \\nATOM    652  C4'  DG I  33      31.673  49.093  30.437  1.00121.33           C  \\nATOM    653  O4'  DG I  33      31.996  49.612  29.124  1.00121.33           O  \\nATOM    654  C3'  DG I  33      32.982  48.587  31.040  1.00121.33           C  \\nATOM    655  O3'  DG I  33      33.053  47.162  30.957  1.00121.33           O  \\nATOM    656  C2'  DG I  33      34.054  49.249  30.190  1.00121.33           C  \\nATOM    657  C1'  DG I  33      33.373  49.412  28.840  1.00121.33           C  \\nATOM    658  N9   DG I  33      33.847  50.570  28.087  1.00135.78           N  \\nATOM    659  C8   DG I  33      34.136  51.812  28.598  1.00135.78           C  \\nATOM    660  N7   DG I  33      34.558  52.653  27.694  1.00135.78           N  \\nATOM    661  C5   DG I  33      34.544  51.928  26.511  1.00135.78           C  \\nATOM    662  C6   DG I  33      34.904  52.314  25.190  1.00135.78           C  \\nATOM    663  O6   DG I  33      35.314  53.409  24.791  1.00135.78           O  \\nATOM    664  N1   DG I  33      34.748  51.268  24.290  1.00135.78           N  \\nATOM    665  C2   DG I  33      34.300  50.018  24.611  1.00135.78           C  \\nATOM    666  N2   DG I  33      34.235  49.162  23.586  1.00135.78           N  \\nATOM    667  N3   DG I  33      33.952  49.640  25.834  1.00135.78           N  \\nATOM    668  C4   DG I  33      34.102  50.640  26.731  1.00135.78           C  \\nATOM    669  P    DT I  34      34.339  46.397  31.539  1.00160.78           P  \\nATOM    670  OP1  DT I  34      33.898  45.094  32.102  1.00160.78           O  \\nATOM    671  OP2  DT I  34      35.112  47.339  32.389  1.00160.78           O  \\nATOM    672  O5'  DT I  34      35.193  46.129  30.229  1.00118.03           O  \\nATOM    673  C5'  DT I  34      36.430  45.460  30.300  1.00118.03           C  \\nATOM    674  C4'  DT I  34      36.575  44.548  29.110  1.00118.03           C  \\nATOM    675  O4'  DT I  34      36.219  45.289  27.919  1.00118.03           O  \\nATOM    676  C3'  DT I  34      38.011  44.087  28.917  1.00118.03           C  \\nATOM    677  O3'  DT I  34      38.063  42.774  28.375  1.00118.03           O  \\nATOM    678  C2'  DT I  34      38.569  45.091  27.930  1.00118.03           C  \\nATOM    679  C1'  DT I  34      37.360  45.464  27.087  1.00118.03           C  \\nATOM    680  N1   DT I  34      37.407  46.877  26.679  1.00125.56           N  \\nATOM    681  C2   DT I  34      37.681  47.191  25.361  1.00125.56           C  \\nATOM    682  O2   DT I  34      37.853  46.352  24.491  1.00125.56           O  \\nATOM    683  N3   DT I  34      37.748  48.536  25.100  1.00125.56           N  \\nATOM    684  C4   DT I  34      37.564  49.570  25.996  1.00125.56           C  \\nATOM    685  O4   DT I  34      37.664  50.732  25.609  1.00125.56           O  \\nATOM    686  C5   DT I  34      37.264  49.167  27.355  1.00125.56           C  \\nATOM    687  C7   DT I  34      37.042  50.217  28.398  1.00125.56           C  \\nATOM    688  C6   DT I  34      37.199  47.859  27.621  1.00125.56           C  \\nATOM    689  P    DA I  35      39.487  42.141  28.005  1.00141.32           P  \\nATOM    690  OP1  DA I  35      39.298  40.709  27.665  1.00141.32           O  \\nATOM    691  OP2  DA I  35      40.414  42.526  29.104  1.00141.32           O  \\nATOM    692  O5'  DA I  35      39.910  42.921  26.681  1.00139.14           O  \\nATOM    693  C5'  DA I  35      39.244  42.669  25.443  1.00139.14           C  \\nATOM    694  C4'  DA I  35      40.075  43.171  24.284  1.00139.14           C  \\nATOM    695  O4'  DA I  35      39.979  44.615  24.175  1.00139.14           O  \\nATOM    696  C3'  DA I  35      41.570  42.844  24.362  1.00139.14           C  \\nATOM    697  O3'  DA I  35      42.055  42.430  23.075  1.00139.14           O  \\nATOM    698  C2'  DA I  35      42.196  44.163  24.781  1.00139.14           C  \\nATOM    699  C1'  DA I  35      41.283  45.178  24.112  1.00139.14           C  \\nATOM    700  N9   DA I  35      41.252  46.492  24.763  1.00 97.78           N  \\nATOM    701  C8   DA I  35      40.977  46.775  26.082  1.00 97.78           C  \\nATOM    702  N7   DA I  35      41.037  48.053  26.376  1.00 97.78           N  \\nATOM    703  C5   DA I  35      41.373  48.655  25.172  1.00 97.78           C  \\nATOM    704  C6   DA I  35      41.589  49.996  24.818  1.00 97.78           C  \\nATOM    705  N6   DA I  35      41.492  51.013  25.678  1.00 97.78           N  \\nATOM    706  N1   DA I  35      41.910  50.261  23.534  1.00 97.78           N  \\nATOM    707  C2   DA I  35      42.002  49.240  22.671  1.00 97.78           C  \\nATOM    708  N3   DA I  35      41.820  47.939  22.882  1.00 97.78           N  \\nATOM    709  C4   DA I  35      41.505  47.707  24.168  1.00 97.78           C  \\nATOM    710  P    DT I  36      43.628  42.158  22.851  1.00101.49           P  \\nATOM    711  OP1  DT I  36      43.776  41.036  21.889  1.00101.49           O  \\nATOM    712  OP2  DT I  36      44.300  42.084  24.183  1.00101.49           O  \\nATOM    713  O5'  DT I  36      44.113  43.476  22.103  1.00154.52           O  \\nATOM    714  C5'  DT I  36      43.501  43.874  20.876  1.00154.52           C  \\nATOM    715  C4'  DT I  36      44.323  44.945  20.200  1.00154.52           C  \\nATOM    716  O4'  DT I  36      44.177  46.212  20.885  1.00154.52           O  \\nATOM    717  C3'  DT I  36      45.824  44.661  20.164  1.00154.52           C  \\nATOM    718  O3'  DT I  36      46.347  45.102  18.907  1.00154.52           O  \\nATOM    719  C2'  DT I  36      46.361  45.498  21.311  1.00154.52           C  \\nATOM    720  C1'  DT I  36      45.459  46.713  21.234  1.00154.52           C  \\nATOM    721  N1   DT I  36      45.326  47.482  22.485  1.00 70.72           N  \\nATOM    722  C2   DT I  36      45.451  48.860  22.415  1.00 70.72           C  \\nATOM    723  O2   DT I  36      45.702  49.463  21.375  1.00 70.72           O  \\nATOM    724  N3   DT I  36      45.276  49.508  23.616  1.00 70.72           N  \\nATOM    725  C4   DT I  36      45.001  48.937  24.848  1.00 70.72           C  \\nATOM    726  O4   DT I  36      44.856  49.658  25.833  1.00 70.72           O  \\nATOM    727  C5   DT I  36      44.906  47.487  24.850  1.00 70.72           C  \\nATOM    728  C7   DT I  36      44.630  46.777  26.139  1.00 70.72           C  \\nATOM    729  C6   DT I  36      45.072  46.843  23.684  1.00 70.72           C  \\nATOM    730  P    DT I  37      47.906  45.455  18.770  1.00 91.25           P  \\nATOM    731  OP1  DT I  37      48.352  45.027  17.415  1.00 91.25           O  \\nATOM    732  OP2  DT I  37      48.624  44.959  19.977  1.00 91.25           O  \\nATOM    733  O5'  DT I  37      47.927  47.047  18.808  1.00109.41           O  \\nATOM    734  C5'  DT I  37      47.139  47.811  17.892  1.00109.41           C  \\nATOM    735  C4'  DT I  37      47.698  49.209  17.759  1.00109.41           C  \\nATOM    736  O4'  DT I  37      47.557  49.903  19.019  1.00109.41           O  \\nATOM    737  C3'  DT I  37      49.184  49.274  17.405  1.00109.41           C  \\nATOM    738  O3'  DT I  37      49.423  50.358  16.508  1.00109.41           O  \\nATOM    739  C2'  DT I  37      49.863  49.508  18.742  1.00109.41           C  \\nATOM    740  C1'  DT I  37      48.826  50.314  19.503  1.00109.41           C  \\nATOM    741  N1   DT I  37      48.832  50.077  20.946  1.00 69.00           N  \\nATOM    742  C2   DT I  37      48.636  51.152  21.778  1.00 69.00           C  \\nATOM    743  O2   DT I  37      48.461  52.292  21.372  1.00 69.00           O  \\nATOM    744  N3   DT I  37      48.652  50.849  23.113  1.00 69.00           N  \\nATOM    745  C4   DT I  37      48.839  49.606  23.686  1.00 69.00           C  \\nATOM    746  O4   DT I  37      48.831  49.493  24.908  1.00 69.00           O  \\nATOM    747  C5   DT I  37      49.036  48.519  22.752  1.00 69.00           C  \\nATOM    748  C7   DT I  37      49.239  47.132  23.279  1.00 69.00           C  \\nATOM    749  C6   DT I  37      49.026  48.809  21.444  1.00 69.00           C  \\nATOM    750  P    DT I  38      50.924  50.708  16.076  1.00 80.38           P  \\nATOM    751  OP1  DT I  38      50.921  51.167  14.658  1.00 80.38           O  \\nATOM    752  OP2  DT I  38      51.793  49.574  16.494  1.00 80.38           O  \\nATOM    753  O5'  DT I  38      51.287  51.952  16.992  1.00 49.42           O  \\nATOM    754  C5'  DT I  38      50.454  53.102  17.003  1.00 49.42           C  \\nATOM    755  C4'  DT I  38      51.025  54.140  17.933  1.00 49.42           C  \\nATOM    756  O4'  DT I  38      50.810  53.752  19.309  1.00 49.42           O  \\nATOM    757  C3'  DT I  38      52.536  54.312  17.770  1.00 49.42           C  \\nATOM    758  O3'  DT I  38      52.877  55.692  17.908  1.00 49.42           O  \\nATOM    759  C2'  DT I  38      53.094  53.520  18.935  1.00 49.42           C  \\nATOM    760  C1'  DT I  38      52.047  53.818  19.977  1.00 49.42           C  \\nATOM    761  N1   DT I  38      52.007  52.914  21.121  1.00 62.92           N  \\nATOM    762  C2   DT I  38      51.769  53.506  22.327  1.00 62.92           C  \\nATOM    763  O2   DT I  38      51.523  54.698  22.434  1.00 62.92           O  \\nATOM    764  N3   DT I  38      51.816  52.659  23.406  1.00 62.92           N  \\nATOM    765  C4   DT I  38      52.054  51.304  23.392  1.00 62.92           C  \\nATOM    766  O4   DT I  38      52.103  50.691  24.452  1.00 62.92           O  \\nATOM    767  C5   DT I  38      52.240  50.723  22.073  1.00 62.92           C  \\nATOM    768  C7   DT I  38      52.436  49.243  21.948  1.00 62.92           C  \\nATOM    769  C6   DT I  38      52.216  51.554  21.013  1.00 62.92           C  \\nATOM    770  P    DG I  39      53.144  56.573  16.599  1.00 63.21           P  \\nATOM    771  OP1  DG I  39      52.078  56.277  15.611  1.00 63.21           O  \\nATOM    772  OP2  DG I  39      54.565  56.380  16.227  1.00 63.21           O  \\nATOM    773  O5'  DG I  39      52.969  58.068  17.104  1.00 51.08           O  \\nATOM    774  C5'  DG I  39      51.739  58.509  17.651  1.00 51.08           C  \\nATOM    775  C4'  DG I  39      51.980  59.154  18.995  1.00 51.08           C  \\nATOM    776  O4'  DG I  39      52.429  58.139  19.923  1.00 51.08           O  \\nATOM    777  C3'  DG I  39      53.065  60.232  18.980  1.00 51.08           C  \\nATOM    778  O3'  DG I  39      52.713  61.335  19.827  1.00 51.08           O  \\nATOM    779  C2'  DG I  39      54.291  59.513  19.508  1.00 51.08           C  \\nATOM    780  C1'  DG I  39      53.706  58.469  20.442  1.00 51.08           C  \\nATOM    781  N9   DG I  39      54.498  57.243  20.503  1.00 87.19           N  \\nATOM    782  C8   DG I  39      55.218  56.655  19.484  1.00 87.19           C  \\nATOM    783  N7   DG I  39      55.871  55.589  19.864  1.00 87.19           N  \\nATOM    784  C5   DG I  39      55.552  55.460  21.209  1.00 87.19           C  \\nATOM    785  C6   DG I  39      55.969  54.505  22.156  1.00 87.19           C  \\nATOM    786  O6   DG I  39      56.740  53.554  21.995  1.00 87.19           O  \\nATOM    787  N1   DG I  39      55.398  54.741  23.405  1.00 87.19           N  \\nATOM    788  C2   DG I  39      54.542  55.773  23.701  1.00 87.19           C  \\nATOM    789  N2   DG I  39      54.092  55.826  24.959  1.00 87.19           N  \\nATOM    790  N3   DG I  39      54.156  56.679  22.829  1.00 87.19           N  \\nATOM    791  C4   DG I  39      54.694  56.464  21.612  1.00 87.19           C  \\nATOM    792  P    DG I  40      53.333  62.797  19.541  1.00 42.89           P  \\nATOM    793  OP1  DG I  40      52.226  63.782  19.665  1.00 42.89           O  \\nATOM    794  OP2  DG I  40      54.122  62.726  18.271  1.00 42.89           O  \\nATOM    795  O5'  DG I  40      54.324  63.014  20.772  1.00 51.93           O  \\nATOM    796  C5'  DG I  40      53.829  62.954  22.107  1.00 51.93           C  \\nATOM    797  C4'  DG I  40      54.924  62.572  23.078  1.00 51.93           C  \\nATOM    798  O4'  DG I  40      55.341  61.189  22.926  1.00 51.93           O  \\nATOM    799  C3'  DG I  40      56.206  63.410  23.040  1.00 51.93           C  \\nATOM    800  O3'  DG I  40      56.574  63.718  24.381  1.00 51.93           O  \\nATOM    801  C2'  DG I  40      57.235  62.450  22.464  1.00 51.93           C  \\nATOM    802  C1'  DG I  40      56.752  61.143  23.063  1.00 51.93           C  \\nATOM    803  N9   DG I  40      57.256  59.895  22.483  1.00 80.43           N  \\nATOM    804  C8   DG I  40      57.638  59.655  21.182  1.00 80.43           C  \\nATOM    805  N7   DG I  40      58.088  58.441  20.993  1.00 80.43           N  \\nATOM    806  C5   DG I  40      57.990  57.837  22.243  1.00 80.43           C  \\nATOM    807  C6   DG I  40      58.333  56.511  22.670  1.00 80.43           C  \\nATOM    808  O6   DG I  40      58.817  55.579  22.008  1.00 80.43           O  \\nATOM    809  N1   DG I  40      58.058  56.323  24.023  1.00 80.43           N  \\nATOM    810  C2   DG I  40      57.528  57.277  24.863  1.00 80.43           C  \\nATOM    811  N2   DG I  40      57.328  56.899  26.144  1.00 80.43           N  \\nATOM    812  N3   DG I  40      57.213  58.508  24.482  1.00 80.43           N  \\nATOM    813  C4   DG I  40      57.468  58.717  23.171  1.00 80.43           C  \\nATOM    814  P    DA I  41      56.605  65.242  24.872  1.00 63.87           P  \\nATOM    815  OP1  DA I  41      55.245  65.826  24.743  1.00 63.87           O  \\nATOM    816  OP2  DA I  41      57.758  65.904  24.210  1.00 63.87           O  \\nATOM    817  O5'  DA I  41      56.929  65.112  26.422  1.00 64.83           O  \\nATOM    818  C5'  DA I  41      55.987  64.509  27.298  1.00 64.83           C  \\nATOM    819  C4'  DA I  41      56.686  63.618  28.299  1.00 64.83           C  \\nATOM    820  O4'  DA I  41      57.196  62.425  27.669  1.00 64.83           O  \\nATOM    821  C3'  DA I  41      57.862  64.241  29.041  1.00 64.83           C  \\nATOM    822  O3'  DA I  41      57.761  63.859  30.414  1.00 64.83           O  \\nATOM    823  C2'  DA I  41      59.078  63.637  28.355  1.00 64.83           C  \\nATOM    824  C1'  DA I  41      58.577  62.264  27.951  1.00 64.83           C  \\nATOM    825  N9   DA I  41      59.187  61.682  26.755  1.00 75.11           N  \\nATOM    826  C8   DA I  41      59.343  62.266  25.521  1.00 75.11           C  \\nATOM    827  N7   DA I  41      59.855  61.467  24.616  1.00 75.11           N  \\nATOM    828  C5   DA I  41      60.069  60.278  25.304  1.00 75.11           C  \\nATOM    829  C6   DA I  41      60.585  59.026  24.900  1.00 75.11           C  \\nATOM    830  N6   DA I  41      60.994  58.758  23.656  1.00 75.11           N  \\nATOM    831  N1   DA I  41      60.664  58.049  25.833  1.00 75.11           N  \\nATOM    832  C2   DA I  41      60.250  58.318  27.085  1.00 75.11           C  \\nATOM    833  N3   DA I  41      59.747  59.450  27.584  1.00 75.11           N  \\nATOM    834  C4   DA I  41      59.679  60.403  26.630  1.00 75.11           C  \\nATOM    835  P    DA I  42      58.968  64.163  31.410  1.00 91.67           P  \\nATOM    836  OP1  DA I  42      58.504  63.871  32.788  1.00 91.67           O  \\nATOM    837  OP2  DA I  42      59.532  65.501  31.084  1.00 91.67           O  \\nATOM    838  O5'  DA I  42      60.020  63.061  30.982  1.00 94.41           O  \\nATOM    839  C5'  DA I  42      59.786  61.697  31.288  1.00 94.41           C  \\nATOM    840  C4'  DA I  42      61.108  60.994  31.447  1.00 94.41           C  \\nATOM    841  O4'  DA I  42      61.532  60.456  30.172  1.00 94.41           O  \\nATOM    842  C3'  DA I  42      62.208  61.950  31.908  1.00 94.41           C  \\nATOM    843  O3'  DA I  42      63.029  61.332  32.896  1.00 94.41           O  \\nATOM    844  C2'  DA I  42      62.981  62.235  30.633  1.00 94.41           C  \\nATOM    845  C1'  DA I  42      62.818  60.947  29.847  1.00 94.41           C  \\nATOM    846  N9   DA I  42      62.866  61.124  28.400  1.00 91.43           N  \\nATOM    847  C8   DA I  42      62.506  62.235  27.675  1.00 91.43           C  \\nATOM    848  N7   DA I  42      62.664  62.094  26.381  1.00 91.43           N  \\nATOM    849  C5   DA I  42      63.160  60.804  26.244  1.00 91.43           C  \\nATOM    850  C6   DA I  42      63.527  60.045  25.118  1.00 91.43           C  \\nATOM    851  N6   DA I  42      63.455  60.498  23.860  1.00 91.43           N  \\nATOM    852  N1   DA I  42      63.975  58.786  25.331  1.00 91.43           N  \\nATOM    853  C2   DA I  42      64.046  58.332  26.590  1.00 91.43           C  \\nATOM    854  N3   DA I  42      63.731  58.949  27.725  1.00 91.43           N  \\nATOM    855  C4   DA I  42      63.289  60.195  27.481  1.00 91.43           C  \\nATOM    856  P    DA I  43      64.215  62.164  33.590  1.00109.59           P  \\nATOM    857  OP1  DA I  43      64.016  62.064  35.058  1.00109.59           O  \\nATOM    858  OP2  DA I  43      64.320  63.508  32.955  1.00109.59           O  \\nATOM    859  O5'  DA I  43      65.504  61.316  33.193  1.00114.51           O  \\nATOM    860  C5'  DA I  43      65.494  59.895  33.323  1.00114.51           C  \\nATOM    861  C4'  DA I  43      66.658  59.276  32.584  1.00114.51           C  \\nATOM    862  O4'  DA I  43      66.441  59.344  31.152  1.00114.51           O  \\nATOM    863  C3'  DA I  43      68.021  59.921  32.855  1.00114.51           C  \\nATOM    864  O3'  DA I  43      69.024  58.921  33.094  1.00114.51           O  \\nATOM    865  C2'  DA I  43      68.310  60.688  31.577  1.00114.51           C  \\nATOM    866  C1'  DA I  43      67.599  59.862  30.521  1.00114.51           C  \\nATOM    867  N9   DA I  43      67.179  60.644  29.357  1.00 76.76           N  \\nATOM    868  C8   DA I  43      66.604  61.893  29.344  1.00 76.76           C  \\nATOM    869  N7   DA I  43      66.390  62.364  28.140  1.00 76.76           N  \\nATOM    870  C5   DA I  43      66.841  61.352  27.300  1.00 76.76           C  \\nATOM    871  C6   DA I  43      66.900  61.241  25.900  1.00 76.76           C  \\nATOM    872  N6   DA I  43      66.487  62.199  25.067  1.00 76.76           N  \\nATOM    873  N1   DA I  43      67.408  60.101  25.379  1.00 76.76           N  \\nATOM    874  C2   DA I  43      67.825  59.145  26.217  1.00 76.76           C  \\nATOM    875  N3   DA I  43      67.825  59.133  27.547  1.00 76.76           N  \\nATOM    876  C4   DA I  43      67.316  60.281  28.035  1.00 76.76           C  \\nATOM    877  P    DC I  44      70.375  59.307  33.889  1.00135.14           P  \\nATOM    878  OP1  DC I  44      70.648  58.274  34.932  1.00135.14           O  \\nATOM    879  OP2  DC I  44      70.286  60.734  34.289  1.00135.14           O  \\nATOM    880  O5'  DC I  44      71.487  59.201  32.753  1.00105.23           O  \\nATOM    881  C5'  DC I  44      71.352  59.935  31.539  1.00105.23           C  \\nATOM    882  C4'  DC I  44      72.003  59.193  30.396  1.00105.23           C  \\nATOM    883  O4'  DC I  44      71.201  59.412  29.212  1.00105.23           O  \\nATOM    884  C3'  DC I  44      73.402  59.708  30.060  1.00105.23           C  \\nATOM    885  O3'  DC I  44      74.259  58.644  29.606  1.00105.23           O  \\nATOM    886  C2'  DC I  44      73.142  60.738  28.977  1.00105.23           C  \\nATOM    887  C1'  DC I  44      71.908  60.201  28.262  1.00105.23           C  \\nATOM    888  N1   DC I  44      71.006  61.273  27.794  1.00 73.33           N  \\nATOM    889  C2   DC I  44      70.648  61.332  26.426  1.00 73.33           C  \\nATOM    890  O2   DC I  44      71.066  60.461  25.644  1.00 73.33           O  \\nATOM    891  N3   DC I  44      69.852  62.342  25.996  1.00 73.33           N  \\nATOM    892  C4   DC I  44      69.408  63.261  26.861  1.00 73.33           C  \\nATOM    893  N4   DC I  44      68.633  64.244  26.385  1.00 73.33           N  \\nATOM    894  C5   DC I  44      69.739  63.215  28.252  1.00 73.33           C  \\nATOM    895  C6   DC I  44      70.532  62.213  28.670  1.00 73.33           C  \\nATOM    896  P    DT I  45      75.851  58.894  29.471  1.00 89.38           P  \\nATOM    897  OP1  DT I  45      76.577  57.597  29.503  1.00 89.38           O  \\nATOM    898  OP2  DT I  45      76.229  59.968  30.424  1.00 89.38           O  \\nATOM    899  O5'  DT I  45      76.000  59.474  28.004  1.00120.01           O  \\nATOM    900  C5'  DT I  45      75.826  58.629  26.878  1.00120.01           C  \\nATOM    901  C4'  DT I  45      76.193  59.380  25.625  1.00120.01           C  \\nATOM    902  O4'  DT I  45      75.170  60.370  25.343  1.00120.01           O  \\nATOM    903  C3'  DT I  45      77.505  60.153  25.771  1.00120.01           C  \\nATOM    904  O3'  DT I  45      78.235  60.113  24.545  1.00120.01           O  \\nATOM    905  C2'  DT I  45      77.042  61.567  26.071  1.00120.01           C  \\nATOM    906  C1'  DT I  45      75.769  61.652  25.248  1.00120.01           C  \\nATOM    907  N1   DT I  45      74.797  62.660  25.715  1.00 82.12           N  \\nATOM    908  C2   DT I  45      74.039  63.324  24.768  1.00 82.12           C  \\nATOM    909  O2   DT I  45      74.106  63.089  23.568  1.00 82.12           O  \\nATOM    910  N3   DT I  45      73.191  64.278  25.282  1.00 82.12           N  \\nATOM    911  C4   DT I  45      73.023  64.618  26.615  1.00 82.12           C  \\nATOM    912  O4   DT I  45      72.228  65.506  26.927  1.00 82.12           O  \\nATOM    913  C5   DT I  45      73.834  63.866  27.552  1.00 82.12           C  \\nATOM    914  C7   DT I  45      73.707  64.151  29.017  1.00 82.12           C  \\nATOM    915  C6   DT I  45      74.668  62.937  27.059  1.00 82.12           C  \\nATOM    916  P    DG I  46      79.678  60.811  24.450  1.00 84.74           P  \\nATOM    917  OP1  DG I  46      80.673  59.813  24.907  1.00 84.74           O  \\nATOM    918  OP2  DG I  46      79.627  62.145  25.103  1.00 84.74           O  \\nATOM    919  O5'  DG I  46      79.867  61.037  22.885  1.00 85.38           O  \\nATOM    920  C5'  DG I  46      78.959  60.458  21.942  1.00 85.38           C  \\nATOM    921  C4'  DG I  46      78.583  61.472  20.885  1.00 85.38           C  \\nATOM    922  O4'  DG I  46      77.621  62.433  21.388  1.00 85.38           O  \\nATOM    923  C3'  DG I  46      79.747  62.296  20.335  1.00 85.38           C  \\nATOM    924  O3'  DG I  46      79.546  62.497  18.939  1.00 85.38           O  \\nATOM    925  C2'  DG I  46      79.631  63.612  21.085  1.00 85.38           C  \\nATOM    926  C1'  DG I  46      78.125  63.755  21.227  1.00 85.38           C  \\nATOM    927  N9   DG I  46      77.688  64.537  22.378  1.00 97.88           N  \\nATOM    928  C8   DG I  46      78.163  64.465  23.667  1.00 97.88           C  \\nATOM    929  N7   DG I  46      77.543  65.268  24.487  1.00 97.88           N  \\nATOM    930  C5   DG I  46      76.607  65.913  23.690  1.00 97.88           C  \\nATOM    931  C6   DG I  46      75.631  66.892  24.022  1.00 97.88           C  \\nATOM    932  O6   DG I  46      75.373  67.384  25.127  1.00 97.88           O  \\nATOM    933  N1   DG I  46      74.904  67.286  22.903  1.00 97.88           N  \\nATOM    934  C2   DG I  46      75.077  66.790  21.635  1.00 97.88           C  \\nATOM    935  N2   DG I  46      74.266  67.302  20.700  1.00 97.88           N  \\nATOM    936  N3   DG I  46      75.970  65.869  21.314  1.00 97.88           N  \\nATOM    937  C4   DG I  46      76.696  65.481  22.383  1.00 97.88           C  \\nATOM    938  P    DC I  47      80.741  63.063  18.033  1.00 93.20           P  \\nATOM    939  OP1  DC I  47      81.229  61.973  17.141  1.00 93.20           O  \\nATOM    940  OP2  DC I  47      81.685  63.769  18.941  1.00 93.20           O  \\nATOM    941  O5'  DC I  47      80.014  64.138  17.117  1.00 97.12           O  \\nATOM    942  C5'  DC I  47      78.600  64.306  17.195  1.00 97.12           C  \\nATOM    943  C4'  DC I  47      78.243  65.761  17.028  1.00 97.12           C  \\nATOM    944  O4'  DC I  47      77.992  66.360  18.323  1.00 97.12           O  \\nATOM    945  C3'  DC I  47      79.360  66.570  16.384  1.00 97.12           C  \\nATOM    946  O3'  DC I  47      78.784  67.452  15.428  1.00 97.12           O  \\nATOM    947  C2'  DC I  47      80.009  67.292  17.557  1.00 97.12           C  \\nATOM    948  C1'  DC I  47      78.861  67.458  18.542  1.00 97.12           C  \\nATOM    949  N1   DC I  47      79.222  67.479  19.980  1.00 65.35           N  \\nATOM    950  C2   DC I  47      78.547  68.369  20.828  1.00 65.35           C  \\nATOM    951  O2   DC I  47      77.647  69.071  20.363  1.00 65.35           O  \\nATOM    952  N3   DC I  47      78.883  68.435  22.137  1.00 65.35           N  \\nATOM    953  C4   DC I  47      79.833  67.642  22.620  1.00 65.35           C  \\nATOM    954  N4   DC I  47      80.126  67.753  23.920  1.00 65.35           N  \\nATOM    955  C5   DC I  47      80.524  66.703  21.793  1.00 65.35           C  \\nATOM    956  C6   DC I  47      80.192  66.659  20.487  1.00 65.35           C  \\nATOM    957  P    DT I  48      79.374  67.515  13.931  1.00 93.31           P  \\nATOM    958  OP1  DT I  48      78.377  66.952  12.967  1.00 93.31           O  \\nATOM    959  OP2  DT I  48      80.757  66.979  13.957  1.00 93.31           O  \\nATOM    960  O5'  DT I  48      79.481  69.083  13.698  1.00 70.47           O  \\nATOM    961  C5'  DT I  48      79.382  69.971  14.814  1.00 70.47           C  \\nATOM    962  C4'  DT I  48      77.978  70.526  14.923  1.00 70.47           C  \\nATOM    963  O4'  DT I  48      77.591  70.556  16.309  1.00 70.47           O  \\nATOM    964  C3'  DT I  48      77.824  71.959  14.432  1.00 70.47           C  \\nATOM    965  O3'  DT I  48      76.489  72.177  13.945  1.00 70.47           O  \\nATOM    966  C2'  DT I  48      78.146  72.769  15.678  1.00 70.47           C  \\nATOM    967  C1'  DT I  48      77.682  71.875  16.822  1.00 70.47           C  \\nATOM    968  N1   DT I  48      78.590  71.815  17.978  1.00 98.38           N  \\nATOM    969  C2   DT I  48      78.271  72.519  19.112  1.00 98.38           C  \\nATOM    970  O2   DT I  48      77.308  73.260  19.187  1.00 98.38           O  \\nATOM    971  N3   DT I  48      79.125  72.320  20.166  1.00 98.38           N  \\nATOM    972  C4   DT I  48      80.243  71.518  20.197  1.00 98.38           C  \\nATOM    973  O4   DT I  48      80.890  71.416  21.237  1.00 98.38           O  \\nATOM    974  C5   DT I  48      80.543  70.839  18.955  1.00 98.38           C  \\nATOM    975  C7   DT I  48      81.748  69.956  18.877  1.00 98.38           C  \\nATOM    976  C6   DT I  48      79.716  71.026  17.922  1.00 98.38           C  \\nATOM    977  P    DC I  49      76.156  73.491  13.072  1.00 65.72           P  \\nATOM    978  OP1  DC I  49      74.862  73.290  12.362  1.00 65.72           O  \\nATOM    979  OP2  DC I  49      77.379  73.832  12.301  1.00 65.72           O  \\nATOM    980  O5'  DC I  49      75.873  74.590  14.174  1.00 37.82           O  \\nATOM    981  C5'  DC I  49      75.082  74.237  15.292  1.00 37.82           C  \\nATOM    982  C4'  DC I  49      74.887  75.434  16.177  1.00 37.82           C  \\nATOM    983  O4'  DC I  49      75.929  75.477  17.178  1.00 37.82           O  \\nATOM    984  C3'  DC I  49      74.985  76.743  15.413  1.00 37.82           C  \\nATOM    985  O3'  DC I  49      74.022  77.627  15.999  1.00 37.82           O  \\nATOM    986  C2'  DC I  49      76.438  77.149  15.615  1.00 37.82           C  \\nATOM    987  C1'  DC I  49      76.734  76.638  17.014  1.00 37.82           C  \\nATOM    988  N1   DC I  49      78.133  76.239  17.274  1.00 81.63           N  \\nATOM    989  C2   DC I  49      78.586  76.159  18.606  1.00 81.63           C  \\nATOM    990  O2   DC I  49      77.837  76.531  19.527  1.00 81.63           O  \\nATOM    991  N3   DC I  49      79.827  75.679  18.850  1.00 81.63           N  \\nATOM    992  C4   DC I  49      80.609  75.305  17.838  1.00 81.63           C  \\nATOM    993  N4   DC I  49      81.790  74.772  18.127  1.00 81.63           N  \\nATOM    994  C5   DC I  49      80.204  75.442  16.481  1.00 81.63           C  \\nATOM    995  C6   DC I  49      78.971  75.911  16.246  1.00 81.63           C  \\nATOM    996  P    DC I  50      74.239  79.206  15.947  1.00 53.70           P  \\nATOM    997  OP1  DC I  50      73.294  79.774  14.940  1.00 53.70           O  \\nATOM    998  OP2  DC I  50      75.688  79.497  15.807  1.00 53.70           O  \\nATOM    999  O5'  DC I  50      73.861  79.614  17.432  1.00 37.09           O  \\nATOM   1000  C5'  DC I  50      74.711  80.509  18.105  1.00 37.09           C  \\nATOM   1001  C4'  DC I  50      74.622  80.365  19.606  1.00 37.09           C  \\nATOM   1002  O4'  DC I  50      75.652  79.454  20.057  1.00 37.09           O  \\nATOM   1003  C3'  DC I  50      75.017  81.720  20.178  1.00 37.09           C  \\nATOM   1004  O3'  DC I  50      74.354  82.103  21.356  1.00 37.09           O  \\nATOM   1005  C2'  DC I  50      76.510  81.637  20.397  1.00 37.09           C  \\nATOM   1006  C1'  DC I  50      76.754  80.167  20.652  1.00 37.09           C  \\nATOM   1007  N1   DC I  50      78.008  79.715  20.004  1.00 51.49           N  \\nATOM   1008  C2   DC I  50      79.002  79.089  20.779  1.00 51.49           C  \\nATOM   1009  O2   DC I  50      78.833  78.962  22.001  1.00 51.49           O  \\nATOM   1010  N3   DC I  50      80.123  78.649  20.177  1.00 51.49           N  \\nATOM   1011  C4   DC I  50      80.290  78.824  18.866  1.00 51.49           C  \\nATOM   1012  N4   DC I  50      81.417  78.361  18.310  1.00 51.49           N  \\nATOM   1013  C5   DC I  50      79.313  79.477  18.061  1.00 51.49           C  \\nATOM   1014  C6   DC I  50      78.199  79.902  18.663  1.00 51.49           C  \\nATOM   1015  P    DA I  51      74.351  83.652  21.721  1.00 35.38           P  \\nATOM   1016  OP1  DA I  51      73.059  84.050  22.327  1.00 35.38           O  \\nATOM   1017  OP2  DA I  51      74.837  84.321  20.469  1.00 35.38           O  \\nATOM   1018  O5'  DA I  51      75.474  83.774  22.827  1.00 41.04           O  \\nATOM   1019  C5'  DA I  51      75.313  83.163  24.097  1.00 41.04           C  \\nATOM   1020  C4'  DA I  51      76.523  83.466  24.943  1.00 41.04           C  \\nATOM   1021  O4'  DA I  51      77.671  82.861  24.293  1.00 41.04           O  \\nATOM   1022  C3'  DA I  51      76.828  84.962  25.041  1.00 41.04           C  \\nATOM   1023  O3'  DA I  51      77.303  85.275  26.350  1.00 41.04           O  \\nATOM   1024  C2'  DA I  51      77.885  85.181  23.975  1.00 41.04           C  \\nATOM   1025  C1'  DA I  51      78.619  83.852  23.945  1.00 41.04           C  \\nATOM   1026  N9   DA I  51      79.185  83.484  22.648  1.00 73.66           N  \\nATOM   1027  C8   DA I  51      78.753  83.844  21.395  1.00 73.66           C  \\nATOM   1028  N7   DA I  51      79.484  83.353  20.424  1.00 73.66           N  \\nATOM   1029  C5   DA I  51      80.459  82.616  21.082  1.00 73.66           C  \\nATOM   1030  C6   DA I  51      81.540  81.854  20.617  1.00 73.66           C  \\nATOM   1031  N6   DA I  51      81.817  81.685  19.325  1.00 73.66           N  \\nATOM   1032  N1   DA I  51      82.336  81.261  21.534  1.00 73.66           N  \\nATOM   1033  C2   DA I  51      82.048  81.421  22.828  1.00 73.66           C  \\nATOM   1034  N3   DA I  51      81.055  82.104  23.389  1.00 73.66           N  \\nATOM   1035  C4   DA I  51      80.288  82.688  22.450  1.00 73.66           C  \\nATOM   1036  P    DT I  52      77.972  86.709  26.642  1.00 66.62           P  \\nATOM   1037  OP1  DT I  52      77.614  87.092  28.031  1.00 66.62           O  \\nATOM   1038  OP2  DT I  52      77.681  87.645  25.523  1.00 66.62           O  \\nATOM   1039  O5'  DT I  52      79.527  86.375  26.596  1.00 76.18           O  \\nATOM   1040  C5'  DT I  52      80.064  85.320  27.397  1.00 76.18           C  \\nATOM   1041  C4'  DT I  52      81.571  85.310  27.310  1.00 76.18           C  \\nATOM   1042  O4'  DT I  52      81.985  84.790  26.022  1.00 76.18           O  \\nATOM   1043  C3'  DT I  52      82.220  86.692  27.442  1.00 76.18           C  \\nATOM   1044  O3'  DT I  52      83.412  86.622  28.236  1.00 76.18           O  \\nATOM   1045  C2'  DT I  52      82.580  87.040  26.011  1.00 76.18           C  \\nATOM   1046  C1'  DT I  52      82.933  85.675  25.461  1.00 76.18           C  \\nATOM   1047  N1   DT I  52      82.848  85.582  24.004  1.00111.58           N  \\nATOM   1048  C2   DT I  52      83.806  84.852  23.334  1.00111.58           C  \\nATOM   1049  O2   DT I  52      84.692  84.220  23.897  1.00111.58           O  \\nATOM   1050  N3   DT I  52      83.683  84.880  21.971  1.00111.58           N  \\nATOM   1051  C4   DT I  52      82.708  85.524  21.232  1.00111.58           C  \\nATOM   1052  O4   DT I  52      82.728  85.461  20.012  1.00111.58           O  \\nATOM   1053  C5   DT I  52      81.722  86.239  22.001  1.00111.58           C  \\nATOM   1054  C7   DT I  52      80.616  86.949  21.285  1.00111.58           C  \\nATOM   1055  C6   DT I  52      81.841  86.235  23.332  1.00111.58           C  \\nATOM   1056  P    DC I  53      84.029  87.962  28.880  1.00 81.59           P  \\nATOM   1057  OP1  DC I  53      83.945  87.804  30.355  1.00 81.59           O  \\nATOM   1058  OP2  DC I  53      83.417  89.152  28.225  1.00 81.59           O  \\nATOM   1059  O5'  DC I  53      85.555  87.913  28.432  1.00 99.57           O  \\nATOM   1060  C5'  DC I  53      85.883  87.643  27.080  1.00 99.57           C  \\nATOM   1061  C4'  DC I  53      87.378  87.667  26.879  1.00 99.57           C  \\nATOM   1062  O4'  DC I  53      87.599  87.122  25.560  1.00 99.57           O  \\nATOM   1063  C3'  DC I  53      87.955  89.081  26.856  1.00 99.57           C  \\nATOM   1064  O3'  DC I  53      89.295  89.168  27.351  1.00 99.57           O  \\nATOM   1065  C2'  DC I  53      87.914  89.473  25.395  1.00 99.57           C  \\nATOM   1066  C1'  DC I  53      87.872  88.160  24.627  1.00 99.57           C  \\nATOM   1067  N1   DC I  53      86.749  88.224  23.691  1.00 94.23           N  \\nATOM   1068  C2   DC I  53      86.851  87.628  22.435  1.00 94.23           C  \\nATOM   1069  O2   DC I  53      87.870  86.980  22.150  1.00 94.23           O  \\nATOM   1070  N3   DC I  53      85.833  87.776  21.560  1.00 94.23           N  \\nATOM   1071  C4   DC I  53      84.752  88.480  21.907  1.00 94.23           C  \\nATOM   1072  N4   DC I  53      83.795  88.644  21.004  1.00 94.23           N  \\nATOM   1073  C5   DC I  53      84.610  89.058  23.195  1.00 94.23           C  \\nATOM   1074  C6   DC I  53      85.618  88.904  24.047  1.00 94.23           C  \\nATOM   1075  P    DA I  54      90.124  90.535  27.134  1.00113.09           P  \\nATOM   1076  OP1  DA I  54      91.235  90.566  28.116  1.00113.09           O  \\nATOM   1077  OP2  DA I  54      89.153  91.666  27.092  1.00113.09           O  \\nATOM   1078  O5'  DA I  54      90.744  90.372  25.672  1.00119.58           O  \\nATOM   1079  C5'  DA I  54      91.633  89.293  25.370  1.00119.58           C  \\nATOM   1080  C4'  DA I  54      92.247  89.475  23.999  1.00119.58           C  \\nATOM   1081  O4'  DA I  54      91.229  89.315  22.985  1.00119.58           O  \\nATOM   1082  C3'  DA I  54      92.874  90.848  23.752  1.00119.58           C  \\nATOM   1083  O3'  DA I  54      94.010  90.741  22.888  1.00119.58           O  \\nATOM   1084  C2'  DA I  54      91.771  91.602  23.042  1.00119.58           C  \\nATOM   1085  C1'  DA I  54      91.126  90.504  22.219  1.00119.58           C  \\nATOM   1086  N9   DA I  54      89.713  90.745  21.960  1.00120.14           N  \\nATOM   1087  C8   DA I  54      88.752  91.235  22.812  1.00120.14           C  \\nATOM   1088  N7   DA I  54      87.574  91.360  22.258  1.00120.14           N  \\nATOM   1089  C5   DA I  54      87.774  90.917  20.959  1.00120.14           C  \\nATOM   1090  C6   DA I  54      86.922  90.806  19.868  1.00120.14           C  \\nATOM   1091  N6   DA I  54      85.632  91.143  19.906  1.00120.14           N  \\nATOM   1092  N1   DA I  54      87.441  90.330  18.716  1.00120.14           N  \\nATOM   1093  C2   DA I  54      88.733  89.995  18.679  1.00120.14           C  \\nATOM   1094  N3   DA I  54      89.635  90.054  19.640  1.00120.14           N  \\nATOM   1095  C4   DA I  54      89.084  90.531  20.767  1.00120.14           C  \\nATOM   1096  P    DA I  55      94.915  92.038  22.604  1.00142.98           P  \\nATOM   1097  OP1  DA I  55      96.332  91.629  22.735  1.00142.98           O  \\nATOM   1098  OP2  DA I  55      94.396  93.163  23.427  1.00142.98           O  \\nATOM   1099  O5'  DA I  55      94.640  92.369  21.073  1.00156.61           O  \\nATOM   1100  C5'  DA I  55      95.199  91.558  20.046  1.00156.61           C  \\nATOM   1101  C4'  DA I  55      94.995  92.205  18.698  1.00156.61           C  \\nATOM   1102  O4'  DA I  55      93.563  92.257  18.472  1.00156.61           O  \\nATOM   1103  C3'  DA I  55      95.507  93.644  18.593  1.00156.61           C  \\nATOM   1104  O3'  DA I  55      96.477  93.871  17.530  1.00156.61           O  \\nATOM   1105  C2'  DA I  55      94.265  94.522  18.640  1.00156.61           C  \\nATOM   1106  C1'  DA I  55      93.104  93.592  18.285  1.00156.61           C  \\nATOM   1107  N9   DA I  55      91.904  93.784  19.115  1.00 79.18           N  \\nATOM   1108  C8   DA I  55      91.849  94.284  20.398  1.00 79.18           C  \\nATOM   1109  N7   DA I  55      90.630  94.382  20.878  1.00 79.18           N  \\nATOM   1110  C5   DA I  55      89.825  93.905  19.852  1.00 79.18           C  \\nATOM   1111  C6   DA I  55      88.429  93.756  19.734  1.00 79.18           C  \\nATOM   1112  N6   DA I  55      87.561  94.063  20.699  1.00 79.18           N  \\nATOM   1113  N1   DA I  55      87.948  93.265  18.573  1.00 79.18           N  \\nATOM   1114  C2   DA I  55      88.813  92.930  17.609  1.00 79.18           C  \\nATOM   1115  N3   DA I  55      90.143  93.013  17.600  1.00 79.18           N  \\nATOM   1116  C4   DA I  55      90.595  93.521  18.762  1.00 79.18           C  \\nATOM   1117  P    DA I  56      96.081  93.728  15.964  1.00118.11           P  \\nATOM   1118  OP1  DA I  56      96.610  92.425  15.487  1.00118.11           O  \\nATOM   1119  OP2  DA I  56      96.494  94.980  15.268  1.00118.11           O  \\nATOM   1120  O5'  DA I  56      94.493  93.640  15.931  1.00154.03           O  \\nATOM   1121  C5'  DA I  56      93.833  92.759  15.020  1.00154.03           C  \\nATOM   1122  C4'  DA I  56      93.035  93.554  14.014  1.00154.03           C  \\nATOM   1123  O4'  DA I  56      91.938  94.215  14.687  1.00154.03           O  \\nATOM   1124  C3'  DA I  56      93.830  94.658  13.319  1.00154.03           C  \\nATOM   1125  O3'  DA I  56      93.411  94.756  11.953  1.00154.03           O  \\nATOM   1126  C2'  DA I  56      93.483  95.897  14.125  1.00154.03           C  \\nATOM   1127  C1'  DA I  56      92.052  95.625  14.554  1.00154.03           C  \\nATOM   1128  N9   DA I  56      91.692  96.223  15.840  1.00103.77           N  \\nATOM   1129  C8   DA I  56      92.478  96.981  16.677  1.00103.77           C  \\nATOM   1130  N7   DA I  56      91.867  97.366  17.771  1.00103.77           N  \\nATOM   1131  C5   DA I  56      90.590  96.828  17.646  1.00103.77           C  \\nATOM   1132  C6   DA I  56      89.450  96.871  18.479  1.00103.77           C  \\nATOM   1133  N6   DA I  56      89.408  97.501  19.655  1.00103.77           N  \\nATOM   1134  N1   DA I  56      88.338  96.232  18.054  1.00103.77           N  \\nATOM   1135  C2   DA I  56      88.373  95.596  16.878  1.00103.77           C  \\nATOM   1136  N3   DA I  56      89.376  95.480  16.012  1.00103.77           N  \\nATOM   1137  C4   DA I  56      90.469  96.125  16.460  1.00103.77           C  \\nATOM   1138  P    DA I  57      93.607  96.130  11.140  1.00159.99           P  \\nATOM   1139  OP1  DA I  57      94.106  95.794   9.784  1.00159.99           O  \\nATOM   1140  OP2  DA I  57      94.359  97.101  11.981  1.00159.99           O  \\nATOM   1141  O5'  DA I  57      92.116  96.658  10.981  1.00157.02           O  \\nATOM   1142  C5'  DA I  57      91.087  95.773  10.547  1.00157.02           C  \\nATOM   1143  C4'  DA I  57      89.775  96.509  10.415  1.00157.02           C  \\nATOM   1144  O4'  DA I  57      89.276  96.859  11.729  1.00157.02           O  \\nATOM   1145  C3'  DA I  57      89.839  97.807   9.607  1.00157.02           C  \\nATOM   1146  O3'  DA I  57      88.719  97.868   8.714  1.00157.02           O  \\nATOM   1147  C2'  DA I  57      89.809  98.895  10.671  1.00157.02           C  \\nATOM   1148  C1'  DA I  57      89.038  98.255  11.822  1.00157.02           C  \\nATOM   1149  N9   DA I  57      89.455  98.694  13.160  1.00115.79           N  \\nATOM   1150  C8   DA I  57      90.734  98.743  13.666  1.00115.79           C  \\nATOM   1151  N7   DA I  57      90.802  99.194  14.896  1.00115.79           N  \\nATOM   1152  C5   DA I  57      89.480  99.459  15.227  1.00115.79           C  \\nATOM   1153  C6   DA I  57      88.884  99.967  16.391  1.00115.79           C  \\nATOM   1154  N6   DA I  57      89.568 100.308  17.485  1.00115.79           N  \\nATOM   1155  N1   DA I  57      87.544 100.118  16.395  1.00115.79           N  \\nATOM   1156  C2   DA I  57      86.856  99.775  15.303  1.00115.79           C  \\nATOM   1157  N3   DA I  57      87.300  99.285  14.148  1.00115.79           N  \\nATOM   1158  C4   DA I  57      88.639  99.152  14.172  1.00115.79           C  \\nATOM   1159  P    DG I  58      88.603  99.054   7.632  1.00 92.50           P  \\nATOM   1160  OP1  DG I  58      88.056  98.474   6.378  1.00 92.50           O  \\nATOM   1161  OP2  DG I  58      89.867  99.839   7.588  1.00 92.50           O  \\nATOM   1162  O5'  DG I  58      87.481  99.977   8.277  1.00109.15           O  \\nATOM   1163  C5'  DG I  58      86.292  99.389   8.800  1.00109.15           C  \\nATOM   1164  C4'  DG I  58      85.165 100.388   8.759  1.00109.15           C  \\nATOM   1165  O4'  DG I  58      85.153 101.172   9.972  1.00109.15           O  \\nATOM   1166  C3'  DG I  58      85.303 101.370   7.605  1.00109.15           C  \\nATOM   1167  O3'  DG I  58      84.092 101.431   6.841  1.00109.15           O  \\nATOM   1168  C2'  DG I  58      85.846 102.643   8.239  1.00109.15           C  \\nATOM   1169  C1'  DG I  58      85.604 102.501   9.746  1.00109.15           C  \\nATOM   1170  N9   DG I  58      86.822 102.670  10.540  1.00106.40           N  \\nATOM   1171  C8   DG I  58      88.110 102.697  10.055  1.00106.40           C  \\nATOM   1172  N7   DG I  58      89.014 102.788  10.994  1.00106.40           N  \\nATOM   1173  C5   DG I  58      88.286 102.837  12.177  1.00106.40           C  \\nATOM   1174  C6   DG I  58      88.731 102.919  13.527  1.00106.40           C  \\nATOM   1175  O6   DG I  58      89.890 102.936  13.957  1.00106.40           O  \\nATOM   1176  N1   DG I  58      87.664 102.970  14.417  1.00106.40           N  \\nATOM   1177  C2   DG I  58      86.339 102.927  14.059  1.00106.40           C  \\nATOM   1178  N2   DG I  58      85.462 103.000  15.072  1.00106.40           N  \\nATOM   1179  N3   DG I  58      85.906 102.825  12.805  1.00106.40           N  \\nATOM   1180  C4   DG I  58      86.928 102.789  11.919  1.00106.40           C  \\nATOM   1181  P    DG I  59      83.025 102.601   7.077  1.00 63.53           P  \\nATOM   1182  OP1  DG I  59      82.331 102.785   5.777  1.00 63.53           O  \\nATOM   1183  OP2  DG I  59      83.617 103.770   7.767  1.00 63.53           O  \\nATOM   1184  O5'  DG I  59      81.988 101.955   8.087  1.00 52.63           O  \\nATOM   1185  C5'  DG I  59      80.766 102.616   8.329  1.00 52.63           C  \\nATOM   1186  C4'  DG I  59      80.702 103.119   9.751  1.00 52.63           C  \\nATOM   1187  O4'  DG I  59      81.988 103.602  10.215  1.00 52.63           O  \\nATOM   1188  C3'  DG I  59      79.740 104.296   9.895  1.00 52.63           C  \\nATOM   1189  O3'  DG I  59      78.922 104.174  11.043  1.00 52.63           O  \\nATOM   1190  C2'  DG I  59      80.656 105.491  10.071  1.00 52.63           C  \\nATOM   1191  C1'  DG I  59      81.792 104.864  10.830  1.00 52.63           C  \\nATOM   1192  N9   DG I  59      83.050 105.591  10.778  1.00 82.27           N  \\nATOM   1193  C8   DG I  59      83.773 105.952   9.665  1.00 82.27           C  \\nATOM   1194  N7   DG I  59      84.910 106.517   9.961  1.00 82.27           N  \\nATOM   1195  C5   DG I  59      84.926 106.542  11.350  1.00 82.27           C  \\nATOM   1196  C6   DG I  59      85.916 106.999  12.251  1.00 82.27           C  \\nATOM   1197  O6   DG I  59      87.034 107.461  12.000  1.00 82.27           O  \\nATOM   1198  N1   DG I  59      85.509 106.857  13.573  1.00 82.27           N  \\nATOM   1199  C2   DG I  59      84.314 106.326  13.978  1.00 82.27           C  \\nATOM   1200  N2   DG I  59      84.104 106.289  15.301  1.00 82.27           N  \\nATOM   1201  N3   DG I  59      83.396 105.871  13.150  1.00 82.27           N  \\nATOM   1202  C4   DG I  59      83.768 106.007  11.862  1.00 82.27           C  \\nATOM   1203  P    DC I  60      77.616 105.077  11.146  1.00 41.85           P  \\nATOM   1204  OP1  DC I  60      76.489 104.163  11.475  1.00 41.85           O  \\nATOM   1205  OP2  DC I  60      77.535 105.942   9.942  1.00 41.85           O  \\nATOM   1206  O5'  DC I  60      77.909 106.039  12.373  1.00 45.42           O  \\nATOM   1207  C5'  DC I  60      77.704 105.583  13.703  1.00 45.42           C  \\nATOM   1208  C4'  DC I  60      78.129 106.640  14.695  1.00 45.42           C  \\nATOM   1209  O4'  DC I  60      79.468 107.086  14.381  1.00 45.42           O  \\nATOM   1210  C3'  DC I  60      77.265 107.898  14.729  1.00 45.42           C  \\nATOM   1211  O3'  DC I  60      77.252 108.375  16.056  1.00 45.42           O  \\nATOM   1212  C2'  DC I  60      78.034 108.873  13.861  1.00 45.42           C  \\nATOM   1213  C1'  DC I  60      79.477 108.494  14.182  1.00 45.42           C  \\nATOM   1214  N1   DC I  60      80.470 108.790  13.131  1.00 68.12           N  \\nATOM   1215  C2   DC I  60      81.694 109.385  13.498  1.00 68.12           C  \\nATOM   1216  O2   DC I  60      81.899 109.672  14.696  1.00 68.12           O  \\nATOM   1217  N3   DC I  60      82.616 109.634  12.539  1.00 68.12           N  \\nATOM   1218  C4   DC I  60      82.356 109.323  11.261  1.00 68.12           C  \\nATOM   1219  N4   DC I  60      83.302 109.581  10.346  1.00 68.12           N  \\nATOM   1220  C5   DC I  60      81.119 108.732  10.865  1.00 68.12           C  \\nATOM   1221  C6   DC I  60      80.215 108.484  11.821  1.00 68.12           C  \\nATOM   1222  P    DA I  61      75.898 108.925  16.681  1.00 63.86           P  \\nATOM   1223  OP1  DA I  61      75.188 107.821  17.365  1.00 63.86           O  \\nATOM   1224  OP2  DA I  61      75.207 109.732  15.646  1.00 63.86           O  \\nATOM   1225  O5'  DA I  61      76.413 109.917  17.801  1.00 44.23           O  \\nATOM   1226  C5'  DA I  61      77.549 109.579  18.582  1.00 44.23           C  \\nATOM   1227  C4'  DA I  61      78.461 110.772  18.714  1.00 44.23           C  \\nATOM   1228  O4'  DA I  61      79.233 110.978  17.504  1.00 44.23           O  \\nATOM   1229  C3'  DA I  61      77.711 112.072  18.978  1.00 44.23           C  \\nATOM   1230  O3'  DA I  61      78.218 112.687  20.151  1.00 44.23           O  \\nATOM   1231  C2'  DA I  61      77.948 112.912  17.731  1.00 44.23           C  \\nATOM   1232  C1'  DA I  61      79.214 112.342  17.138  1.00 44.23           C  \\nATOM   1233  N9   DA I  61      79.260 112.390  15.685  1.00 65.56           N  \\nATOM   1234  C8   DA I  61      78.279 112.036  14.800  1.00 65.56           C  \\nATOM   1235  N7   DA I  61      78.633 112.152  13.544  1.00 65.56           N  \\nATOM   1236  C5   DA I  61      79.933 112.620  13.611  1.00 65.56           C  \\nATOM   1237  C6   DA I  61      80.869 112.936  12.622  1.00 65.56           C  \\nATOM   1238  N6   DA I  61      80.628 112.828  11.317  1.00 65.56           N  \\nATOM   1239  N1   DA I  61      82.079 113.374  13.021  1.00 65.56           N  \\nATOM   1240  C2   DA I  61      82.318 113.486  14.331  1.00 65.56           C  \\nATOM   1241  N3   DA I  61      81.517 113.219  15.359  1.00 65.56           N  \\nATOM   1242  C4   DA I  61      80.326 112.782  14.924  1.00 65.56           C  \\nATOM   1243  P    DT I  62      77.371 113.842  20.867  1.00 52.42           P  \\nATOM   1244  OP1  DT I  62      77.499 113.652  22.335  1.00 52.42           O  \\nATOM   1245  OP2  DT I  62      76.019 113.952  20.250  1.00 52.42           O  \\nATOM   1246  O5'  DT I  62      78.210 115.111  20.433  1.00 50.64           O  \\nATOM   1247  C5'  DT I  62      79.058 115.034  19.292  1.00 50.64           C  \\nATOM   1248  C4'  DT I  62      79.950 116.245  19.233  1.00 50.64           C  \\nATOM   1249  O4'  DT I  62      80.631 116.207  17.960  1.00 50.64           O  \\nATOM   1250  C3'  DT I  62      79.147 117.538  19.260  1.00 50.64           C  \\nATOM   1251  O3'  DT I  62      79.763 118.512  20.100  1.00 50.64           O  \\nATOM   1252  C2'  DT I  62      79.049 117.956  17.804  1.00 50.64           C  \\nATOM   1253  C1'  DT I  62      80.190 117.240  17.104  1.00 50.64           C  \\nATOM   1254  N1   DT I  62      79.758 116.612  15.846  1.00 62.94           N  \\nATOM   1255  C2   DT I  62      80.637 116.597  14.792  1.00 62.94           C  \\nATOM   1256  O2   DT I  62      81.777 117.025  14.869  1.00 62.94           O  \\nATOM   1257  N3   DT I  62      80.134 116.056  13.635  1.00 62.94           N  \\nATOM   1258  C4   DT I  62      78.869 115.524  13.436  1.00 62.94           C  \\nATOM   1259  O4   DT I  62      78.553 115.079  12.336  1.00 62.94           O  \\nATOM   1260  C5   DT I  62      78.005 115.550  14.593  1.00 62.94           C  \\nATOM   1261  C7   DT I  62      76.617 114.999  14.473  1.00 62.94           C  \\nATOM   1262  C6   DT I  62      78.488 116.078  15.728  1.00 62.94           C  \\nATOM   1263  P    DG I  63      78.918 119.795  20.581  1.00 85.98           P  \\nATOM   1264  OP1  DG I  63      79.368 120.142  21.954  1.00 85.98           O  \\nATOM   1265  OP2  DG I  63      77.473 119.548  20.318  1.00 85.98           O  \\nATOM   1266  O5'  DG I  63      79.389 120.935  19.574  1.00 97.04           O  \\nATOM   1267  C5'  DG I  63      80.773 121.111  19.274  1.00 97.04           C  \\nATOM   1268  C4'  DG I  63      80.941 122.111  18.157  1.00 97.04           C  \\nATOM   1269  O4'  DG I  63      80.618 121.508  16.884  1.00 97.04           O  \\nATOM   1270  C3'  DG I  63      80.024 123.323  18.289  1.00 97.04           C  \\nATOM   1271  O3'  DG I  63      80.701 124.476  17.786  1.00 97.04           O  \\nATOM   1272  C2'  DG I  63      78.847 122.951  17.410  1.00 97.04           C  \\nATOM   1273  C1'  DG I  63      79.534 122.206  16.284  1.00 97.04           C  \\nATOM   1274  N9   DG I  63      78.682 121.224  15.625  1.00 65.42           N  \\nATOM   1275  C8   DG I  63      77.664 120.496  16.191  1.00 65.42           C  \\nATOM   1276  N7   DG I  63      77.097 119.673  15.352  1.00 65.42           N  \\nATOM   1277  C5   DG I  63      77.778 119.874  14.163  1.00 65.42           C  \\nATOM   1278  C6   DG I  63      77.612 119.262  12.898  1.00 65.42           C  \\nATOM   1279  O6   DG I  63      76.813 118.384  12.567  1.00 65.42           O  \\nATOM   1280  N1   DG I  63      78.504 119.773  11.964  1.00 65.42           N  \\nATOM   1281  C2   DG I  63      79.438 120.746  12.215  1.00 65.42           C  \\nATOM   1282  N2   DG I  63      80.180 121.105  11.163  1.00 65.42           N  \\nATOM   1283  N3   DG I  63      79.617 121.317  13.395  1.00 65.42           N  \\nATOM   1284  C4   DG I  63      78.755 120.837  14.314  1.00 65.42           C  \\nATOM   1285  P    DT I  64      79.892 125.845  17.538  1.00147.98           P  \\nATOM   1286  OP1  DT I  64      80.688 126.954  18.122  1.00147.98           O  \\nATOM   1287  OP2  DT I  64      78.480 125.651  17.968  1.00147.98           O  \\nATOM   1288  O5'  DT I  64      79.938 125.991  15.952  1.00116.41           O  \\nATOM   1289  C5'  DT I  64      81.176 125.873  15.250  1.00116.41           C  \\nATOM   1290  C4'  DT I  64      81.048 126.440  13.856  1.00116.41           C  \\nATOM   1291  O4'  DT I  64      80.364 125.499  12.993  1.00116.41           O  \\nATOM   1292  C3'  DT I  64      80.266 127.751  13.774  1.00116.41           C  \\nATOM   1293  O3'  DT I  64      80.946 128.685  12.922  1.00116.41           O  \\nATOM   1294  C2'  DT I  64      78.910 127.330  13.225  1.00116.41           C  \\nATOM   1295  C1'  DT I  64      79.242 126.116  12.371  1.00116.41           C  \\nATOM   1296  N1   DT I  64      78.161 125.100  12.268  1.00 69.74           N  \\nATOM   1297  C2   DT I  64      78.012 124.415  11.076  1.00 69.74           C  \\nATOM   1298  O2   DT I  64      78.692 124.632  10.087  1.00 69.74           O  \\nATOM   1299  N3   DT I  64      77.028 123.458  11.086  1.00 69.74           N  \\nATOM   1300  C4   DT I  64      76.187 123.130  12.130  1.00 69.74           C  \\nATOM   1301  O4   DT I  64      75.357 122.235  11.986  1.00 69.74           O  \\nATOM   1302  C5   DT I  64      76.375 123.900  13.337  1.00 69.74           C  \\nATOM   1303  C7   DT I  64      75.494 123.622  14.514  1.00 69.74           C  \\nATOM   1304  C6   DT I  64      77.338 124.836  13.346  1.00 69.74           C  \\nATOM   1305  P    DT I  65      80.183 130.002  12.396  1.00 73.21           P  \\nATOM   1306  OP1  DT I  65      81.204 130.970  11.897  1.00 73.21           O  \\nATOM   1307  OP2  DT I  65      79.172 130.442  13.405  1.00 73.21           O  \\nATOM   1308  O5'  DT I  65      79.413 129.443  11.128  1.00 77.01           O  \\nATOM   1309  C5'  DT I  65      80.148 128.867  10.053  1.00 77.01           C  \\nATOM   1310  C4'  DT I  65      79.303 128.863   8.806  1.00 77.01           C  \\nATOM   1311  O4'  DT I  65      78.413 127.725   8.798  1.00 77.01           O  \\nATOM   1312  C3'  DT I  65      78.413 130.097   8.708  1.00 77.01           C  \\nATOM   1313  O3'  DT I  65      78.346 130.503   7.352  1.00 77.01           O  \\nATOM   1314  C2'  DT I  65      77.069 129.595   9.196  1.00 77.01           C  \\nATOM   1315  C1'  DT I  65      77.085 128.177   8.669  1.00 77.01           C  \\nATOM   1316  N1   DT I  65      76.224 127.248   9.394  1.00 41.88           N  \\nATOM   1317  C2   DT I  65      75.715 126.175   8.696  1.00 41.88           C  \\nATOM   1318  O2   DT I  65      75.988 125.940   7.519  1.00 41.88           O  \\nATOM   1319  N3   DT I  65      74.861 125.386   9.424  1.00 41.88           N  \\nATOM   1320  C4   DT I  65      74.467 125.561  10.740  1.00 41.88           C  \\nATOM   1321  O4   DT I  65      73.652 124.777  11.253  1.00 41.88           O  \\nATOM   1322  C5   DT I  65      75.061 126.689  11.411  1.00 41.88           C  \\nATOM   1323  C7   DT I  65      74.696 126.949  12.835  1.00 41.88           C  \\nATOM   1324  C6   DT I  65      75.911 127.462  10.719  1.00 41.88           C  \\nATOM   1325  P    DC I  66      77.638 131.883   6.975  1.00 74.93           P  \\nATOM   1326  OP1  DC I  66      78.634 132.714   6.251  1.00 74.93           O  \\nATOM   1327  OP2  DC I  66      76.991 132.404   8.218  1.00 74.93           O  \\nATOM   1328  O5'  DC I  66      76.519 131.412   5.945  1.00 70.38           O  \\nATOM   1329  C5'  DC I  66      76.782 130.335   5.042  1.00 70.38           C  \\nATOM   1330  C4'  DC I  66      75.499 129.739   4.505  1.00 70.38           C  \\nATOM   1331  O4'  DC I  66      74.832 128.875   5.461  1.00 70.38           O  \\nATOM   1332  C3'  DC I  66      74.435 130.710   4.008  1.00 70.38           C  \\nATOM   1333  O3'  DC I  66      73.901 130.122   2.852  1.00 70.38           O  \\nATOM   1334  C2'  DC I  66      73.372 130.662   5.091  1.00 70.38           C  \\nATOM   1335  C1'  DC I  66      73.449 129.208   5.515  1.00 70.38           C  \\nATOM   1336  N1   DC I  66      72.968 128.924   6.879  1.00 44.13           N  \\nATOM   1337  C2   DC I  66      72.504 127.627   7.187  1.00 44.13           C  \\nATOM   1338  O2   DC I  66      72.452 126.764   6.284  1.00 44.13           O  \\nATOM   1339  N3   DC I  66      72.113 127.354   8.453  1.00 44.13           N  \\nATOM   1340  C4   DC I  66      72.155 128.309   9.384  1.00 44.13           C  \\nATOM   1341  N4   DC I  66      71.797 127.992  10.622  1.00 44.13           N  \\nATOM   1342  C5   DC I  66      72.579 129.633   9.089  1.00 44.13           C  \\nATOM   1343  C6   DC I  66      72.979 129.895   7.839  1.00 44.13           C  \\nATOM   1344  P    DA I  67      73.298 131.034   1.705  1.00 46.51           P  \\nATOM   1345  OP1  DA I  67      74.449 131.557   0.941  1.00 46.51           O  \\nATOM   1346  OP2  DA I  67      72.314 131.977   2.308  1.00 46.51           O  \\nATOM   1347  O5'  DA I  67      72.572 129.947   0.794  1.00 44.45           O  \\nATOM   1348  C5'  DA I  67      73.179 128.655   0.595  1.00 44.45           C  \\nATOM   1349  C4'  DA I  67      72.140 127.549   0.566  1.00 44.45           C  \\nATOM   1350  O4'  DA I  67      71.547 127.321   1.869  1.00 44.45           O  \\nATOM   1351  C3'  DA I  67      70.974 127.758  -0.397  1.00 44.45           C  \\nATOM   1352  O3'  DA I  67      70.680 126.507  -1.037  1.00 44.45           O  \\nATOM   1353  C2'  DA I  67      69.867 128.285   0.505  1.00 44.45           C  \\nATOM   1354  C1'  DA I  67      70.147 127.596   1.835  1.00 44.45           C  \\nATOM   1355  N9   DA I  67      69.833 128.364   3.042  1.00 36.56           N  \\nATOM   1356  C8   DA I  67      70.076 129.684   3.295  1.00 36.56           C  \\nATOM   1357  N7   DA I  67      69.778 130.055   4.523  1.00 36.56           N  \\nATOM   1358  C5   DA I  67      69.279 128.903   5.108  1.00 36.56           C  \\nATOM   1359  C6   DA I  67      68.801 128.617   6.417  1.00 36.56           C  \\nATOM   1360  N6   DA I  67      68.741 129.509   7.415  1.00 36.56           N  \\nATOM   1361  N1   DA I  67      68.379 127.357   6.666  1.00 36.56           N  \\nATOM   1362  C2   DA I  67      68.427 126.456   5.674  1.00 36.56           C  \\nATOM   1363  N3   DA I  67      68.851 126.601   4.415  1.00 36.56           N  \\nATOM   1364  C4   DA I  67      69.277 127.859   4.197  1.00 36.56           C  \\nATOM   1365  P    DG I  68      69.610 126.447  -2.234  1.00 39.82           P  \\nATOM   1366  OP1  DG I  68      69.972 125.447  -3.266  1.00 39.82           O  \\nATOM   1367  OP2  DG I  68      69.311 127.838  -2.638  1.00 39.82           O  \\nATOM   1368  O5'  DG I  68      68.356 125.849  -1.489  1.00 53.10           O  \\nATOM   1369  C5'  DG I  68      68.275 125.944  -0.083  1.00 53.10           C  \\nATOM   1370  C4'  DG I  68      67.105 125.136   0.386  1.00 53.10           C  \\nATOM   1371  O4'  DG I  68      66.638 125.669   1.636  1.00 53.10           O  \\nATOM   1372  C3'  DG I  68      65.958 125.302  -0.594  1.00 53.10           C  \\nATOM   1373  O3'  DG I  68      65.264 124.063  -0.661  1.00 53.10           O  \\nATOM   1374  C2'  DG I  68      65.178 126.483  -0.051  1.00 53.10           C  \\nATOM   1375  C1'  DG I  68      65.517 126.513   1.428  1.00 53.10           C  \\nATOM   1376  N9   DG I  68      65.910 127.846   1.859  1.00 48.31           N  \\nATOM   1377  C8   DG I  68      66.412 128.849   1.069  1.00 48.31           C  \\nATOM   1378  N7   DG I  68      66.669 129.945   1.731  1.00 48.31           N  \\nATOM   1379  C5   DG I  68      66.312 129.648   3.036  1.00 48.31           C  \\nATOM   1380  C6   DG I  68      66.350 130.457   4.205  1.00 48.31           C  \\nATOM   1381  O6   DG I  68      66.716 131.640   4.321  1.00 48.31           O  \\nATOM   1382  N1   DG I  68      65.892 129.757   5.321  1.00 48.31           N  \\nATOM   1383  C2   DG I  68      65.443 128.447   5.307  1.00 48.31           C  \\nATOM   1384  N2   DG I  68      65.023 127.959   6.493  1.00 48.31           N  \\nATOM   1385  N3   DG I  68      65.406 127.687   4.221  1.00 48.31           N  \\nATOM   1386  C4   DG I  68      65.848 128.349   3.132  1.00 48.31           C  \\nATOM   1387  P    DC I  69      63.763 124.009  -1.190  1.00 57.62           P  \\nATOM   1388  OP1  DC I  69      63.676 122.848  -2.106  1.00 57.62           O  \\nATOM   1389  OP2  DC I  69      63.378 125.361  -1.672  1.00 57.62           O  \\nATOM   1390  O5'  DC I  69      62.945 123.709   0.142  1.00 29.96           O  \\nATOM   1391  C5'  DC I  69      63.435 122.799   1.114  1.00 29.96           C  \\nATOM   1392  C4'  DC I  69      62.610 122.931   2.364  1.00 29.96           C  \\nATOM   1393  O4'  DC I  69      62.851 124.249   2.909  1.00 29.96           O  \\nATOM   1394  C3'  DC I  69      61.112 122.865   2.068  1.00 29.96           C  \\nATOM   1395  O3'  DC I  69      60.407 122.269   3.159  1.00 29.96           O  \\nATOM   1396  C2'  DC I  69      60.722 124.318   1.940  1.00 29.96           C  \\nATOM   1397  C1'  DC I  69      61.632 124.977   2.961  1.00 29.96           C  \\nATOM   1398  N1   DC I  69      61.917 126.389   2.638  1.00 24.77           N  \\nATOM   1399  C2   DC I  69      62.025 127.330   3.686  1.00 24.77           C  \\nATOM   1400  O2   DC I  69      61.911 126.946   4.856  1.00 24.77           O  \\nATOM   1401  N3   DC I  69      62.248 128.627   3.389  1.00 24.77           N  \\nATOM   1402  C4   DC I  69      62.378 129.006   2.110  1.00 24.77           C  \\nATOM   1403  N4   DC I  69      62.622 130.312   1.858  1.00 24.77           N  \\nATOM   1404  C5   DC I  69      62.276 128.069   1.028  1.00 24.77           C  \\nATOM   1405  C6   DC I  69      62.052 126.787   1.335  1.00 24.77           C  \\nATOM   1406  P    DT I  70      58.951 121.617   2.918  1.00 35.51           P  \\nATOM   1407  OP1  DT I  70      59.046 120.147   3.065  1.00 35.51           O  \\nATOM   1408  OP2  DT I  70      58.323 122.190   1.692  1.00 35.51           O  \\nATOM   1409  O5'  DT I  70      58.168 122.146   4.180  1.00 30.72           O  \\nATOM   1410  C5'  DT I  70      58.764 122.025   5.445  1.00 30.72           C  \\nATOM   1411  C4'  DT I  70      58.258 123.111   6.354  1.00 30.72           C  \\nATOM   1412  O4'  DT I  70      58.655 124.416   5.864  1.00 30.72           O  \\nATOM   1413  C3'  DT I  70      56.743 123.160   6.504  1.00 30.72           C  \\nATOM   1414  O3'  DT I  70      56.498 123.354   7.887  1.00 30.72           O  \\nATOM   1415  C2'  DT I  70      56.331 124.378   5.677  1.00 30.72           C  \\nATOM   1416  C1'  DT I  70      57.537 125.289   5.823  1.00 30.72           C  \\nATOM   1417  N1   DT I  70      57.780 126.264   4.741  1.00 23.69           N  \\nATOM   1418  C2   DT I  70      58.174 127.531   5.112  1.00 23.69           C  \\nATOM   1419  O2   DT I  70      58.259 127.886   6.276  1.00 23.69           O  \\nATOM   1420  N3   DT I  70      58.454 128.375   4.075  1.00 23.69           N  \\nATOM   1421  C4   DT I  70      58.362 128.101   2.730  1.00 23.69           C  \\nATOM   1422  O4   DT I  70      58.649 128.981   1.915  1.00 23.69           O  \\nATOM   1423  C5   DT I  70      57.914 126.750   2.400  1.00 23.69           C  \\nATOM   1424  C7   DT I  70      57.775 126.349   0.964  1.00 23.69           C  \\nATOM   1425  C6   DT I  70      57.647 125.916   3.414  1.00 23.69           C  \\nATOM   1426  P    DG I  71      55.098 122.939   8.518  1.00 34.42           P  \\nATOM   1427  OP1  DG I  71      55.286 121.749   9.384  1.00 34.42           O  \\nATOM   1428  OP2  DG I  71      54.055 122.937   7.435  1.00 34.42           O  \\nATOM   1429  O5'  DG I  71      54.855 124.114   9.542  1.00 46.23           O  \\nATOM   1430  C5'  DG I  71      53.679 124.851   9.472  1.00 46.23           C  \\nATOM   1431  C4'  DG I  71      53.985 126.323   9.418  1.00 46.23           C  \\nATOM   1432  O4'  DG I  71      54.709 126.695   8.218  1.00 46.23           O  \\nATOM   1433  C3'  DG I  71      52.660 127.061   9.352  1.00 46.23           C  \\nATOM   1434  O3'  DG I  71      52.666 128.103  10.286  1.00 46.23           O  \\nATOM   1435  C2'  DG I  71      52.557 127.551   7.925  1.00 46.23           C  \\nATOM   1436  C1'  DG I  71      54.003 127.732   7.568  1.00 46.23           C  \\nATOM   1437  N9   DG I  71      54.219 127.620   6.141  1.00 34.75           N  \\nATOM   1438  C8   DG I  71      54.009 126.542   5.321  1.00 34.75           C  \\nATOM   1439  N7   DG I  71      54.258 126.799   4.065  1.00 34.75           N  \\nATOM   1440  C5   DG I  71      54.663 128.119   4.075  1.00 34.75           C  \\nATOM   1441  C6   DG I  71      55.065 128.946   3.028  1.00 34.75           C  \\nATOM   1442  O6   DG I  71      55.145 128.668   1.830  1.00 34.75           O  \\nATOM   1443  N1   DG I  71      55.404 130.221   3.482  1.00 34.75           N  \\nATOM   1444  C2   DG I  71      55.357 130.622   4.793  1.00 34.75           C  \\nATOM   1445  N2   DG I  71      55.736 131.863   5.048  1.00 34.75           N  \\nATOM   1446  N3   DG I  71      54.975 129.856   5.779  1.00 34.75           N  \\nATOM   1447  C4   DG I  71      54.649 128.625   5.352  1.00 34.75           C  \\nATOM   1448  P    DA I  72      51.443 128.230  11.287  1.00 45.92           P  \\nATOM   1449  OP1  DA I  72      51.797 127.623  12.601  1.00 45.92           O  \\nATOM   1450  OP2  DA I  72      50.283 127.700  10.508  1.00 45.92           O  \\nATOM   1451  O5'  DA I  72      51.332 129.810  11.438  1.00 65.02           O  \\nATOM   1452  C5'  DA I  72      52.499 130.631  11.416  1.00 65.02           C  \\nATOM   1453  C4'  DA I  72      52.267 131.836  10.537  1.00 65.02           C  \\nATOM   1454  O4'  DA I  72      52.634 131.568   9.166  1.00 65.02           O  \\nATOM   1455  C3'  DA I  72      50.809 132.297  10.499  1.00 65.02           C  \\nATOM   1456  O3'  DA I  72      50.714 133.710  10.589  1.00 65.02           O  \\nATOM   1457  C2'  DA I  72      50.337 131.877   9.125  1.00 65.02           C  \\nATOM   1458  C1'  DA I  72      51.601 132.059   8.333  1.00 65.02           C  \\nATOM   1459  N9   DA I  72      51.611 131.290   7.102  1.00 51.41           N  \\nATOM   1460  C8   DA I  72      51.229 129.992   6.925  1.00 51.41           C  \\nATOM   1461  N7   DA I  72      51.332 129.577   5.687  1.00 51.41           N  \\nATOM   1462  C5   DA I  72      51.822 130.681   5.004  1.00 51.41           C  \\nATOM   1463  C6   DA I  72      52.152 130.894   3.645  1.00 51.41           C  \\nATOM   1464  N6   DA I  72      52.028 129.963   2.687  1.00 51.41           N  \\nATOM   1465  N1   DA I  72      52.613 132.115   3.301  1.00 51.41           N  \\nATOM   1466  C2   DA I  72      52.728 133.052   4.256  1.00 51.41           C  \\nATOM   1467  N3   DA I  72      52.449 132.971   5.559  1.00 51.41           N  \\nATOM   1468  C4   DA I  72      51.998 131.744   5.868  1.00 51.41           C  \\nATOM   1469  P    DA I  73      49.376 134.366  11.183  1.00 53.82           P  \\nATOM   1470  OP1  DA I  73      49.604 134.676  12.619  1.00 53.82           O  \\nATOM   1471  OP2  DA I  73      48.209 133.515  10.779  1.00 53.82           O  \\nATOM   1472  O5'  DA I  73      49.297 135.722  10.380  1.00 57.54           O  \\nATOM   1473  C5'  DA I  73      50.379 136.129   9.571  1.00 57.54           C  \\nATOM   1474  C4'  DA I  73      49.847 136.786   8.326  1.00 57.54           C  \\nATOM   1475  O4'  DA I  73      49.986 135.907   7.186  1.00 57.54           O  \\nATOM   1476  C3'  DA I  73      48.367 137.155   8.415  1.00 57.54           C  \\nATOM   1477  O3'  DA I  73      48.191 138.509   7.975  1.00 57.54           O  \\nATOM   1478  C2'  DA I  73      47.692 136.133   7.511  1.00 57.54           C  \\nATOM   1479  C1'  DA I  73      48.767 135.839   6.483  1.00 57.54           C  \\nATOM   1480  N9   DA I  73      48.693 134.516   5.881  1.00 53.60           N  \\nATOM   1481  C8   DA I  73      48.271 133.341   6.453  1.00 53.60           C  \\nATOM   1482  N7   DA I  73      48.312 132.309   5.639  1.00 53.60           N  \\nATOM   1483  C5   DA I  73      48.796 132.844   4.454  1.00 53.60           C  \\nATOM   1484  C6   DA I  73      49.063 132.272   3.195  1.00 53.60           C  \\nATOM   1485  N6   DA I  73      48.875 130.981   2.912  1.00 53.60           N  \\nATOM   1486  N1   DA I  73      49.538 133.087   2.222  1.00 53.60           N  \\nATOM   1487  C2   DA I  73      49.734 134.382   2.510  1.00 53.60           C  \\nATOM   1488  N3   DA I  73      49.523 135.034   3.656  1.00 53.60           N  \\nATOM   1489  C4   DA I  73      49.044 134.201   4.593  1.00 53.60           C  \\nATOM   1490  P    DT I  74      46.727 139.050   7.601  1.00 68.60           P  \\nATOM   1491  OP1  DT I  74      46.730 140.523   7.800  1.00 68.60           O  \\nATOM   1492  OP2  DT I  74      45.726 138.208   8.317  1.00 68.60           O  \\nATOM   1493  O5'  DT I  74      46.638 138.759   6.039  1.00 51.36           O  \\nATOM   1494  C5'  DT I  74      47.576 139.343   5.145  1.00 51.36           C  \\nATOM   1495  C4'  DT I  74      46.987 139.403   3.759  1.00 51.36           C  \\nATOM   1496  O4'  DT I  74      47.128 138.122   3.103  1.00 51.36           O  \\nATOM   1497  C3'  DT I  74      45.493 139.731   3.745  1.00 51.36           C  \\nATOM   1498  O3'  DT I  74      45.197 140.685   2.713  1.00 51.36           O  \\nATOM   1499  C2'  DT I  74      44.836 138.383   3.482  1.00 51.36           C  \\nATOM   1500  C1'  DT I  74      45.868 137.689   2.611  1.00 51.36           C  \\nATOM   1501  N1   DT I  74      45.844 136.222   2.691  1.00 29.80           N  \\nATOM   1502  C2   DT I  74      46.151 135.496   1.564  1.00 29.80           C  \\nATOM   1503  O2   DT I  74      46.377 136.004   0.471  1.00 29.80           O  \\nATOM   1504  N3   DT I  74      46.163 134.138   1.756  1.00 29.80           N  \\nATOM   1505  C4   DT I  74      45.880 133.452   2.922  1.00 29.80           C  \\nATOM   1506  O4   DT I  74      45.926 132.210   2.937  1.00 29.80           O  \\nATOM   1507  C5   DT I  74      45.537 134.277   4.048  1.00 29.80           C  \\nATOM   1508  C7   DT I  74      45.197 133.621   5.345  1.00 29.80           C  \\nATOM   1509  C6   DT I  74      45.538 135.602   3.881  1.00 29.80           C  \\nATOM   1510  P    DT I  75      43.668 141.066   2.388  1.00 76.25           P  \\nATOM   1511  OP1  DT I  75      43.641 142.499   1.985  1.00 76.25           O  \\nATOM   1512  OP2  DT I  75      42.805 140.590   3.509  1.00 76.25           O  \\nATOM   1513  O5'  DT I  75      43.370 140.182   1.104  1.00 63.46           O  \\nATOM   1514  C5'  DT I  75      44.292 140.199   0.030  1.00 63.46           C  \\nATOM   1515  C4'  DT I  75      43.765 139.398  -1.131  1.00 63.46           C  \\nATOM   1516  O4'  DT I  75      43.957 137.986  -0.907  1.00 63.46           O  \\nATOM   1517  C3'  DT I  75      42.282 139.591  -1.414  1.00 63.46           C  \\nATOM   1518  O3'  DT I  75      42.110 139.601  -2.817  1.00 63.46           O  \\nATOM   1519  C2'  DT I  75      41.652 138.333  -0.848  1.00 63.46           C  \\nATOM   1520  C1'  DT I  75      42.735 137.311  -1.132  1.00 63.46           C  \\nATOM   1521  N1   DT I  75      42.717 136.128  -0.262  1.00 40.15           N  \\nATOM   1522  C2   DT I  75      43.032 134.906  -0.823  1.00 40.15           C  \\nATOM   1523  O2   DT I  75      43.362 134.762  -2.002  1.00 40.15           O  \\nATOM   1524  N3   DT I  75      42.954 133.849   0.057  1.00 40.15           N  \\nATOM   1525  C4   DT I  75      42.620 133.897   1.399  1.00 40.15           C  \\nATOM   1526  O4   DT I  75      42.579 132.865   2.054  1.00 40.15           O  \\nATOM   1527  C5   DT I  75      42.337 135.205   1.917  1.00 40.15           C  \\nATOM   1528  C7   DT I  75      42.003 135.347   3.367  1.00 40.15           C  \\nATOM   1529  C6   DT I  75      42.390 136.243   1.074  1.00 40.15           C  \\nATOM   1530  P    DC I  76      40.900 140.419  -3.458  1.00 62.68           P  \\nATOM   1531  OP1  DC I  76      41.492 141.539  -4.231  1.00 62.68           O  \\nATOM   1532  OP2  DC I  76      39.921 140.704  -2.376  1.00 62.68           O  \\nATOM   1533  O5'  DC I  76      40.279 139.359  -4.471  1.00 64.72           O  \\nATOM   1534  C5'  DC I  76      41.083 138.290  -4.985  1.00 64.72           C  \\nATOM   1535  C4'  DC I  76      40.215 137.126  -5.404  1.00 64.72           C  \\nATOM   1536  O4'  DC I  76      40.309 136.057  -4.432  1.00 64.72           O  \\nATOM   1537  C3'  DC I  76      38.722 137.429  -5.540  1.00 64.72           C  \\nATOM   1538  O3'  DC I  76      38.201 136.628  -6.594  1.00 64.72           O  \\nATOM   1539  C2'  DC I  76      38.153 136.919  -4.229  1.00 64.72           C  \\nATOM   1540  C1'  DC I  76      39.001 135.685  -4.026  1.00 64.72           C  \\nATOM   1541  N1   DC I  76      39.074 135.183  -2.650  1.00 33.62           N  \\nATOM   1542  C2   DC I  76      39.438 133.834  -2.444  1.00 33.62           C  \\nATOM   1543  O2   DC I  76      39.686 133.125  -3.433  1.00 33.62           O  \\nATOM   1544  N3   DC I  76      39.506 133.345  -1.176  1.00 33.62           N  \\nATOM   1545  C4   DC I  76      39.224 134.147  -0.140  1.00 33.62           C  \\nATOM   1546  N4   DC I  76      39.286 133.627   1.098  1.00 33.62           N  \\nATOM   1547  C5   DC I  76      38.858 135.525  -0.325  1.00 33.62           C  \\nATOM   1548  C6   DC I  76      38.796 135.994  -1.584  1.00 33.62           C  \\nATOM   1549  P    DA I  77      37.324 137.297  -7.755  1.00 70.45           P  \\nATOM   1550  OP1  DA I  77      38.146 138.342  -8.418  1.00 70.45           O  \\nATOM   1551  OP2  DA I  77      35.997 137.652  -7.171  1.00 70.45           O  \\nATOM   1552  O5'  DA I  77      37.140 136.104  -8.796  1.00 46.80           O  \\nATOM   1553  C5'  DA I  77      38.281 135.437  -9.348  1.00 46.80           C  \\nATOM   1554  C4'  DA I  77      38.112 133.933  -9.283  1.00 46.80           C  \\nATOM   1555  O4'  DA I  77      38.084 133.471  -7.906  1.00 46.80           O  \\nATOM   1556  C3'  DA I  77      36.848 133.383  -9.939  1.00 46.80           C  \\nATOM   1557  O3'  DA I  77      37.170 132.193 -10.664  1.00 46.80           O  \\nATOM   1558  C2'  DA I  77      35.916 133.119  -8.764  1.00 46.80           C  \\nATOM   1559  C1'  DA I  77      36.870 132.776  -7.626  1.00 46.80           C  \\nATOM   1560  N9   DA I  77      36.417 133.208  -6.300  1.00 35.03           N  \\nATOM   1561  C8   DA I  77      35.781 134.383  -5.980  1.00 35.03           C  \\nATOM   1562  N7   DA I  77      35.533 134.524  -4.697  1.00 35.03           N  \\nATOM   1563  C5   DA I  77      36.033 133.359  -4.131  1.00 35.03           C  \\nATOM   1564  C6   DA I  77      36.086 132.900  -2.791  1.00 35.03           C  \\nATOM   1565  N6   DA I  77      35.641 133.599  -1.739  1.00 35.03           N  \\nATOM   1566  N1   DA I  77      36.629 131.684  -2.573  1.00 35.03           N  \\nATOM   1567  C2   DA I  77      37.099 130.990  -3.630  1.00 35.03           C  \\nATOM   1568  N3   DA I  77      37.121 131.319  -4.924  1.00 35.03           N  \\nATOM   1569  C4   DA I  77      36.567 132.529  -5.111  1.00 35.03           C  \\nATOM   1570  P    DG I  78      36.138 131.617 -11.755  1.00 59.13           P  \\nATOM   1571  OP1  DG I  78      36.912 130.980 -12.852  1.00 59.13           O  \\nATOM   1572  OP2  DG I  78      35.087 132.628 -12.067  1.00 59.13           O  \\nATOM   1573  O5'  DG I  78      35.406 130.459 -10.972  1.00 70.76           O  \\nATOM   1574  C5'  DG I  78      35.253 130.546  -9.572  1.00 70.76           C  \\nATOM   1575  C4'  DG I  78      35.096 129.166  -8.996  1.00 70.76           C  \\nATOM   1576  O4'  DG I  78      34.837 129.289  -7.593  1.00 70.76           O  \\nATOM   1577  C3'  DG I  78      33.887 128.440  -9.549  1.00 70.76           C  \\nATOM   1578  O3'  DG I  78      34.135 127.069  -9.306  1.00 70.76           O  \\nATOM   1579  C2'  DG I  78      32.760 128.998  -8.703  1.00 70.76           C  \\nATOM   1580  C1'  DG I  78      33.442 129.262  -7.366  1.00 70.76           C  \\nATOM   1581  N9   DG I  78      33.116 130.532  -6.739  1.00 48.59           N  \\nATOM   1582  C8   DG I  78      32.826 131.728  -7.346  1.00 48.59           C  \\nATOM   1583  N7   DG I  78      32.616 132.692  -6.491  1.00 48.59           N  \\nATOM   1584  C5   DG I  78      32.767 132.088  -5.252  1.00 48.59           C  \\nATOM   1585  C6   DG I  78      32.642 132.624  -3.950  1.00 48.59           C  \\nATOM   1586  O6   DG I  78      32.346 133.791  -3.616  1.00 48.59           O  \\nATOM   1587  N1   DG I  78      32.879 131.651  -2.976  1.00 48.59           N  \\nATOM   1588  C2   DG I  78      33.175 130.329  -3.234  1.00 48.59           C  \\nATOM   1589  N2   DG I  78      33.340 129.535  -2.168  1.00 48.59           N  \\nATOM   1590  N3   DG I  78      33.291 129.826  -4.441  1.00 48.59           N  \\nATOM   1591  C4   DG I  78      33.073 130.755  -5.394  1.00 48.59           C  \\nATOM   1592  P    DC I  79      33.379 125.945 -10.153  1.00 56.07           P  \\nATOM   1593  OP1  DC I  79      34.184 125.565 -11.344  1.00 56.07           O  \\nATOM   1594  OP2  DC I  79      31.978 126.382 -10.331  1.00 56.07           O  \\nATOM   1595  O5'  DC I  79      33.440 124.732  -9.127  1.00 36.59           O  \\nATOM   1596  C5'  DC I  79      34.666 124.429  -8.462  1.00 36.59           C  \\nATOM   1597  C4'  DC I  79      34.412 124.076  -7.018  1.00 36.59           C  \\nATOM   1598  O4'  DC I  79      33.836 125.183  -6.290  1.00 36.59           O  \\nATOM   1599  C3'  DC I  79      33.469 122.907  -6.793  1.00 36.59           C  \\nATOM   1600  O3'  DC I  79      33.963 122.232  -5.652  1.00 36.59           O  \\nATOM   1601  C2'  DC I  79      32.146 123.582  -6.480  1.00 36.59           C  \\nATOM   1602  C1'  DC I  79      32.610 124.789  -5.692  1.00 36.59           C  \\nATOM   1603  N1   DC I  79      31.725 125.957  -5.722  1.00 35.92           N  \\nATOM   1604  C2   DC I  79      31.571 126.710  -4.559  1.00 35.92           C  \\nATOM   1605  O2   DC I  79      32.127 126.321  -3.508  1.00 35.92           O  \\nATOM   1606  N3   DC I  79      30.824 127.840  -4.603  1.00 35.92           N  \\nATOM   1607  C4   DC I  79      30.241 128.213  -5.747  1.00 35.92           C  \\nATOM   1608  N4   DC I  79      29.546 129.350  -5.757  1.00 35.92           N  \\nATOM   1609  C5   DC I  79      30.352 127.442  -6.933  1.00 35.92           C  \\nATOM   1610  C6   DC I  79      31.092 126.329  -6.875  1.00 35.92           C  \\nATOM   1611  P    DT I  80      33.566 120.718  -5.404  1.00 33.22           P  \\nATOM   1612  OP1  DT I  80      34.800 120.115  -4.851  1.00 33.22           O  \\nATOM   1613  OP2  DT I  80      32.923 120.140  -6.627  1.00 33.22           O  \\nATOM   1614  O5'  DT I  80      32.502 120.835  -4.240  1.00 24.73           O  \\nATOM   1615  C5'  DT I  80      32.924 121.286  -2.976  1.00 24.73           C  \\nATOM   1616  C4'  DT I  80      31.735 121.661  -2.132  1.00 24.73           C  \\nATOM   1617  O4'  DT I  80      31.118 122.843  -2.699  1.00 24.73           O  \\nATOM   1618  C3'  DT I  80      30.635 120.598  -2.019  1.00 24.73           C  \\nATOM   1619  O3'  DT I  80      30.244 120.482  -0.638  1.00 24.73           O  \\nATOM   1620  C2'  DT I  80      29.520 121.156  -2.891  1.00 24.73           C  \\nATOM   1621  C1'  DT I  80      29.721 122.659  -2.753  1.00 24.73           C  \\nATOM   1622  N1   DT I  80      29.184 123.487  -3.862  1.00 35.42           N  \\nATOM   1623  C2   DT I  80      28.673 124.749  -3.582  1.00 35.42           C  \\nATOM   1624  O2   DT I  80      28.667 125.261  -2.466  1.00 35.42           O  \\nATOM   1625  N3   DT I  80      28.168 125.398  -4.672  1.00 35.42           N  \\nATOM   1626  C4   DT I  80      28.134 124.947  -5.980  1.00 35.42           C  \\nATOM   1627  O4   DT I  80      27.662 125.659  -6.863  1.00 35.42           O  \\nATOM   1628  C5   DT I  80      28.688 123.643  -6.195  1.00 35.42           C  \\nATOM   1629  C7   DT I  80      28.692 123.083  -7.579  1.00 35.42           C  \\nATOM   1630  C6   DT I  80      29.180 122.987  -5.143  1.00 35.42           C  \\nATOM   1631  P    DG I  81      29.165 119.385  -0.178  1.00 22.94           P  \\nATOM   1632  OP1  DG I  81      29.806 118.352   0.670  1.00 22.94           O  \\nATOM   1633  OP2  DG I  81      28.358 118.951  -1.338  1.00 22.94           O  \\nATOM   1634  O5'  DG I  81      28.253 120.254   0.780  1.00 25.83           O  \\nATOM   1635  C5'  DG I  81      28.852 121.127   1.739  1.00 25.83           C  \\nATOM   1636  C4'  DG I  81      27.818 122.081   2.285  1.00 25.83           C  \\nATOM   1637  O4'  DG I  81      27.408 123.006   1.255  1.00 25.83           O  \\nATOM   1638  C3'  DG I  81      26.543 121.381   2.742  1.00 25.83           C  \\nATOM   1639  O3'  DG I  81      25.987 122.115   3.810  1.00 25.83           O  \\nATOM   1640  C2'  DG I  81      25.630 121.471   1.538  1.00 25.83           C  \\nATOM   1641  C1'  DG I  81      26.035 122.800   0.924  1.00 25.83           C  \\nATOM   1642  N9   DG I  81      25.920 122.826  -0.529  1.00 33.91           N  \\nATOM   1643  C8   DG I  81      26.342 121.872  -1.421  1.00 33.91           C  \\nATOM   1644  N7   DG I  81      26.080 122.176  -2.661  1.00 33.91           N  \\nATOM   1645  C5   DG I  81      25.449 123.406  -2.580  1.00 33.91           C  \\nATOM   1646  C6   DG I  81      24.920 124.234  -3.600  1.00 33.91           C  \\nATOM   1647  O6   DG I  81      24.883 124.022  -4.820  1.00 33.91           O  \\nATOM   1648  N1   DG I  81      24.379 125.410  -3.080  1.00 33.91           N  \\nATOM   1649  C2   DG I  81      24.336 125.734  -1.740  1.00 33.91           C  \\nATOM   1650  N2   DG I  81      23.766 126.903  -1.429  1.00 33.91           N  \\nATOM   1651  N3   DG I  81      24.814 124.963  -0.779  1.00 33.91           N  \\nATOM   1652  C4   DG I  81      25.353 123.823  -1.269  1.00 33.91           C  \\nATOM   1653  P    DA I  82      24.787 121.496   4.638  1.00 20.26           P  \\nATOM   1654  OP1  DA I  82      25.090 121.643   6.089  1.00 20.26           O  \\nATOM   1655  OP2  DA I  82      24.505 120.157   4.058  1.00 20.26           O  \\nATOM   1656  O5'  DA I  82      23.586 122.450   4.257  1.00 24.82           O  \\nATOM   1657  C5'  DA I  82      23.628 123.827   4.594  1.00 24.82           C  \\nATOM   1658  C4'  DA I  82      22.362 124.504   4.132  1.00 24.82           C  \\nATOM   1659  O4'  DA I  82      22.374 124.607   2.691  1.00 24.82           O  \\nATOM   1660  C3'  DA I  82      21.071 123.768   4.497  1.00 24.82           C  \\nATOM   1661  O3'  DA I  82      20.104 124.750   4.866  1.00 24.82           O  \\nATOM   1662  C2'  DA I  82      20.692 123.082   3.198  1.00 24.82           C  \\nATOM   1663  C1'  DA I  82      21.181 124.073   2.166  1.00 24.82           C  \\nATOM   1664  N9   DA I  82      21.488 123.504   0.857  1.00 28.26           N  \\nATOM   1665  C8   DA I  82      21.929 122.241   0.568  1.00 28.26           C  \\nATOM   1666  N7   DA I  82      22.069 122.011  -0.718  1.00 28.26           N  \\nATOM   1667  C5   DA I  82      21.701 123.211  -1.314  1.00 28.26           C  \\nATOM   1668  C6   DA I  82      21.609 123.613  -2.663  1.00 28.26           C  \\nATOM   1669  N6   DA I  82      21.858 122.803  -3.697  1.00 28.26           N  \\nATOM   1670  N1   DA I  82      21.230 124.884  -2.916  1.00 28.26           N  \\nATOM   1671  C2   DA I  82      20.943 125.681  -1.886  1.00 28.26           C  \\nATOM   1672  N3   DA I  82      20.970 125.416  -0.575  1.00 28.26           N  \\nATOM   1673  C4   DA I  82      21.362 124.146  -0.355  1.00 28.26           C  \\nATOM   1674  P    DA I  83      18.702 124.312   5.518  1.00 28.62           P  \\nATOM   1675  OP1  DA I  83      18.459 125.303   6.622  1.00 28.62           O  \\nATOM   1676  OP2  DA I  83      18.706 122.836   5.808  1.00 28.62           O  \\nATOM   1677  O5'  DA I  83      17.676 124.593   4.333  1.00 31.28           O  \\nATOM   1678  C5'  DA I  83      17.777 125.795   3.576  1.00 31.28           C  \\nATOM   1679  C4'  DA I  83      16.861 125.745   2.377  1.00 31.28           C  \\nATOM   1680  O4'  DA I  83      17.498 125.148   1.220  1.00 31.28           O  \\nATOM   1681  C3'  DA I  83      15.550 124.989   2.593  1.00 31.28           C  \\nATOM   1682  O3'  DA I  83      14.465 125.769   2.077  1.00 31.28           O  \\nATOM   1683  C2'  DA I  83      15.747 123.725   1.773  1.00 31.28           C  \\nATOM   1684  C1'  DA I  83      16.602 124.230   0.632  1.00 31.28           C  \\nATOM   1685  N9   DA I  83      17.379 123.204  -0.063  1.00 38.29           N  \\nATOM   1686  C8   DA I  83      17.968 122.079   0.456  1.00 38.29           C  \\nATOM   1687  N7   DA I  83      18.593 121.349  -0.441  1.00 38.29           N  \\nATOM   1688  C5   DA I  83      18.405 122.045  -1.631  1.00 38.29           C  \\nATOM   1689  C6   DA I  83      18.823 121.799  -2.964  1.00 38.29           C  \\nATOM   1690  N6   DA I  83      19.591 120.777  -3.335  1.00 38.29           N  \\nATOM   1691  N1   DA I  83      18.429 122.666  -3.910  1.00 38.29           N  \\nATOM   1692  C2   DA I  83      17.701 123.721  -3.545  1.00 38.29           C  \\nATOM   1693  N3   DA I  83      17.269 124.079  -2.330  1.00 38.29           N  \\nATOM   1694  C4   DA I  83      17.654 123.184  -1.410  1.00 38.29           C  \\nATOM   1695  P    DC I  84      12.947 125.369   2.412  1.00 53.71           P  \\nATOM   1696  OP1  DC I  84      12.386 126.501   3.185  1.00 53.71           O  \\nATOM   1697  OP2  DC I  84      12.877 123.991   2.981  1.00 53.71           O  \\nATOM   1698  O5'  DC I  84      12.326 125.401   0.952  1.00 50.38           O  \\nATOM   1699  C5'  DC I  84      13.095 125.949  -0.125  1.00 50.38           C  \\nATOM   1700  C4'  DC I  84      12.440 125.628  -1.444  1.00 50.38           C  \\nATOM   1701  O4'  DC I  84      13.277 124.735  -2.222  1.00 50.38           O  \\nATOM   1702  C3'  DC I  84      11.121 124.900  -1.237  1.00 50.38           C  \\nATOM   1703  O3'  DC I  84      10.201 125.305  -2.248  1.00 50.38           O  \\nATOM   1704  C2'  DC I  84      11.512 123.442  -1.368  1.00 50.38           C  \\nATOM   1705  C1'  DC I  84      12.612 123.493  -2.414  1.00 50.38           C  \\nATOM   1706  N1   DC I  84      13.592 122.397  -2.271  1.00 33.88           N  \\nATOM   1707  C2   DC I  84      14.262 121.905  -3.424  1.00 33.88           C  \\nATOM   1708  O2   DC I  84      14.055 122.446  -4.533  1.00 33.88           O  \\nATOM   1709  N3   DC I  84      15.117 120.851  -3.290  1.00 33.88           N  \\nATOM   1710  C4   DC I  84      15.322 120.299  -2.080  1.00 33.88           C  \\nATOM   1711  N4   DC I  84      16.154 119.251  -1.997  1.00 33.88           N  \\nATOM   1712  C5   DC I  84      14.677 120.796  -0.902  1.00 33.88           C  \\nATOM   1713  C6   DC I  84      13.833 121.836  -1.043  1.00 33.88           C  \\nATOM   1714  P    DA I  85       8.677 124.783  -2.210  1.00 57.81           P  \\nATOM   1715  OP1  DA I  85       7.808 125.989  -2.154  1.00 57.81           O  \\nATOM   1716  OP2  DA I  85       8.533 123.724  -1.169  1.00 57.81           O  \\nATOM   1717  O5'  DA I  85       8.518 124.116  -3.646  1.00 56.09           O  \\nATOM   1718  C5'  DA I  85       8.990 124.788  -4.807  1.00 56.09           C  \\nATOM   1719  C4'  DA I  85       9.030 123.832  -5.971  1.00 56.09           C  \\nATOM   1720  O4'  DA I  85      10.131 122.911  -5.790  1.00 56.09           O  \\nATOM   1721  C3'  DA I  85       7.769 122.971  -6.103  1.00 56.09           C  \\nATOM   1722  O3'  DA I  85       7.423 122.794  -7.493  1.00 56.09           O  \\nATOM   1723  C2'  DA I  85       8.175 121.661  -5.449  1.00 56.09           C  \\nATOM   1724  C1'  DA I  85       9.648 121.578  -5.805  1.00 56.09           C  \\nATOM   1725  N9   DA I  85      10.449 120.782  -4.873  1.00 47.43           N  \\nATOM   1726  C8   DA I  85      10.415 120.766  -3.500  1.00 47.43           C  \\nATOM   1727  N7   DA I  85      11.222 119.885  -2.962  1.00 47.43           N  \\nATOM   1728  C5   DA I  85      11.839 119.286  -4.054  1.00 47.43           C  \\nATOM   1729  C6   DA I  85      12.799 118.251  -4.164  1.00 47.43           C  \\nATOM   1730  N6   DA I  85      13.291 117.577  -3.123  1.00 47.43           N  \\nATOM   1731  N1   DA I  85      13.223 117.917  -5.406  1.00 47.43           N  \\nATOM   1732  C2   DA I  85      12.698 118.559  -6.459  1.00 47.43           C  \\nATOM   1733  N3   DA I  85      11.780 119.525  -6.486  1.00 47.43           N  \\nATOM   1734  C4   DA I  85      11.389 119.847  -5.236  1.00 47.43           C  \\nATOM   1735  P    DT I  86       5.944 122.273  -7.914  1.00 47.26           P  \\nATOM   1736  OP1  DT I  86       5.423 123.201  -8.958  1.00 47.26           O  \\nATOM   1737  OP2  DT I  86       5.116 121.981  -6.698  1.00 47.26           O  \\nATOM   1738  O5'  DT I  86       6.260 120.885  -8.625  1.00 52.82           O  \\nATOM   1739  C5'  DT I  86       7.319 120.786  -9.573  1.00 52.82           C  \\nATOM   1740  C4'  DT I  86       7.716 119.343  -9.771  1.00 52.82           C  \\nATOM   1741  O4'  DT I  86       8.601 118.856  -8.727  1.00 52.82           O  \\nATOM   1742  C3'  DT I  86       6.558 118.346  -9.857  1.00 52.82           C  \\nATOM   1743  O3'  DT I  86       6.804 117.512 -10.989  1.00 52.82           O  \\nATOM   1744  C2'  DT I  86       6.694 117.538  -8.569  1.00 52.82           C  \\nATOM   1745  C1'  DT I  86       8.199 117.539  -8.377  1.00 52.82           C  \\nATOM   1746  N1   DT I  86       8.735 117.217  -7.025  1.00 36.85           N  \\nATOM   1747  C2   DT I  86       9.848 116.394  -6.942  1.00 36.85           C  \\nATOM   1748  O2   DT I  86      10.412 115.910  -7.909  1.00 36.85           O  \\nATOM   1749  N3   DT I  86      10.283 116.158  -5.673  1.00 36.85           N  \\nATOM   1750  C4   DT I  86       9.757 116.639  -4.500  1.00 36.85           C  \\nATOM   1751  O4   DT I  86      10.279 116.344  -3.432  1.00 36.85           O  \\nATOM   1752  C5   DT I  86       8.600 117.477  -4.641  1.00 36.85           C  \\nATOM   1753  C7   DT I  86       7.954 118.020  -3.405  1.00 36.85           C  \\nATOM   1754  C6   DT I  86       8.149 117.727  -5.884  1.00 36.85           C  \\nATOM   1755  P    DG I  87       5.600 117.055 -11.951  1.00 25.47           P  \\nATOM   1756  OP1  DG I  87       5.516 117.916 -13.158  1.00 25.47           O  \\nATOM   1757  OP2  DG I  87       4.402 116.771 -11.119  1.00 25.47           O  \\nATOM   1758  O5'  DG I  87       6.143 115.689 -12.510  1.00 27.94           O  \\nATOM   1759  C5'  DG I  87       7.537 115.503 -12.625  1.00 27.94           C  \\nATOM   1760  C4'  DG I  87       7.921 114.193 -11.993  1.00 27.94           C  \\nATOM   1761  O4'  DG I  87       8.067 114.303 -10.559  1.00 27.94           O  \\nATOM   1762  C3'  DG I  87       6.908 113.075 -12.239  1.00 27.94           C  \\nATOM   1763  O3'  DG I  87       7.600 112.044 -12.914  1.00 27.94           O  \\nATOM   1764  C2'  DG I  87       6.423 112.684 -10.842  1.00 27.94           C  \\nATOM   1765  C1'  DG I  87       7.589 113.107  -9.973  1.00 27.94           C  \\nATOM   1766  N9   DG I  87       7.380 113.365  -8.550  1.00 54.83           N  \\nATOM   1767  C8   DG I  87       6.409 114.140  -7.963  1.00 54.83           C  \\nATOM   1768  N7   DG I  87       6.552 114.253  -6.666  1.00 54.83           N  \\nATOM   1769  C5   DG I  87       7.673 113.487  -6.375  1.00 54.83           C  \\nATOM   1770  C6   DG I  87       8.336 113.245  -5.132  1.00 54.83           C  \\nATOM   1771  O6   DG I  87       8.057 113.687  -4.005  1.00 54.83           O  \\nATOM   1772  N1   DG I  87       9.443 112.404  -5.293  1.00 54.83           N  \\nATOM   1773  C2   DG I  87       9.871 111.877  -6.491  1.00 54.83           C  \\nATOM   1774  N2   DG I  87      10.959 111.097  -6.442  1.00 54.83           N  \\nATOM   1775  N3   DG I  87       9.271 112.103  -7.655  1.00 54.83           N  \\nATOM   1776  C4   DG I  87       8.185 112.911  -7.523  1.00 54.83           C  \\nATOM   1777  P    DC I  88       6.862 110.680 -13.240  1.00 36.08           P  \\nATOM   1778  OP1  DC I  88       6.302 110.745 -14.617  1.00 36.08           O  \\nATOM   1779  OP2  DC I  88       5.982 110.400 -12.084  1.00 36.08           O  \\nATOM   1780  O5'  DC I  88       8.065 109.637 -13.195  1.00 50.77           O  \\nATOM   1781  C5'  DC I  88       9.417 110.094 -13.260  1.00 50.77           C  \\nATOM   1782  C4'  DC I  88      10.287 109.303 -12.315  1.00 50.77           C  \\nATOM   1783  O4'  DC I  88       9.882 109.536 -10.952  1.00 50.77           O  \\nATOM   1784  C3'  DC I  88      10.247 107.787 -12.492  1.00 50.77           C  \\nATOM   1785  O3'  DC I  88      11.541 107.268 -12.190  1.00 50.77           O  \\nATOM   1786  C2'  DC I  88       9.276 107.337 -11.418  1.00 50.77           C  \\nATOM   1787  C1'  DC I  88       9.647 108.292 -10.313  1.00 50.77           C  \\nATOM   1788  N1   DC I  88       8.630 108.518  -9.292  1.00 56.98           N  \\nATOM   1789  C2   DC I  88       9.041 108.625  -7.959  1.00 56.98           C  \\nATOM   1790  O2   DC I  88      10.244 108.434  -7.675  1.00 56.98           O  \\nATOM   1791  N3   DC I  88       8.127 108.937  -7.018  1.00 56.98           N  \\nATOM   1792  C4   DC I  88       6.855 109.146  -7.367  1.00 56.98           C  \\nATOM   1793  N4   DC I  88       6.009 109.542  -6.419  1.00 56.98           N  \\nATOM   1794  C5   DC I  88       6.401 108.981  -8.709  1.00 56.98           C  \\nATOM   1795  C6   DC I  88       7.314 108.666  -9.629  1.00 56.98           C  \\nATOM   1796  P    DC I  89      11.998 105.872 -12.818  1.00 74.09           P  \\nATOM   1797  OP1  DC I  89      12.918 106.182 -13.947  1.00 74.09           O  \\nATOM   1798  OP2  DC I  89      10.778 105.054 -13.050  1.00 74.09           O  \\nATOM   1799  O5'  DC I  89      12.837 105.183 -11.659  1.00 42.03           O  \\nATOM   1800  C5'  DC I  89      13.052 105.844 -10.429  1.00 42.03           C  \\nATOM   1801  C4'  DC I  89      12.900 104.865  -9.296  1.00 42.03           C  \\nATOM   1802  O4'  DC I  89      11.641 105.106  -8.636  1.00 42.03           O  \\nATOM   1803  C3'  DC I  89      12.878 103.390  -9.702  1.00 42.03           C  \\nATOM   1804  O3'  DC I  89      13.338 102.646  -8.574  1.00 42.03           O  \\nATOM   1805  C2'  DC I  89      11.393 103.124  -9.839  1.00 42.03           C  \\nATOM   1806  C1'  DC I  89      10.890 103.908  -8.647  1.00 42.03           C  \\nATOM   1807  N1   DC I  89       9.475 104.274  -8.633  1.00 38.14           N  \\nATOM   1808  C2   DC I  89       8.880 104.493  -7.402  1.00 38.14           C  \\nATOM   1809  O2   DC I  89       9.563 104.354  -6.382  1.00 38.14           O  \\nATOM   1810  N3   DC I  89       7.585 104.852  -7.346  1.00 38.14           N  \\nATOM   1811  C4   DC I  89       6.881 104.983  -8.476  1.00 38.14           C  \\nATOM   1812  N4   DC I  89       5.598 105.347  -8.369  1.00 38.14           N  \\nATOM   1813  C5   DC I  89       7.462 104.754  -9.755  1.00 38.14           C  \\nATOM   1814  C6   DC I  89       8.753 104.404  -9.788  1.00 38.14           C  \\nATOM   1815  P    DT I  90      14.474 101.521  -8.731  1.00 25.78           P  \\nATOM   1816  OP1  DT I  90      15.704 102.142  -9.285  1.00 25.78           O  \\nATOM   1817  OP2  DT I  90      13.867 100.331  -9.398  1.00 25.78           O  \\nATOM   1818  O5'  DT I  90      14.738 101.184  -7.205  1.00 20.65           O  \\nATOM   1819  C5'  DT I  90      15.061 102.242  -6.313  1.00 20.65           C  \\nATOM   1820  C4'  DT I  90      14.230 102.176  -5.051  1.00 20.65           C  \\nATOM   1821  O4'  DT I  90      12.838 102.478  -5.326  1.00 20.65           O  \\nATOM   1822  C3'  DT I  90      14.246 100.857  -4.285  1.00 20.65           C  \\nATOM   1823  O3'  DT I  90      14.519 101.095  -2.918  1.00 20.65           O  \\nATOM   1824  C2'  DT I  90      12.832 100.322  -4.431  1.00 20.65           C  \\nATOM   1825  C1'  DT I  90      12.002 101.581  -4.608  1.00 20.65           C  \\nATOM   1826  N1   DT I  90      10.757 101.410  -5.401  1.00 50.17           N  \\nATOM   1827  C2   DT I  90       9.536 101.698  -4.812  1.00 50.17           C  \\nATOM   1828  O2   DT I  90       9.413 102.023  -3.631  1.00 50.17           O  \\nATOM   1829  N3   DT I  90       8.457 101.581  -5.662  1.00 50.17           N  \\nATOM   1830  C4   DT I  90       8.473 101.193  -6.990  1.00 50.17           C  \\nATOM   1831  O4   DT I  90       7.428 101.151  -7.630  1.00 50.17           O  \\nATOM   1832  C5   DT I  90       9.765 100.871  -7.520  1.00 50.17           C  \\nATOM   1833  C7   DT I  90       9.867 100.419  -8.942  1.00 50.17           C  \\nATOM   1834  C6   DT I  90      10.830 100.993  -6.715  1.00 50.17           C  \\nATOM   1835  P    DT I  91      14.640  99.852  -1.927  1.00 26.11           P  \\nATOM   1836  OP1  DT I  91      15.635 100.164  -0.866  1.00 26.11           O  \\nATOM   1837  OP2  DT I  91      14.809  98.647  -2.786  1.00 26.11           O  \\nATOM   1838  O5'  DT I  91      13.203  99.772  -1.264  1.00 34.41           O  \\nATOM   1839  C5'  DT I  91      12.710 100.852  -0.488  1.00 34.41           C  \\nATOM   1840  C4'  DT I  91      11.361 100.501   0.081  1.00 34.41           C  \\nATOM   1841  O4'  DT I  91      10.384 100.481  -0.993  1.00 34.41           O  \\nATOM   1842  C3'  DT I  91      11.323  99.119   0.729  1.00 34.41           C  \\nATOM   1843  O3'  DT I  91      10.624  99.193   1.970  1.00 34.41           O  \\nATOM   1844  C2'  DT I  91      10.590  98.252  -0.287  1.00 34.41           C  \\nATOM   1845  C1'  DT I  91       9.672  99.249  -0.982  1.00 34.41           C  \\nATOM   1846  N1   DT I  91       9.283  98.926  -2.382  1.00 39.57           N  \\nATOM   1847  C2   DT I  91       8.001  99.261  -2.789  1.00 39.57           C  \\nATOM   1848  O2   DT I  91       7.190  99.807  -2.058  1.00 39.57           O  \\nATOM   1849  N3   DT I  91       7.703  98.938  -4.095  1.00 39.57           N  \\nATOM   1850  C4   DT I  91       8.546  98.345  -5.024  1.00 39.57           C  \\nATOM   1851  O4   DT I  91       8.149  98.140  -6.173  1.00 39.57           O  \\nATOM   1852  C5   DT I  91       9.872  98.016  -4.532  1.00 39.57           C  \\nATOM   1853  C7   DT I  91      10.847  97.367  -5.464  1.00 39.57           C  \\nATOM   1854  C6   DT I  91      10.168  98.316  -3.251  1.00 39.57           C  \\nATOM   1855  P    DT I  92      10.435  97.870   2.867  1.00 56.01           P  \\nATOM   1856  OP1  DT I  92      10.436  98.293   4.289  1.00 56.01           O  \\nATOM   1857  OP2  DT I  92      11.402  96.843   2.412  1.00 56.01           O  \\nATOM   1858  O5'  DT I  92       8.969  97.396   2.466  1.00 51.56           O  \\nATOM   1859  C5'  DT I  92       7.902  98.350   2.415  1.00 51.56           C  \\nATOM   1860  C4'  DT I  92       6.579  97.668   2.152  1.00 51.56           C  \\nATOM   1861  O4'  DT I  92       6.307  97.570   0.733  1.00 51.56           O  \\nATOM   1862  C3'  DT I  92       6.437  96.259   2.732  1.00 51.56           C  \\nATOM   1863  O3'  DT I  92       5.198  96.151   3.440  1.00 51.56           O  \\nATOM   1864  C2'  DT I  92       6.474  95.363   1.504  1.00 51.56           C  \\nATOM   1865  C1'  DT I  92       5.896  96.255   0.415  1.00 51.56           C  \\nATOM   1866  N1   DT I  92       6.369  95.956  -0.952  1.00 55.43           N  \\nATOM   1867  C2   DT I  92       5.462  96.063  -1.987  1.00 55.43           C  \\nATOM   1868  O2   DT I  92       4.295  96.367  -1.818  1.00 55.43           O  \\nATOM   1869  N3   DT I  92       5.976  95.798  -3.234  1.00 55.43           N  \\nATOM   1870  C4   DT I  92       7.274  95.443  -3.540  1.00 55.43           C  \\nATOM   1871  O4   DT I  92       7.593  95.262  -4.706  1.00 55.43           O  \\nATOM   1872  C5   DT I  92       8.165  95.325  -2.410  1.00 55.43           C  \\nATOM   1873  C7   DT I  92       9.581  94.919  -2.649  1.00 55.43           C  \\nATOM   1874  C6   DT I  92       7.679  95.587  -1.188  1.00 55.43           C  \\nATOM   1875  P    DT I  93       4.876  94.836   4.313  1.00 75.42           P  \\nATOM   1876  OP1  DT I  93       4.276  95.298   5.592  1.00 75.42           O  \\nATOM   1877  OP2  DT I  93       6.035  93.898   4.338  1.00 75.42           O  \\nATOM   1878  O5'  DT I  93       3.730  94.160   3.453  1.00111.96           O  \\nATOM   1879  C5'  DT I  93       2.538  94.882   3.166  1.00111.96           C  \\nATOM   1880  C4'  DT I  93       1.575  93.998   2.418  1.00111.96           C  \\nATOM   1881  O4'  DT I  93       1.965  93.943   1.029  1.00111.96           O  \\nATOM   1882  C3'  DT I  93       1.587  92.557   2.926  1.00111.96           C  \\nATOM   1883  O3'  DT I  93       0.266  92.013   2.936  1.00111.96           O  \\nATOM   1884  C2'  DT I  93       2.492  91.843   1.939  1.00111.96           C  \\nATOM   1885  C1'  DT I  93       2.222  92.602   0.655  1.00111.96           C  \\nATOM   1886  N1   DT I  93       3.334  92.617  -0.303  1.00 75.69           N  \\nATOM   1887  C2   DT I  93       3.015  92.729  -1.633  1.00 75.69           C  \\nATOM   1888  O2   DT I  93       1.867  92.843  -2.031  1.00 75.69           O  \\nATOM   1889  N3   DT I  93       4.091  92.715  -2.488  1.00 75.69           N  \\nATOM   1890  C4   DT I  93       5.424  92.624  -2.147  1.00 75.69           C  \\nATOM   1891  O4   DT I  93       6.279  92.622  -3.033  1.00 75.69           O  \\nATOM   1892  C5   DT I  93       5.686  92.533  -0.721  1.00 75.69           C  \\nATOM   1893  C7   DT I  93       7.098  92.462  -0.242  1.00 75.69           C  \\nATOM   1894  C6   DT I  93       4.640  92.524   0.116  1.00 75.69           C  \\nATOM   1895  P    DG I  94       0.011  90.558   3.565  1.00120.46           P  \\nATOM   1896  OP1  DG I  94      -1.279  90.595   4.301  1.00120.46           O  \\nATOM   1897  OP2  DG I  94       1.244  90.119   4.267  1.00120.46           O  \\nATOM   1898  O5'  DG I  94      -0.151  89.643   2.276  1.00 81.48           O  \\nATOM   1899  C5'  DG I  94       0.326  90.080   1.008  1.00 81.48           C  \\nATOM   1900  C4'  DG I  94      -0.381  89.325  -0.088  1.00 81.48           C  \\nATOM   1901  O4'  DG I  94       0.259  89.622  -1.354  1.00 81.48           O  \\nATOM   1902  C3'  DG I  94      -0.249  87.818   0.110  1.00 81.48           C  \\nATOM   1903  O3'  DG I  94      -1.427  87.128  -0.310  1.00 81.48           O  \\nATOM   1904  C2'  DG I  94       0.941  87.447  -0.743  1.00 81.48           C  \\nATOM   1905  C1'  DG I  94       0.891  88.459  -1.873  1.00 81.48           C  \\nATOM   1906  N9   DG I  94       2.248  88.811  -2.271  1.00 71.31           N  \\nATOM   1907  C8   DG I  94       3.299  89.068  -1.424  1.00 71.31           C  \\nATOM   1908  N7   DG I  94       4.425  89.260  -2.050  1.00 71.31           N  \\nATOM   1909  C5   DG I  94       4.094  89.149  -3.396  1.00 71.31           C  \\nATOM   1910  C6   DG I  94       4.907  89.253  -4.550  1.00 71.31           C  \\nATOM   1911  O6   DG I  94       6.119  89.486  -4.620  1.00 71.31           O  \\nATOM   1912  N1   DG I  94       4.172  89.057  -5.712  1.00 71.31           N  \\nATOM   1913  C2   DG I  94       2.831  88.807  -5.763  1.00 71.31           C  \\nATOM   1914  N2   DG I  94       2.325  88.656  -6.996  1.00 71.31           N  \\nATOM   1915  N3   DG I  94       2.055  88.713  -4.694  1.00 71.31           N  \\nATOM   1916  C4   DG I  94       2.750  88.890  -3.551  1.00 71.31           C  \\nATOM   1917  P    DA I  95      -1.471  85.520  -0.247  1.00132.32           P  \\nATOM   1918  OP1  DA I  95      -2.854  85.084   0.060  1.00132.32           O  \\nATOM   1919  OP2  DA I  95      -0.345  85.042   0.602  1.00132.32           O  \\nATOM   1920  O5'  DA I  95      -1.162  85.109  -1.747  1.00 84.29           O  \\nATOM   1921  C5'  DA I  95      -1.888  85.688  -2.821  1.00 84.29           C  \\nATOM   1922  C4'  DA I  95      -1.401  85.090  -4.113  1.00 84.29           C  \\nATOM   1923  O4'  DA I  95      -0.123  85.678  -4.475  1.00 84.29           O  \\nATOM   1924  C3'  DA I  95      -1.141  83.595  -3.933  1.00 84.29           C  \\nATOM   1925  O3'  DA I  95      -1.495  82.879  -5.118  1.00 84.29           O  \\nATOM   1926  C2'  DA I  95       0.355  83.535  -3.696  1.00 84.29           C  \\nATOM   1927  C1'  DA I  95       0.828  84.638  -4.619  1.00 84.29           C  \\nATOM   1928  N9   DA I  95       2.172  85.149  -4.326  1.00 77.14           N  \\nATOM   1929  C8   DA I  95       2.740  85.475  -3.111  1.00 77.14           C  \\nATOM   1930  N7   DA I  95       4.011  85.799  -3.191  1.00 77.14           N  \\nATOM   1931  C5   DA I  95       4.294  85.701  -4.551  1.00 77.14           C  \\nATOM   1932  C6   DA I  95       5.476  85.896  -5.290  1.00 77.14           C  \\nATOM   1933  N6   DA I  95       6.644  86.229  -4.736  1.00 77.14           N  \\nATOM   1934  N1   DA I  95       5.414  85.725  -6.633  1.00 77.14           N  \\nATOM   1935  C2   DA I  95       4.243  85.373  -7.184  1.00 77.14           C  \\nATOM   1936  N3   DA I  95       3.071  85.151  -6.597  1.00 77.14           N  \\nATOM   1937  C4   DA I  95       3.164  85.331  -5.264  1.00 77.14           C  \\nATOM   1938  P    DT I  96      -1.428  81.272  -5.135  1.00104.59           P  \\nATOM   1939  OP1  DT I  96      -2.802  80.760  -5.371  1.00104.59           O  \\nATOM   1940  OP2  DT I  96      -0.661  80.788  -3.951  1.00104.59           O  \\nATOM   1941  O5'  DT I  96      -0.562  80.998  -6.438  1.00132.20           O  \\nATOM   1942  C5'  DT I  96      -0.799  81.741  -7.634  1.00132.20           C  \\nATOM   1943  C4'  DT I  96       0.211  81.349  -8.682  1.00132.20           C  \\nATOM   1944  O4'  DT I  96       1.471  82.028  -8.431  1.00132.20           O  \\nATOM   1945  C3'  DT I  96       0.510  79.849  -8.638  1.00132.20           C  \\nATOM   1946  O3'  DT I  96       0.606  79.284  -9.943  1.00132.20           O  \\nATOM   1947  C2'  DT I  96       1.856  79.776  -7.947  1.00132.20           C  \\nATOM   1948  C1'  DT I  96       2.511  81.066  -8.405  1.00132.20           C  \\nATOM   1949  N1   DT I  96       3.579  81.524  -7.495  1.00 58.49           N  \\nATOM   1950  C2   DT I  96       4.736  82.044  -8.049  1.00 58.49           C  \\nATOM   1951  O2   DT I  96       4.869  82.274  -9.243  1.00 58.49           O  \\nATOM   1952  N3   DT I  96       5.734  82.295  -7.141  1.00 58.49           N  \\nATOM   1953  C4   DT I  96       5.684  82.121  -5.766  1.00 58.49           C  \\nATOM   1954  O4   DT I  96       6.680  82.362  -5.088  1.00 58.49           O  \\nATOM   1955  C5   DT I  96       4.415  81.644  -5.245  1.00 58.49           C  \\nATOM   1956  C7   DT I  96       4.250  81.469  -3.765  1.00 58.49           C  \\nATOM   1957  C6   DT I  96       3.440  81.377  -6.126  1.00 58.49           C  \\nATOM   1958  P    DG I  97       0.627  77.685 -10.114  1.00104.02           P  \\nATOM   1959  OP1  DG I  97      -0.664  77.258 -10.708  1.00104.02           O  \\nATOM   1960  OP2  DG I  97       1.076  77.086  -8.827  1.00104.02           O  \\nATOM   1961  O5'  DG I  97       1.763  77.454 -11.202  1.00104.90           O  \\nATOM   1962  C5'  DG I  97       2.036  78.445 -12.192  1.00104.90           C  \\nATOM   1963  C4'  DG I  97       3.504  78.429 -12.544  1.00104.90           C  \\nATOM   1964  O4'  DG I  97       4.300  78.965 -11.458  1.00104.90           O  \\nATOM   1965  C3'  DG I  97       4.045  77.026 -12.807  1.00104.90           C  \\nATOM   1966  O3'  DG I  97       5.007  77.085 -13.857  1.00104.90           O  \\nATOM   1967  C2'  DG I  97       4.716  76.662 -11.497  1.00104.90           C  \\nATOM   1968  C1'  DG I  97       5.267  78.004 -11.057  1.00104.90           C  \\nATOM   1969  N9   DG I  97       5.474  78.137  -9.619  1.00 65.16           N  \\nATOM   1970  C8   DG I  97       4.666  77.661  -8.613  1.00 65.16           C  \\nATOM   1971  N7   DG I  97       5.116  77.940  -7.419  1.00 65.16           N  \\nATOM   1972  C5   DG I  97       6.292  78.643  -7.652  1.00 65.16           C  \\nATOM   1973  C6   DG I  97       7.220  79.211  -6.743  1.00 65.16           C  \\nATOM   1974  O6   DG I  97       7.184  79.222  -5.516  1.00 65.16           O  \\nATOM   1975  N1   DG I  97       8.276  79.818  -7.401  1.00 65.16           N  \\nATOM   1976  C2   DG I  97       8.422  79.884  -8.756  1.00 65.16           C  \\nATOM   1977  N2   DG I  97       9.532  80.505  -9.183  1.00 65.16           N  \\nATOM   1978  N3   DG I  97       7.560  79.378  -9.621  1.00 65.16           N  \\nATOM   1979  C4   DG I  97       6.527  78.770  -9.003  1.00 65.16           C  \\nATOM   1980  P    DG I  98       5.498  75.729 -14.566  1.00 71.67           P  \\nATOM   1981  OP1  DG I  98       5.522  75.981 -16.036  1.00 71.67           O  \\nATOM   1982  OP2  DG I  98       4.702  74.591 -14.008  1.00 71.67           O  \\nATOM   1983  O5'  DG I  98       6.997  75.553 -14.050  1.00 69.98           O  \\nATOM   1984  C5'  DG I  98       7.989  76.567 -14.265  1.00 69.98           C  \\nATOM   1985  C4'  DG I  98       9.208  76.299 -13.410  1.00 69.98           C  \\nATOM   1986  O4'  DG I  98       8.964  76.633 -12.021  1.00 69.98           O  \\nATOM   1987  C3'  DG I  98       9.674  74.845 -13.412  1.00 69.98           C  \\nATOM   1988  O3'  DG I  98      11.090  74.813 -13.412  1.00 69.98           O  \\nATOM   1989  C2'  DG I  98       9.165  74.311 -12.086  1.00 69.98           C  \\nATOM   1990  C1'  DG I  98       9.316  75.529 -11.207  1.00 69.98           C  \\nATOM   1991  N9   DG I  98       8.459  75.544 -10.031  1.00 84.48           N  \\nATOM   1992  C8   DG I  98       7.140  75.169  -9.946  1.00 84.48           C  \\nATOM   1993  N7   DG I  98       6.643  75.310  -8.747  1.00 84.48           N  \\nATOM   1994  C5   DG I  98       7.701  75.805  -7.997  1.00 84.48           C  \\nATOM   1995  C6   DG I  98       7.769  76.163  -6.621  1.00 84.48           C  \\nATOM   1996  O6   DG I  98       6.872  76.110  -5.760  1.00 84.48           O  \\nATOM   1997  N1   DG I  98       9.039  76.625  -6.280  1.00 84.48           N  \\nATOM   1998  C2   DG I  98      10.098  76.727  -7.147  1.00 84.48           C  \\nATOM   1999  N2   DG I  98      11.225  77.183  -6.622  1.00 84.48           N  \\nATOM   2000  N3   DG I  98      10.049  76.400  -8.424  1.00 84.48           N  \\nATOM   2001  C4   DG I  98       8.829  75.951  -8.778  1.00 84.48           C  \\nATOM   2002  P    DA I  99      11.852  73.888 -14.462  1.00 84.90           P  \\nATOM   2003  OP1  DA I  99      11.268  74.125 -15.802  1.00 84.90           O  \\nATOM   2004  OP2  DA I  99      11.886  72.511 -13.896  1.00 84.90           O  \\nATOM   2005  O5'  DA I  99      13.313  74.503 -14.470  1.00108.09           O  \\nATOM   2006  C5'  DA I  99      13.494  75.908 -14.583  1.00108.09           C  \\nATOM   2007  C4'  DA I  99      14.323  76.412 -13.428  1.00108.09           C  \\nATOM   2008  O4'  DA I  99      13.586  76.232 -12.193  1.00108.09           O  \\nATOM   2009  C3'  DA I  99      15.648  75.673 -13.247  1.00108.09           C  \\nATOM   2010  O3'  DA I  99      16.674  76.613 -12.912  1.00108.09           O  \\nATOM   2011  C2'  DA I  99      15.362  74.700 -12.115  1.00108.09           C  \\nATOM   2012  C1'  DA I  99      14.331  75.441 -11.280  1.00108.09           C  \\nATOM   2013  N9   DA I  99      13.389  74.573 -10.573  1.00 48.72           N  \\nATOM   2014  C8   DA I  99      12.630  73.551 -11.096  1.00 48.72           C  \\nATOM   2015  N7   DA I  99      11.866  72.948 -10.210  1.00 48.72           N  \\nATOM   2016  C5   DA I  99      12.142  73.620  -9.022  1.00 48.72           C  \\nATOM   2017  C6   DA I  99      11.662  73.461  -7.703  1.00 48.72           C  \\nATOM   2018  N6   DA I  99      10.750  72.556  -7.347  1.00 48.72           N  \\nATOM   2019  N1   DA I  99      12.160  74.281  -6.750  1.00 48.72           N  \\nATOM   2020  C2   DA I  99      13.057  75.200  -7.104  1.00 48.72           C  \\nATOM   2021  N3   DA I  99      13.576  75.458  -8.302  1.00 48.72           N  \\nATOM   2022  C4   DA I  99      13.078  74.621  -9.231  1.00 48.72           C  \\nATOM   2023  P    DG I 100      18.215  76.157 -12.906  1.00100.05           P  \\nATOM   2024  OP1  DG I 100      19.036  77.313 -13.366  1.00100.05           O  \\nATOM   2025  OP2  DG I 100      18.316  74.855 -13.616  1.00100.05           O  \\nATOM   2026  O5'  DG I 100      18.492  75.903 -11.359  1.00 37.80           O  \\nATOM   2027  C5'  DG I 100      17.420  75.524 -10.513  1.00 37.80           C  \\nATOM   2028  C4'  DG I 100      17.928  75.184  -9.140  1.00 37.80           C  \\nATOM   2029  O4'  DG I 100      16.938  74.312  -8.557  1.00 37.80           O  \\nATOM   2030  C3'  DG I 100      19.217  74.370  -9.151  1.00 37.80           C  \\nATOM   2031  O3'  DG I 100      19.807  74.498  -7.857  1.00 37.80           O  \\nATOM   2032  C2'  DG I 100      18.708  72.956  -9.345  1.00 37.80           C  \\nATOM   2033  C1'  DG I 100      17.449  72.979  -8.491  1.00 37.80           C  \\nATOM   2034  N9   DG I 100      16.384  72.056  -8.891  1.00 72.12           N  \\nATOM   2035  C8   DG I 100      16.226  71.402 -10.096  1.00 72.12           C  \\nATOM   2036  N7   DG I 100      15.165  70.638 -10.129  1.00 72.12           N  \\nATOM   2037  C5   DG I 100      14.592  70.799  -8.874  1.00 72.12           C  \\nATOM   2038  C6   DG I 100      13.421  70.232  -8.317  1.00 72.12           C  \\nATOM   2039  O6   DG I 100      12.617  69.443  -8.838  1.00 72.12           O  \\nATOM   2040  N1   DG I 100      13.214  70.677  -7.014  1.00 72.12           N  \\nATOM   2041  C2   DG I 100      14.027  71.557  -6.340  1.00 72.12           C  \\nATOM   2042  N2   DG I 100      13.651  71.878  -5.100  1.00 72.12           N  \\nATOM   2043  N3   DG I 100      15.113  72.084  -6.845  1.00 72.12           N  \\nATOM   2044  C4   DG I 100      15.335  71.670  -8.104  1.00 72.12           C  \\nATOM   2045  P    DC I 101      21.396  74.603  -7.693  1.00 34.39           P  \\nATOM   2046  OP1  DC I 101      21.913  75.752  -8.455  1.00 34.39           O  \\nATOM   2047  OP2  DC I 101      21.976  73.265  -7.899  1.00 34.39           O  \\nATOM   2048  O5'  DC I 101      21.574  74.952  -6.165  1.00 47.73           O  \\nATOM   2049  C5'  DC I 101      21.884  73.926  -5.264  1.00 47.73           C  \\nATOM   2050  C4'  DC I 101      20.850  73.871  -4.173  1.00 47.73           C  \\nATOM   2051  O4'  DC I 101      19.600  73.361  -4.697  1.00 47.73           O  \\nATOM   2052  C3'  DC I 101      21.281  72.914  -3.076  1.00 47.73           C  \\nATOM   2053  O3'  DC I 101      21.055  73.516  -1.812  1.00 47.73           O  \\nATOM   2054  C2'  DC I 101      20.479  71.647  -3.336  1.00 47.73           C  \\nATOM   2055  C1'  DC I 101      19.242  72.138  -4.072  1.00 47.73           C  \\nATOM   2056  N1   DC I 101      18.733  71.222  -5.123  1.00 41.45           N  \\nATOM   2057  C2   DC I 101      17.621  70.418  -4.827  1.00 41.45           C  \\nATOM   2058  O2   DC I 101      17.124  70.474  -3.690  1.00 41.45           O  \\nATOM   2059  N3   DC I 101      17.115  69.595  -5.787  1.00 41.45           N  \\nATOM   2060  C4   DC I 101      17.678  69.554  -6.997  1.00 41.45           C  \\nATOM   2061  N4   DC I 101      17.120  68.748  -7.917  1.00 41.45           N  \\nATOM   2062  C5   DC I 101      18.829  70.342  -7.320  1.00 41.45           C  \\nATOM   2063  C6   DC I 101      19.317  71.157  -6.361  1.00 41.45           C  \\nATOM   2064  P    DA I 102      21.849  72.970  -0.540  1.00 96.48           P  \\nATOM   2065  OP1  DA I 102      21.695  73.955   0.564  1.00 96.48           O  \\nATOM   2066  OP2  DA I 102      23.206  72.541  -0.977  1.00 96.48           O  \\nATOM   2067  O5'  DA I 102      21.013  71.673  -0.179  1.00 92.71           O  \\nATOM   2068  C5'  DA I 102      19.636  71.794   0.150  1.00 92.71           C  \\nATOM   2069  C4'  DA I 102      19.036  70.432   0.384  1.00 92.71           C  \\nATOM   2070  O4'  DA I 102      18.707  69.807  -0.874  1.00 92.71           O  \\nATOM   2071  C3'  DA I 102      19.960  69.463   1.122  1.00 92.71           C  \\nATOM   2072  O3'  DA I 102      19.194  68.767   2.104  1.00 92.71           O  \\nATOM   2073  C2'  DA I 102      20.441  68.536   0.018  1.00 92.71           C  \\nATOM   2074  C1'  DA I 102      19.224  68.498  -0.878  1.00 92.71           C  \\nATOM   2075  N9   DA I 102      19.469  68.128  -2.262  1.00 56.56           N  \\nATOM   2076  C8   DA I 102      20.529  68.442  -3.073  1.00 56.56           C  \\nATOM   2077  N7   DA I 102      20.433  67.946  -4.288  1.00 56.56           N  \\nATOM   2078  C5   DA I 102      19.221  67.260  -4.271  1.00 56.56           C  \\nATOM   2079  C6   DA I 102      18.527  66.506  -5.256  1.00 56.56           C  \\nATOM   2080  N6   DA I 102      18.967  66.319  -6.509  1.00 56.56           N  \\nATOM   2081  N1   DA I 102      17.348  65.947  -4.897  1.00 56.56           N  \\nATOM   2082  C2   DA I 102      16.897  66.138  -3.644  1.00 56.56           C  \\nATOM   2083  N3   DA I 102      17.448  66.823  -2.643  1.00 56.56           N  \\nATOM   2084  C4   DA I 102      18.621  67.363  -3.025  1.00 56.56           C  \\nATOM   2085  P    DG I 103      19.907  67.736   3.108  1.00 65.02           P  \\nATOM   2086  OP1  DG I 103      20.317  68.428   4.360  1.00 65.02           O  \\nATOM   2087  OP2  DG I 103      20.908  66.935   2.335  1.00 65.02           O  \\nATOM   2088  O5'  DG I 103      18.690  66.794   3.494  1.00 82.77           O  \\nATOM   2089  C5'  DG I 103      18.903  65.420   3.693  1.00 82.77           C  \\nATOM   2090  C4'  DG I 103      17.812  64.618   3.035  1.00 82.77           C  \\nATOM   2091  O4'  DG I 103      17.777  64.854   1.604  1.00 82.77           O  \\nATOM   2092  C3'  DG I 103      18.108  63.139   3.211  1.00 82.77           C  \\nATOM   2093  O3'  DG I 103      16.956  62.448   3.641  1.00 82.77           O  \\nATOM   2094  C2'  DG I 103      18.577  62.675   1.847  1.00 82.77           C  \\nATOM   2095  C1'  DG I 103      17.867  63.620   0.909  1.00 82.77           C  \\nATOM   2096  N9   DG I 103      18.614  63.835  -0.326  1.00 67.50           N  \\nATOM   2097  C8   DG I 103      19.733  64.609  -0.502  1.00 67.50           C  \\nATOM   2098  N7   DG I 103      20.198  64.569  -1.723  1.00 67.50           N  \\nATOM   2099  C5   DG I 103      19.327  63.726  -2.394  1.00 67.50           C  \\nATOM   2100  C6   DG I 103      19.315  63.301  -3.753  1.00 67.50           C  \\nATOM   2101  O6   DG I 103      20.093  63.596  -4.667  1.00 67.50           O  \\nATOM   2102  N1   DG I 103      18.253  62.446  -4.009  1.00 67.50           N  \\nATOM   2103  C2   DG I 103      17.318  62.049  -3.081  1.00 67.50           C  \\nATOM   2104  N2   DG I 103      16.370  61.213  -3.531  1.00 67.50           N  \\nATOM   2105  N3   DG I 103      17.314  62.439  -1.816  1.00 67.50           N  \\nATOM   2106  C4   DG I 103      18.340  63.270  -1.545  1.00 67.50           C  \\nATOM   2107  P    DT I 104      17.141  61.102   4.473  1.00 88.97           P  \\nATOM   2108  OP1  DT I 104      15.887  60.843   5.230  1.00 88.97           O  \\nATOM   2109  OP2  DT I 104      18.431  61.246   5.201  1.00 88.97           O  \\nATOM   2110  O5'  DT I 104      17.321  60.021   3.323  1.00 95.25           O  \\nATOM   2111  C5'  DT I 104      16.308  59.851   2.336  1.00 95.25           C  \\nATOM   2112  C4'  DT I 104      16.630  58.669   1.455  1.00 95.25           C  \\nATOM   2113  O4'  DT I 104      17.213  59.083   0.197  1.00 95.25           O  \\nATOM   2114  C3'  DT I 104      17.612  57.682   2.083  1.00 95.25           C  \\nATOM   2115  O3'  DT I 104      17.169  56.350   1.829  1.00 95.25           O  \\nATOM   2116  C2'  DT I 104      18.910  57.976   1.351  1.00 95.25           C  \\nATOM   2117  C1'  DT I 104      18.401  58.352  -0.026  1.00 95.25           C  \\nATOM   2118  N1   DT I 104      19.306  59.186  -0.829  1.00 71.00           N  \\nATOM   2119  C2   DT I 104      19.269  59.020  -2.191  1.00 71.00           C  \\nATOM   2120  O2   DT I 104      18.508  58.246  -2.742  1.00 71.00           O  \\nATOM   2121  N3   DT I 104      20.155  59.805  -2.893  1.00 71.00           N  \\nATOM   2122  C4   DT I 104      21.040  60.734  -2.376  1.00 71.00           C  \\nATOM   2123  O4   DT I 104      21.769  61.369  -3.135  1.00 71.00           O  \\nATOM   2124  C5   DT I 104      21.013  60.871  -0.936  1.00 71.00           C  \\nATOM   2125  C7   DT I 104      21.921  61.864  -0.286  1.00 71.00           C  \\nATOM   2126  C6   DT I 104      20.162  60.095  -0.242  1.00 71.00           C  \\nATOM   2127  P    DT I 105      17.884  55.115   2.560  1.00104.52           P  \\nATOM   2128  OP1  DT I 105      16.904  54.585   3.536  1.00104.52           O  \\nATOM   2129  OP2  DT I 105      19.236  55.516   3.028  1.00104.52           O  \\nATOM   2130  O5'  DT I 105      18.053  54.094   1.354  1.00104.76           O  \\nATOM   2131  C5'  DT I 105      17.147  54.141   0.257  1.00104.76           C  \\nATOM   2132  C4'  DT I 105      17.816  53.662  -1.009  1.00104.76           C  \\nATOM   2133  O4'  DT I 105      18.655  54.686  -1.599  1.00104.76           O  \\nATOM   2134  C3'  DT I 105      18.694  52.421  -0.853  1.00104.76           C  \\nATOM   2135  O3'  DT I 105      18.391  51.501  -1.907  1.00104.76           O  \\nATOM   2136  C2'  DT I 105      20.109  52.969  -0.975  1.00104.76           C  \\nATOM   2137  C1'  DT I 105      19.912  54.120  -1.945  1.00104.76           C  \\nATOM   2138  N1   DT I 105      20.932  55.199  -1.915  1.00 78.32           N  \\nATOM   2139  C2   DT I 105      21.529  55.555  -3.110  1.00 78.32           C  \\nATOM   2140  O2   DT I 105      21.303  54.985  -4.165  1.00 78.32           O  \\nATOM   2141  N3   DT I 105      22.414  56.607  -3.021  1.00 78.32           N  \\nATOM   2142  C4   DT I 105      22.764  57.314  -1.882  1.00 78.32           C  \\nATOM   2143  O4   DT I 105      23.558  58.251  -1.961  1.00 78.32           O  \\nATOM   2144  C5   DT I 105      22.128  56.868  -0.662  1.00 78.32           C  \\nATOM   2145  C7   DT I 105      22.462  57.564   0.620  1.00 78.32           C  \\nATOM   2146  C6   DT I 105      21.257  55.845  -0.737  1.00 78.32           C  \\nATOM   2147  P    DT I 106      19.158  50.095  -1.983  1.00113.89           P  \\nATOM   2148  OP1  DT I 106      18.239  49.091  -2.584  1.00113.89           O  \\nATOM   2149  OP2  DT I 106      19.786  49.825  -0.663  1.00113.89           O  \\nATOM   2150  O5'  DT I 106      20.317  50.401  -3.021  1.00133.78           O  \\nATOM   2151  C5'  DT I 106      20.032  51.030  -4.264  1.00133.78           C  \\nATOM   2152  C4'  DT I 106      21.288  51.073  -5.093  1.00133.78           C  \\nATOM   2153  O4'  DT I 106      22.066  52.256  -4.775  1.00133.78           O  \\nATOM   2154  C3'  DT I 106      22.177  49.872  -4.777  1.00133.78           C  \\nATOM   2155  O3'  DT I 106      22.701  49.292  -5.963  1.00133.78           O  \\nATOM   2156  C2'  DT I 106      23.283  50.456  -3.914  1.00133.78           C  \\nATOM   2157  C1'  DT I 106      23.394  51.869  -4.457  1.00133.78           C  \\nATOM   2158  N1   DT I 106      23.983  52.875  -3.528  1.00 93.55           N  \\nATOM   2159  C2   DT I 106      24.672  53.937  -4.084  1.00 93.55           C  \\nATOM   2160  O2   DT I 106      24.773  54.115  -5.287  1.00 93.55           O  \\nATOM   2161  N3   DT I 106      25.236  54.795  -3.175  1.00 93.55           N  \\nATOM   2162  C4   DT I 106      25.170  54.721  -1.797  1.00 93.55           C  \\nATOM   2163  O4   DT I 106      25.732  55.577  -1.114  1.00 93.55           O  \\nATOM   2164  C5   DT I 106      24.414  53.597  -1.276  1.00 93.55           C  \\nATOM   2165  C7   DT I 106      24.280  53.438   0.205  1.00 93.55           C  \\nATOM   2166  C6   DT I 106      23.865  52.743  -2.155  1.00 93.55           C  \\nATOM   2167  P    DC I 107      22.762  47.696  -6.095  1.00101.03           P  \\nATOM   2168  OP1  DC I 107      21.557  47.238  -6.823  1.00101.03           O  \\nATOM   2169  OP2  DC I 107      23.064  47.143  -4.747  1.00101.03           O  \\nATOM   2170  O5'  DC I 107      24.029  47.472  -7.022  1.00 84.59           O  \\nATOM   2171  C5'  DC I 107      25.324  47.817  -6.550  1.00 84.59           C  \\nATOM   2172  C4'  DC I 107      26.021  48.713  -7.545  1.00 84.59           C  \\nATOM   2173  O4'  DC I 107      26.041  50.055  -7.009  1.00 84.59           O  \\nATOM   2174  C3'  DC I 107      27.478  48.314  -7.760  1.00 84.59           C  \\nATOM   2175  O3'  DC I 107      27.883  48.464  -9.119  1.00 84.59           O  \\nATOM   2176  C2'  DC I 107      28.259  49.213  -6.822  1.00 84.59           C  \\nATOM   2177  C1'  DC I 107      27.352  50.414  -6.582  1.00 84.59           C  \\nATOM   2178  N1   DC I 107      27.277  50.766  -5.152  1.00 73.55           N  \\nATOM   2179  C2   DC I 107      27.837  51.967  -4.728  1.00 73.55           C  \\nATOM   2180  O2   DC I 107      28.382  52.698  -5.567  1.00 73.55           O  \\nATOM   2181  N3   DC I 107      27.779  52.303  -3.414  1.00 73.55           N  \\nATOM   2182  C4   DC I 107      27.190  51.482  -2.541  1.00 73.55           C  \\nATOM   2183  N4   DC I 107      27.150  51.856  -1.255  1.00 73.55           N  \\nATOM   2184  C5   DC I 107      26.613  50.242  -2.946  1.00 73.55           C  \\nATOM   2185  C6   DC I 107      26.675  49.928  -4.249  1.00 73.55           C  \\nATOM   2186  P    DC I 108      28.822  47.343  -9.783  1.00115.61           P  \\nATOM   2187  OP1  DC I 108      28.146  46.795 -10.987  1.00115.61           O  \\nATOM   2188  OP2  DC I 108      29.251  46.425  -8.693  1.00115.61           O  \\nATOM   2189  O5'  DC I 108      30.097  48.157 -10.267  1.00 79.75           O  \\nATOM   2190  C5'  DC I 108      29.945  49.365 -11.009  1.00 79.75           C  \\nATOM   2191  C4'  DC I 108      31.107  50.291 -10.739  1.00 79.75           C  \\nATOM   2192  O4'  DC I 108      31.072  50.761  -9.372  1.00 79.75           O  \\nATOM   2193  C3'  DC I 108      32.483  49.657 -10.916  1.00 79.75           C  \\nATOM   2194  O3'  DC I 108      33.354  50.686 -11.348  1.00 79.75           O  \\nATOM   2195  C2'  DC I 108      32.865  49.271  -9.500  1.00 79.75           C  \\nATOM   2196  C1'  DC I 108      32.303  50.453  -8.742  1.00 79.75           C  \\nATOM   2197  N1   DC I 108      32.038  50.245  -7.317  1.00 69.94           N  \\nATOM   2198  C2   DC I 108      31.990  51.364  -6.484  1.00 69.94           C  \\nATOM   2199  O2   DC I 108      32.179  52.492  -6.975  1.00 69.94           O  \\nATOM   2200  N3   DC I 108      31.745  51.199  -5.169  1.00 69.94           N  \\nATOM   2201  C4   DC I 108      31.553  49.978  -4.677  1.00 69.94           C  \\nATOM   2202  N4   DC I 108      31.315  49.869  -3.369  1.00 69.94           N  \\nATOM   2203  C5   DC I 108      31.599  48.817  -5.502  1.00 69.94           C  \\nATOM   2204  C6   DC I 108      31.839  48.996  -6.807  1.00 69.94           C  \\nATOM   2205  P    DA I 109      34.309  50.451 -12.604  1.00 87.07           P  \\nATOM   2206  OP1  DA I 109      33.495  50.490 -13.849  1.00 87.07           O  \\nATOM   2207  OP2  DA I 109      35.125  49.252 -12.290  1.00 87.07           O  \\nATOM   2208  O5'  DA I 109      35.250  51.735 -12.556  1.00 74.61           O  \\nATOM   2209  C5'  DA I 109      34.689  53.051 -12.502  1.00 74.61           C  \\nATOM   2210  C4'  DA I 109      35.498  53.943 -11.585  1.00 74.61           C  \\nATOM   2211  O4'  DA I 109      35.234  53.636 -10.198  1.00 74.61           O  \\nATOM   2212  C3'  DA I 109      37.014  53.862 -11.759  1.00 74.61           C  \\nATOM   2213  O3'  DA I 109      37.601  55.161 -11.661  1.00 74.61           O  \\nATOM   2214  C2'  DA I 109      37.456  52.989 -10.602  1.00 74.61           C  \\nATOM   2215  C1'  DA I 109      36.437  53.305  -9.528  1.00 74.61           C  \\nATOM   2216  N9   DA I 109      36.151  52.143  -8.707  1.00 61.81           N  \\nATOM   2217  C8   DA I 109      36.103  50.838  -9.122  1.00 61.81           C  \\nATOM   2218  N7   DA I 109      35.786  49.996  -8.173  1.00 61.81           N  \\nATOM   2219  C5   DA I 109      35.621  50.803  -7.054  1.00 61.81           C  \\nATOM   2220  C6   DA I 109      35.268  50.514  -5.722  1.00 61.81           C  \\nATOM   2221  N6   DA I 109      35.001  49.279  -5.282  1.00 61.81           N  \\nATOM   2222  N1   DA I 109      35.193  51.548  -4.855  1.00 61.81           N  \\nATOM   2223  C2   DA I 109      35.451  52.783  -5.306  1.00 61.81           C  \\nATOM   2224  N3   DA I 109      35.786  53.181  -6.535  1.00 61.81           N  \\nATOM   2225  C4   DA I 109      35.853  52.129  -7.369  1.00 61.81           C  \\nATOM   2226  P    DA I 110      39.196  55.321 -11.732  1.00101.93           P  \\nATOM   2227  OP1  DA I 110      39.543  56.377 -12.721  1.00101.93           O  \\nATOM   2228  OP2  DA I 110      39.784  53.966 -11.863  1.00101.93           O  \\nATOM   2229  O5'  DA I 110      39.554  55.835 -10.279  1.00 70.56           O  \\nATOM   2230  C5'  DA I 110      38.589  56.536  -9.518  1.00 70.56           C  \\nATOM   2231  C4'  DA I 110      38.999  56.552  -8.070  1.00 70.56           C  \\nATOM   2232  O4'  DA I 110      38.638  55.324  -7.398  1.00 70.56           O  \\nATOM   2233  C3'  DA I 110      40.503  56.708  -7.892  1.00 70.56           C  \\nATOM   2234  O3'  DA I 110      40.732  57.620  -6.833  1.00 70.56           O  \\nATOM   2235  C2'  DA I 110      40.963  55.307  -7.526  1.00 70.56           C  \\nATOM   2236  C1'  DA I 110      39.773  54.784  -6.750  1.00 70.56           C  \\nATOM   2237  N9   DA I 110      39.627  53.333  -6.754  1.00 69.21           N  \\nATOM   2238  C8   DA I 110      39.861  52.466  -7.789  1.00 69.21           C  \\nATOM   2239  N7   DA I 110      39.598  51.214  -7.497  1.00 69.21           N  \\nATOM   2240  C5   DA I 110      39.168  51.263  -6.177  1.00 69.21           C  \\nATOM   2241  C6   DA I 110      38.724  50.267  -5.284  1.00 69.21           C  \\nATOM   2242  N6   DA I 110      38.606  48.977  -5.609  1.00 69.21           N  \\nATOM   2243  N1   DA I 110      38.387  50.650  -4.034  1.00 69.21           N  \\nATOM   2244  C2   DA I 110      38.470  51.942  -3.717  1.00 69.21           C  \\nATOM   2245  N3   DA I 110      38.853  52.971  -4.470  1.00 69.21           N  \\nATOM   2246  C4   DA I 110      39.195  52.559  -5.704  1.00 69.21           C  \\nATOM   2247  P    DA I 111      42.223  58.060  -6.480  1.00 78.14           P  \\nATOM   2248  OP1  DA I 111      42.243  59.532  -6.623  1.00 78.14           O  \\nATOM   2249  OP2  DA I 111      43.176  57.229  -7.267  1.00 78.14           O  \\nATOM   2250  O5'  DA I 111      42.313  57.657  -4.945  1.00 70.74           O  \\nATOM   2251  C5'  DA I 111      41.204  57.889  -4.073  1.00 70.74           C  \\nATOM   2252  C4'  DA I 111      41.396  57.150  -2.769  1.00 70.74           C  \\nATOM   2253  O4'  DA I 111      40.974  55.766  -2.901  1.00 70.74           O  \\nATOM   2254  C3'  DA I 111      42.854  57.121  -2.312  1.00 70.74           C  \\nATOM   2255  O3'  DA I 111      42.979  57.364  -0.916  1.00 70.74           O  \\nATOM   2256  C2'  DA I 111      43.297  55.708  -2.629  1.00 70.74           C  \\nATOM   2257  C1'  DA I 111      42.016  54.904  -2.462  1.00 70.74           C  \\nATOM   2258  N9   DA I 111      41.998  53.673  -3.270  1.00 72.28           N  \\nATOM   2259  C8   DA I 111      42.241  53.540  -4.620  1.00 72.28           C  \\nATOM   2260  N7   DA I 111      42.237  52.296  -5.040  1.00 72.28           N  \\nATOM   2261  C5   DA I 111      41.953  51.559  -3.898  1.00 72.28           C  \\nATOM   2262  C6   DA I 111      41.815  50.174  -3.671  1.00 72.28           C  \\nATOM   2263  N6   DA I 111      41.980  49.248  -4.615  1.00 72.28           N  \\nATOM   2264  N1   DA I 111      41.509  49.767  -2.420  1.00 72.28           N  \\nATOM   2265  C2   DA I 111      41.369  50.691  -1.465  1.00 72.28           C  \\nATOM   2266  N3   DA I 111      41.486  52.018  -1.548  1.00 72.28           N  \\nATOM   2267  C4   DA I 111      41.782  52.393  -2.805  1.00 72.28           C  \\nATOM   2268  P    DT I 112      44.444  57.527  -0.271  1.00 42.86           P  \\nATOM   2269  OP1  DT I 112      44.581  58.853   0.371  1.00 42.86           O  \\nATOM   2270  OP2  DT I 112      45.430  57.122  -1.305  1.00 42.86           O  \\nATOM   2271  O5'  DT I 112      44.415  56.480   0.920  1.00 50.49           O  \\nATOM   2272  C5'  DT I 112      43.391  56.559   1.897  1.00 50.49           C  \\nATOM   2273  C4'  DT I 112      43.267  55.248   2.628  1.00 50.49           C  \\nATOM   2274  O4'  DT I 112      43.030  54.170   1.682  1.00 50.49           O  \\nATOM   2275  C3'  DT I 112      44.511  54.855   3.418  1.00 50.49           C  \\nATOM   2276  O3'  DT I 112      44.093  54.353   4.682  1.00 50.49           O  \\nATOM   2277  C2'  DT I 112      45.151  53.760   2.576  1.00 50.49           C  \\nATOM   2278  C1'  DT I 112      43.946  53.108   1.926  1.00 50.49           C  \\nATOM   2279  N1   DT I 112      44.218  52.424   0.637  1.00 56.91           N  \\nATOM   2280  C2   DT I 112      44.020  51.058   0.570  1.00 56.91           C  \\nATOM   2281  O2   DT I 112      43.673  50.386   1.528  1.00 56.91           O  \\nATOM   2282  N3   DT I 112      44.255  50.506  -0.670  1.00 56.91           N  \\nATOM   2283  C4   DT I 112      44.665  51.165  -1.812  1.00 56.91           C  \\nATOM   2284  O4   DT I 112      44.805  50.544  -2.857  1.00 56.91           O  \\nATOM   2285  C5   DT I 112      44.891  52.577  -1.662  1.00 56.91           C  \\nATOM   2286  C7   DT I 112      45.392  53.352  -2.839  1.00 56.91           C  \\nATOM   2287  C6   DT I 112      44.650  53.134  -0.465  1.00 56.91           C  \\nATOM   2288  P    DA I 113      45.145  53.617   5.632  1.00 70.99           P  \\nATOM   2289  OP1  DA I 113      44.510  53.477   6.972  1.00 70.99           O  \\nATOM   2290  OP2  DA I 113      46.451  54.323   5.495  1.00 70.99           O  \\nATOM   2291  O5'  DA I 113      45.263  52.174   4.972  1.00105.55           O  \\nATOM   2292  C5'  DA I 113      44.312  51.157   5.277  1.00105.55           C  \\nATOM   2293  C4'  DA I 113      45.025  49.841   5.465  1.00105.55           C  \\nATOM   2294  O4'  DA I 113      45.362  49.293   4.169  1.00105.55           O  \\nATOM   2295  C3'  DA I 113      46.341  49.990   6.230  1.00105.55           C  \\nATOM   2296  O3'  DA I 113      46.525  48.905   7.147  1.00105.55           O  \\nATOM   2297  C2'  DA I 113      47.388  50.018   5.128  1.00105.55           C  \\nATOM   2298  C1'  DA I 113      46.771  49.159   4.032  1.00105.55           C  \\nATOM   2299  N9   DA I 113      47.127  49.558   2.665  1.00 70.52           N  \\nATOM   2300  C8   DA I 113      47.392  50.822   2.196  1.00 70.52           C  \\nATOM   2301  N7   DA I 113      47.663  50.867   0.912  1.00 70.52           N  \\nATOM   2302  C5   DA I 113      47.577  49.546   0.507  1.00 70.52           C  \\nATOM   2303  C6   DA I 113      47.749  48.932  -0.740  1.00 70.52           C  \\nATOM   2304  N6   DA I 113      48.048  49.593  -1.860  1.00 70.52           N  \\nATOM   2305  N1   DA I 113      47.598  47.594  -0.803  1.00 70.52           N  \\nATOM   2306  C2   DA I 113      47.289  46.927   0.319  1.00 70.52           C  \\nATOM   2307  N3   DA I 113      47.096  47.391   1.549  1.00 70.52           N  \\nATOM   2308  C4   DA I 113      47.254  48.725   1.577  1.00 70.52           C  \\nATOM   2309  P    DC I 114      47.860  48.829   8.041  1.00105.53           P  \\nATOM   2310  OP1  DC I 114      47.775  47.576   8.832  1.00105.53           O  \\nATOM   2311  OP2  DC I 114      48.051  50.128   8.744  1.00105.53           O  \\nATOM   2312  O5'  DC I 114      49.002  48.669   6.938  1.00 92.52           O  \\nATOM   2313  C5'  DC I 114      50.216  47.978   7.213  1.00 92.52           C  \\nATOM   2314  C4'  DC I 114      50.149  46.562   6.684  1.00 92.52           C  \\nATOM   2315  O4'  DC I 114      49.610  46.517   5.340  1.00 92.52           O  \\nATOM   2316  C3'  DC I 114      51.513  45.890   6.614  1.00 92.52           C  \\nATOM   2317  O3'  DC I 114      51.422  44.535   7.041  1.00 92.52           O  \\nATOM   2318  C2'  DC I 114      51.904  45.989   5.153  1.00 92.52           C  \\nATOM   2319  C1'  DC I 114      50.578  46.035   4.414  1.00 92.52           C  \\nATOM   2320  N1   DC I 114      50.624  46.987   3.292  1.00 63.64           N  \\nATOM   2321  C2   DC I 114      50.478  46.517   1.972  1.00 63.64           C  \\nATOM   2322  O2   DC I 114      50.314  45.303   1.774  1.00 63.64           O  \\nATOM   2323  N3   DC I 114      50.530  47.408   0.946  1.00 63.64           N  \\nATOM   2324  C4   DC I 114      50.732  48.708   1.196  1.00 63.64           C  \\nATOM   2325  N4   DC I 114      50.798  49.548   0.160  1.00 63.64           N  \\nATOM   2326  C5   DC I 114      50.882  49.206   2.524  1.00 63.64           C  \\nATOM   2327  C6   DC I 114      50.820  48.321   3.530  1.00 63.64           C  \\nATOM   2328  P    DA I 115      52.764  43.732   7.375  1.00 86.86           P  \\nATOM   2329  OP1  DA I 115      52.404  42.445   8.033  1.00 86.86           O  \\nATOM   2330  OP2  DA I 115      53.677  44.683   8.061  1.00 86.86           O  \\nATOM   2331  O5'  DA I 115      53.341  43.420   5.929  1.00154.94           O  \\nATOM   2332  C5'  DA I 115      52.705  42.455   5.100  1.00154.94           C  \\nATOM   2333  C4'  DA I 115      53.546  42.194   3.876  1.00154.94           C  \\nATOM   2334  O4'  DA I 115      53.291  43.211   2.878  1.00154.94           O  \\nATOM   2335  C3'  DA I 115      55.048  42.226   4.163  1.00154.94           C  \\nATOM   2336  O3'  DA I 115      55.703  41.162   3.472  1.00154.94           O  \\nATOM   2337  C2'  DA I 115      55.477  43.582   3.628  1.00154.94           C  \\nATOM   2338  C1'  DA I 115      54.516  43.795   2.470  1.00154.94           C  \\nATOM   2339  N9   DA I 115      54.267  45.201   2.139  1.00 93.27           N  \\nATOM   2340  C8   DA I 115      54.022  46.239   3.004  1.00 93.27           C  \\nATOM   2341  N7   DA I 115      53.881  47.400   2.410  1.00 93.27           N  \\nATOM   2342  C5   DA I 115      54.035  47.107   1.061  1.00 93.27           C  \\nATOM   2343  C6   DA I 115      54.003  47.913  -0.099  1.00 93.27           C  \\nATOM   2344  N6   DA I 115      53.805  49.239  -0.085  1.00 93.27           N  \\nATOM   2345  N1   DA I 115      54.187  47.303  -1.289  1.00 93.27           N  \\nATOM   2346  C2   DA I 115      54.390  45.982  -1.309  1.00 93.27           C  \\nATOM   2347  N3   DA I 115      54.445  45.122  -0.294  1.00 93.27           N  \\nATOM   2348  C4   DA I 115      54.259  45.754   0.879  1.00 93.27           C  \\nATOM   2349  P    DC I 116      57.244  40.822   3.790  1.00106.13           P  \\nATOM   2350  OP1  DC I 116      57.301  39.569   4.585  1.00106.13           O  \\nATOM   2351  OP2  DC I 116      57.907  42.050   4.307  1.00106.13           O  \\nATOM   2352  O5'  DC I 116      57.817  40.534   2.335  1.00158.95           O  \\nATOM   2353  C5'  DC I 116      57.048  40.887   1.183  1.00158.95           C  \\nATOM   2354  C4'  DC I 116      57.953  41.298   0.045  1.00158.95           C  \\nATOM   2355  O4'  DC I 116      57.598  42.630  -0.407  1.00158.95           O  \\nATOM   2356  C3'  DC I 116      59.443  41.352   0.391  1.00158.95           C  \\nATOM   2357  O3'  DC I 116      60.206  40.807  -0.690  1.00158.95           O  \\nATOM   2358  C2'  DC I 116      59.715  42.836   0.555  1.00158.95           C  \\nATOM   2359  C1'  DC I 116      58.761  43.446  -0.452  1.00158.95           C  \\nATOM   2360  N1   DC I 116      58.375  44.833  -0.137  1.00116.12           N  \\nATOM   2361  C2   DC I 116      57.827  45.644  -1.150  1.00116.12           C  \\nATOM   2362  O2   DC I 116      57.656  45.166  -2.290  1.00116.12           O  \\nATOM   2363  N3   DC I 116      57.500  46.926  -0.856  1.00116.12           N  \\nATOM   2364  C4   DC I 116      57.695  47.403   0.380  1.00116.12           C  \\nATOM   2365  N4   DC I 116      57.362  48.668   0.624  1.00116.12           N  \\nATOM   2366  C5   DC I 116      58.240  46.599   1.421  1.00116.12           C  \\nATOM   2367  C6   DC I 116      58.560  45.334   1.123  1.00116.12           C  \\nATOM   2368  P    DT I 117      61.774  41.138  -0.812  1.00120.60           P  \\nATOM   2369  OP1  DT I 117      62.445  39.942  -1.381  1.00120.60           O  \\nATOM   2370  OP2  DT I 117      62.242  41.693   0.488  1.00120.60           O  \\nATOM   2371  O5'  DT I 117      61.812  42.303  -1.898  1.00135.17           O  \\nATOM   2372  C5'  DT I 117      61.129  42.155  -3.144  1.00135.17           C  \\nATOM   2373  C4'  DT I 117      61.633  43.167  -4.146  1.00135.17           C  \\nATOM   2374  O4'  DT I 117      61.104  44.481  -3.842  1.00135.17           O  \\nATOM   2375  C3'  DT I 117      63.154  43.308  -4.187  1.00135.17           C  \\nATOM   2376  O3'  DT I 117      63.617  43.380  -5.536  1.00135.17           O  \\nATOM   2377  C2'  DT I 117      63.422  44.596  -3.429  1.00135.17           C  \\nATOM   2378  C1'  DT I 117      62.158  45.415  -3.644  1.00135.17           C  \\nATOM   2379  N1   DT I 117      61.805  46.249  -2.474  1.00 83.79           N  \\nATOM   2380  C2   DT I 117      61.443  47.559  -2.683  1.00 83.79           C  \\nATOM   2381  O2   DT I 117      61.365  48.057  -3.793  1.00 83.79           O  \\nATOM   2382  N3   DT I 117      61.166  48.266  -1.533  1.00 83.79           N  \\nATOM   2383  C4   DT I 117      61.197  47.793  -0.229  1.00 83.79           C  \\nATOM   2384  O4   DT I 117      60.926  48.548   0.702  1.00 83.79           O  \\nATOM   2385  C5   DT I 117      61.562  46.402  -0.086  1.00 83.79           C  \\nATOM   2386  C7   DT I 117      61.599  45.794   1.282  1.00 83.79           C  \\nATOM   2387  C6   DT I 117      61.850  45.712  -1.199  1.00 83.79           C  \\nATOM   2388  P    DT I 118      65.154  43.737  -5.836  1.00120.38           P  \\nATOM   2389  OP1  DT I 118      65.542  43.011  -7.075  1.00120.38           O  \\nATOM   2390  OP2  DT I 118      65.971  43.578  -4.602  1.00120.38           O  \\nATOM   2391  O5'  DT I 118      65.076  45.283  -6.183  1.00 90.80           O  \\nATOM   2392  C5'  DT I 118      64.069  45.752  -7.068  1.00 90.80           C  \\nATOM   2393  C4'  DT I 118      64.163  47.248  -7.225  1.00 90.80           C  \\nATOM   2394  O4'  DT I 118      63.832  47.873  -5.965  1.00 90.80           O  \\nATOM   2395  C3'  DT I 118      65.548  47.775  -7.607  1.00 90.80           C  \\nATOM   2396  O3'  DT I 118      65.394  48.833  -8.566  1.00 90.80           O  \\nATOM   2397  C2'  DT I 118      66.104  48.277  -6.286  1.00 90.80           C  \\nATOM   2398  C1'  DT I 118      64.850  48.793  -5.622  1.00 90.80           C  \\nATOM   2399  N1   DT I 118      64.886  48.888  -4.166  1.00 77.56           N  \\nATOM   2400  C2   DT I 118      64.614  50.113  -3.607  1.00 77.56           C  \\nATOM   2401  O2   DT I 118      64.437  51.126  -4.268  1.00 77.56           O  \\nATOM   2402  N3   DT I 118      64.567  50.115  -2.240  1.00 77.56           N  \\nATOM   2403  C4   DT I 118      64.794  49.050  -1.397  1.00 77.56           C  \\nATOM   2404  O4   DT I 118      64.691  49.206  -0.188  1.00 77.56           O  \\nATOM   2405  C5   DT I 118      65.134  47.804  -2.053  1.00 77.56           C  \\nATOM   2406  C7   DT I 118      65.452  46.603  -1.219  1.00 77.56           C  \\nATOM   2407  C6   DT I 118      65.153  47.786  -3.391  1.00 77.56           C  \\nATOM   2408  P    DT I 119      66.613  49.838  -8.865  1.00 87.10           P  \\nATOM   2409  OP1  DT I 119      66.486  50.279 -10.281  1.00 87.10           O  \\nATOM   2410  OP2  DT I 119      67.890  49.231  -8.397  1.00 87.10           O  \\nATOM   2411  O5'  DT I 119      66.309  51.069  -7.899  1.00 88.48           O  \\nATOM   2412  C5'  DT I 119      65.320  52.037  -8.236  1.00 88.48           C  \\nATOM   2413  C4'  DT I 119      65.819  53.424  -7.909  1.00 88.48           C  \\nATOM   2414  O4'  DT I 119      65.733  53.594  -6.475  1.00 88.48           O  \\nATOM   2415  C3'  DT I 119      67.282  53.669  -8.292  1.00 88.48           C  \\nATOM   2416  O3'  DT I 119      67.510  54.774  -9.190  1.00 88.48           O  \\nATOM   2417  C2'  DT I 119      68.047  53.728  -6.982  1.00 88.48           C  \\nATOM   2418  C1'  DT I 119      66.991  53.934  -5.907  1.00 88.48           C  \\nATOM   2419  N1   DT I 119      67.205  53.053  -4.741  1.00 89.04           N  \\nATOM   2420  C2   DT I 119      67.051  53.571  -3.474  1.00 89.04           C  \\nATOM   2421  O2   DT I 119      66.748  54.733  -3.258  1.00 89.04           O  \\nATOM   2422  N3   DT I 119      67.272  52.671  -2.460  1.00 89.04           N  \\nATOM   2423  C4   DT I 119      67.629  51.343  -2.585  1.00 89.04           C  \\nATOM   2424  O4   DT I 119      67.791  50.658  -1.584  1.00 89.04           O  \\nATOM   2425  C5   DT I 119      67.777  50.873  -3.936  1.00 89.04           C  \\nATOM   2426  C7   DT I 119      68.166  49.450  -4.166  1.00 89.04           C  \\nATOM   2427  C6   DT I 119      67.559  51.736  -4.933  1.00 89.04           C  \\nATOM   2428  P    DT I 120      66.619  56.107  -9.103  1.00 75.71           P  \\nATOM   2429  OP1  DT I 120      65.225  55.757  -9.496  1.00 75.71           O  \\nATOM   2430  OP2  DT I 120      67.346  57.162  -9.856  1.00 75.71           O  \\nATOM   2431  O5'  DT I 120      66.646  56.503  -7.563  1.00 67.52           O  \\nATOM   2432  C5'  DT I 120      65.537  57.171  -6.975  1.00 67.52           C  \\nATOM   2433  C4'  DT I 120      66.016  58.185  -5.970  1.00 67.52           C  \\nATOM   2434  O4'  DT I 120      66.621  57.500  -4.849  1.00 67.52           O  \\nATOM   2435  C3'  DT I 120      67.066  59.162  -6.495  1.00 67.52           C  \\nATOM   2436  O3'  DT I 120      66.821  60.421  -5.886  1.00 67.52           O  \\nATOM   2437  C2'  DT I 120      68.368  58.582  -5.971  1.00 67.52           C  \\nATOM   2438  C1'  DT I 120      67.935  57.982  -4.640  1.00 67.52           C  \\nATOM   2439  N1   DT I 120      68.748  56.852  -4.154  1.00 89.08           N  \\nATOM   2440  C2   DT I 120      68.808  56.635  -2.792  1.00 89.08           C  \\nATOM   2441  O2   DT I 120      68.248  57.346  -1.978  1.00 89.08           O  \\nATOM   2442  N3   DT I 120      69.559  55.552  -2.416  1.00 89.08           N  \\nATOM   2443  C4   DT I 120      70.248  54.686  -3.241  1.00 89.08           C  \\nATOM   2444  O4   DT I 120      70.864  53.743  -2.747  1.00 89.08           O  \\nATOM   2445  C5   DT I 120      70.162  54.990  -4.666  1.00 89.08           C  \\nATOM   2446  C7   DT I 120      70.901  54.134  -5.648  1.00 89.08           C  \\nATOM   2447  C6   DT I 120      69.421  56.039  -5.040  1.00 89.08           C  \\nATOM   2448  P    DG I 121      66.998  61.776  -6.722  1.00 63.18           P  \\nATOM   2449  OP1  DG I 121      65.909  61.914  -7.731  1.00 63.18           O  \\nATOM   2450  OP2  DG I 121      68.424  61.848  -7.150  1.00 63.18           O  \\nATOM   2451  O5'  DG I 121      66.749  62.879  -5.600  1.00 58.04           O  \\nATOM   2452  C5'  DG I 121      65.685  62.722  -4.654  1.00 58.04           C  \\nATOM   2453  C4'  DG I 121      66.200  62.896  -3.243  1.00 58.04           C  \\nATOM   2454  O4'  DG I 121      67.114  61.830  -2.900  1.00 58.04           O  \\nATOM   2455  C3'  DG I 121      66.971  64.189  -3.007  1.00 58.04           C  \\nATOM   2456  O3'  DG I 121      66.756  64.628  -1.672  1.00 58.04           O  \\nATOM   2457  C2'  DG I 121      68.418  63.766  -3.166  1.00 58.04           C  \\nATOM   2458  C1'  DG I 121      68.398  62.367  -2.586  1.00 58.04           C  \\nATOM   2459  N9   DG I 121      69.402  61.491  -3.177  1.00 74.45           N  \\nATOM   2460  C8   DG I 121      69.836  61.488  -4.483  1.00 74.45           C  \\nATOM   2461  N7   DG I 121      70.732  60.573  -4.721  1.00 74.45           N  \\nATOM   2462  C5   DG I 121      70.902  59.940  -3.501  1.00 74.45           C  \\nATOM   2463  C6   DG I 121      71.738  58.869  -3.147  1.00 74.45           C  \\nATOM   2464  O6   DG I 121      72.512  58.233  -3.873  1.00 74.45           O  \\nATOM   2465  N1   DG I 121      71.612  58.547  -1.794  1.00 74.45           N  \\nATOM   2466  C2   DG I 121      70.773  59.177  -0.906  1.00 74.45           C  \\nATOM   2467  N2   DG I 121      70.806  58.736   0.359  1.00 74.45           N  \\nATOM   2468  N3   DG I 121      69.970  60.169  -1.235  1.00 74.45           N  \\nATOM   2469  C4   DG I 121      70.091  60.500  -2.537  1.00 74.45           C  \\nATOM   2470  P    DG I 122      67.134  66.127  -1.261  1.00 45.73           P  \\nATOM   2471  OP1  DG I 122      65.899  66.708  -0.714  1.00 45.73           O  \\nATOM   2472  OP2  DG I 122      67.829  66.807  -2.384  1.00 45.73           O  \\nATOM   2473  O5'  DG I 122      68.136  65.926  -0.050  1.00 41.47           O  \\nATOM   2474  C5'  DG I 122      67.659  65.344   1.153  1.00 41.47           C  \\nATOM   2475  C4'  DG I 122      68.804  64.880   2.019  1.00 41.47           C  \\nATOM   2476  O4'  DG I 122      69.479  63.766   1.395  1.00 41.47           O  \\nATOM   2477  C3'  DG I 122      69.878  65.923   2.324  1.00 41.47           C  \\nATOM   2478  O3'  DG I 122      70.139  65.914   3.724  1.00 41.47           O  \\nATOM   2479  C2'  DG I 122      71.090  65.451   1.537  1.00 41.47           C  \\nATOM   2480  C1'  DG I 122      70.875  63.954   1.487  1.00 41.47           C  \\nATOM   2481  N9   DG I 122      71.498  63.265   0.363  1.00 80.72           N  \\nATOM   2482  C8   DG I 122      71.443  63.589  -0.973  1.00 80.72           C  \\nATOM   2483  N7   DG I 122      72.141  62.780  -1.725  1.00 80.72           N  \\nATOM   2484  C5   DG I 122      72.684  61.865  -0.830  1.00 80.72           C  \\nATOM   2485  C6   DG I 122      73.539  60.751  -1.048  1.00 80.72           C  \\nATOM   2486  O6   DG I 122      74.018  60.338  -2.114  1.00 80.72           O  \\nATOM   2487  N1   DG I 122      73.831  60.092   0.145  1.00 80.72           N  \\nATOM   2488  C2   DG I 122      73.358  60.452   1.388  1.00 80.72           C  \\nATOM   2489  N2   DG I 122      73.727  59.683   2.418  1.00 80.72           N  \\nATOM   2490  N3   DG I 122      72.577  61.489   1.604  1.00 80.72           N  \\nATOM   2491  C4   DG I 122      72.282  62.147   0.459  1.00 80.72           C  \\nATOM   2492  P    DT I 123      71.235  66.911   4.336  1.00 63.59           P  \\nATOM   2493  OP1  DT I 123      70.810  67.322   5.706  1.00 63.59           O  \\nATOM   2494  OP2  DT I 123      71.544  67.951   3.315  1.00 63.59           O  \\nATOM   2495  O5'  DT I 123      72.488  65.947   4.461  1.00 96.42           O  \\nATOM   2496  C5'  DT I 123      72.366  64.691   5.119  1.00 96.42           C  \\nATOM   2497  C4'  DT I 123      73.736  64.107   5.344  1.00 96.42           C  \\nATOM   2498  O4'  DT I 123      74.198  63.475   4.124  1.00 96.42           O  \\nATOM   2499  C3'  DT I 123      74.763  65.187   5.694  1.00 96.42           C  \\nATOM   2500  O3'  DT I 123      75.593  64.775   6.791  1.00 96.42           O  \\nATOM   2501  C2'  DT I 123      75.539  65.380   4.399  1.00 96.42           C  \\nATOM   2502  C1'  DT I 123      75.468  63.998   3.774  1.00 96.42           C  \\nATOM   2503  N1   DT I 123      75.617  63.943   2.298  1.00 65.23           N  \\nATOM   2504  C2   DT I 123      76.111  62.771   1.751  1.00 65.23           C  \\nATOM   2505  O2   DT I 123      76.341  61.772   2.413  1.00 65.23           O  \\nATOM   2506  N3   DT I 123      76.317  62.811   0.390  1.00 65.23           N  \\nATOM   2507  C4   DT I 123      76.053  63.868  -0.466  1.00 65.23           C  \\nATOM   2508  O4   DT I 123      76.299  63.763  -1.668  1.00 65.23           O  \\nATOM   2509  C5   DT I 123      75.498  65.046   0.161  1.00 65.23           C  \\nATOM   2510  C7   DT I 123      75.171  66.225  -0.697  1.00 65.23           C  \\nATOM   2511  C6   DT I 123      75.308  65.028   1.495  1.00 65.23           C  \\nATOM   2512  P    DA I 124      76.714  65.778   7.375  1.00 96.30           P  \\nATOM   2513  OP1  DA I 124      76.651  65.804   8.868  1.00 96.30           O  \\nATOM   2514  OP2  DA I 124      76.668  67.054   6.609  1.00 96.30           O  \\nATOM   2515  O5'  DA I 124      78.066  65.059   6.959  1.00117.14           O  \\nATOM   2516  C5'  DA I 124      78.314  63.703   7.320  1.00117.14           C  \\nATOM   2517  C4'  DA I 124      79.695  63.317   6.857  1.00117.14           C  \\nATOM   2518  O4'  DA I 124      79.671  63.203   5.415  1.00117.14           O  \\nATOM   2519  C3'  DA I 124      80.687  64.432   7.179  1.00117.14           C  \\nATOM   2520  O3'  DA I 124      81.953  63.934   7.594  1.00117.14           O  \\nATOM   2521  C2'  DA I 124      80.787  65.214   5.884  1.00117.14           C  \\nATOM   2522  C1'  DA I 124      80.556  64.146   4.837  1.00117.14           C  \\nATOM   2523  N9   DA I 124      79.947  64.657   3.612  1.00 80.33           N  \\nATOM   2524  C8   DA I 124      79.258  65.837   3.444  1.00 80.33           C  \\nATOM   2525  N7   DA I 124      78.909  66.073   2.201  1.00 80.33           N  \\nATOM   2526  C5   DA I 124      79.381  64.963   1.506  1.00 80.33           C  \\nATOM   2527  C6   DA I 124      79.347  64.610   0.138  1.00 80.33           C  \\nATOM   2528  N6   DA I 124      78.812  65.387  -0.816  1.00 80.33           N  \\nATOM   2529  N1   DA I 124      79.900  63.421  -0.219  1.00 80.33           N  \\nATOM   2530  C2   DA I 124      80.451  62.655   0.735  1.00 80.33           C  \\nATOM   2531  N3   DA I 124      80.554  62.884   2.044  1.00 80.33           N  \\nATOM   2532  C4   DA I 124      79.997  64.069   2.369  1.00 80.33           C  \\nATOM   2533  P    DG I 125      82.956  64.921   8.356  1.00133.47           P  \\nATOM   2534  OP1  DG I 125      84.273  64.247   8.450  1.00133.47           O  \\nATOM   2535  OP2  DG I 125      82.279  65.392   9.594  1.00133.47           O  \\nATOM   2536  O5'  DG I 125      83.069  66.152   7.351  1.00103.83           O  \\nATOM   2537  C5'  DG I 125      84.320  66.512   6.782  1.00103.83           C  \\nATOM   2538  C4'  DG I 125      84.902  65.339   6.030  1.00103.83           C  \\nATOM   2539  O4'  DG I 125      84.003  64.943   4.969  1.00103.83           O  \\nATOM   2540  C3'  DG I 125      86.239  65.640   5.361  1.00103.83           C  \\nATOM   2541  O3'  DG I 125      87.092  64.493   5.422  1.00103.83           O  \\nATOM   2542  C2'  DG I 125      85.851  65.960   3.932  1.00103.83           C  \\nATOM   2543  C1'  DG I 125      84.635  65.082   3.704  1.00103.83           C  \\nATOM   2544  N9   DG I 125      83.681  65.716   2.804  1.00119.69           N  \\nATOM   2545  C8   DG I 125      82.875  66.792   3.096  1.00119.69           C  \\nATOM   2546  N7   DG I 125      82.145  67.176   2.084  1.00119.69           N  \\nATOM   2547  C5   DG I 125      82.480  66.297   1.060  1.00119.69           C  \\nATOM   2548  C6   DG I 125      82.011  66.226  -0.282  1.00119.69           C  \\nATOM   2549  O6   DG I 125      81.173  66.948  -0.845  1.00119.69           O  \\nATOM   2550  N1   DG I 125      82.618  65.184  -0.981  1.00119.69           N  \\nATOM   2551  C2   DG I 125      83.537  64.307  -0.454  1.00119.69           C  \\nATOM   2552  N2   DG I 125      83.971  63.353  -1.288  1.00119.69           N  \\nATOM   2553  N3   DG I 125      83.987  64.362   0.794  1.00119.69           N  \\nATOM   2554  C4   DG I 125      83.421  65.379   1.490  1.00119.69           C  \\nATOM   2555  P    DA I 126      88.491  64.506   4.637  1.00114.28           P  \\nATOM   2556  OP1  DA I 126      89.195  63.221   4.882  1.00114.28           O  \\nATOM   2557  OP2  DA I 126      89.170  65.790   4.950  1.00114.28           O  \\nATOM   2558  O5'  DA I 126      88.040  64.545   3.114  1.00151.17           O  \\nATOM   2559  C5'  DA I 126      88.438  63.525   2.211  1.00151.17           C  \\nATOM   2560  C4'  DA I 126      89.018  64.150   0.967  1.00151.17           C  \\nATOM   2561  O4'  DA I 126      87.953  64.722   0.162  1.00151.17           O  \\nATOM   2562  C3'  DA I 126      89.990  65.294   1.271  1.00151.17           C  \\nATOM   2563  O3'  DA I 126      91.123  65.220   0.398  1.00151.17           O  \\nATOM   2564  C2'  DA I 126      89.157  66.536   1.011  1.00151.17           C  \\nATOM   2565  C1'  DA I 126      88.249  66.081  -0.116  1.00151.17           C  \\nATOM   2566  N9   DA I 126      86.992  66.831  -0.209  1.00138.40           N  \\nATOM   2567  C8   DA I 126      86.439  67.650   0.749  1.00138.40           C  \\nATOM   2568  N7   DA I 126      85.336  68.246   0.362  1.00138.40           N  \\nATOM   2569  C5   DA I 126      85.139  67.779  -0.931  1.00138.40           C  \\nATOM   2570  C6   DA I 126      84.145  68.044  -1.891  1.00138.40           C  \\nATOM   2571  N6   DA I 126      83.125  68.881  -1.689  1.00138.40           N  \\nATOM   2572  N1   DA I 126      84.238  67.413  -3.081  1.00138.40           N  \\nATOM   2573  C2   DA I 126      85.264  66.577  -3.284  1.00138.40           C  \\nATOM   2574  N3   DA I 126      86.262  66.249  -2.465  1.00138.40           N  \\nATOM   2575  C4   DA I 126      86.142  66.893  -1.290  1.00138.40           C  \\nATOM   2576  P    DA I 127      92.055  66.513   0.165  1.00165.61           P  \\nATOM   2577  OP1  DA I 127      93.475  66.094   0.282  1.00165.61           O  \\nATOM   2578  OP2  DA I 127      91.550  67.616   1.022  1.00165.61           O  \\nATOM   2579  O5'  DA I 127      91.763  66.883  -1.361  1.00174.46           O  \\nATOM   2580  C5'  DA I 127      91.477  65.851  -2.312  1.00174.46           C  \\nATOM   2581  C4'  DA I 127      91.145  66.437  -3.666  1.00174.46           C  \\nATOM   2582  O4'  DA I 127      89.849  67.087  -3.637  1.00174.46           O  \\nATOM   2583  C3'  DA I 127      92.136  67.473  -4.196  1.00174.46           C  \\nATOM   2584  O3'  DA I 127      92.402  67.226  -5.583  1.00174.46           O  \\nATOM   2585  C2'  DA I 127      91.423  68.798  -3.971  1.00174.46           C  \\nATOM   2586  C1'  DA I 127      89.953  68.429  -4.103  1.00174.46           C  \\nATOM   2587  N9   DA I 127      89.039  69.258  -3.304  1.00130.98           N  \\nATOM   2588  C8   DA I 127      89.261  69.783  -2.050  1.00130.98           C  \\nATOM   2589  N7   DA I 127      88.247  70.466  -1.573  1.00130.98           N  \\nATOM   2590  C5   DA I 127      87.293  70.393  -2.579  1.00130.98           C  \\nATOM   2591  C6   DA I 127      85.990  70.908  -2.682  1.00130.98           C  \\nATOM   2592  N6   DA I 127      85.399  71.630  -1.725  1.00130.98           N  \\nATOM   2593  N1   DA I 127      85.304  70.651  -3.817  1.00130.98           N  \\nATOM   2594  C2   DA I 127      85.897  69.932  -4.780  1.00130.98           C  \\nATOM   2595  N3   DA I 127      87.113  69.395  -4.802  1.00130.98           N  \\nATOM   2596  C4   DA I 127      87.769  69.660  -3.657  1.00130.98           C  \\nATOM   2597  P    DT I 128      93.154  68.338  -6.470  1.00175.78           P  \\nATOM   2598  OP1  DT I 128      93.865  67.626  -7.565  1.00175.78           O  \\nATOM   2599  OP2  DT I 128      93.922  69.238  -5.570  1.00175.78           O  \\nATOM   2600  O5'  DT I 128      91.939  69.156  -7.102  1.00146.66           O  \\nATOM   2601  C5'  DT I 128      90.905  68.480  -7.827  1.00146.66           C  \\nATOM   2602  C4'  DT I 128      90.127  69.464  -8.668  1.00146.66           C  \\nATOM   2603  O4'  DT I 128      88.994  69.998  -7.938  1.00146.66           O  \\nATOM   2604  C3'  DT I 128      90.962  70.666  -9.110  1.00146.66           C  \\nATOM   2605  O3'  DT I 128      90.718  70.976 -10.480  1.00146.66           O  \\nATOM   2606  C2'  DT I 128      90.471  71.786  -8.214  1.00146.66           C  \\nATOM   2607  C1'  DT I 128      89.014  71.413  -8.016  1.00146.66           C  \\nATOM   2608  N1   DT I 128      88.417  71.963  -6.782  1.00109.45           N  \\nATOM   2609  C2   DT I 128      87.085  72.327  -6.803  1.00109.45           C  \\nATOM   2610  O2   DT I 128      86.357  72.152  -7.774  1.00109.45           O  \\nATOM   2611  N3   DT I 128      86.634  72.907  -5.632  1.00109.45           N  \\nATOM   2612  C4   DT I 128      87.357  73.123  -4.465  1.00109.45           C  \\nATOM   2613  O4   DT I 128      86.815  73.658  -3.493  1.00109.45           O  \\nATOM   2614  C5   DT I 128      88.736  72.686  -4.508  1.00109.45           C  \\nATOM   2615  C7   DT I 128      89.593  72.869  -3.295  1.00109.45           C  \\nATOM   2616  C6   DT I 128      89.189  72.135  -5.646  1.00109.45           C  \\nATOM   2617  P    DC I 129      91.267  72.356 -11.088  1.00107.64           P  \\nATOM   2618  OP1  DC I 129      91.479  72.189 -12.555  1.00107.64           O  \\nATOM   2619  OP2  DC I 129      92.398  72.802 -10.222  1.00107.64           O  \\nATOM   2620  O5'  DC I 129      90.036  73.346 -10.871  1.00101.14           O  \\nATOM   2621  C5'  DC I 129      88.709  72.949 -11.231  1.00101.14           C  \\nATOM   2622  C4'  DC I 129      87.882  74.149 -11.632  1.00101.14           C  \\nATOM   2623  O4'  DC I 129      87.173  74.566 -10.442  1.00101.14           O  \\nATOM   2624  C3'  DC I 129      88.668  75.373 -12.120  1.00101.14           C  \\nATOM   2625  O3'  DC I 129      88.316  75.867 -13.431  1.00101.14           O  \\nATOM   2626  C2'  DC I 129      88.559  76.403 -11.014  1.00101.14           C  \\nATOM   2627  C1'  DC I 129      87.402  75.940 -10.147  1.00101.14           C  \\nATOM   2628  N1   DC I 129      87.731  76.050  -8.713  1.00 95.28           N  \\nATOM   2629  C2   DC I 129      86.726  76.408  -7.795  1.00 95.28           C  \\nATOM   2630  O2   DC I 129      85.564  76.576  -8.200  1.00 95.28           O  \\nATOM   2631  N3   DC I 129      87.050  76.560  -6.489  1.00 95.28           N  \\nATOM   2632  C4   DC I 129      88.309  76.362  -6.086  1.00 95.28           C  \\nATOM   2633  N4   DC I 129      88.586  76.545  -4.789  1.00 95.28           N  \\nATOM   2634  C5   DC I 129      89.341  75.974  -6.992  1.00 95.28           C  \\nATOM   2635  C6   DC I 129      89.010  75.828  -8.281  1.00 95.28           C  \\nATOM   2636  P    DT I 130      86.779  76.010 -13.890  1.00 83.96           P  \\nATOM   2637  OP1  DT I 130      86.086  74.707 -13.661  1.00 83.96           O  \\nATOM   2638  OP2  DT I 130      86.814  76.594 -15.259  1.00 83.96           O  \\nATOM   2639  O5'  DT I 130      86.133  77.125 -12.949  1.00 71.24           O  \\nATOM   2640  C5'  DT I 130      84.704  77.268 -12.879  1.00 71.24           C  \\nATOM   2641  C4'  DT I 130      84.315  78.633 -12.359  1.00 71.24           C  \\nATOM   2642  O4'  DT I 130      84.863  78.869 -11.043  1.00 71.24           O  \\nATOM   2643  C3'  DT I 130      84.762  79.822 -13.197  1.00 71.24           C  \\nATOM   2644  O3'  DT I 130      83.782  80.825 -13.014  1.00 71.24           O  \\nATOM   2645  C2'  DT I 130      86.013  80.287 -12.481  1.00 71.24           C  \\nATOM   2646  C1'  DT I 130      85.575  80.097 -11.046  1.00 71.24           C  \\nATOM   2647  N1   DT I 130      86.652  79.985 -10.060  1.00 91.95           N  \\nATOM   2648  C2   DT I 130      86.447  80.513  -8.804  1.00 91.95           C  \\nATOM   2649  O2   DT I 130      85.438  81.120  -8.483  1.00 91.95           O  \\nATOM   2650  N3   DT I 130      87.475  80.302  -7.928  1.00 91.95           N  \\nATOM   2651  C4   DT I 130      88.666  79.649  -8.173  1.00 91.95           C  \\nATOM   2652  O4   DT I 130      89.483  79.518  -7.267  1.00 91.95           O  \\nATOM   2653  C5   DT I 130      88.827  79.156  -9.524  1.00 91.95           C  \\nATOM   2654  C7   DT I 130      90.093  78.459  -9.900  1.00 91.95           C  \\nATOM   2655  C6   DT I 130      87.826  79.347 -10.386  1.00 91.95           C  \\nATOM   2656  P    DG I 131      82.843  81.247 -14.227  1.00 52.84           P  \\nATOM   2657  OP1  DG I 131      82.040  80.068 -14.636  1.00 52.84           O  \\nATOM   2658  OP2  DG I 131      83.707  81.939 -15.216  1.00 52.84           O  \\nATOM   2659  O5'  DG I 131      81.870  82.321 -13.570  1.00 44.44           O  \\nATOM   2660  C5'  DG I 131      80.932  81.943 -12.560  1.00 44.44           C  \\nATOM   2661  C4'  DG I 131      80.717  83.073 -11.578  1.00 44.44           C  \\nATOM   2662  O4'  DG I 131      81.837  83.228 -10.677  1.00 44.44           O  \\nATOM   2663  C3'  DG I 131      80.442  84.460 -12.147  1.00 44.44           C  \\nATOM   2664  O3'  DG I 131      79.424  85.037 -11.319  1.00 44.44           O  \\nATOM   2665  C2'  DG I 131      81.797  85.154 -12.035  1.00 44.44           C  \\nATOM   2666  C1'  DG I 131      82.462  84.500 -10.826  1.00 44.44           C  \\nATOM   2667  N9   DG I 131      83.898  84.238 -10.952  1.00 54.66           N  \\nATOM   2668  C8   DG I 131      84.568  83.842 -12.088  1.00 54.66           C  \\nATOM   2669  N7   DG I 131      85.812  83.507 -11.862  1.00 54.66           N  \\nATOM   2670  C5   DG I 131      85.990  83.731 -10.502  1.00 54.66           C  \\nATOM   2671  C6   DG I 131      87.125  83.505  -9.670  1.00 54.66           C  \\nATOM   2672  O6   DG I 131      88.218  83.015  -9.970  1.00 54.66           O  \\nATOM   2673  N1   DG I 131      86.881  83.889  -8.361  1.00 54.66           N  \\nATOM   2674  C2   DG I 131      85.698  84.395  -7.897  1.00 54.66           C  \\nATOM   2675  N2   DG I 131      85.681  84.692  -6.594  1.00 54.66           N  \\nATOM   2676  N3   DG I 131      84.622  84.588  -8.647  1.00 54.66           N  \\nATOM   2677  C4   DG I 131      84.836  84.235  -9.933  1.00 54.66           C  \\nATOM   2678  P    DC I 132      78.863  86.515 -11.601  1.00 51.60           P  \\nATOM   2679  OP1  DC I 132      77.475  86.504 -11.074  1.00 51.60           O  \\nATOM   2680  OP2  DC I 132      79.104  86.880 -13.017  1.00 51.60           O  \\nATOM   2681  O5'  DC I 132      79.732  87.408 -10.611  1.00 42.51           O  \\nATOM   2682  C5'  DC I 132      80.189  86.851  -9.379  1.00 42.51           C  \\nATOM   2683  C4'  DC I 132      81.082  87.825  -8.652  1.00 42.51           C  \\nATOM   2684  O4'  DC I 132      82.471  87.439  -8.795  1.00 42.51           O  \\nATOM   2685  C3'  DC I 132      80.997  89.261  -9.159  1.00 42.51           C  \\nATOM   2686  O3'  DC I 132      81.233  90.143  -8.058  1.00 42.51           O  \\nATOM   2687  C2'  DC I 132      82.176  89.344 -10.108  1.00 42.51           C  \\nATOM   2688  C1'  DC I 132      83.201  88.521  -9.349  1.00 42.51           C  \\nATOM   2689  N1   DC I 132      84.289  87.964 -10.168  1.00 51.98           N  \\nATOM   2690  C2   DC I 132      85.429  87.489  -9.519  1.00 51.98           C  \\nATOM   2691  O2   DC I 132      85.501  87.594  -8.288  1.00 51.98           O  \\nATOM   2692  N3   DC I 132      86.423  86.936 -10.254  1.00 51.98           N  \\nATOM   2693  C4   DC I 132      86.313  86.872 -11.593  1.00 51.98           C  \\nATOM   2694  N4   DC I 132      87.319  86.323 -12.283  1.00 51.98           N  \\nATOM   2695  C5   DC I 132      85.167  87.370 -12.280  1.00 51.98           C  \\nATOM   2696  C6   DC I 132      84.189  87.901 -11.536  1.00 51.98           C  \\nATOM   2697  P    DA I 133      80.090  91.167  -7.580  1.00 53.13           P  \\nATOM   2698  OP1  DA I 133      78.852  90.350  -7.428  1.00 53.13           O  \\nATOM   2699  OP2  DA I 133      80.077  92.373  -8.459  1.00 53.13           O  \\nATOM   2700  O5'  DA I 133      80.622  91.604  -6.146  1.00 68.57           O  \\nATOM   2701  C5'  DA I 133      80.997  90.618  -5.182  1.00 68.57           C  \\nATOM   2702  C4'  DA I 133      82.263  91.026  -4.462  1.00 68.57           C  \\nATOM   2703  O4'  DA I 133      83.414  90.883  -5.327  1.00 68.57           O  \\nATOM   2704  C3'  DA I 133      82.287  92.466  -3.961  1.00 68.57           C  \\nATOM   2705  O3'  DA I 133      83.004  92.523  -2.730  1.00 68.57           O  \\nATOM   2706  C2'  DA I 133      83.024  93.204  -5.064  1.00 68.57           C  \\nATOM   2707  C1'  DA I 133      83.992  92.152  -5.604  1.00 68.57           C  \\nATOM   2708  N9   DA I 133      84.208  92.210  -7.047  1.00 67.29           N  \\nATOM   2709  C8   DA I 133      83.419  92.769  -8.036  1.00 67.29           C  \\nATOM   2710  N7   DA I 133      83.876  92.570  -9.248  1.00 67.29           N  \\nATOM   2711  C5   DA I 133      85.049  91.847  -9.041  1.00 67.29           C  \\nATOM   2712  C6   DA I 133      85.994  91.312  -9.921  1.00 67.29           C  \\nATOM   2713  N6   DA I 133      85.906  91.412 -11.244  1.00 67.29           N  \\nATOM   2714  N1   DA I 133      87.047  90.654  -9.390  1.00 67.29           N  \\nATOM   2715  C2   DA I 133      87.137  90.550  -8.063  1.00 67.29           C  \\nATOM   2716  N3   DA I 133      86.313  91.004  -7.131  1.00 67.29           N  \\nATOM   2717  C4   DA I 133      85.275  91.645  -7.692  1.00 67.29           C  \\nATOM   2718  P    DG I 134      82.938  93.847  -1.832  1.00 71.31           P  \\nATOM   2719  OP1  DG I 134      82.165  93.571  -0.602  1.00 71.31           O  \\nATOM   2720  OP2  DG I 134      82.560  94.997  -2.691  1.00 71.31           O  \\nATOM   2721  O5'  DG I 134      84.450  94.035  -1.409  1.00 72.42           O  \\nATOM   2722  C5'  DG I 134      85.085  95.273  -1.619  1.00 72.42           C  \\nATOM   2723  C4'  DG I 134      86.452  95.064  -2.215  1.00 72.42           C  \\nATOM   2724  O4'  DG I 134      86.382  94.500  -3.553  1.00 72.42           O  \\nATOM   2725  C3'  DG I 134      87.161  96.399  -2.356  1.00 72.42           C  \\nATOM   2726  O3'  DG I 134      88.515  96.244  -1.986  1.00 72.42           O  \\nATOM   2727  C2'  DG I 134      87.031  96.726  -3.828  1.00 72.42           C  \\nATOM   2728  C1'  DG I 134      87.067  95.352  -4.463  1.00 72.42           C  \\nATOM   2729  N9   DG I 134      86.387  95.310  -5.757  1.00 53.77           N  \\nATOM   2730  C8   DG I 134      85.109  95.749  -6.045  1.00 53.77           C  \\nATOM   2731  N7   DG I 134      84.783  95.610  -7.306  1.00 53.77           N  \\nATOM   2732  C5   DG I 134      85.906  95.032  -7.885  1.00 53.77           C  \\nATOM   2733  C6   DG I 134      86.138  94.638  -9.220  1.00 53.77           C  \\nATOM   2734  O6   DG I 134      85.364  94.698 -10.183  1.00 53.77           O  \\nATOM   2735  N1   DG I 134      87.422  94.121  -9.382  1.00 53.77           N  \\nATOM   2736  C2   DG I 134      88.356  93.994  -8.378  1.00 53.77           C  \\nATOM   2737  N2   DG I 134      89.541  93.503  -8.751  1.00 53.77           N  \\nATOM   2738  N3   DG I 134      88.145  94.332  -7.118  1.00 53.77           N  \\nATOM   2739  C4   DG I 134      86.909  94.845  -6.943  1.00 53.77           C  \\nATOM   2740  P    DG I 135      89.323  97.505  -1.441  1.00121.64           P  \\nATOM   2741  OP1  DG I 135      89.552  97.299   0.011  1.00121.64           O  \\nATOM   2742  OP2  DG I 135      88.585  98.710  -1.912  1.00121.64           O  \\nATOM   2743  O5'  DG I 135      90.707  97.393  -2.217  1.00 79.97           O  \\nATOM   2744  C5'  DG I 135      90.749  96.792  -3.505  1.00 79.97           C  \\nATOM   2745  C4'  DG I 135      91.858  97.388  -4.336  1.00 79.97           C  \\nATOM   2746  O4'  DG I 135      91.615  96.934  -5.690  1.00 79.97           O  \\nATOM   2747  C3'  DG I 135      91.848  98.918  -4.392  1.00 79.97           C  \\nATOM   2748  O3'  DG I 135      93.179  99.452  -4.509  1.00 79.97           O  \\nATOM   2749  C2'  DG I 135      91.019  99.214  -5.621  1.00 79.97           C  \\nATOM   2750  C1'  DG I 135      91.314  98.034  -6.526  1.00 79.97           C  \\nATOM   2751  N9   DG I 135      90.146  97.695  -7.322  1.00 55.24           N  \\nATOM   2752  C8   DG I 135      88.833  97.824  -6.952  1.00 55.24           C  \\nATOM   2753  N7   DG I 135      88.004  97.554  -7.917  1.00 55.24           N  \\nATOM   2754  C5   DG I 135      88.822  97.198  -8.974  1.00 55.24           C  \\nATOM   2755  C6   DG I 135      88.497  96.816 -10.288  1.00 55.24           C  \\nATOM   2756  O6   DG I 135      87.383  96.703 -10.808  1.00 55.24           O  \\nATOM   2757  N1   DG I 135      89.637  96.549 -11.037  1.00 55.24           N  \\nATOM   2758  C2   DG I 135      90.924  96.627 -10.572  1.00 55.24           C  \\nATOM   2759  N2   DG I 135      91.884  96.320 -11.449  1.00 55.24           N  \\nATOM   2760  N3   DG I 135      91.239  96.979  -9.342  1.00 55.24           N  \\nATOM   2761  C4   DG I 135      90.146  97.255  -8.607  1.00 55.24           C  \\nATOM   2762  P    DT I 136      93.435 100.824  -5.324  1.00 85.90           P  \\nATOM   2763  OP1  DT I 136      94.750 101.374  -4.906  1.00 85.90           O  \\nATOM   2764  OP2  DT I 136      92.223 101.683  -5.257  1.00 85.90           O  \\nATOM   2765  O5'  DT I 136      93.566 100.340  -6.834  1.00 99.73           O  \\nATOM   2766  C5'  DT I 136      94.698  99.590  -7.265  1.00 99.73           C  \\nATOM   2767  C4'  DT I 136      95.167 100.108  -8.602  1.00 99.73           C  \\nATOM   2768  O4'  DT I 136      94.196  99.731  -9.609  1.00 99.73           O  \\nATOM   2769  C3'  DT I 136      95.250 101.634  -8.637  1.00 99.73           C  \\nATOM   2770  O3'  DT I 136      96.374 102.093  -9.396  1.00 99.73           O  \\nATOM   2771  C2'  DT I 136      93.949 102.044  -9.294  1.00 99.73           C  \\nATOM   2772  C1'  DT I 136      93.644 100.885 -10.227  1.00 99.73           C  \\nATOM   2773  N1   DT I 136      92.191 100.682 -10.355  1.00 66.59           N  \\nATOM   2774  C2   DT I 136      91.627 100.417 -11.591  1.00 66.59           C  \\nATOM   2775  O2   DT I 136      92.271 100.268 -12.616  1.00 66.59           O  \\nATOM   2776  N3   DT I 136      90.268 100.323 -11.578  1.00 66.59           N  \\nATOM   2777  C4   DT I 136      89.431 100.435 -10.485  1.00 66.59           C  \\nATOM   2778  O4   DT I 136      88.219 100.325 -10.643  1.00 66.59           O  \\nATOM   2779  C5   DT I 136      90.095 100.679  -9.218  1.00 66.59           C  \\nATOM   2780  C7   DT I 136      89.286 100.794  -7.966  1.00 66.59           C  \\nATOM   2781  C6   DT I 136      91.417 100.789  -9.223  1.00 66.59           C  \\nATOM   2782  P    DG I 137      96.339 103.559 -10.062  1.00111.43           P  \\nATOM   2783  OP1  DG I 137      97.722 103.971 -10.392  1.00111.43           O  \\nATOM   2784  OP2  DG I 137      95.492 104.458  -9.228  1.00111.43           O  \\nATOM   2785  O5'  DG I 137      95.577 103.276 -11.425  1.00112.14           O  \\nATOM   2786  C5'  DG I 137      96.137 102.405 -12.406  1.00112.14           C  \\nATOM   2787  C4'  DG I 137      95.875 102.969 -13.780  1.00112.14           C  \\nATOM   2788  O4'  DG I 137      94.462 102.837 -14.068  1.00112.14           O  \\nATOM   2789  C3'  DG I 137      96.178 104.465 -13.824  1.00112.14           C  \\nATOM   2790  O3'  DG I 137      96.689 104.874 -15.097  1.00112.14           O  \\nATOM   2791  C2'  DG I 137      94.840 105.106 -13.504  1.00112.14           C  \\nATOM   2792  C1'  DG I 137      93.827 104.112 -14.058  1.00112.14           C  \\nATOM   2793  N9   DG I 137      92.616 104.004 -13.246  1.00 71.97           N  \\nATOM   2794  C8   DG I 137      92.495 104.212 -11.884  1.00 71.97           C  \\nATOM   2795  N7   DG I 137      91.275 104.049 -11.447  1.00 71.97           N  \\nATOM   2796  C5   DG I 137      90.550 103.709 -12.583  1.00 71.97           C  \\nATOM   2797  C6   DG I 137      89.187 103.418 -12.736  1.00 71.97           C  \\nATOM   2798  O6   DG I 137      88.316 103.381 -11.865  1.00 71.97           O  \\nATOM   2799  N1   DG I 137      88.867 103.149 -14.064  1.00 71.97           N  \\nATOM   2800  C2   DG I 137      89.754 103.149 -15.109  1.00 71.97           C  \\nATOM   2801  N2   DG I 137      89.251 102.863 -16.309  1.00 71.97           N  \\nATOM   2802  N3   DG I 137      91.033 103.410 -14.982  1.00 71.97           N  \\nATOM   2803  C4   DG I 137      91.363 103.682 -13.700  1.00 71.97           C  \\nATOM   2804  P    DG I 138      96.674 106.432 -15.491  1.00106.48           P  \\nATOM   2805  OP1  DG I 138      97.622 106.655 -16.610  1.00106.48           O  \\nATOM   2806  OP2  DG I 138      96.781 107.256 -14.255  1.00106.48           O  \\nATOM   2807  O5'  DG I 138      95.206 106.636 -16.049  1.00108.29           O  \\nATOM   2808  C5'  DG I 138      94.733 105.843 -17.125  1.00108.29           C  \\nATOM   2809  C4'  DG I 138      93.495 106.476 -17.698  1.00108.29           C  \\nATOM   2810  O4'  DG I 138      92.394 106.312 -16.779  1.00108.29           O  \\nATOM   2811  C3'  DG I 138      93.646 107.982 -17.889  1.00108.29           C  \\nATOM   2812  O3'  DG I 138      92.822 108.340 -18.986  1.00108.29           O  \\nATOM   2813  C2'  DG I 138      93.066 108.543 -16.604  1.00108.29           C  \\nATOM   2814  C1'  DG I 138      91.909 107.592 -16.421  1.00108.29           C  \\nATOM   2815  N9   DG I 138      91.300 107.490 -15.104  1.00 47.71           N  \\nATOM   2816  C8   DG I 138      91.811 107.822 -13.868  1.00 47.71           C  \\nATOM   2817  N7   DG I 138      90.960 107.616 -12.896  1.00 47.71           N  \\nATOM   2818  C5   DG I 138      89.834 107.112 -13.537  1.00 47.71           C  \\nATOM   2819  C6   DG I 138      88.587 106.706 -13.024  1.00 47.71           C  \\nATOM   2820  O6   DG I 138      88.205 106.668 -11.838  1.00 47.71           O  \\nATOM   2821  N1   DG I 138      87.730 106.297 -14.044  1.00 47.71           N  \\nATOM   2822  C2   DG I 138      88.047 106.253 -15.377  1.00 47.71           C  \\nATOM   2823  N2   DG I 138      87.093 105.829 -16.215  1.00 47.71           N  \\nATOM   2824  N3   DG I 138      89.206 106.602 -15.857  1.00 47.71           N  \\nATOM   2825  C4   DG I 138      90.041 107.028 -14.894  1.00 47.71           C  \\nATOM   2826  P    DA I 139      93.040 109.736 -19.730  1.00 87.47           P  \\nATOM   2827  OP1  DA I 139      94.239 109.625 -20.595  1.00 87.47           O  \\nATOM   2828  OP2  DA I 139      92.946 110.826 -18.723  1.00 87.47           O  \\nATOM   2829  O5'  DA I 139      91.752 109.811 -20.651  1.00 58.85           O  \\nATOM   2830  C5'  DA I 139      91.129 108.618 -21.105  1.00 58.85           C  \\nATOM   2831  C4'  DA I 139      89.644 108.684 -20.846  1.00 58.85           C  \\nATOM   2832  O4'  DA I 139      89.343 108.430 -19.450  1.00 58.85           O  \\nATOM   2833  C3'  DA I 139      89.012 110.035 -21.184  1.00 58.85           C  \\nATOM   2834  O3'  DA I 139      87.791 109.821 -21.896  1.00 58.85           O  \\nATOM   2835  C2'  DA I 139      88.741 110.648 -19.819  1.00 58.85           C  \\nATOM   2836  C1'  DA I 139      88.441 109.418 -18.983  1.00 58.85           C  \\nATOM   2837  N9   DA I 139      88.651 109.588 -17.546  1.00 41.52           N  \\nATOM   2838  C8   DA I 139      89.836 109.847 -16.900  1.00 41.52           C  \\nATOM   2839  N7   DA I 139      89.714 109.977 -15.599  1.00 41.52           N  \\nATOM   2840  C5   DA I 139      88.359 109.779 -15.369  1.00 41.52           C  \\nATOM   2841  C6   DA I 139      87.595 109.776 -14.191  1.00 41.52           C  \\nATOM   2842  N6   DA I 139      88.117 109.966 -12.977  1.00 41.52           N  \\nATOM   2843  N1   DA I 139      86.265 109.560 -14.304  1.00 41.52           N  \\nATOM   2844  C2   DA I 139      85.753 109.339 -15.526  1.00 41.52           C  \\nATOM   2845  N3   DA I 139      86.371 109.297 -16.706  1.00 41.52           N  \\nATOM   2846  C4   DA I 139      87.689 109.533 -16.558  1.00 41.52           C  \\nATOM   2847  P    DT I 140      87.167 111.004 -22.789  1.00 84.09           P  \\nATOM   2848  OP1  DT I 140      86.761 110.435 -24.104  1.00 84.09           O  \\nATOM   2849  OP2  DT I 140      88.085 112.178 -22.736  1.00 84.09           O  \\nATOM   2850  O5'  DT I 140      85.841 111.398 -22.001  1.00 83.73           O  \\nATOM   2851  C5'  DT I 140      84.924 110.398 -21.555  1.00 83.73           C  \\nATOM   2852  C4'  DT I 140      83.999 110.977 -20.511  1.00 83.73           C  \\nATOM   2853  O4'  DT I 140      84.605 111.019 -19.192  1.00 83.73           O  \\nATOM   2854  C3'  DT I 140      83.533 112.405 -20.804  1.00 83.73           C  \\nATOM   2855  O3'  DT I 140      82.175 112.497 -20.407  1.00 83.73           O  \\nATOM   2856  C2'  DT I 140      84.351 113.233 -19.827  1.00 83.73           C  \\nATOM   2857  C1'  DT I 140      84.355 112.301 -18.635  1.00 83.73           C  \\nATOM   2858  N1   DT I 140      85.341 112.567 -17.558  1.00 60.47           N  \\nATOM   2859  C2   DT I 140      84.890 112.528 -16.242  1.00 60.47           C  \\nATOM   2860  O2   DT I 140      83.740 112.253 -15.926  1.00 60.47           O  \\nATOM   2861  N3   DT I 140      85.845 112.818 -15.298  1.00 60.47           N  \\nATOM   2862  C4   DT I 140      87.177 113.123 -15.517  1.00 60.47           C  \\nATOM   2863  O4   DT I 140      87.914 113.370 -14.563  1.00 60.47           O  \\nATOM   2864  C5   DT I 140      87.587 113.121 -16.909  1.00 60.47           C  \\nATOM   2865  C7   DT I 140      89.016 113.413 -17.239  1.00 60.47           C  \\nATOM   2866  C6   DT I 140      86.660 112.852 -17.847  1.00 60.47           C  \\nATOM   2867  P    DA I 141      81.047 112.942 -21.452  1.00 98.02           P  \\nATOM   2868  OP1  DA I 141      80.978 111.958 -22.565  1.00 98.02           O  \\nATOM   2869  OP2  DA I 141      81.254 114.385 -21.757  1.00 98.02           O  \\nATOM   2870  O5'  DA I 141      79.741 112.792 -20.552  1.00 77.28           O  \\nATOM   2871  C5'  DA I 141      79.650 111.742 -19.572  1.00 77.28           C  \\nATOM   2872  C4'  DA I 141      79.236 112.283 -18.218  1.00 77.28           C  \\nATOM   2873  O4'  DA I 141      80.339 112.651 -17.360  1.00 77.28           O  \\nATOM   2874  C3'  DA I 141      78.306 113.488 -18.224  1.00 77.28           C  \\nATOM   2875  O3'  DA I 141      77.341 113.312 -17.210  1.00 77.28           O  \\nATOM   2876  C2'  DA I 141      79.206 114.629 -17.805  1.00 77.28           C  \\nATOM   2877  C1'  DA I 141      80.067 113.923 -16.793  1.00 77.28           C  \\nATOM   2878  N9   DA I 141      81.340 114.572 -16.522  1.00 41.39           N  \\nATOM   2879  C8   DA I 141      82.301 115.006 -17.401  1.00 41.39           C  \\nATOM   2880  N7   DA I 141      83.372 115.487 -16.816  1.00 41.39           N  \\nATOM   2881  C5   DA I 141      83.086 115.373 -15.461  1.00 41.39           C  \\nATOM   2882  C6   DA I 141      83.819 115.697 -14.307  1.00 41.39           C  \\nATOM   2883  N6   DA I 141      85.057 116.199 -14.326  1.00 41.39           N  \\nATOM   2884  N1   DA I 141      83.228 115.476 -13.114  1.00 41.39           N  \\nATOM   2885  C2   DA I 141      81.993 114.958 -13.089  1.00 41.39           C  \\nATOM   2886  N3   DA I 141      81.212 114.601 -14.102  1.00 41.39           N  \\nATOM   2887  C4   DA I 141      81.827 114.836 -15.271  1.00 41.39           C  \\nATOM   2888  P    DT I 142      75.820 113.641 -17.529  1.00 89.61           P  \\nATOM   2889  OP1  DT I 142      75.130 112.405 -17.987  1.00 89.61           O  \\nATOM   2890  OP2  DT I 142      75.806 114.866 -18.379  1.00 89.61           O  \\nATOM   2891  O5'  DT I 142      75.267 114.038 -16.113  1.00 62.85           O  \\nATOM   2892  C5'  DT I 142      75.496 115.328 -15.638  1.00 62.85           C  \\nATOM   2893  C4'  DT I 142      75.937 115.261 -14.205  1.00 62.85           C  \\nATOM   2894  O4'  DT I 142      77.377 115.412 -14.135  1.00 62.85           O  \\nATOM   2895  C3'  DT I 142      75.342 116.419 -13.418  1.00 62.85           C  \\nATOM   2896  O3'  DT I 142      74.886 115.950 -12.161  1.00 62.85           O  \\nATOM   2897  C2'  DT I 142      76.478 117.421 -13.307  1.00 62.85           C  \\nATOM   2898  C1'  DT I 142      77.709 116.541 -13.334  1.00 62.85           C  \\nATOM   2899  N1   DT I 142      78.884 117.203 -13.925  1.00 53.31           N  \\nATOM   2900  C2   DT I 142      79.854 117.660 -13.058  1.00 53.31           C  \\nATOM   2901  O2   DT I 142      79.775 117.543 -11.840  1.00 53.31           O  \\nATOM   2902  N3   DT I 142      80.926 118.264 -13.668  1.00 53.31           N  \\nATOM   2903  C4   DT I 142      81.119 118.453 -15.019  1.00 53.31           C  \\nATOM   2904  O4   DT I 142      82.135 119.015 -15.408  1.00 53.31           O  \\nATOM   2905  C5   DT I 142      80.063 117.950 -15.871  1.00 53.31           C  \\nATOM   2906  C7   DT I 142      80.193 118.103 -17.351  1.00 53.31           C  \\nATOM   2907  C6   DT I 142      79.011 117.361 -15.290  1.00 53.31           C  \\nATOM   2908  P    DT I 143      73.749 116.764 -11.398  1.00 50.87           P  \\nATOM   2909  OP1  DT I 143      73.107 115.840 -10.426  1.00 50.87           O  \\nATOM   2910  OP2  DT I 143      72.931 117.423 -12.455  1.00 50.87           O  \\nATOM   2911  O5'  DT I 143      74.586 117.854 -10.595  1.00 52.75           O  \\nATOM   2912  C5'  DT I 143      75.529 117.439  -9.614  1.00 52.75           C  \\nATOM   2913  C4'  DT I 143      76.327 118.613  -9.100  1.00 52.75           C  \\nATOM   2914  O4'  DT I 143      77.414 118.975  -9.988  1.00 52.75           O  \\nATOM   2915  C3'  DT I 143      75.532 119.892  -8.844  1.00 52.75           C  \\nATOM   2916  O3'  DT I 143      75.847 120.366  -7.532  1.00 52.75           O  \\nATOM   2917  C2'  DT I 143      76.039 120.846  -9.915  1.00 52.75           C  \\nATOM   2918  C1'  DT I 143      77.474 120.385 -10.086  1.00 52.75           C  \\nATOM   2919  N1   DT I 143      78.118 120.732 -11.365  1.00 39.29           N  \\nATOM   2920  C2   DT I 143      79.389 121.262 -11.319  1.00 39.29           C  \\nATOM   2921  O2   DT I 143      80.001 121.462 -10.273  1.00 39.29           O  \\nATOM   2922  N3   DT I 143      79.926 121.551 -12.550  1.00 39.29           N  \\nATOM   2923  C4   DT I 143      79.333 121.373 -13.788  1.00 39.29           C  \\nATOM   2924  O4   DT I 143      79.949 121.679 -14.813  1.00 39.29           O  \\nATOM   2925  C5   DT I 143      78.004 120.819 -13.758  1.00 39.29           C  \\nATOM   2926  C7   DT I 143      77.288 120.593 -15.051  1.00 39.29           C  \\nATOM   2927  C6   DT I 143      77.469 120.529 -12.564  1.00 39.29           C  \\nATOM   2928  P    DG I 144      74.960 121.526  -6.861  1.00 47.55           P  \\nATOM   2929  OP1  DG I 144      74.698 121.199  -5.437  1.00 47.55           O  \\nATOM   2930  OP2  DG I 144      73.825 121.821  -7.773  1.00 47.55           O  \\nATOM   2931  O5'  DG I 144      75.965 122.750  -6.856  1.00 82.56           O  \\nATOM   2932  C5'  DG I 144      77.159 122.687  -6.089  1.00 82.56           C  \\nATOM   2933  C4'  DG I 144      77.953 123.949  -6.296  1.00 82.56           C  \\nATOM   2934  O4'  DG I 144      78.575 123.924  -7.601  1.00 82.56           O  \\nATOM   2935  C3'  DG I 144      77.083 125.205  -6.261  1.00 82.56           C  \\nATOM   2936  O3'  DG I 144      77.749 126.200  -5.487  1.00 82.56           O  \\nATOM   2937  C2'  DG I 144      76.931 125.579  -7.726  1.00 82.56           C  \\nATOM   2938  C1'  DG I 144      78.242 125.101  -8.304  1.00 82.56           C  \\nATOM   2939  N9   DG I 144      78.214 124.789  -9.725  1.00 43.55           N  \\nATOM   2940  C8   DG I 144      77.147 124.358 -10.478  1.00 43.55           C  \\nATOM   2941  N7   DG I 144      77.434 124.234 -11.751  1.00 43.55           N  \\nATOM   2942  C5   DG I 144      78.778 124.588 -11.836  1.00 43.55           C  \\nATOM   2943  C6   DG I 144      79.649 124.676 -12.970  1.00 43.55           C  \\nATOM   2944  O6   DG I 144      79.394 124.441 -14.164  1.00 43.55           O  \\nATOM   2945  N1   DG I 144      80.930 125.093 -12.599  1.00 43.55           N  \\nATOM   2946  C2   DG I 144      81.329 125.378 -11.304  1.00 43.55           C  \\nATOM   2947  N2   DG I 144      82.614 125.737 -11.143  1.00 43.55           N  \\nATOM   2948  N3   DG I 144      80.529 125.311 -10.250  1.00 43.55           N  \\nATOM   2949  C4   DG I 144      79.277 124.915 -10.588  1.00 43.55           C  \\nATOM   2950  P    DA I 145      77.299 127.736  -5.581  1.00 80.34           P  \\nATOM   2951  OP1  DA I 145      77.036 128.227  -4.199  1.00 80.34           O  \\nATOM   2952  OP2  DA I 145      76.242 127.875  -6.628  1.00 80.34           O  \\nATOM   2953  O5'  DA I 145      78.641 128.412  -6.099  1.00 66.94           O  \\nATOM   2954  C5'  DA I 145      79.915 128.027  -5.575  1.00 66.94           C  \\nATOM   2955  C4'  DA I 145      80.984 128.823  -6.279  1.00 66.94           C  \\nATOM   2956  O4'  DA I 145      81.139 128.254  -7.599  1.00 66.94           O  \\nATOM   2957  C3'  DA I 145      80.486 130.256  -6.486  1.00 66.94           C  \\nATOM   2958  O3'  DA I 145      81.434 131.297  -6.294  1.00 66.94           O  \\nATOM   2959  C2'  DA I 145      80.033 130.295  -7.922  1.00 66.94           C  \\nATOM   2960  C1'  DA I 145      80.873 129.235  -8.580  1.00 66.94           C  \\nATOM   2961  N9   DA I 145      80.030 128.648  -9.597  1.00 35.04           N  \\nATOM   2962  C8   DA I 145      78.795 128.088  -9.435  1.00 35.04           C  \\nATOM   2963  N7   DA I 145      78.194 127.806 -10.566  1.00 35.04           N  \\nATOM   2964  C5   DA I 145      79.116 128.174 -11.528  1.00 35.04           C  \\nATOM   2965  C6   DA I 145      79.076 128.151 -12.915  1.00 35.04           C  \\nATOM   2966  N6   DA I 145      78.000 127.778 -13.615  1.00 35.04           N  \\nATOM   2967  N1   DA I 145      80.185 128.555 -13.582  1.00 35.04           N  \\nATOM   2968  C2   DA I 145      81.238 128.990 -12.874  1.00 35.04           C  \\nATOM   2969  N3   DA I 145      81.379 129.087 -11.563  1.00 35.04           N  \\nATOM   2970  C4   DA I 145      80.270 128.652 -10.942  1.00 35.04           C  \\nATOM   2971  P    DT I 146      80.908 132.819  -6.318  1.00 79.53           P  \\nATOM   2972  OP1  DT I 146      80.973 133.380  -4.940  1.00 79.53           O  \\nATOM   2973  OP2  DT I 146      79.613 132.831  -7.059  1.00 79.53           O  \\nATOM   2974  O5'  DT I 146      81.967 133.557  -7.237  1.00 74.83           O  \\nATOM   2975  C5'  DT I 146      83.074 132.860  -7.785  1.00 74.83           C  \\nATOM   2976  C4'  DT I 146      83.354 133.389  -9.168  1.00 74.83           C  \\nATOM   2977  O4'  DT I 146      82.627 132.623 -10.160  1.00 74.83           O  \\nATOM   2978  C3'  DT I 146      82.906 134.845  -9.336  1.00 74.83           C  \\nATOM   2979  O3'  DT I 146      83.686 135.572 -10.277  1.00 74.83           O  \\nATOM   2980  C2'  DT I 146      81.571 134.698 -10.036  1.00 74.83           C  \\nATOM   2981  C1'  DT I 146      81.855 133.512 -10.943  1.00 74.83           C  \\nATOM   2982  N1   DT I 146      80.646 132.808 -11.374  1.00 54.79           N  \\nATOM   2983  C2   DT I 146      80.514 132.436 -12.701  1.00 54.79           C  \\nATOM   2984  O2   DT I 146      81.383 132.604 -13.545  1.00 54.79           O  \\nATOM   2985  N3   DT I 146      79.317 131.852 -13.004  1.00 54.79           N  \\nATOM   2986  C4   DT I 146      78.270 131.586 -12.142  1.00 54.79           C  \\nATOM   2987  O4   DT I 146      77.247 131.053 -12.576  1.00 54.79           O  \\nATOM   2988  C5   DT I 146      78.492 131.980 -10.758  1.00 54.79           C  \\nATOM   2989  C7   DT I 146      77.426 131.738  -9.738  1.00 54.79           C  \\nATOM   2990  C6   DT I 146      79.654 132.556 -10.453  1.00 54.79           C  \\nTER    2991       DT I 146                                                      \\nATOM   2992  O5'  DA J 147      76.848 129.368 -22.671  1.00202.00           O  \\nATOM   2993  C5'  DA J 147      77.522 130.162 -23.648  1.00202.00           C  \\nATOM   2994  C4'  DA J 147      78.764 130.836 -23.109  1.00202.00           C  \\nATOM   2995  O4'  DA J 147      78.414 131.513 -21.877  1.00202.00           O  \\nATOM   2996  C3'  DA J 147      79.913 129.883 -22.767  1.00202.00           C  \\nATOM   2997  O3'  DA J 147      81.187 130.417 -23.150  1.00202.00           O  \\nATOM   2998  C2'  DA J 147      79.844 129.760 -21.259  1.00202.00           C  \\nATOM   2999  C1'  DA J 147      79.251 131.085 -20.815  1.00202.00           C  \\nATOM   3000  N9   DA J 147      78.423 130.903 -19.624  1.00 42.19           N  \\nATOM   3001  C8   DA J 147      77.192 130.281 -19.553  1.00 42.19           C  \\nATOM   3002  N7   DA J 147      76.737 130.142 -18.323  1.00 42.19           N  \\nATOM   3003  C5   DA J 147      77.720 130.730 -17.533  1.00 42.19           C  \\nATOM   3004  C6   DA J 147      77.848 130.885 -16.129  1.00 42.19           C  \\nATOM   3005  N6   DA J 147      76.962 130.413 -15.239  1.00 42.19           N  \\nATOM   3006  N1   DA J 147      78.937 131.539 -15.669  1.00 42.19           N  \\nATOM   3007  C2   DA J 147      79.835 131.999 -16.558  1.00 42.19           C  \\nATOM   3008  N3   DA J 147      79.835 131.902 -17.897  1.00 42.19           N  \\nATOM   3009  C4   DA J 147      78.743 131.244 -18.325  1.00 42.19           C  \\nATOM   3010  P    DT J 148      82.495 129.470 -23.114  1.00128.18           P  \\nATOM   3011  OP1  DT J 148      83.399 129.898 -24.212  1.00128.18           O  \\nATOM   3012  OP2  DT J 148      82.045 128.054 -23.052  1.00128.18           O  \\nATOM   3013  O5'  DT J 148      83.193 129.827 -21.726  1.00106.82           O  \\nATOM   3014  C5'  DT J 148      83.880 131.065 -21.547  1.00106.82           C  \\nATOM   3015  C4'  DT J 148      84.714 131.023 -20.287  1.00106.82           C  \\nATOM   3016  O4'  DT J 148      83.843 130.994 -19.131  1.00106.82           O  \\nATOM   3017  C3'  DT J 148      85.606 129.786 -20.168  1.00106.82           C  \\nATOM   3018  O3'  DT J 148      86.813 130.112 -19.470  1.00106.82           O  \\nATOM   3019  C2'  DT J 148      84.775 128.851 -19.316  1.00106.82           C  \\nATOM   3020  C1'  DT J 148      84.115 129.829 -18.362  1.00106.82           C  \\nATOM   3021  N1   DT J 148      82.844 129.339 -17.800  1.00 74.82           N  \\nATOM   3022  C2   DT J 148      82.644 129.447 -16.437  1.00 74.82           C  \\nATOM   3023  O2   DT J 148      83.472 129.937 -15.669  1.00 74.82           O  \\nATOM   3024  N3   DT J 148      81.431 128.953 -16.004  1.00 74.82           N  \\nATOM   3025  C4   DT J 148      80.432 128.378 -16.775  1.00 74.82           C  \\nATOM   3026  O4   DT J 148      79.396 127.983 -16.244  1.00 74.82           O  \\nATOM   3027  C5   DT J 148      80.712 128.296 -18.184  1.00 74.82           C  \\nATOM   3028  C7   DT J 148      79.691 127.679 -19.086  1.00 74.82           C  \\nATOM   3029  C6   DT J 148      81.884 128.777 -18.623  1.00 74.82           C  \\nATOM   3030  P    DC J 149      87.956 128.993 -19.286  1.00124.16           P  \\nATOM   3031  OP1  DC J 149      89.001 129.524 -18.366  1.00124.16           O  \\nATOM   3032  OP2  DC J 149      88.336 128.524 -20.646  1.00124.16           O  \\nATOM   3033  O5'  DC J 149      87.219 127.792 -18.544  1.00112.14           O  \\nATOM   3034  C5'  DC J 149      87.955 126.665 -18.078  1.00112.14           C  \\nATOM   3035  C4'  DC J 149      88.475 126.937 -16.687  1.00112.14           C  \\nATOM   3036  O4'  DC J 149      87.390 127.474 -15.893  1.00112.14           O  \\nATOM   3037  C3'  DC J 149      88.982 125.707 -15.943  1.00112.14           C  \\nATOM   3038  O3'  DC J 149      90.151 126.024 -15.185  1.00112.14           O  \\nATOM   3039  C2'  DC J 149      87.804 125.275 -15.093  1.00112.14           C  \\nATOM   3040  C1'  DC J 149      86.921 126.517 -14.949  1.00112.14           C  \\nATOM   3041  N1   DC J 149      85.514 126.201 -15.286  1.00 67.30           N  \\nATOM   3042  C2   DC J 149      84.517 126.304 -14.298  1.00 67.30           C  \\nATOM   3043  O2   DC J 149      84.821 126.731 -13.174  1.00 67.30           O  \\nATOM   3044  N3   DC J 149      83.249 125.933 -14.604  1.00 67.30           N  \\nATOM   3045  C4   DC J 149      82.960 125.487 -15.837  1.00 67.30           C  \\nATOM   3046  N4   DC J 149      81.702 125.097 -16.100  1.00 67.30           N  \\nATOM   3047  C5   DC J 149      83.946 125.410 -16.862  1.00 67.30           C  \\nATOM   3048  C6   DC J 149      85.193 125.776 -16.548  1.00 67.30           C  \\nATOM   3049  P    DA J 150      90.045 127.017 -13.928  1.00106.86           P  \\nATOM   3050  OP1  DA J 150      89.491 128.320 -14.395  1.00106.86           O  \\nATOM   3051  OP2  DA J 150      91.339 126.982 -13.198  1.00106.86           O  \\nATOM   3052  O5'  DA J 150      88.964 126.355 -12.978  1.00 87.06           O  \\nATOM   3053  C5'  DA J 150      88.553 127.028 -11.802  1.00 87.06           C  \\nATOM   3054  C4'  DA J 150      88.199 126.024 -10.735  1.00 87.06           C  \\nATOM   3055  O4'  DA J 150      87.025 125.296 -11.160  1.00 87.06           O  \\nATOM   3056  C3'  DA J 150      89.271 124.975 -10.453  1.00 87.06           C  \\nATOM   3057  O3'  DA J 150      89.286 124.723  -9.041  1.00 87.06           O  \\nATOM   3058  C2'  DA J 150      88.813 123.781 -11.279  1.00 87.06           C  \\nATOM   3059  C1'  DA J 150      87.299 123.908 -11.243  1.00 87.06           C  \\nATOM   3060  N9   DA J 150      86.575 123.398 -12.408  1.00 53.74           N  \\nATOM   3061  C8   DA J 150      87.037 123.107 -13.669  1.00 53.74           C  \\nATOM   3062  N7   DA J 150      86.094 122.727 -14.501  1.00 53.74           N  \\nATOM   3063  C5   DA J 150      84.937 122.755 -13.729  1.00 53.74           C  \\nATOM   3064  C6   DA J 150      83.590 122.468 -14.020  1.00 53.74           C  \\nATOM   3065  N6   DA J 150      83.143 122.125 -15.231  1.00 53.74           N  \\nATOM   3066  N1   DA J 150      82.697 122.564 -13.013  1.00 53.74           N  \\nATOM   3067  C2   DA J 150      83.126 122.948 -11.808  1.00 53.74           C  \\nATOM   3068  N3   DA J 150      84.351 123.266 -11.417  1.00 53.74           N  \\nATOM   3069  C4   DA J 150      85.222 123.146 -12.436  1.00 53.74           C  \\nATOM   3070  P    DA J 151      89.918 123.361  -8.463  1.00 67.15           P  \\nATOM   3071  OP1  DA J 151      90.679 123.681  -7.226  1.00 67.15           O  \\nATOM   3072  OP2  DA J 151      90.589 122.647  -9.577  1.00 67.15           O  \\nATOM   3073  O5'  DA J 151      88.649 122.507  -8.007  1.00 94.04           O  \\nATOM   3074  C5'  DA J 151      87.723 123.052  -7.063  1.00 94.04           C  \\nATOM   3075  C4'  DA J 151      86.667 122.041  -6.674  1.00 94.04           C  \\nATOM   3076  O4'  DA J 151      85.841 121.672  -7.806  1.00 94.04           O  \\nATOM   3077  C3'  DA J 151      87.150 120.736  -6.047  1.00 94.04           C  \\nATOM   3078  O3'  DA J 151      86.273 120.446  -4.938  1.00 94.04           O  \\nATOM   3079  C2'  DA J 151      87.046 119.742  -7.200  1.00 94.04           C  \\nATOM   3080  C1'  DA J 151      85.861 120.267  -8.006  1.00 94.04           C  \\nATOM   3081  N9   DA J 151      85.890 120.047  -9.456  1.00 41.12           N  \\nATOM   3082  C8   DA J 151      86.934 120.244 -10.333  1.00 41.12           C  \\nATOM   3083  N7   DA J 151      86.608 120.068 -11.597  1.00 41.12           N  \\nATOM   3084  C5   DA J 151      85.268 119.708 -11.547  1.00 41.12           C  \\nATOM   3085  C6   DA J 151      84.334 119.417 -12.550  1.00 41.12           C  \\nATOM   3086  N6   DA J 151      84.613 119.455 -13.851  1.00 41.12           N  \\nATOM   3087  N1   DA J 151      83.080 119.090 -12.166  1.00 41.12           N  \\nATOM   3088  C2   DA J 151      82.792 119.068 -10.856  1.00 41.12           C  \\nATOM   3089  N3   DA J 151      83.578 119.333  -9.816  1.00 41.12           N  \\nATOM   3090  C4   DA J 151      84.820 119.656 -10.233  1.00 41.12           C  \\nATOM   3091  P    DT J 152      86.773 119.521  -3.711  1.00 80.90           P  \\nATOM   3092  OP1  DT J 152      86.184 119.982  -2.422  1.00 80.90           O  \\nATOM   3093  OP2  DT J 152      88.237 119.333  -3.829  1.00 80.90           O  \\nATOM   3094  O5'  DT J 152      86.125 118.127  -4.082  1.00 57.87           O  \\nATOM   3095  C5'  DT J 152      85.792 117.873  -5.433  1.00 57.87           C  \\nATOM   3096  C4'  DT J 152      84.463 117.180  -5.507  1.00 57.87           C  \\nATOM   3097  O4'  DT J 152      83.980 117.291  -6.858  1.00 57.87           O  \\nATOM   3098  C3'  DT J 152      84.574 115.698  -5.188  1.00 57.87           C  \\nATOM   3099  O3'  DT J 152      83.448 115.292  -4.409  1.00 57.87           O  \\nATOM   3100  C2'  DT J 152      84.672 115.046  -6.552  1.00 57.87           C  \\nATOM   3101  C1'  DT J 152      83.988 116.031  -7.490  1.00 57.87           C  \\nATOM   3102  N1   DT J 152      84.699 116.188  -8.767  1.00 43.58           N  \\nATOM   3103  C2   DT J 152      83.974 116.078  -9.935  1.00 43.58           C  \\nATOM   3104  O2   DT J 152      82.765 115.879  -9.969  1.00 43.58           O  \\nATOM   3105  N3   DT J 152      84.718 116.192 -11.074  1.00 43.58           N  \\nATOM   3106  C4   DT J 152      86.073 116.387 -11.175  1.00 43.58           C  \\nATOM   3107  O4   DT J 152      86.594 116.447 -12.283  1.00 43.58           O  \\nATOM   3108  C5   DT J 152      86.775 116.495  -9.917  1.00 43.58           C  \\nATOM   3109  C7   DT J 152      88.262 116.678  -9.931  1.00 43.58           C  \\nATOM   3110  C6   DT J 152      86.060 116.410  -8.788  1.00 43.58           C  \\nATOM   3111  P    DA J 153      83.233 113.744  -4.039  1.00 54.44           P  \\nATOM   3112  OP1  DA J 153      82.469 113.744  -2.765  1.00 54.44           O  \\nATOM   3113  OP2  DA J 153      84.512 112.995  -4.124  1.00 54.44           O  \\nATOM   3114  O5'  DA J 153      82.297 113.257  -5.229  1.00 51.97           O  \\nATOM   3115  C5'  DA J 153      81.209 114.076  -5.647  1.00 51.97           C  \\nATOM   3116  C4'  DA J 153      80.481 113.436  -6.799  1.00 51.97           C  \\nATOM   3117  O4'  DA J 153      81.236 113.571  -8.022  1.00 51.97           O  \\nATOM   3118  C3'  DA J 153      80.218 111.948  -6.627  1.00 51.97           C  \\nATOM   3119  O3'  DA J 153      78.914 111.675  -7.152  1.00 51.97           O  \\nATOM   3120  C2'  DA J 153      81.341 111.301  -7.426  1.00 51.97           C  \\nATOM   3121  C1'  DA J 153      81.558 112.294  -8.555  1.00 51.97           C  \\nATOM   3122  N9   DA J 153      82.922 112.376  -9.093  1.00 47.69           N  \\nATOM   3123  C8   DA J 153      84.102 112.499  -8.395  1.00 47.69           C  \\nATOM   3124  N7   DA J 153      85.162 112.617  -9.165  1.00 47.69           N  \\nATOM   3125  C5   DA J 153      84.650 112.560 -10.457  1.00 47.69           C  \\nATOM   3126  C6   DA J 153      85.262 112.646 -11.734  1.00 47.69           C  \\nATOM   3127  N6   DA J 153      86.575 112.835 -11.921  1.00 47.69           N  \\nATOM   3128  N1   DA J 153      84.464 112.537 -12.824  1.00 47.69           N  \\nATOM   3129  C2   DA J 153      83.150 112.362 -12.637  1.00 47.69           C  \\nATOM   3130  N3   DA J 153      82.457 112.279 -11.497  1.00 47.69           N  \\nATOM   3131  C4   DA J 153      83.274 112.388 -10.430  1.00 47.69           C  \\nATOM   3132  P    DT J 154      78.319 110.186  -7.101  1.00 62.64           P  \\nATOM   3133  OP1  DT J 154      76.848 110.349  -7.047  1.00 62.64           O  \\nATOM   3134  OP2  DT J 154      79.018 109.388  -6.049  1.00 62.64           O  \\nATOM   3135  O5'  DT J 154      78.679 109.623  -8.542  1.00 53.68           O  \\nATOM   3136  C5'  DT J 154      78.215 110.310  -9.695  1.00 53.68           C  \\nATOM   3137  C4'  DT J 154      78.607 109.561 -10.942  1.00 53.68           C  \\nATOM   3138  O4'  DT J 154      79.967 109.847 -11.351  1.00 53.68           O  \\nATOM   3139  C3'  DT J 154      78.521 108.048 -10.798  1.00 53.68           C  \\nATOM   3140  O3'  DT J 154      78.037 107.508 -12.024  1.00 53.68           O  \\nATOM   3141  C2'  DT J 154      79.969 107.647 -10.606  1.00 53.68           C  \\nATOM   3142  C1'  DT J 154      80.639 108.620 -11.555  1.00 53.68           C  \\nATOM   3143  N1   DT J 154      82.071 108.831 -11.309  1.00 44.79           N  \\nATOM   3144  C2   DT J 154      82.891 109.029 -12.392  1.00 44.79           C  \\nATOM   3145  O2   DT J 154      82.483 109.045 -13.542  1.00 44.79           O  \\nATOM   3146  N3   DT J 154      84.210 109.207 -12.078  1.00 44.79           N  \\nATOM   3147  C4   DT J 154      84.772 109.215 -10.811  1.00 44.79           C  \\nATOM   3148  O4   DT J 154      85.985 109.408 -10.677  1.00 44.79           O  \\nATOM   3149  C5   DT J 154      83.845 108.997  -9.726  1.00 44.79           C  \\nATOM   3150  C7   DT J 154      84.355 108.984  -8.323  1.00 44.79           C  \\nATOM   3151  C6   DT J 154      82.562 108.818 -10.025  1.00 44.79           C  \\nATOM   3152  P    DC J 155      77.617 105.968 -12.101  1.00 83.45           P  \\nATOM   3153  OP1  DC J 155      76.135 105.902 -12.128  1.00 83.45           O  \\nATOM   3154  OP2  DC J 155      78.378 105.245 -11.041  1.00 83.45           O  \\nATOM   3155  O5'  DC J 155      78.172 105.537 -13.521  1.00 90.12           O  \\nATOM   3156  C5'  DC J 155      79.501 105.863 -13.869  1.00 90.12           C  \\nATOM   3157  C4'  DC J 155      79.700 105.752 -15.358  1.00 90.12           C  \\nATOM   3158  O4'  DC J 155      80.940 106.429 -15.645  1.00 90.12           O  \\nATOM   3159  C3'  DC J 155      79.886 104.313 -15.826  1.00 90.12           C  \\nATOM   3160  O3'  DC J 155      79.364 104.118 -17.145  1.00 90.12           O  \\nATOM   3161  C2'  DC J 155      81.385 104.096 -15.736  1.00 90.12           C  \\nATOM   3162  C1'  DC J 155      82.005 105.496 -15.723  1.00 90.12           C  \\nATOM   3163  N1   DC J 155      82.857 105.697 -14.531  1.00 43.59           N  \\nATOM   3164  C2   DC J 155      84.224 105.950 -14.705  1.00 43.59           C  \\nATOM   3165  O2   DC J 155      84.674 106.071 -15.869  1.00 43.59           O  \\nATOM   3166  N3   DC J 155      85.017 106.052 -13.605  1.00 43.59           N  \\nATOM   3167  C4   DC J 155      84.492 105.915 -12.379  1.00 43.59           C  \\nATOM   3168  N4   DC J 155      85.322 105.971 -11.318  1.00 43.59           N  \\nATOM   3169  C5   DC J 155      83.100 105.701 -12.180  1.00 43.59           C  \\nATOM   3170  C6   DC J 155      82.328 105.604 -13.271  1.00 43.59           C  \\nATOM   3171  P    DC J 156      79.074 102.625 -17.677  1.00 62.07           P  \\nATOM   3172  OP1  DC J 156      77.970 102.683 -18.672  1.00 62.07           O  \\nATOM   3173  OP2  DC J 156      78.958 101.725 -16.492  1.00 62.07           O  \\nATOM   3174  O5'  DC J 156      80.411 102.256 -18.459  1.00 75.04           O  \\nATOM   3175  C5'  DC J 156      81.370 103.276 -18.767  1.00 75.04           C  \\nATOM   3176  C4'  DC J 156      82.596 102.677 -19.415  1.00 75.04           C  \\nATOM   3177  O4'  DC J 156      83.759 103.035 -18.642  1.00 75.04           O  \\nATOM   3178  C3'  DC J 156      82.611 101.154 -19.514  1.00 75.04           C  \\nATOM   3179  O3'  DC J 156      83.274 100.768 -20.715  1.00 75.04           O  \\nATOM   3180  C2'  DC J 156      83.424 100.729 -18.311  1.00 75.04           C  \\nATOM   3181  C1'  DC J 156      84.414 101.867 -18.179  1.00 75.04           C  \\nATOM   3182  N1   DC J 156      84.783 102.101 -16.790  1.00 50.44           N  \\nATOM   3183  C2   DC J 156      86.050 102.570 -16.503  1.00 50.44           C  \\nATOM   3184  O2   DC J 156      86.822 102.827 -17.449  1.00 50.44           O  \\nATOM   3185  N3   DC J 156      86.404 102.742 -15.207  1.00 50.44           N  \\nATOM   3186  C4   DC J 156      85.528 102.484 -14.234  1.00 50.44           C  \\nATOM   3187  N4   DC J 156      85.912 102.652 -12.975  1.00 50.44           N  \\nATOM   3188  C5   DC J 156      84.219 102.035 -14.510  1.00 50.44           C  \\nATOM   3189  C6   DC J 156      83.891 101.854 -15.790  1.00 50.44           C  \\nATOM   3190  P    DA J 157      83.537  99.214 -21.017  1.00 54.11           P  \\nATOM   3191  OP1  DA J 157      83.307  99.032 -22.480  1.00 54.11           O  \\nATOM   3192  OP2  DA J 157      82.803  98.367 -20.023  1.00 54.11           O  \\nATOM   3193  O5'  DA J 157      85.085  99.026 -20.698  1.00 50.89           O  \\nATOM   3194  C5'  DA J 157      86.069  99.691 -21.470  1.00 50.89           C  \\nATOM   3195  C4'  DA J 157      87.433  99.176 -21.093  1.00 50.89           C  \\nATOM   3196  O4'  DA J 157      87.735  99.623 -19.750  1.00 50.89           O  \\nATOM   3197  C3'  DA J 157      87.519  97.651 -21.072  1.00 50.89           C  \\nATOM   3198  O3'  DA J 157      88.737  97.207 -21.695  1.00 50.89           O  \\nATOM   3199  C2'  DA J 157      87.465  97.316 -19.591  1.00 50.89           C  \\nATOM   3200  C1'  DA J 157      88.085  98.531 -18.936  1.00 50.89           C  \\nATOM   3201  N9   DA J 157      87.552  98.795 -17.608  1.00 48.77           N  \\nATOM   3202  C8   DA J 157      86.253  98.627 -17.202  1.00 48.77           C  \\nATOM   3203  N7   DA J 157      86.059  98.885 -15.929  1.00 48.77           N  \\nATOM   3204  C5   DA J 157      87.314  99.262 -15.468  1.00 48.77           C  \\nATOM   3205  C6   DA J 157      87.781  99.639 -14.194  1.00 48.77           C  \\nATOM   3206  N6   DA J 157      87.009  99.679 -13.110  1.00 48.77           N  \\nATOM   3207  N1   DA J 157      89.084  99.966 -14.072  1.00 48.77           N  \\nATOM   3208  C2   DA J 157      89.859  99.907 -15.156  1.00 48.77           C  \\nATOM   3209  N3   DA J 157      89.543  99.555 -16.408  1.00 48.77           N  \\nATOM   3210  C4   DA J 157      88.239  99.235 -16.498  1.00 48.77           C  \\nATOM   3211  P    DC J 158      88.836  95.712 -22.299  1.00 68.14           P  \\nATOM   3212  OP1  DC J 158      89.593  95.758 -23.577  1.00 68.14           O  \\nATOM   3213  OP2  DC J 158      87.491  95.088 -22.278  1.00 68.14           O  \\nATOM   3214  O5'  DC J 158      89.732  94.979 -21.213  1.00 64.73           O  \\nATOM   3215  C5'  DC J 158      89.604  95.323 -19.842  1.00 64.73           C  \\nATOM   3216  C4'  DC J 158      90.959  95.593 -19.237  1.00 64.73           C  \\nATOM   3217  O4'  DC J 158      90.758  96.483 -18.113  1.00 64.73           O  \\nATOM   3218  C3'  DC J 158      91.569  94.319 -18.664  1.00 64.73           C  \\nATOM   3219  O3'  DC J 158      92.983  94.236 -18.794  1.00 64.73           O  \\nATOM   3220  C2'  DC J 158      91.201  94.356 -17.197  1.00 64.73           C  \\nATOM   3221  C1'  DC J 158      91.040  95.827 -16.883  1.00 64.73           C  \\nATOM   3222  N1   DC J 158      89.874  95.969 -16.011  1.00 38.98           N  \\nATOM   3223  C2   DC J 158      90.070  96.256 -14.657  1.00 38.98           C  \\nATOM   3224  O2   DC J 158      91.211  96.528 -14.257  1.00 38.98           O  \\nATOM   3225  N3   DC J 158      89.008  96.238 -13.819  1.00 38.98           N  \\nATOM   3226  C4   DC J 158      87.791  95.978 -14.293  1.00 38.98           C  \\nATOM   3227  N4   DC J 158      86.781  95.923 -13.427  1.00 38.98           N  \\nATOM   3228  C5   DC J 158      87.554  95.752 -15.681  1.00 38.98           C  \\nATOM   3229  C6   DC J 158      88.616  95.760 -16.498  1.00 38.98           C  \\nATOM   3230  P    DC J 159      93.725  92.903 -18.291  1.00 74.22           P  \\nATOM   3231  OP1  DC J 159      95.146  92.957 -18.699  1.00 74.22           O  \\nATOM   3232  OP2  DC J 159      92.878  91.757 -18.711  1.00 74.22           O  \\nATOM   3233  O5'  DC J 159      93.643  92.986 -16.705  1.00 68.71           O  \\nATOM   3234  C5'  DC J 159      94.325  94.011 -15.990  1.00 68.71           C  \\nATOM   3235  C4'  DC J 159      94.639  93.529 -14.594  1.00 68.71           C  \\nATOM   3236  O4'  DC J 159      93.514  93.799 -13.725  1.00 68.71           O  \\nATOM   3237  C3'  DC J 159      94.881  92.024 -14.493  1.00 68.71           C  \\nATOM   3238  O3'  DC J 159      95.792  91.781 -13.416  1.00 68.71           O  \\nATOM   3239  C2'  DC J 159      93.503  91.488 -14.155  1.00 68.71           C  \\nATOM   3240  C1'  DC J 159      92.968  92.579 -13.237  1.00 68.71           C  \\nATOM   3241  N1   DC J 159      91.501  92.715 -13.232  1.00 58.46           N  \\nATOM   3242  C2   DC J 159      90.843  92.990 -12.013  1.00 58.46           C  \\nATOM   3243  O2   DC J 159      91.513  93.056 -10.955  1.00 58.46           O  \\nATOM   3244  N3   DC J 159      89.495  93.169 -12.024  1.00 58.46           N  \\nATOM   3245  C4   DC J 159      88.814  93.071 -13.173  1.00 58.46           C  \\nATOM   3246  N4   DC J 159      87.497  93.285 -13.141  1.00 58.46           N  \\nATOM   3247  C5   DC J 159      89.455  92.758 -14.407  1.00 58.46           C  \\nATOM   3248  C6   DC J 159      90.783  92.592 -14.392  1.00 58.46           C  \\nATOM   3249  P    DT J 160      96.561  90.371 -13.306  1.00 70.67           P  \\nATOM   3250  OP1  DT J 160      98.019  90.661 -13.281  1.00 70.67           O  \\nATOM   3251  OP2  DT J 160      96.014  89.440 -14.329  1.00 70.67           O  \\nATOM   3252  O5'  DT J 160      96.137  89.843 -11.865  1.00 98.25           O  \\nATOM   3253  C5'  DT J 160      96.211  90.699 -10.726  1.00 98.25           C  \\nATOM   3254  C4'  DT J 160      95.385  90.132  -9.596  1.00 98.25           C  \\nATOM   3255  O4'  DT J 160      93.973  90.426  -9.770  1.00 98.25           O  \\nATOM   3256  C3'  DT J 160      95.491  88.610  -9.451  1.00 98.25           C  \\nATOM   3257  O3'  DT J 160      95.541  88.268  -8.070  1.00 98.25           O  \\nATOM   3258  C2'  DT J 160      94.177  88.116 -10.028  1.00 98.25           C  \\nATOM   3259  C1'  DT J 160      93.247  89.222  -9.569  1.00 98.25           C  \\nATOM   3260  N1   DT J 160      91.939  89.321 -10.259  1.00 65.27           N  \\nATOM   3261  C2   DT J 160      90.903  89.894  -9.557  1.00 65.27           C  \\nATOM   3262  O2   DT J 160      91.035  90.370  -8.438  1.00 65.27           O  \\nATOM   3263  N3   DT J 160      89.702  89.899 -10.219  1.00 65.27           N  \\nATOM   3264  C4   DT J 160      89.445  89.426 -11.487  1.00 65.27           C  \\nATOM   3265  O4   DT J 160      88.316  89.497 -11.943  1.00 65.27           O  \\nATOM   3266  C5   DT J 160      90.575  88.874 -12.183  1.00 65.27           C  \\nATOM   3267  C7   DT J 160      90.382  88.375 -13.580  1.00 65.27           C  \\nATOM   3268  C6   DT J 160      91.755  88.840 -11.542  1.00 65.27           C  \\nATOM   3269  P    DG J 161      96.525  87.106  -7.570  1.00124.73           P  \\nATOM   3270  OP1  DG J 161      97.891  87.685  -7.480  1.00124.73           O  \\nATOM   3271  OP2  DG J 161      96.288  85.894  -8.399  1.00124.73           O  \\nATOM   3272  O5'  DG J 161      96.006  86.822  -6.095  1.00118.51           O  \\nATOM   3273  C5'  DG J 161      95.751  87.909  -5.213  1.00118.51           C  \\nATOM   3274  C4'  DG J 161      94.431  87.721  -4.502  1.00118.51           C  \\nATOM   3275  O4'  DG J 161      93.323  87.823  -5.433  1.00118.51           O  \\nATOM   3276  C3'  DG J 161      94.279  86.380  -3.790  1.00118.51           C  \\nATOM   3277  O3'  DG J 161      93.716  86.600  -2.498  1.00118.51           O  \\nATOM   3278  C2'  DG J 161      93.328  85.603  -4.684  1.00118.51           C  \\nATOM   3279  C1'  DG J 161      92.470  86.694  -5.307  1.00118.51           C  \\nATOM   3280  N9   DG J 161      91.957  86.361  -6.637  1.00 77.99           N  \\nATOM   3281  C8   DG J 161      92.616  85.670  -7.625  1.00 77.99           C  \\nATOM   3282  N7   DG J 161      91.904  85.514  -8.708  1.00 77.99           N  \\nATOM   3283  C5   DG J 161      90.703  86.141  -8.422  1.00 77.99           C  \\nATOM   3284  C6   DG J 161      89.550  86.292  -9.213  1.00 77.99           C  \\nATOM   3285  O6   DG J 161      89.349  85.902 -10.368  1.00 77.99           O  \\nATOM   3286  N1   DG J 161      88.557  86.981  -8.535  1.00 77.99           N  \\nATOM   3287  C2   DG J 161      88.666  87.472  -7.259  1.00 77.99           C  \\nATOM   3288  N2   DG J 161      87.593  88.105  -6.780  1.00 77.99           N  \\nATOM   3289  N3   DG J 161      89.744  87.348  -6.510  1.00 77.99           N  \\nATOM   3290  C4   DG J 161      90.717  86.672  -7.147  1.00 77.99           C  \\nATOM   3291  P    DC J 162      93.891  85.493  -1.344  1.00104.81           P  \\nATOM   3292  OP1  DC J 162      94.455  86.163  -0.136  1.00104.81           O  \\nATOM   3293  OP2  DC J 162      94.552  84.282  -1.902  1.00104.81           O  \\nATOM   3294  O5'  DC J 162      92.388  85.121  -1.019  1.00 96.09           O  \\nATOM   3295  C5'  DC J 162      91.425  86.153  -0.881  1.00 96.09           C  \\nATOM   3296  C4'  DC J 162      90.120  85.567  -0.419  1.00 96.09           C  \\nATOM   3297  O4'  DC J 162      89.313  85.363  -1.599  1.00 96.09           O  \\nATOM   3298  C3'  DC J 162      90.287  84.202   0.243  1.00 96.09           C  \\nATOM   3299  O3'  DC J 162      89.615  84.153   1.524  1.00 96.09           O  \\nATOM   3300  C2'  DC J 162      89.941  83.194  -0.846  1.00 96.09           C  \\nATOM   3301  C1'  DC J 162      89.106  83.984  -1.858  1.00 96.09           C  \\nATOM   3302  N1   DC J 162      89.410  83.749  -3.290  1.00 83.72           N  \\nATOM   3303  C2   DC J 162      88.652  84.434  -4.260  1.00 83.72           C  \\nATOM   3304  O2   DC J 162      87.785  85.244  -3.885  1.00 83.72           O  \\nATOM   3305  N3   DC J 162      88.889  84.198  -5.578  1.00 83.72           N  \\nATOM   3306  C4   DC J 162      89.841  83.335  -5.943  1.00 83.72           C  \\nATOM   3307  N4   DC J 162      90.034  83.135  -7.250  1.00 83.72           N  \\nATOM   3308  C5   DC J 162      90.637  82.642  -4.982  1.00 83.72           C  \\nATOM   3309  C6   DC J 162      90.392  82.877  -3.678  1.00 83.72           C  \\nATOM   3310  P    DA J 163      88.086  83.674   1.643  1.00137.94           P  \\nATOM   3311  OP1  DA J 163      87.487  84.428   2.777  1.00137.94           O  \\nATOM   3312  OP2  DA J 163      88.068  82.186   1.666  1.00137.94           O  \\nATOM   3313  O5'  DA J 163      87.423  84.184   0.285  1.00106.21           O  \\nATOM   3314  C5'  DA J 163      86.616  85.367   0.229  1.00106.21           C  \\nATOM   3315  C4'  DA J 163      85.192  84.980  -0.083  1.00106.21           C  \\nATOM   3316  O4'  DA J 163      85.230  84.129  -1.254  1.00106.21           O  \\nATOM   3317  C3'  DA J 163      84.598  84.116   1.026  1.00106.21           C  \\nATOM   3318  O3'  DA J 163      83.178  84.255   1.079  1.00106.21           O  \\nATOM   3319  C2'  DA J 163      84.988  82.712   0.621  1.00106.21           C  \\nATOM   3320  C1'  DA J 163      84.965  82.776  -0.891  1.00106.21           C  \\nATOM   3321  N9   DA J 163      86.005  81.933  -1.475  1.00 87.75           N  \\nATOM   3322  C8   DA J 163      87.003  81.260  -0.814  1.00 87.75           C  \\nATOM   3323  N7   DA J 163      87.792  80.577  -1.601  1.00 87.75           N  \\nATOM   3324  C5   DA J 163      87.282  80.817  -2.869  1.00 87.75           C  \\nATOM   3325  C6   DA J 163      87.677  80.384  -4.146  1.00 87.75           C  \\nATOM   3326  N6   DA J 163      88.724  79.582  -4.369  1.00 87.75           N  \\nATOM   3327  N1   DA J 163      86.947  80.805  -5.203  1.00 87.75           N  \\nATOM   3328  C2   DA J 163      85.896  81.603  -4.982  1.00 87.75           C  \\nATOM   3329  N3   DA J 163      85.430  82.081  -3.831  1.00 87.75           N  \\nATOM   3330  C4   DA J 163      86.178  81.647  -2.803  1.00 87.75           C  \\nATOM   3331  P    DG J 164      82.315  83.322   2.073  1.00 96.36           P  \\nATOM   3332  OP1  DG J 164      81.667  84.187   3.091  1.00 96.36           O  \\nATOM   3333  OP2  DG J 164      83.150  82.170   2.511  1.00 96.36           O  \\nATOM   3334  O5'  DG J 164      81.185  82.759   1.110  1.00 68.80           O  \\nATOM   3335  C5'  DG J 164      80.937  83.398  -0.128  1.00 68.80           C  \\nATOM   3336  C4'  DG J 164      80.863  82.377  -1.236  1.00 68.80           C  \\nATOM   3337  O4'  DG J 164      82.129  81.716  -1.488  1.00 68.80           O  \\nATOM   3338  C3'  DG J 164      79.850  81.253  -1.044  1.00 68.80           C  \\nATOM   3339  O3'  DG J 164      79.301  81.046  -2.333  1.00 68.80           O  \\nATOM   3340  C2'  DG J 164      80.721  80.058  -0.695  1.00 68.80           C  \\nATOM   3341  C1'  DG J 164      81.870  80.328  -1.638  1.00 68.80           C  \\nATOM   3342  N9   DG J 164      83.113  79.592  -1.427  1.00 84.97           N  \\nATOM   3343  C8   DG J 164      83.724  79.291  -0.234  1.00 84.97           C  \\nATOM   3344  N7   DG J 164      84.845  78.636  -0.383  1.00 84.97           N  \\nATOM   3345  C5   DG J 164      84.979  78.493  -1.758  1.00 84.97           C  \\nATOM   3346  C6   DG J 164      86.008  77.879  -2.526  1.00 84.97           C  \\nATOM   3347  O6   DG J 164      87.053  77.331  -2.128  1.00 84.97           O  \\nATOM   3348  N1   DG J 164      85.735  77.955  -3.891  1.00 84.97           N  \\nATOM   3349  C2   DG J 164      84.638  78.564  -4.445  1.00 84.97           C  \\nATOM   3350  N2   DG J 164      84.580  78.544  -5.779  1.00 84.97           N  \\nATOM   3351  N3   DG J 164      83.683  79.147  -3.745  1.00 84.97           N  \\nATOM   3352  C4   DG J 164      83.915  79.071  -2.416  1.00 84.97           C  \\nATOM   3353  P    DA J 165      77.967  80.206  -2.506  1.00 66.14           P  \\nATOM   3354  OP1  DA J 165      76.807  81.107  -2.331  1.00 66.14           O  \\nATOM   3355  OP2  DA J 165      78.088  78.987  -1.671  1.00 66.14           O  \\nATOM   3356  O5'  DA J 165      78.027  79.785  -4.030  1.00 59.08           O  \\nATOM   3357  C5'  DA J 165      77.608  78.499  -4.411  1.00 59.08           C  \\nATOM   3358  C4'  DA J 165      77.871  78.296  -5.878  1.00 59.08           C  \\nATOM   3359  O4'  DA J 165      79.299  78.408  -6.069  1.00 59.08           O  \\nATOM   3360  C3'  DA J 165      77.472  76.901  -6.341  1.00 59.08           C  \\nATOM   3361  O3'  DA J 165      76.660  76.922  -7.529  1.00 59.08           O  \\nATOM   3362  C2'  DA J 165      78.766  76.106  -6.354  1.00 59.08           C  \\nATOM   3363  C1'  DA J 165      79.889  77.137  -6.308  1.00 59.08           C  \\nATOM   3364  N9   DA J 165      80.834  76.876  -5.215  1.00 69.83           N  \\nATOM   3365  C8   DA J 165      80.685  77.199  -3.885  1.00 69.83           C  \\nATOM   3366  N7   DA J 165      81.698  76.829  -3.133  1.00 69.83           N  \\nATOM   3367  C5   DA J 165      82.576  76.223  -4.025  1.00 69.83           C  \\nATOM   3368  C6   DA J 165      83.842  75.621  -3.857  1.00 69.83           C  \\nATOM   3369  N6   DA J 165      84.469  75.517  -2.683  1.00 69.83           N  \\nATOM   3370  N1   DA J 165      84.450  75.120  -4.954  1.00 69.83           N  \\nATOM   3371  C2   DA J 165      83.825  75.210  -6.133  1.00 69.83           C  \\nATOM   3372  N3   DA J 165      82.639  75.741  -6.420  1.00 69.83           N  \\nATOM   3373  C4   DA J 165      82.057  76.242  -5.312  1.00 69.83           C  \\nATOM   3374  P    DT J 166      77.331  76.890  -8.978  1.00 95.43           P  \\nATOM   3375  OP1  DT J 166      77.716  78.283  -9.316  1.00 95.43           O  \\nATOM   3376  OP2  DT J 166      76.370  76.156  -9.848  1.00 95.43           O  \\nATOM   3377  O5'  DT J 166      78.656  76.027  -8.820  1.00 75.61           O  \\nATOM   3378  C5'  DT J 166      78.583  74.614  -8.782  1.00 75.61           C  \\nATOM   3379  C4'  DT J 166      79.862  74.004  -9.302  1.00 75.61           C  \\nATOM   3380  O4'  DT J 166      80.906  74.132  -8.300  1.00 75.61           O  \\nATOM   3381  C3'  DT J 166      79.694  72.508  -9.552  1.00 75.61           C  \\nATOM   3382  O3'  DT J 166      80.205  72.117 -10.817  1.00 75.61           O  \\nATOM   3383  C2'  DT J 166      80.433  71.837  -8.413  1.00 75.61           C  \\nATOM   3384  C1'  DT J 166      81.470  72.860  -8.015  1.00 75.61           C  \\nATOM   3385  N1   DT J 166      81.766  72.789  -6.574  1.00115.63           N  \\nATOM   3386  C2   DT J 166      82.903  72.117  -6.189  1.00115.63           C  \\nATOM   3387  O2   DT J 166      83.693  71.622  -6.984  1.00115.63           O  \\nATOM   3388  N3   DT J 166      83.087  72.044  -4.831  1.00115.63           N  \\nATOM   3389  C4   DT J 166      82.280  72.576  -3.844  1.00115.63           C  \\nATOM   3390  O4   DT J 166      82.579  72.419  -2.662  1.00115.63           O  \\nATOM   3391  C5   DT J 166      81.121  73.290  -4.319  1.00115.63           C  \\nATOM   3392  C7   DT J 166      80.202  73.924  -3.323  1.00115.63           C  \\nATOM   3393  C6   DT J 166      80.922  73.357  -5.644  1.00115.63           C  \\nATOM   3394  P    DT J 167      79.287  71.214 -11.773  1.00117.46           P  \\nATOM   3395  OP1  DT J 167      79.328  71.807 -13.130  1.00117.46           O  \\nATOM   3396  OP2  DT J 167      77.976  71.021 -11.095  1.00117.46           O  \\nATOM   3397  O5'  DT J 167      80.054  69.825 -11.816  1.00112.13           O  \\nATOM   3398  C5'  DT J 167      81.319  69.746 -12.447  1.00112.13           C  \\nATOM   3399  C4'  DT J 167      82.192  68.722 -11.763  1.00112.13           C  \\nATOM   3400  O4'  DT J 167      82.476  69.115 -10.392  1.00112.13           O  \\nATOM   3401  C3'  DT J 167      81.603  67.312 -11.691  1.00112.13           C  \\nATOM   3402  O3'  DT J 167      82.628  66.374 -12.036  1.00112.13           O  \\nATOM   3403  C2'  DT J 167      81.211  67.176 -10.230  1.00112.13           C  \\nATOM   3404  C1'  DT J 167      82.316  67.973  -9.568  1.00112.13           C  \\nATOM   3405  N1   DT J 167      82.042  68.409  -8.183  1.00103.01           N  \\nATOM   3406  C2   DT J 167      83.117  68.573  -7.325  1.00103.01           C  \\nATOM   3407  O2   DT J 167      84.281  68.417  -7.665  1.00103.01           O  \\nATOM   3408  N3   DT J 167      82.772  68.929  -6.042  1.00103.01           N  \\nATOM   3409  C4   DT J 167      81.497  69.135  -5.543  1.00103.01           C  \\nATOM   3410  O4   DT J 167      81.345  69.433  -4.363  1.00103.01           O  \\nATOM   3411  C5   DT J 167      80.427  68.967  -6.499  1.00103.01           C  \\nATOM   3412  C7   DT J 167      79.018  69.183  -6.052  1.00103.01           C  \\nATOM   3413  C6   DT J 167      80.747  68.621  -7.755  1.00103.01           C  \\nATOM   3414  P    DC J 168      82.711  64.963 -11.278  1.00125.07           P  \\nATOM   3415  OP1  DC J 168      83.681  64.123 -12.022  1.00125.07           O  \\nATOM   3416  OP2  DC J 168      81.327  64.469 -11.059  1.00125.07           O  \\nATOM   3417  O5'  DC J 168      83.340  65.329  -9.860  1.00169.04           O  \\nATOM   3418  C5'  DC J 168      84.743  65.212  -9.624  1.00169.04           C  \\nATOM   3419  C4'  DC J 168      85.031  63.915  -8.906  1.00169.04           C  \\nATOM   3420  O4'  DC J 168      84.826  64.115  -7.486  1.00169.04           O  \\nATOM   3421  C3'  DC J 168      84.085  62.784  -9.312  1.00169.04           C  \\nATOM   3422  O3'  DC J 168      84.764  61.524  -9.356  1.00169.04           O  \\nATOM   3423  C2'  DC J 168      83.027  62.798  -8.228  1.00169.04           C  \\nATOM   3424  C1'  DC J 168      83.809  63.245  -7.007  1.00169.04           C  \\nATOM   3425  N1   DC J 168      82.982  63.992  -6.047  1.00110.48           N  \\nATOM   3426  C2   DC J 168      83.545  64.399  -4.833  1.00110.48           C  \\nATOM   3427  O2   DC J 168      84.738  64.131  -4.602  1.00110.48           O  \\nATOM   3428  N3   DC J 168      82.775  65.075  -3.946  1.00110.48           N  \\nATOM   3429  C4   DC J 168      81.501  65.350  -4.238  1.00110.48           C  \\nATOM   3430  N4   DC J 168      80.784  66.026  -3.342  1.00110.48           N  \\nATOM   3431  C5   DC J 168      80.905  64.947  -5.467  1.00110.48           C  \\nATOM   3432  C6   DC J 168      81.674  64.278  -6.334  1.00110.48           C  \\nATOM   3433  P    DT J 169      83.924  60.159  -9.216  1.00121.12           P  \\nATOM   3434  OP1  DT J 169      84.690  59.072  -9.875  1.00121.12           O  \\nATOM   3435  OP2  DT J 169      82.515  60.418  -9.628  1.00121.12           O  \\nATOM   3436  O5'  DT J 169      83.966  59.889  -7.651  1.00150.72           O  \\nATOM   3437  C5'  DT J 169      85.217  59.757  -6.983  1.00150.72           C  \\nATOM   3438  C4'  DT J 169      85.050  58.923  -5.737  1.00150.72           C  \\nATOM   3439  O4'  DT J 169      84.383  59.720  -4.727  1.00150.72           O  \\nATOM   3440  C3'  DT J 169      84.198  57.666  -5.944  1.00150.72           C  \\nATOM   3441  O3'  DT J 169      84.800  56.519  -5.317  1.00150.72           O  \\nATOM   3442  C2'  DT J 169      82.857  58.034  -5.330  1.00150.72           C  \\nATOM   3443  C1'  DT J 169      83.215  59.061  -4.263  1.00150.72           C  \\nATOM   3444  N1   DT J 169      82.164  60.085  -4.039  1.00138.36           N  \\nATOM   3445  C2   DT J 169      82.188  60.830  -2.873  1.00138.36           C  \\nATOM   3446  O2   DT J 169      83.056  60.720  -2.021  1.00138.36           O  \\nATOM   3447  N3   DT J 169      81.147  61.722  -2.744  1.00138.36           N  \\nATOM   3448  C4   DT J 169      80.125  61.952  -3.647  1.00138.36           C  \\nATOM   3449  O4   DT J 169      79.262  62.790  -3.392  1.00138.36           O  \\nATOM   3450  C5   DT J 169      80.170  61.150  -4.849  1.00138.36           C  \\nATOM   3451  C7   DT J 169      79.103  61.330  -5.883  1.00138.36           C  \\nATOM   3452  C6   DT J 169      81.173  60.272  -4.983  1.00138.36           C  \\nATOM   3453  P    DA J 170      84.064  55.080  -5.376  1.00140.46           P  \\nATOM   3454  OP1  DA J 170      85.105  54.021  -5.462  1.00140.46           O  \\nATOM   3455  OP2  DA J 170      82.969  55.109  -6.382  1.00140.46           O  \\nATOM   3456  O5'  DA J 170      83.402  54.996  -3.935  1.00126.15           O  \\nATOM   3457  C5'  DA J 170      84.144  55.396  -2.788  1.00126.15           C  \\nATOM   3458  C4'  DA J 170      83.251  55.411  -1.573  1.00126.15           C  \\nATOM   3459  O4'  DA J 170      82.447  56.618  -1.533  1.00126.15           O  \\nATOM   3460  C3'  DA J 170      82.272  54.237  -1.519  1.00126.15           C  \\nATOM   3461  O3'  DA J 170      82.262  53.677  -0.204  1.00126.15           O  \\nATOM   3462  C2'  DA J 170      80.934  54.877  -1.853  1.00126.15           C  \\nATOM   3463  C1'  DA J 170      81.096  56.270  -1.273  1.00126.15           C  \\nATOM   3464  N9   DA J 170      80.229  57.290  -1.869  1.00111.14           N  \\nATOM   3465  C8   DA J 170      79.755  57.330  -3.159  1.00111.14           C  \\nATOM   3466  N7   DA J 170      78.984  58.362  -3.411  1.00111.14           N  \\nATOM   3467  C5   DA J 170      78.948  59.052  -2.209  1.00111.14           C  \\nATOM   3468  C6   DA J 170      78.303  60.237  -1.825  1.00111.14           C  \\nATOM   3469  N6   DA J 170      77.543  60.966  -2.652  1.00111.14           N  \\nATOM   3470  N1   DA J 170      78.467  60.655  -0.550  1.00111.14           N  \\nATOM   3471  C2   DA J 170      79.234  59.924   0.273  1.00111.14           C  \\nATOM   3472  N3   DA J 170      79.895  58.795   0.028  1.00111.14           N  \\nATOM   3473  C4   DA J 170      79.710  58.405  -1.246  1.00111.14           C  \\nATOM   3474  P    DC J 171      81.172  52.564   0.182  1.00146.06           P  \\nATOM   3475  OP1  DC J 171      81.870  51.480   0.910  1.00146.06           O  \\nATOM   3476  OP2  DC J 171      80.382  52.241  -1.038  1.00146.06           O  \\nATOM   3477  O5'  DC J 171      80.231  53.332   1.211  1.00102.70           O  \\nATOM   3478  C5'  DC J 171      80.783  54.237   2.177  1.00102.70           C  \\nATOM   3479  C4'  DC J 171      79.759  54.541   3.246  1.00102.70           C  \\nATOM   3480  O4'  DC J 171      78.961  55.677   2.833  1.00102.70           O  \\nATOM   3481  C3'  DC J 171      78.777  53.395   3.454  1.00102.70           C  \\nATOM   3482  O3'  DC J 171      78.413  53.248   4.822  1.00102.70           O  \\nATOM   3483  C2'  DC J 171      77.582  53.775   2.601  1.00102.70           C  \\nATOM   3484  C1'  DC J 171      77.607  55.294   2.603  1.00102.70           C  \\nATOM   3485  N1   DC J 171      77.193  55.870   1.310  1.00103.61           N  \\nATOM   3486  C2   DC J 171      76.563  57.117   1.292  1.00103.61           C  \\nATOM   3487  O2   DC J 171      76.386  57.714   2.364  1.00103.61           O  \\nATOM   3488  N3   DC J 171      76.167  57.639   0.103  1.00103.61           N  \\nATOM   3489  C4   DC J 171      76.388  56.965  -1.033  1.00103.61           C  \\nATOM   3490  N4   DC J 171      75.980  57.512  -2.182  1.00103.61           N  \\nATOM   3491  C5   DC J 171      77.036  55.698  -1.042  1.00103.61           C  \\nATOM   3492  C6   DC J 171      77.417  55.192   0.140  1.00103.61           C  \\nATOM   3493  P    DC J 172      77.467  52.027   5.243  1.00104.62           P  \\nATOM   3494  OP1  DC J 172      77.166  52.126   6.691  1.00104.62           O  \\nATOM   3495  OP2  DC J 172      78.051  50.773   4.698  1.00104.62           O  \\nATOM   3496  O5'  DC J 172      76.142  52.327   4.417  1.00 98.24           O  \\nATOM   3497  C5'  DC J 172      74.897  51.752   4.791  1.00 98.24           C  \\nATOM   3498  C4'  DC J 172      74.025  52.795   5.449  1.00 98.24           C  \\nATOM   3499  O4'  DC J 172      74.009  54.001   4.654  1.00 98.24           O  \\nATOM   3500  C3'  DC J 172      72.572  52.374   5.604  1.00 98.24           C  \\nATOM   3501  O3'  DC J 172      72.055  52.906   6.818  1.00 98.24           O  \\nATOM   3502  C2'  DC J 172      71.895  52.997   4.399  1.00 98.24           C  \\nATOM   3503  C1'  DC J 172      72.709  54.253   4.147  1.00 98.24           C  \\nATOM   3504  N1   DC J 172      72.857  54.560   2.721  1.00 99.46           N  \\nATOM   3505  C2   DC J 172      73.074  55.882   2.330  1.00 99.46           C  \\nATOM   3506  O2   DC J 172      73.099  56.773   3.200  1.00 99.46           O  \\nATOM   3507  N3   DC J 172      73.245  56.159   1.014  1.00 99.46           N  \\nATOM   3508  C4   DC J 172      73.189  55.175   0.111  1.00 99.46           C  \\nATOM   3509  N4   DC J 172      73.367  55.490  -1.176  1.00 99.46           N  \\nATOM   3510  C5   DC J 172      72.950  53.826   0.487  1.00 99.46           C  \\nATOM   3511  C6   DC J 172      72.794  53.565   1.788  1.00 99.46           C  \\nATOM   3512  P    DA J 173      71.116  51.999   7.751  1.00138.20           P  \\nATOM   3513  OP1  DA J 173      71.910  51.554   8.925  1.00138.20           O  \\nATOM   3514  OP2  DA J 173      70.438  50.985   6.897  1.00138.20           O  \\nATOM   3515  O5'  DA J 173      70.031  53.048   8.253  1.00 80.00           O  \\nATOM   3516  C5'  DA J 173      70.400  54.410   8.483  1.00 80.00           C  \\nATOM   3517  C4'  DA J 173      69.457  55.338   7.754  1.00 80.00           C  \\nATOM   3518  O4'  DA J 173      69.713  55.294   6.325  1.00 80.00           O  \\nATOM   3519  C3'  DA J 173      67.985  54.978   7.939  1.00 80.00           C  \\nATOM   3520  O3'  DA J 173      67.207  56.149   8.169  1.00 80.00           O  \\nATOM   3521  C2'  DA J 173      67.602  54.341   6.615  1.00 80.00           C  \\nATOM   3522  C1'  DA J 173      68.505  55.050   5.625  1.00 80.00           C  \\nATOM   3523  N9   DA J 173      68.815  54.242   4.443  1.00 81.91           N  \\nATOM   3524  C8   DA J 173      68.714  52.878   4.330  1.00 81.91           C  \\nATOM   3525  N7   DA J 173      69.046  52.416   3.146  1.00 81.91           N  \\nATOM   3526  C5   DA J 173      69.393  53.553   2.430  1.00 81.91           C  \\nATOM   3527  C6   DA J 173      69.841  53.740   1.104  1.00 81.91           C  \\nATOM   3528  N6   DA J 173      70.026  52.746   0.229  1.00 81.91           N  \\nATOM   3529  N1   DA J 173      70.097  55.000   0.703  1.00 81.91           N  \\nATOM   3530  C2   DA J 173      69.919  55.997   1.579  1.00 81.91           C  \\nATOM   3531  N3   DA J 173      69.508  55.950   2.848  1.00 81.91           N  \\nATOM   3532  C4   DA J 173      69.257  54.686   3.217  1.00 81.91           C  \\nATOM   3533  P    DA J 174      65.692  56.011   8.692  1.00126.78           P  \\nATOM   3534  OP1  DA J 174      65.648  56.471  10.105  1.00126.78           O  \\nATOM   3535  OP2  DA J 174      65.191  54.658   8.342  1.00126.78           O  \\nATOM   3536  O5'  DA J 174      64.893  57.045   7.786  1.00 83.96           O  \\nATOM   3537  C5'  DA J 174      65.579  58.106   7.127  1.00 83.96           C  \\nATOM   3538  C4'  DA J 174      65.105  58.227   5.698  1.00 83.96           C  \\nATOM   3539  O4'  DA J 174      65.700  57.224   4.834  1.00 83.96           O  \\nATOM   3540  C3'  DA J 174      63.591  58.105   5.522  1.00 83.96           C  \\nATOM   3541  O3'  DA J 174      63.146  59.119   4.627  1.00 83.96           O  \\nATOM   3542  C2'  DA J 174      63.417  56.742   4.873  1.00 83.96           C  \\nATOM   3543  C1'  DA J 174      64.677  56.648   4.034  1.00 83.96           C  \\nATOM   3544  N9   DA J 174      65.078  55.287   3.678  1.00 86.48           N  \\nATOM   3545  C8   DA J 174      64.953  54.152   4.434  1.00 86.48           C  \\nATOM   3546  N7   DA J 174      65.365  53.065   3.826  1.00 86.48           N  \\nATOM   3547  C5   DA J 174      65.796  53.518   2.587  1.00 86.48           C  \\nATOM   3548  C6   DA J 174      66.329  52.852   1.465  1.00 86.48           C  \\nATOM   3549  N6   DA J 174      66.515  51.533   1.401  1.00 86.48           N  \\nATOM   3550  N1   DA J 174      66.660  53.598   0.394  1.00 86.48           N  \\nATOM   3551  C2   DA J 174      66.459  54.914   0.450  1.00 86.48           C  \\nATOM   3552  N3   DA J 174      65.957  55.652   1.437  1.00 86.48           N  \\nATOM   3553  C4   DA J 174      65.640  54.885   2.489  1.00 86.48           C  \\nATOM   3554  P    DA J 175      62.123  60.238   5.145  1.00117.29           P  \\nATOM   3555  OP1  DA J 175      62.815  61.557   5.183  1.00117.29           O  \\nATOM   3556  OP2  DA J 175      61.481  59.709   6.372  1.00117.29           O  \\nATOM   3557  O5'  DA J 175      61.025  60.265   3.999  1.00 81.99           O  \\nATOM   3558  C5'  DA J 175      60.698  59.079   3.291  1.00 81.99           C  \\nATOM   3559  C4'  DA J 175      61.258  59.153   1.892  1.00 81.99           C  \\nATOM   3560  O4'  DA J 175      62.195  58.073   1.717  1.00 81.99           O  \\nATOM   3561  C3'  DA J 175      60.213  58.992   0.790  1.00 81.99           C  \\nATOM   3562  O3'  DA J 175      60.566  59.777  -0.354  1.00 81.99           O  \\nATOM   3563  C2'  DA J 175      60.282  57.515   0.466  1.00 81.99           C  \\nATOM   3564  C1'  DA J 175      61.747  57.202   0.693  1.00 81.99           C  \\nATOM   3565  N9   DA J 175      61.997  55.832   1.130  1.00 86.90           N  \\nATOM   3566  C8   DA J 175      61.809  55.272   2.371  1.00 86.90           C  \\nATOM   3567  N7   DA J 175      62.159  54.012   2.437  1.00 86.90           N  \\nATOM   3568  C5   DA J 175      62.604  53.723   1.152  1.00 86.90           C  \\nATOM   3569  C6   DA J 175      63.120  52.553   0.566  1.00 86.90           C  \\nATOM   3570  N6   DA J 175      63.293  51.409   1.230  1.00 86.90           N  \\nATOM   3571  N1   DA J 175      63.461  52.602  -0.744  1.00 86.90           N  \\nATOM   3572  C2   DA J 175      63.298  53.754  -1.407  1.00 86.90           C  \\nATOM   3573  N3   DA J 175      62.834  54.917  -0.966  1.00 86.90           N  \\nATOM   3574  C4   DA J 175      62.501  54.833   0.337  1.00 86.90           C  \\nATOM   3575  P    DA J 176      59.413  60.449  -1.252  1.00 79.70           P  \\nATOM   3576  OP1  DA J 176      59.973  61.726  -1.777  1.00 79.70           O  \\nATOM   3577  OP2  DA J 176      58.124  60.442  -0.503  1.00 79.70           O  \\nATOM   3578  O5'  DA J 176      59.237  59.445  -2.465  1.00 61.35           O  \\nATOM   3579  C5'  DA J 176      60.304  59.214  -3.362  1.00 61.35           C  \\nATOM   3580  C4'  DA J 176      60.094  57.896  -4.063  1.00 61.35           C  \\nATOM   3581  O4'  DA J 176      60.399  56.772  -3.200  1.00 61.35           O  \\nATOM   3582  C3'  DA J 176      58.665  57.673  -4.552  1.00 61.35           C  \\nATOM   3583  O3'  DA J 176      58.742  57.072  -5.827  1.00 61.35           O  \\nATOM   3584  C2'  DA J 176      58.107  56.662  -3.564  1.00 61.35           C  \\nATOM   3585  C1'  DA J 176      59.343  55.831  -3.302  1.00 61.35           C  \\nATOM   3586  N9   DA J 176      59.344  55.007  -2.093  1.00 72.02           N  \\nATOM   3587  C8   DA J 176      58.939  55.328  -0.822  1.00 72.02           C  \\nATOM   3588  N7   DA J 176      59.093  54.355   0.045  1.00 72.02           N  \\nATOM   3589  C5   DA J 176      59.630  53.319  -0.710  1.00 72.02           C  \\nATOM   3590  C6   DA J 176      60.023  52.005  -0.383  1.00 72.02           C  \\nATOM   3591  N6   DA J 176      59.936  51.487   0.846  1.00 72.02           N  \\nATOM   3592  N1   DA J 176      60.517  51.231  -1.377  1.00 72.02           N  \\nATOM   3593  C2   DA J 176      60.610  51.748  -2.605  1.00 72.02           C  \\nATOM   3594  N3   DA J 176      60.277  52.960  -3.035  1.00 72.02           N  \\nATOM   3595  C4   DA J 176      59.787  53.707  -2.028  1.00 72.02           C  \\nATOM   3596  P    DG J 177      57.528  57.225  -6.847  1.00 78.59           P  \\nATOM   3597  OP1  DG J 177      57.802  58.347  -7.789  1.00 78.59           O  \\nATOM   3598  OP2  DG J 177      56.282  57.233  -6.034  1.00 78.59           O  \\nATOM   3599  O5'  DG J 177      57.608  55.866  -7.670  1.00 79.54           O  \\nATOM   3600  C5'  DG J 177      58.866  55.378  -8.137  1.00 79.54           C  \\nATOM   3601  C4'  DG J 177      58.877  53.868  -8.134  1.00 79.54           C  \\nATOM   3602  O4'  DG J 177      59.099  53.337  -6.798  1.00 79.54           O  \\nATOM   3603  C3'  DG J 177      57.580  53.242  -8.640  1.00 79.54           C  \\nATOM   3604  O3'  DG J 177      57.862  52.259  -9.631  1.00 79.54           O  \\nATOM   3605  C2'  DG J 177      56.975  52.602  -7.400  1.00 79.54           C  \\nATOM   3606  C1'  DG J 177      58.189  52.282  -6.548  1.00 79.54           C  \\nATOM   3607  N9   DG J 177      57.886  52.268  -5.122  1.00 74.30           N  \\nATOM   3608  C8   DG J 177      57.604  53.354  -4.339  1.00 74.30           C  \\nATOM   3609  N7   DG J 177      57.290  53.036  -3.114  1.00 74.30           N  \\nATOM   3610  C5   DG J 177      57.388  51.655  -3.081  1.00 74.30           C  \\nATOM   3611  C6   DG J 177      57.142  50.742  -2.019  1.00 74.30           C  \\nATOM   3612  O6   DG J 177      56.746  50.984  -0.874  1.00 74.30           O  \\nATOM   3613  N1   DG J 177      57.383  49.427  -2.405  1.00 74.30           N  \\nATOM   3614  C2   DG J 177      57.785  49.035  -3.654  1.00 74.30           C  \\nATOM   3615  N2   DG J 177      57.966  47.708  -3.808  1.00 74.30           N  \\nATOM   3616  N3   DG J 177      57.994  49.876  -4.666  1.00 74.30           N  \\nATOM   3617  C4   DG J 177      57.780  51.164  -4.306  1.00 74.30           C  \\nATOM   3618  P    DT J 178      56.656  51.604 -10.466  1.00114.94           P  \\nATOM   3619  OP1  DT J 178      57.228  51.287 -11.799  1.00114.94           O  \\nATOM   3620  OP2  DT J 178      55.438  52.451 -10.382  1.00114.94           O  \\nATOM   3621  O5'  DT J 178      56.384  50.247  -9.679  1.00105.86           O  \\nATOM   3622  C5'  DT J 178      57.435  49.302  -9.500  1.00105.86           C  \\nATOM   3623  C4'  DT J 178      56.899  48.008  -8.935  1.00105.86           C  \\nATOM   3624  O4'  DT J 178      56.708  48.117  -7.505  1.00105.86           O  \\nATOM   3625  C3'  DT J 178      55.571  47.521  -9.522  1.00105.86           C  \\nATOM   3626  O3'  DT J 178      55.668  46.119  -9.828  1.00105.86           O  \\nATOM   3627  C2'  DT J 178      54.570  47.804  -8.409  1.00105.86           C  \\nATOM   3628  C1'  DT J 178      55.416  47.653  -7.155  1.00105.86           C  \\nATOM   3629  N1   DT J 178      54.966  48.436  -5.990  1.00111.58           N  \\nATOM   3630  C2   DT J 178      54.948  47.817  -4.752  1.00111.58           C  \\nATOM   3631  O2   DT J 178      55.241  46.642  -4.579  1.00111.58           O  \\nATOM   3632  N3   DT J 178      54.567  48.628  -3.716  1.00111.58           N  \\nATOM   3633  C4   DT J 178      54.205  49.961  -3.781  1.00111.58           C  \\nATOM   3634  O4   DT J 178      53.910  50.564  -2.745  1.00111.58           O  \\nATOM   3635  C5   DT J 178      54.215  50.537  -5.114  1.00111.58           C  \\nATOM   3636  C7   DT J 178      53.805  51.964  -5.293  1.00111.58           C  \\nATOM   3637  C6   DT J 178      54.592  49.755  -6.136  1.00111.58           C  \\nATOM   3638  P    DG J 179      54.516  45.384 -10.687  1.00 98.21           P  \\nATOM   3639  OP1  DG J 179      55.164  44.590 -11.763  1.00 98.21           O  \\nATOM   3640  OP2  DG J 179      53.439  46.352 -11.039  1.00 98.21           O  \\nATOM   3641  O5'  DG J 179      53.926  44.374  -9.615  1.00108.05           O  \\nATOM   3642  C5'  DG J 179      54.796  43.714  -8.695  1.00108.05           C  \\nATOM   3643  C4'  DG J 179      53.985  43.047  -7.615  1.00108.05           C  \\nATOM   3644  O4'  DG J 179      53.813  43.920  -6.471  1.00108.05           O  \\nATOM   3645  C3'  DG J 179      52.581  42.697  -8.103  1.00108.05           C  \\nATOM   3646  O3'  DG J 179      52.189  41.408  -7.653  1.00108.05           O  \\nATOM   3647  C2'  DG J 179      51.708  43.756  -7.458  1.00108.05           C  \\nATOM   3648  C1'  DG J 179      52.434  43.982  -6.150  1.00108.05           C  \\nATOM   3649  N9   DG J 179      52.154  45.278  -5.550  1.00 80.42           N  \\nATOM   3650  C8   DG J 179      52.028  46.481  -6.199  1.00 80.42           C  \\nATOM   3651  N7   DG J 179      51.713  47.461  -5.401  1.00 80.42           N  \\nATOM   3652  C5   DG J 179      51.638  46.871  -4.145  1.00 80.42           C  \\nATOM   3653  C6   DG J 179      51.314  47.434  -2.872  1.00 80.42           C  \\nATOM   3654  O6   DG J 179      51.018  48.604  -2.589  1.00 80.42           O  \\nATOM   3655  N1   DG J 179      51.352  46.476  -1.866  1.00 80.42           N  \\nATOM   3656  C2   DG J 179      51.664  45.155  -2.047  1.00 80.42           C  \\nATOM   3657  N2   DG J 179      51.647  44.408  -0.935  1.00 80.42           N  \\nATOM   3658  N3   DG J 179      51.966  44.615  -3.222  1.00 80.42           N  \\nATOM   3659  C4   DG J 179      51.927  45.527  -4.220  1.00 80.42           C  \\nATOM   3660  P    DT J 180      50.949  40.677  -8.354  1.00136.92           P  \\nATOM   3661  OP1  DT J 180      51.477  39.597  -9.220  1.00136.92           O  \\nATOM   3662  OP2  DT J 180      50.064  41.716  -8.943  1.00136.92           O  \\nATOM   3663  O5'  DT J 180      50.196  40.022  -7.120  1.00101.12           O  \\nATOM   3664  C5'  DT J 180      48.937  40.510  -6.692  1.00101.12           C  \\nATOM   3665  C4'  DT J 180      48.822  40.378  -5.194  1.00101.12           C  \\nATOM   3666  O4'  DT J 180      49.304  41.596  -4.567  1.00101.12           O  \\nATOM   3667  C3'  DT J 180      47.377  40.205  -4.740  1.00101.12           C  \\nATOM   3668  O3'  DT J 180      47.268  39.211  -3.724  1.00101.12           O  \\nATOM   3669  C2'  DT J 180      46.983  41.570  -4.218  1.00101.12           C  \\nATOM   3670  C1'  DT J 180      48.295  42.149  -3.727  1.00101.12           C  \\nATOM   3671  N1   DT J 180      48.314  43.629  -3.854  1.00 87.11           N  \\nATOM   3672  C2   DT J 180      48.075  44.380  -2.721  1.00 87.11           C  \\nATOM   3673  O2   DT J 180      47.954  43.895  -1.610  1.00 87.11           O  \\nATOM   3674  N3   DT J 180      47.992  45.727  -2.937  1.00 87.11           N  \\nATOM   3675  C4   DT J 180      48.144  46.394  -4.129  1.00 87.11           C  \\nATOM   3676  O4   DT J 180      48.004  47.612  -4.158  1.00 87.11           O  \\nATOM   3677  C5   DT J 180      48.457  45.555  -5.268  1.00 87.11           C  \\nATOM   3678  C7   DT J 180      48.700  46.189  -6.599  1.00 87.11           C  \\nATOM   3679  C6   DT J 180      48.523  44.233  -5.075  1.00 87.11           C  \\nATOM   3680  P    DA J 181      45.813  38.715  -3.264  1.00141.70           P  \\nATOM   3681  OP1  DA J 181      45.957  37.481  -2.451  1.00141.70           O  \\nATOM   3682  OP2  DA J 181      44.936  38.708  -4.464  1.00141.70           O  \\nATOM   3683  O5'  DA J 181      45.336  39.888  -2.306  1.00123.98           O  \\nATOM   3684  C5'  DA J 181      46.029  40.144  -1.092  1.00123.98           C  \\nATOM   3685  C4'  DA J 181      45.119  40.861  -0.127  1.00123.98           C  \\nATOM   3686  O4'  DA J 181      45.132  42.285  -0.387  1.00123.98           O  \\nATOM   3687  C3'  DA J 181      43.662  40.414  -0.206  1.00123.98           C  \\nATOM   3688  O3'  DA J 181      43.141  40.269   1.119  1.00123.98           O  \\nATOM   3689  C2'  DA J 181      42.994  41.515  -1.019  1.00123.98           C  \\nATOM   3690  C1'  DA J 181      43.826  42.756  -0.694  1.00123.98           C  \\nATOM   3691  N9   DA J 181      43.960  43.740  -1.777  1.00 91.38           N  \\nATOM   3692  C8   DA J 181      43.901  43.529  -3.138  1.00 91.38           C  \\nATOM   3693  N7   DA J 181      44.109  44.612  -3.852  1.00 91.38           N  \\nATOM   3694  C5   DA J 181      44.308  45.604  -2.901  1.00 91.38           C  \\nATOM   3695  C6   DA J 181      44.580  46.976  -3.014  1.00 91.38           C  \\nATOM   3696  N6   DA J 181      44.725  47.610  -4.179  1.00 91.38           N  \\nATOM   3697  N1   DA J 181      44.706  47.688  -1.871  1.00 91.38           N  \\nATOM   3698  C2   DA J 181      44.576  47.052  -0.702  1.00 91.38           C  \\nATOM   3699  N3   DA J 181      44.332  45.765  -0.465  1.00 91.38           N  \\nATOM   3700  C4   DA J 181      44.204  45.086  -1.620  1.00 91.38           C  \\nATOM   3701  P    DT J 182      41.557  40.167   1.357  1.00 90.97           P  \\nATOM   3702  OP1  DT J 182      41.327  39.348   2.584  1.00 90.97           O  \\nATOM   3703  OP2  DT J 182      40.902  39.784   0.073  1.00 90.97           O  \\nATOM   3704  O5'  DT J 182      41.179  41.673   1.689  1.00154.72           O  \\nATOM   3705  C5'  DT J 182      41.832  42.352   2.760  1.00154.72           C  \\nATOM   3706  C4'  DT J 182      41.053  43.587   3.134  1.00154.72           C  \\nATOM   3707  O4'  DT J 182      41.334  44.640   2.180  1.00154.72           O  \\nATOM   3708  C3'  DT J 182      39.542  43.359   3.101  1.00154.72           C  \\nATOM   3709  O3'  DT J 182      38.906  43.958   4.237  1.00154.72           O  \\nATOM   3710  C2'  DT J 182      39.118  43.981   1.781  1.00154.72           C  \\nATOM   3711  C1'  DT J 182      40.127  45.102   1.597  1.00154.72           C  \\nATOM   3712  N1   DT J 182      40.396  45.441   0.184  1.00 78.21           N  \\nATOM   3713  C2   DT J 182      40.851  46.717  -0.125  1.00 78.21           C  \\nATOM   3714  O2   DT J 182      41.064  47.584   0.716  1.00 78.21           O  \\nATOM   3715  N3   DT J 182      41.047  46.942  -1.470  1.00 78.21           N  \\nATOM   3716  C4   DT J 182      40.852  46.046  -2.509  1.00 78.21           C  \\nATOM   3717  O4   DT J 182      41.093  46.392  -3.668  1.00 78.21           O  \\nATOM   3718  C5   DT J 182      40.369  44.734  -2.109  1.00 78.21           C  \\nATOM   3719  C7   DT J 182      40.095  43.707  -3.161  1.00 78.21           C  \\nATOM   3720  C6   DT J 182      40.178  44.501  -0.801  1.00 78.21           C  \\nATOM   3721  P    DT J 183      37.380  44.454   4.132  1.00 66.93           P  \\nATOM   3722  OP1  DT J 183      36.753  44.437   5.483  1.00 66.93           O  \\nATOM   3723  OP2  DT J 183      36.731  43.720   3.004  1.00 66.93           O  \\nATOM   3724  O5'  DT J 183      37.566  45.977   3.705  1.00 77.51           O  \\nATOM   3725  C5'  DT J 183      38.719  46.711   4.142  1.00 77.51           C  \\nATOM   3726  C4'  DT J 183      38.562  48.181   3.828  1.00 77.51           C  \\nATOM   3727  O4'  DT J 183      38.916  48.478   2.454  1.00 77.51           O  \\nATOM   3728  C3'  DT J 183      37.144  48.703   4.034  1.00 77.51           C  \\nATOM   3729  O3'  DT J 183      37.192  49.951   4.716  1.00 77.51           O  \\nATOM   3730  C2'  DT J 183      36.603  48.848   2.621  1.00 77.51           C  \\nATOM   3731  C1'  DT J 183      37.852  49.169   1.818  1.00 77.51           C  \\nATOM   3732  N1   DT J 183      37.804  48.730   0.411  1.00 83.98           N  \\nATOM   3733  C2   DT J 183      38.280  49.586  -0.556  1.00 83.98           C  \\nATOM   3734  O2   DT J 183      38.737  50.684  -0.312  1.00 83.98           O  \\nATOM   3735  N3   DT J 183      38.205  49.105  -1.831  1.00 83.98           N  \\nATOM   3736  C4   DT J 183      37.730  47.879  -2.234  1.00 83.98           C  \\nATOM   3737  O4   DT J 183      37.749  47.583  -3.422  1.00 83.98           O  \\nATOM   3738  C5   DT J 183      37.243  47.029  -1.175  1.00 83.98           C  \\nATOM   3739  C7   DT J 183      36.705  45.677  -1.522  1.00 83.98           C  \\nATOM   3740  C6   DT J 183      37.298  47.493   0.080  1.00 83.98           C  \\nATOM   3741  P    DT J 184      35.831  50.645   5.195  1.00 65.25           P  \\nATOM   3742  OP1  DT J 184      36.127  51.329   6.483  1.00 65.25           O  \\nATOM   3743  OP2  DT J 184      34.728  49.651   5.126  1.00 65.25           O  \\nATOM   3744  O5'  DT J 184      35.566  51.730   4.055  1.00 61.23           O  \\nATOM   3745  C5'  DT J 184      36.546  52.730   3.756  1.00 61.23           C  \\nATOM   3746  C4'  DT J 184      36.065  53.631   2.642  1.00 61.23           C  \\nATOM   3747  O4'  DT J 184      36.157  52.979   1.352  1.00 61.23           O  \\nATOM   3748  C3'  DT J 184      34.615  54.096   2.781  1.00 61.23           C  \\nATOM   3749  O3'  DT J 184      34.515  55.450   2.337  1.00 61.23           O  \\nATOM   3750  C2'  DT J 184      33.883  53.199   1.803  1.00 61.23           C  \\nATOM   3751  C1'  DT J 184      34.910  53.090   0.700  1.00 61.23           C  \\nATOM   3752  N1   DT J 184      34.758  51.931  -0.167  1.00 51.98           N  \\nATOM   3753  C2   DT J 184      35.157  52.070  -1.469  1.00 51.98           C  \\nATOM   3754  O2   DT J 184      35.660  53.088  -1.913  1.00 51.98           O  \\nATOM   3755  N3   DT J 184      34.956  50.971  -2.242  1.00 51.98           N  \\nATOM   3756  C4   DT J 184      34.428  49.766  -1.852  1.00 51.98           C  \\nATOM   3757  O4   DT J 184      34.304  48.875  -2.669  1.00 51.98           O  \\nATOM   3758  C5   DT J 184      34.055  49.674  -0.466  1.00 51.98           C  \\nATOM   3759  C7   DT J 184      33.502  48.385   0.047  1.00 51.98           C  \\nATOM   3760  C6   DT J 184      34.229  50.753   0.302  1.00 51.98           C  \\nATOM   3761  P    DG J 185      34.470  56.647   3.410  1.00 67.28           P  \\nATOM   3762  OP1  DG J 185      35.608  56.507   4.363  1.00 67.28           O  \\nATOM   3763  OP2  DG J 185      33.081  56.720   3.930  1.00 67.28           O  \\nATOM   3764  O5'  DG J 185      34.726  57.937   2.510  1.00 58.47           O  \\nATOM   3765  C5'  DG J 185      36.005  58.181   1.925  1.00 58.47           C  \\nATOM   3766  C4'  DG J 185      35.846  58.614   0.486  1.00 58.47           C  \\nATOM   3767  O4'  DG J 185      35.335  57.523  -0.313  1.00 58.47           O  \\nATOM   3768  C3'  DG J 185      34.866  59.762   0.288  1.00 58.47           C  \\nATOM   3769  O3'  DG J 185      35.316  60.557  -0.806  1.00 58.47           O  \\nATOM   3770  C2'  DG J 185      33.572  59.049  -0.055  1.00 58.47           C  \\nATOM   3771  C1'  DG J 185      34.052  57.841  -0.836  1.00 58.47           C  \\nATOM   3772  N9   DG J 185      33.220  56.653  -0.676  1.00 60.29           N  \\nATOM   3773  C8   DG J 185      32.647  56.191   0.489  1.00 60.29           C  \\nATOM   3774  N7   DG J 185      32.037  55.045   0.343  1.00 60.29           N  \\nATOM   3775  C5   DG J 185      32.205  54.738  -1.004  1.00 60.29           C  \\nATOM   3776  C6   DG J 185      31.796  53.602  -1.747  1.00 60.29           C  \\nATOM   3777  O6   DG J 185      31.217  52.590  -1.344  1.00 60.29           O  \\nATOM   3778  N1   DG J 185      32.145  53.710  -3.090  1.00 60.29           N  \\nATOM   3779  C2   DG J 185      32.801  54.773  -3.649  1.00 60.29           C  \\nATOM   3780  N2   DG J 185      32.984  54.710  -4.978  1.00 60.29           N  \\nATOM   3781  N3   DG J 185      33.229  55.822  -2.963  1.00 60.29           N  \\nATOM   3782  C4   DG J 185      32.899  55.739  -1.655  1.00 60.29           C  \\nATOM   3783  P    DG J 186      34.758  62.042  -0.994  1.00 35.38           P  \\nATOM   3784  OP1  DG J 186      35.885  62.874  -1.482  1.00 35.38           O  \\nATOM   3785  OP2  DG J 186      34.065  62.399   0.270  1.00 35.38           O  \\nATOM   3786  O5'  DG J 186      33.736  61.890  -2.196  1.00 53.97           O  \\nATOM   3787  C5'  DG J 186      34.171  61.347  -3.431  1.00 53.97           C  \\nATOM   3788  C4'  DG J 186      32.978  60.881  -4.226  1.00 53.97           C  \\nATOM   3789  O4'  DG J 186      32.419  59.671  -3.648  1.00 53.97           O  \\nATOM   3790  C3'  DG J 186      31.842  61.908  -4.230  1.00 53.97           C  \\nATOM   3791  O3'  DG J 186      31.200  61.919  -5.508  1.00 53.97           O  \\nATOM   3792  C2'  DG J 186      30.877  61.353  -3.198  1.00 53.97           C  \\nATOM   3793  C1'  DG J 186      31.027  59.876  -3.475  1.00 53.97           C  \\nATOM   3794  N9   DG J 186      30.526  58.951  -2.462  1.00 62.85           N  \\nATOM   3795  C8   DG J 186      30.332  59.165  -1.115  1.00 62.85           C  \\nATOM   3796  N7   DG J 186      29.857  58.119  -0.493  1.00 62.85           N  \\nATOM   3797  C5   DG J 186      29.741  57.157  -1.489  1.00 62.85           C  \\nATOM   3798  C6   DG J 186      29.297  55.802  -1.427  1.00 62.85           C  \\nATOM   3799  O6   DG J 186      28.947  55.140  -0.425  1.00 62.85           O  \\nATOM   3800  N1   DG J 186      29.304  55.210  -2.697  1.00 62.85           N  \\nATOM   3801  C2   DG J 186      29.727  55.830  -3.863  1.00 62.85           C  \\nATOM   3802  N2   DG J 186      29.666  55.115  -4.997  1.00 62.85           N  \\nATOM   3803  N3   DG J 186      30.175  57.065  -3.917  1.00 62.85           N  \\nATOM   3804  C4   DG J 186      30.145  57.667  -2.709  1.00 62.85           C  \\nATOM   3805  P    DA J 187      31.310  63.217  -6.443  1.00 64.00           P  \\nATOM   3806  OP1  DA J 187      32.739  63.638  -6.433  1.00 64.00           O  \\nATOM   3807  OP2  DA J 187      30.245  64.174  -6.026  1.00 64.00           O  \\nATOM   3808  O5'  DA J 187      30.946  62.657  -7.886  1.00 77.10           O  \\nATOM   3809  C5'  DA J 187      31.682  61.575  -8.459  1.00 77.10           C  \\nATOM   3810  C4'  DA J 187      30.740  60.614  -9.151  1.00 77.10           C  \\nATOM   3811  O4'  DA J 187      30.155  59.695  -8.196  1.00 77.10           O  \\nATOM   3812  C3'  DA J 187      29.574  61.294  -9.869  1.00 77.10           C  \\nATOM   3813  O3'  DA J 187      29.327  60.668 -11.134  1.00 77.10           O  \\nATOM   3814  C2'  DA J 187      28.411  61.100  -8.914  1.00 77.10           C  \\nATOM   3815  C1'  DA J 187      28.738  59.780  -8.234  1.00 77.10           C  \\nATOM   3816  N9   DA J 187      28.257  59.696  -6.858  1.00 72.73           N  \\nATOM   3817  C8   DA J 187      28.174  60.707  -5.930  1.00 72.73           C  \\nATOM   3818  N7   DA J 187      27.713  60.322  -4.767  1.00 72.73           N  \\nATOM   3819  C5   DA J 187      27.468  58.963  -4.940  1.00 72.73           C  \\nATOM   3820  C6   DA J 187      26.966  57.960  -4.067  1.00 72.73           C  \\nATOM   3821  N6   DA J 187      26.607  58.190  -2.794  1.00 72.73           N  \\nATOM   3822  N1   DA J 187      26.846  56.701  -4.558  1.00 72.73           N  \\nATOM   3823  C2   DA J 187      27.205  56.474  -5.828  1.00 72.73           C  \\nATOM   3824  N3   DA J 187      27.687  57.328  -6.741  1.00 72.73           N  \\nATOM   3825  C4   DA J 187      27.796  58.567  -6.226  1.00 72.73           C  \\nATOM   3826  P    DA J 188      28.331  61.364 -12.193  1.00128.75           P  \\nATOM   3827  OP1  DA J 188      28.974  61.358 -13.533  1.00128.75           O  \\nATOM   3828  OP2  DA J 188      27.848  62.646 -11.616  1.00128.75           O  \\nATOM   3829  O5'  DA J 188      27.103  60.356 -12.235  1.00 96.02           O  \\nATOM   3830  C5'  DA J 188      27.323  58.968 -12.472  1.00 96.02           C  \\nATOM   3831  C4'  DA J 188      26.005  58.243 -12.603  1.00 96.02           C  \\nATOM   3832  O4'  DA J 188      25.568  57.774 -11.306  1.00 96.02           O  \\nATOM   3833  C3'  DA J 188      24.886  59.106 -13.177  1.00 96.02           C  \\nATOM   3834  O3'  DA J 188      24.423  58.586 -14.437  1.00 96.02           O  \\nATOM   3835  C2'  DA J 188      23.914  59.329 -12.027  1.00 96.02           C  \\nATOM   3836  C1'  DA J 188      24.324  58.343 -10.926  1.00 96.02           C  \\nATOM   3837  N9   DA J 188      24.508  58.981  -9.611  1.00 96.48           N  \\nATOM   3838  C8   DA J 188      24.919  60.274  -9.381  1.00 96.48           C  \\nATOM   3839  N7   DA J 188      24.947  60.606  -8.111  1.00 96.48           N  \\nATOM   3840  C5   DA J 188      24.538  59.454  -7.454  1.00 96.48           C  \\nATOM   3841  C6   DA J 188      24.340  59.160  -6.084  1.00 96.48           C  \\nATOM   3842  N6   DA J 188      24.535  60.039  -5.097  1.00 96.48           N  \\nATOM   3843  N1   DA J 188      23.926  57.916  -5.761  1.00 96.48           N  \\nATOM   3844  C2   DA J 188      23.728  57.036  -6.746  1.00 96.48           C  \\nATOM   3845  N3   DA J 188      23.874  57.191  -8.066  1.00 96.48           N  \\nATOM   3846  C4   DA J 188      24.282  58.438  -8.361  1.00 96.48           C  \\nATOM   3847  P    DA J 189      23.043  57.778 -14.567  1.00 87.94           P  \\nATOM   3848  OP1  DA J 189      23.442  56.523 -15.247  1.00 87.94           O  \\nATOM   3849  OP2  DA J 189      22.030  58.665 -15.197  1.00 87.94           O  \\nATOM   3850  O5'  DA J 189      22.568  57.422 -13.087  1.00110.01           O  \\nATOM   3851  C5'  DA J 189      21.977  56.151 -12.809  1.00110.01           C  \\nATOM   3852  C4'  DA J 189      20.580  56.312 -12.252  1.00110.01           C  \\nATOM   3853  O4'  DA J 189      20.655  56.871 -10.918  1.00110.01           O  \\nATOM   3854  C3'  DA J 189      19.600  57.194 -13.042  1.00110.01           C  \\nATOM   3855  O3'  DA J 189      18.315  56.530 -13.164  1.00110.01           O  \\nATOM   3856  C2'  DA J 189      19.520  58.459 -12.204  1.00110.01           C  \\nATOM   3857  C1'  DA J 189      19.741  57.944 -10.790  1.00110.01           C  \\nATOM   3858  N9   DA J 189      20.321  58.932  -9.877  1.00 55.04           N  \\nATOM   3859  C8   DA J 189      21.006  60.070 -10.224  1.00 55.04           C  \\nATOM   3860  N7   DA J 189      21.387  60.794  -9.198  1.00 55.04           N  \\nATOM   3861  C5   DA J 189      20.930  60.086  -8.098  1.00 55.04           C  \\nATOM   3862  C6   DA J 189      21.009  60.334  -6.716  1.00 55.04           C  \\nATOM   3863  N6   DA J 189      21.570  61.422  -6.194  1.00 55.04           N  \\nATOM   3864  N1   DA J 189      20.473  59.423  -5.880  1.00 55.04           N  \\nATOM   3865  C2   DA J 189      19.877  58.347  -6.407  1.00 55.04           C  \\nATOM   3866  N3   DA J 189      19.718  58.010  -7.690  1.00 55.04           N  \\nATOM   3867  C4   DA J 189      20.278  58.930  -8.497  1.00 55.04           C  \\nATOM   3868  P    DC J 190      17.009  57.338 -13.689  1.00 94.27           P  \\nATOM   3869  OP1  DC J 190      15.903  56.361 -13.873  1.00 94.27           O  \\nATOM   3870  OP2  DC J 190      17.399  58.216 -14.830  1.00 94.27           O  \\nATOM   3871  O5'  DC J 190      16.643  58.243 -12.428  1.00104.70           O  \\nATOM   3872  C5'  DC J 190      15.297  58.588 -12.133  1.00104.70           C  \\nATOM   3873  C4'  DC J 190      14.937  58.163 -10.727  1.00104.70           C  \\nATOM   3874  O4'  DC J 190      16.023  58.419  -9.802  1.00104.70           O  \\nATOM   3875  C3'  DC J 190      13.729  58.918 -10.178  1.00104.70           C  \\nATOM   3876  O3'  DC J 190      12.847  58.042  -9.492  1.00104.70           O  \\nATOM   3877  C2'  DC J 190      14.322  59.930  -9.218  1.00104.70           C  \\nATOM   3878  C1'  DC J 190      15.573  59.234  -8.725  1.00104.70           C  \\nATOM   3879  N1   DC J 190      16.641  60.188  -8.399  1.00 60.46           N  \\nATOM   3880  C2   DC J 190      16.854  60.528  -7.057  1.00 60.46           C  \\nATOM   3881  O2   DC J 190      16.139  60.015  -6.187  1.00 60.46           O  \\nATOM   3882  N3   DC J 190      17.829  61.417  -6.744  1.00 60.46           N  \\nATOM   3883  C4   DC J 190      18.568  61.969  -7.715  1.00 60.46           C  \\nATOM   3884  N4   DC J 190      19.513  62.856  -7.365  1.00 60.46           N  \\nATOM   3885  C5   DC J 190      18.371  61.639  -9.092  1.00 60.46           C  \\nATOM   3886  C6   DC J 190      17.409  60.748  -9.384  1.00 60.46           C  \\nATOM   3887  P    DT J 191      11.332  58.495  -9.261  1.00111.31           P  \\nATOM   3888  OP1  DT J 191      10.571  57.346  -8.708  1.00111.31           O  \\nATOM   3889  OP2  DT J 191      10.880  59.140 -10.518  1.00111.31           O  \\nATOM   3890  O5'  DT J 191      11.465  59.616  -8.141  1.00103.30           O  \\nATOM   3891  C5'  DT J 191      11.838  59.259  -6.815  1.00103.30           C  \\nATOM   3892  C4'  DT J 191      11.827  60.473  -5.918  1.00103.30           C  \\nATOM   3893  O4'  DT J 191      13.034  61.248  -6.096  1.00103.30           O  \\nATOM   3894  C3'  DT J 191      10.662  61.437  -6.147  1.00103.30           C  \\nATOM   3895  O3'  DT J 191      10.177  61.896  -4.886  1.00103.30           O  \\nATOM   3896  C2'  DT J 191      11.316  62.591  -6.885  1.00103.30           C  \\nATOM   3897  C1'  DT J 191      12.667  62.605  -6.207  1.00103.30           C  \\nATOM   3898  N1   DT J 191      13.748  63.317  -6.897  1.00 61.88           N  \\nATOM   3899  C2   DT J 191      14.745  63.858  -6.109  1.00 61.88           C  \\nATOM   3900  O2   DT J 191      14.745  63.790  -4.882  1.00 61.88           O  \\nATOM   3901  N3   DT J 191      15.741  64.492  -6.811  1.00 61.88           N  \\nATOM   3902  C4   DT J 191      15.839  64.633  -8.184  1.00 61.88           C  \\nATOM   3903  O4   DT J 191      16.810  65.200  -8.671  1.00 61.88           O  \\nATOM   3904  C5   DT J 191      14.745  64.069  -8.938  1.00 61.88           C  \\nATOM   3905  C7   DT J 191      14.740  64.216 -10.423  1.00 61.88           C  \\nATOM   3906  C6   DT J 191      13.771  63.439  -8.267  1.00 61.88           C  \\nATOM   3907  P    DG J 192       8.599  62.019  -4.639  1.00 89.02           P  \\nATOM   3908  OP1  DG J 192       8.003  60.670  -4.800  1.00 89.02           O  \\nATOM   3909  OP2  DG J 192       8.120  63.152  -5.477  1.00 89.02           O  \\nATOM   3910  O5'  DG J 192       8.475  62.440  -3.112  1.00 84.27           O  \\nATOM   3911  C5'  DG J 192       9.464  62.051  -2.167  1.00 84.27           C  \\nATOM   3912  C4'  DG J 192      10.089  63.275  -1.537  1.00 84.27           C  \\nATOM   3913  O4'  DG J 192      11.064  63.901  -2.411  1.00 84.27           O  \\nATOM   3914  C3'  DG J 192       9.103  64.376  -1.154  1.00 84.27           C  \\nATOM   3915  O3'  DG J 192       9.474  64.877   0.130  1.00 84.27           O  \\nATOM   3916  C2'  DG J 192       9.312  65.431  -2.233  1.00 84.27           C  \\nATOM   3917  C1'  DG J 192      10.804  65.298  -2.491  1.00 84.27           C  \\nATOM   3918  N9   DG J 192      11.324  65.783  -3.774  1.00 66.15           N  \\nATOM   3919  C8   DG J 192      10.878  65.457  -5.035  1.00 66.15           C  \\nATOM   3920  N7   DG J 192      11.617  65.964  -5.991  1.00 66.15           N  \\nATOM   3921  C5   DG J 192      12.597  66.689  -5.325  1.00 66.15           C  \\nATOM   3922  C6   DG J 192      13.706  67.437  -5.833  1.00 66.15           C  \\nATOM   3923  O6   DG J 192      14.077  67.592  -7.012  1.00 66.15           O  \\nATOM   3924  N1   DG J 192      14.430  68.024  -4.806  1.00 66.15           N  \\nATOM   3925  C2   DG J 192      14.142  67.904  -3.464  1.00 66.15           C  \\nATOM   3926  N2   DG J 192      14.958  68.564  -2.630  1.00 66.15           N  \\nATOM   3927  N3   DG J 192      13.134  67.197  -2.978  1.00 66.15           N  \\nATOM   3928  C4   DG J 192      12.409  66.619  -3.955  1.00 66.15           C  \\nATOM   3929  P    DC J 193       8.409  65.695   1.009  1.00106.91           P  \\nATOM   3930  OP1  DC J 193       8.360  65.105   2.377  1.00106.91           O  \\nATOM   3931  OP2  DC J 193       7.166  65.808   0.199  1.00106.91           O  \\nATOM   3932  O5'  DC J 193       9.063  67.142   1.115  1.00 88.46           O  \\nATOM   3933  C5'  DC J 193      10.481  67.313   1.027  1.00 88.46           C  \\nATOM   3934  C4'  DC J 193      10.824  68.747   0.696  1.00 88.46           C  \\nATOM   3935  O4'  DC J 193      11.170  68.864  -0.703  1.00 88.46           O  \\nATOM   3936  C3'  DC J 193       9.716  69.779   0.940  1.00 88.46           C  \\nATOM   3937  O3'  DC J 193      10.318  70.990   1.400  1.00 88.46           O  \\nATOM   3938  C2'  DC J 193       9.161  70.013  -0.452  1.00 88.46           C  \\nATOM   3939  C1'  DC J 193      10.436  69.939  -1.257  1.00 88.46           C  \\nATOM   3940  N1   DC J 193      10.289  69.700  -2.693  1.00 88.37           N  \\nATOM   3941  C2   DC J 193      11.168  70.353  -3.560  1.00 88.37           C  \\nATOM   3942  O2   DC J 193      12.047  71.093  -3.079  1.00 88.37           O  \\nATOM   3943  N3   DC J 193      11.048  70.163  -4.895  1.00 88.37           N  \\nATOM   3944  C4   DC J 193      10.097  69.355  -5.370  1.00 88.37           C  \\nATOM   3945  N4   DC J 193      10.012  69.208  -6.702  1.00 88.37           N  \\nATOM   3946  C5   DC J 193       9.192  68.667  -4.504  1.00 88.37           C  \\nATOM   3947  C6   DC J 193       9.322  68.869  -3.184  1.00 88.37           C  \\nATOM   3948  P    DT J 194       9.946  71.584   2.850  1.00 87.58           P  \\nATOM   3949  OP1  DT J 194       9.948  70.532   3.914  1.00 87.58           O  \\nATOM   3950  OP2  DT J 194       8.744  72.433   2.644  1.00 87.58           O  \\nATOM   3951  O5'  DT J 194      11.158  72.562   3.160  1.00 77.34           O  \\nATOM   3952  C5'  DT J 194      11.190  73.870   2.605  1.00 77.34           C  \\nATOM   3953  C4'  DT J 194      12.567  74.177   2.068  1.00 77.34           C  \\nATOM   3954  O4'  DT J 194      12.699  73.700   0.707  1.00 77.34           O  \\nATOM   3955  C3'  DT J 194      12.838  75.672   2.010  1.00 77.34           C  \\nATOM   3956  O3'  DT J 194      14.194  75.901   2.390  1.00 77.34           O  \\nATOM   3957  C2'  DT J 194      12.554  76.035   0.565  1.00 77.34           C  \\nATOM   3958  C1'  DT J 194      12.966  74.782  -0.176  1.00 77.34           C  \\nATOM   3959  N1   DT J 194      12.198  74.548  -1.408  1.00 72.36           N  \\nATOM   3960  C2   DT J 194      12.812  74.682  -2.646  1.00 72.36           C  \\nATOM   3961  O2   DT J 194      13.967  75.068  -2.798  1.00 72.36           O  \\nATOM   3962  N3   DT J 194      12.008  74.353  -3.712  1.00 72.36           N  \\nATOM   3963  C4   DT J 194      10.691  73.937  -3.669  1.00 72.36           C  \\nATOM   3964  O4   DT J 194      10.117  73.624  -4.708  1.00 72.36           O  \\nATOM   3965  C5   DT J 194      10.103  73.889  -2.352  1.00 72.36           C  \\nATOM   3966  C7   DT J 194       8.659  73.526  -2.213  1.00 72.36           C  \\nATOM   3967  C6   DT J 194      10.879  74.181  -1.304  1.00 72.36           C  \\nATOM   3968  P    DC J 195      14.708  77.397   2.642  1.00 57.79           P  \\nATOM   3969  OP1  DC J 195      16.090  77.285   3.167  1.00 57.79           O  \\nATOM   3970  OP2  DC J 195      13.686  78.156   3.411  1.00 57.79           O  \\nATOM   3971  O5'  DC J 195      14.746  77.974   1.165  1.00 40.36           O  \\nATOM   3972  C5'  DC J 195      15.057  77.118   0.082  1.00 40.36           C  \\nATOM   3973  C4'  DC J 195      15.375  77.946  -1.129  1.00 40.36           C  \\nATOM   3974  O4'  DC J 195      14.389  77.712  -2.153  1.00 40.36           O  \\nATOM   3975  C3'  DC J 195      15.349  79.443  -0.854  1.00 40.36           C  \\nATOM   3976  O3'  DC J 195      16.374  80.011  -1.682  1.00 40.36           O  \\nATOM   3977  C2'  DC J 195      13.924  79.836  -1.214  1.00 40.36           C  \\nATOM   3978  C1'  DC J 195      13.593  78.874  -2.356  1.00 40.36           C  \\nATOM   3979  N1   DC J 195      12.187  78.422  -2.463  1.00 64.42           N  \\nATOM   3980  C2   DC J 195      11.680  78.090  -3.733  1.00 64.42           C  \\nATOM   3981  O2   DC J 195      12.400  78.252  -4.725  1.00 64.42           O  \\nATOM   3982  N3   DC J 195      10.423  77.606  -3.841  1.00 64.42           N  \\nATOM   3983  C4   DC J 195       9.672  77.456  -2.752  1.00 64.42           C  \\nATOM   3984  N4   DC J 195       8.457  76.948  -2.905  1.00 64.42           N  \\nATOM   3985  C5   DC J 195      10.142  77.816  -1.454  1.00 64.42           C  \\nATOM   3986  C6   DC J 195      11.394  78.294  -1.355  1.00 64.42           C  \\nATOM   3987  P    DC J 196      16.532  81.594  -1.816  1.00 47.94           P  \\nATOM   3988  OP1  DC J 196      17.946  81.831  -1.512  1.00 47.94           O  \\nATOM   3989  OP2  DC J 196      15.481  82.313  -1.052  1.00 47.94           O  \\nATOM   3990  O5'  DC J 196      16.337  81.811  -3.372  1.00 40.61           O  \\nATOM   3991  C5'  DC J 196      17.039  80.980  -4.284  1.00 40.61           C  \\nATOM   3992  C4'  DC J 196      16.639  81.297  -5.706  1.00 40.61           C  \\nATOM   3993  O4'  DC J 196      15.333  80.724  -5.955  1.00 40.61           O  \\nATOM   3994  C3'  DC J 196      16.534  82.783  -6.051  1.00 40.61           C  \\nATOM   3995  O3'  DC J 196      17.150  83.058  -7.300  1.00 40.61           O  \\nATOM   3996  C2'  DC J 196      15.042  83.049  -6.120  1.00 40.61           C  \\nATOM   3997  C1'  DC J 196      14.442  81.700  -6.477  1.00 40.61           C  \\nATOM   3998  N1   DC J 196      13.121  81.471  -5.861  1.00 49.17           N  \\nATOM   3999  C2   DC J 196      12.047  81.051  -6.668  1.00 49.17           C  \\nATOM   4000  O2   DC J 196      12.241  80.857  -7.879  1.00 49.17           O  \\nATOM   4001  N3   DC J 196      10.832  80.866  -6.096  1.00 49.17           N  \\nATOM   4002  C4   DC J 196      10.665  81.081  -4.779  1.00 49.17           C  \\nATOM   4003  N4   DC J 196       9.450  80.899  -4.257  1.00 49.17           N  \\nATOM   4004  C5   DC J 196      11.738  81.495  -3.941  1.00 49.17           C  \\nATOM   4005  C6   DC J 196      12.938  81.674  -4.516  1.00 49.17           C  \\nATOM   4006  P    DA J 197      16.976  84.503  -7.961  1.00 27.94           P  \\nATOM   4007  OP1  DA J 197      18.153  84.723  -8.849  1.00 27.94           O  \\nATOM   4008  OP2  DA J 197      16.619  85.524  -6.924  1.00 27.94           O  \\nATOM   4009  O5'  DA J 197      15.712  84.299  -8.894  1.00 38.92           O  \\nATOM   4010  C5'  DA J 197      15.731  83.280  -9.881  1.00 38.92           C  \\nATOM   4011  C4'  DA J 197      14.692  83.556 -10.937  1.00 38.92           C  \\nATOM   4012  O4'  DA J 197      13.380  83.317 -10.390  1.00 38.92           O  \\nATOM   4013  C3'  DA J 197      14.678  84.987 -11.458  1.00 38.92           C  \\nATOM   4014  O3'  DA J 197      14.424  84.958 -12.865  1.00 38.92           O  \\nATOM   4015  C2'  DA J 197      13.550  85.636 -10.672  1.00 38.92           C  \\nATOM   4016  C1'  DA J 197      12.591  84.491 -10.435  1.00 38.92           C  \\nATOM   4017  N9   DA J 197      11.875  84.547  -9.169  1.00 37.21           N  \\nATOM   4018  C8   DA J 197      12.317  85.045  -7.976  1.00 37.21           C  \\nATOM   4019  N7   DA J 197      11.471  84.884  -6.989  1.00 37.21           N  \\nATOM   4020  C5   DA J 197      10.393  84.249  -7.579  1.00 37.21           C  \\nATOM   4021  C6   DA J 197       9.181  83.799  -7.065  1.00 37.21           C  \\nATOM   4022  N6   DA J 197       8.854  83.904  -5.780  1.00 37.21           N  \\nATOM   4023  N1   DA J 197       8.305  83.224  -7.920  1.00 37.21           N  \\nATOM   4024  C2   DA J 197       8.651  83.109  -9.209  1.00 37.21           C  \\nATOM   4025  N3   DA J 197       9.777  83.481  -9.813  1.00 37.21           N  \\nATOM   4026  C4   DA J 197      10.617  84.054  -8.928  1.00 37.21           C  \\nATOM   4027  P    DT J 198      13.841  86.258 -13.598  1.00 61.91           P  \\nATOM   4028  OP1  DT J 198      13.822  85.980 -15.058  1.00 61.91           O  \\nATOM   4029  OP2  DT J 198      14.564  87.461 -13.069  1.00 61.91           O  \\nATOM   4030  O5'  DT J 198      12.332  86.278 -13.105  1.00 74.61           O  \\nATOM   4031  C5'  DT J 198      11.447  85.246 -13.512  1.00 74.61           C  \\nATOM   4032  C4'  DT J 198      10.031  85.759 -13.532  1.00 74.61           C  \\nATOM   4033  O4'  DT J 198       9.438  85.619 -12.222  1.00 74.61           O  \\nATOM   4034  C3'  DT J 198       9.917  87.238 -13.904  1.00 74.61           C  \\nATOM   4035  O3'  DT J 198       8.817  87.432 -14.798  1.00 74.61           O  \\nATOM   4036  C2'  DT J 198       9.655  87.911 -12.569  1.00 74.61           C  \\nATOM   4037  C1'  DT J 198       8.851  86.849 -11.857  1.00 74.61           C  \\nATOM   4038  N1   DT J 198       8.868  86.938 -10.402  1.00 47.31           N  \\nATOM   4039  C2   DT J 198       7.798  86.399  -9.718  1.00 47.31           C  \\nATOM   4040  O2   DT J 198       6.889  85.795 -10.260  1.00 47.31           O  \\nATOM   4041  N3   DT J 198       7.839  86.581  -8.365  1.00 47.31           N  \\nATOM   4042  C4   DT J 198       8.830  87.203  -7.638  1.00 47.31           C  \\nATOM   4043  O4   DT J 198       8.715  87.289  -6.424  1.00 47.31           O  \\nATOM   4044  C5   DT J 198       9.947  87.711  -8.414  1.00 47.31           C  \\nATOM   4045  C7   DT J 198      11.080  88.376  -7.705  1.00 47.31           C  \\nATOM   4046  C6   DT J 198       9.909  87.556  -9.741  1.00 47.31           C  \\nATOM   4047  P    DC J 199       8.392  88.920 -15.243  1.00100.93           P  \\nATOM   4048  OP1  DC J 199       8.261  88.917 -16.719  1.00100.93           O  \\nATOM   4049  OP2  DC J 199       9.280  89.921 -14.588  1.00100.93           O  \\nATOM   4050  O5'  DC J 199       6.936  89.060 -14.619  1.00 70.94           O  \\nATOM   4051  C5'  DC J 199       6.075  87.924 -14.534  1.00 70.94           C  \\nATOM   4052  C4'  DC J 199       4.676  88.352 -14.159  1.00 70.94           C  \\nATOM   4053  O4'  DC J 199       4.501  88.075 -12.746  1.00 70.94           O  \\nATOM   4054  C3'  DC J 199       4.398  89.847 -14.355  1.00 70.94           C  \\nATOM   4055  O3'  DC J 199       3.114  90.102 -14.952  1.00 70.94           O  \\nATOM   4056  C2'  DC J 199       4.501  90.428 -12.956  1.00 70.94           C  \\nATOM   4057  C1'  DC J 199       4.166  89.259 -12.037  1.00 70.94           C  \\nATOM   4058  N1   DC J 199       4.974  89.303 -10.803  1.00 66.89           N  \\nATOM   4059  C2   DC J 199       4.380  88.972  -9.569  1.00 66.89           C  \\nATOM   4060  O2   DC J 199       3.205  88.551  -9.547  1.00 66.89           O  \\nATOM   4061  N3   DC J 199       5.107  89.121  -8.435  1.00 66.89           N  \\nATOM   4062  C4   DC J 199       6.367  89.565  -8.501  1.00 66.89           C  \\nATOM   4063  N4   DC J 199       7.027  89.745  -7.359  1.00 66.89           N  \\nATOM   4064  C5   DC J 199       7.002  89.854  -9.740  1.00 66.89           C  \\nATOM   4065  C6   DC J 199       6.281  89.706 -10.853  1.00 66.89           C  \\nATOM   4066  P    DA J 200       2.493  91.591 -14.908  1.00107.67           P  \\nATOM   4067  OP1  DA J 200       1.297  91.659 -15.787  1.00107.67           O  \\nATOM   4068  OP2  DA J 200       3.592  92.580 -15.091  1.00107.67           O  \\nATOM   4069  O5'  DA J 200       1.973  91.693 -13.409  1.00 74.03           O  \\nATOM   4070  C5'  DA J 200       0.957  90.816 -12.925  1.00 74.03           C  \\nATOM   4071  C4'  DA J 200       0.175  91.511 -11.840  1.00 74.03           C  \\nATOM   4072  O4'  DA J 200       0.850  91.414 -10.565  1.00 74.03           O  \\nATOM   4073  C3'  DA J 200       0.024  93.001 -12.124  1.00 74.03           C  \\nATOM   4074  O3'  DA J 200      -1.255  93.440 -11.698  1.00 74.03           O  \\nATOM   4075  C2'  DA J 200       1.109  93.630 -11.270  1.00 74.03           C  \\nATOM   4076  C1'  DA J 200       1.125  92.714 -10.066  1.00 74.03           C  \\nATOM   4077  N9   DA J 200       2.416  92.672  -9.383  1.00 50.04           N  \\nATOM   4078  C8   DA J 200       3.670  92.716  -9.940  1.00 50.04           C  \\nATOM   4079  N7   DA J 200       4.639  92.670  -9.058  1.00 50.04           N  \\nATOM   4080  C5   DA J 200       3.980  92.590  -7.837  1.00 50.04           C  \\nATOM   4081  C6   DA J 200       4.446  92.523  -6.500  1.00 50.04           C  \\nATOM   4082  N6   DA J 200       5.740  92.505  -6.154  1.00 50.04           N  \\nATOM   4083  N1   DA J 200       3.518  92.468  -5.515  1.00 50.04           N  \\nATOM   4084  C2   DA J 200       2.219  92.473  -5.858  1.00 50.04           C  \\nATOM   4085  N3   DA J 200       1.664  92.529  -7.071  1.00 50.04           N  \\nATOM   4086  C4   DA J 200       2.610  92.589  -8.024  1.00 50.04           C  \\nATOM   4087  P    DA J 201      -1.729  94.937 -12.019  1.00 89.49           P  \\nATOM   4088  OP1  DA J 201      -2.374  94.939 -13.361  1.00 89.49           O  \\nATOM   4089  OP2  DA J 201      -0.601  95.873 -11.741  1.00 89.49           O  \\nATOM   4090  O5'  DA J 201      -2.828  95.159 -10.895  1.00 80.35           O  \\nATOM   4091  C5'  DA J 201      -2.679  94.554  -9.609  1.00 80.35           C  \\nATOM   4092  C4'  DA J 201      -2.261  95.596  -8.599  1.00 80.35           C  \\nATOM   4093  O4'  DA J 201      -0.880  95.428  -8.188  1.00 80.35           O  \\nATOM   4094  C3'  DA J 201      -2.384  97.036  -9.107  1.00 80.35           C  \\nATOM   4095  O3'  DA J 201      -2.970  97.853  -8.096  1.00 80.35           O  \\nATOM   4096  C2'  DA J 201      -0.940  97.452  -9.335  1.00 80.35           C  \\nATOM   4097  C1'  DA J 201      -0.255  96.702  -8.209  1.00 80.35           C  \\nATOM   4098  N9   DA J 201       1.198  96.526  -8.330  1.00 66.94           N  \\nATOM   4099  C8   DA J 201       1.980  96.576  -9.466  1.00 66.94           C  \\nATOM   4100  N7   DA J 201       3.265  96.416  -9.231  1.00 66.94           N  \\nATOM   4101  C5   DA J 201       3.335  96.242  -7.851  1.00 66.94           C  \\nATOM   4102  C6   DA J 201       4.421  96.026  -6.968  1.00 66.94           C  \\nATOM   4103  N6   DA J 201       5.693  95.954  -7.363  1.00 66.94           N  \\nATOM   4104  N1   DA J 201       4.146  95.887  -5.650  1.00 66.94           N  \\nATOM   4105  C2   DA J 201       2.872  95.961  -5.253  1.00 66.94           C  \\nATOM   4106  N3   DA J 201       1.769  96.164  -5.978  1.00 66.94           N  \\nATOM   4107  C4   DA J 201       2.070  96.298  -7.284  1.00 66.94           C  \\nATOM   4108  P    DA J 202      -3.686  99.237  -8.498  1.00103.61           P  \\nATOM   4109  OP1  DA J 202      -5.095  98.938  -8.861  1.00103.61           O  \\nATOM   4110  OP2  DA J 202      -2.813  99.978  -9.460  1.00103.61           O  \\nATOM   4111  O5'  DA J 202      -3.674 100.033  -7.120  1.00 98.69           O  \\nATOM   4112  C5'  DA J 202      -3.851  99.343  -5.883  1.00 98.69           C  \\nATOM   4113  C4'  DA J 202      -2.998  99.968  -4.802  1.00 98.69           C  \\nATOM   4114  O4'  DA J 202      -1.614  99.542  -4.892  1.00 98.69           O  \\nATOM   4115  C3'  DA J 202      -2.978 101.496  -4.791  1.00 98.69           C  \\nATOM   4116  O3'  DA J 202      -3.180 101.962  -3.455  1.00 98.69           O  \\nATOM   4117  C2'  DA J 202      -1.592 101.842  -5.315  1.00 98.69           C  \\nATOM   4118  C1'  DA J 202      -0.747 100.667  -4.844  1.00 98.69           C  \\nATOM   4119  N9   DA J 202       0.420 100.376  -5.687  1.00 70.27           N  \\nATOM   4120  C8   DA J 202       0.464 100.394  -7.063  1.00 70.27           C  \\nATOM   4121  N7   DA J 202       1.636 100.075  -7.564  1.00 70.27           N  \\nATOM   4122  C5   DA J 202       2.423  99.833  -6.447  1.00 70.27           C  \\nATOM   4123  C6   DA J 202       3.769  99.446  -6.309  1.00 70.27           C  \\nATOM   4124  N6   DA J 202       4.580  99.217  -7.347  1.00 70.27           N  \\nATOM   4125  N1   DA J 202       4.258  99.297  -5.056  1.00 70.27           N  \\nATOM   4126  C2   DA J 202       3.440  99.522  -4.020  1.00 70.27           C  \\nATOM   4127  N3   DA J 202       2.151  99.884  -4.020  1.00 70.27           N  \\nATOM   4128  C4   DA J 202       1.693 100.024  -5.281  1.00 70.27           C  \\nATOM   4129  P    DA J 203      -3.082 103.531  -3.129  1.00 91.72           P  \\nATOM   4130  OP1  DA J 203      -3.944 103.818  -1.950  1.00 91.72           O  \\nATOM   4131  OP2  DA J 203      -3.262 104.308  -4.387  1.00 91.72           O  \\nATOM   4132  O5'  DA J 203      -1.574 103.681  -2.663  1.00140.54           O  \\nATOM   4133  C5'  DA J 203      -1.097 102.918  -1.563  1.00140.54           C  \\nATOM   4134  C4'  DA J 203       0.034 103.650  -0.888  1.00140.54           C  \\nATOM   4135  O4'  DA J 203       1.260 103.456  -1.629  1.00140.54           O  \\nATOM   4136  C3'  DA J 203      -0.186 105.157  -0.795  1.00140.54           C  \\nATOM   4137  O3'  DA J 203       0.218 105.591   0.506  1.00140.54           O  \\nATOM   4138  C2'  DA J 203       0.638 105.711  -1.949  1.00140.54           C  \\nATOM   4139  C1'  DA J 203       1.764 104.695  -2.109  1.00140.54           C  \\nATOM   4140  N9   DA J 203       2.242 104.472  -3.481  1.00 56.43           N  \\nATOM   4141  C8   DA J 203       1.659 104.831  -4.679  1.00 56.43           C  \\nATOM   4142  N7   DA J 203       2.337 104.442  -5.737  1.00 56.43           N  \\nATOM   4143  C5   DA J 203       3.448 103.792  -5.204  1.00 56.43           C  \\nATOM   4144  C6   DA J 203       4.556 103.136  -5.802  1.00 56.43           C  \\nATOM   4145  N6   DA J 203       4.739 103.019  -7.117  1.00 56.43           N  \\nATOM   4146  N1   DA J 203       5.479 102.594  -4.982  1.00 56.43           N  \\nATOM   4147  C2   DA J 203       5.304 102.698  -3.658  1.00 56.43           C  \\nATOM   4148  N3   DA J 203       4.316 103.282  -2.976  1.00 56.43           N  \\nATOM   4149  C4   DA J 203       3.408 103.814  -3.816  1.00 56.43           C  \\nATOM   4150  P    DG J 204       0.676 107.106   0.756  1.00 81.30           P  \\nATOM   4151  OP1  DG J 204       0.096 107.547   2.043  1.00 81.30           O  \\nATOM   4152  OP2  DG J 204       0.466 107.925  -0.471  1.00 81.30           O  \\nATOM   4153  O5'  DG J 204       2.228 106.928   0.997  1.00110.04           O  \\nATOM   4154  C5'  DG J 204       2.722 105.738   1.601  1.00110.04           C  \\nATOM   4155  C4'  DG J 204       4.217 105.837   1.739  1.00110.04           C  \\nATOM   4156  O4'  DG J 204       4.817 105.848   0.423  1.00110.04           O  \\nATOM   4157  C3'  DG J 204       4.622 107.152   2.386  1.00110.04           C  \\nATOM   4158  O3'  DG J 204       5.796 106.940   3.145  1.00110.04           O  \\nATOM   4159  C2'  DG J 204       4.868 108.073   1.203  1.00110.04           C  \\nATOM   4160  C1'  DG J 204       5.388 107.123   0.138  1.00110.04           C  \\nATOM   4161  N9   DG J 204       4.997 107.484  -1.222  1.00 73.48           N  \\nATOM   4162  C8   DG J 204       4.005 108.360  -1.591  1.00 73.48           C  \\nATOM   4163  N7   DG J 204       3.854 108.450  -2.886  1.00 73.48           N  \\nATOM   4164  C5   DG J 204       4.808 107.585  -3.406  1.00 73.48           C  \\nATOM   4165  C6   DG J 204       5.113 107.246  -4.763  1.00 73.48           C  \\nATOM   4166  O6   DG J 204       4.559 107.629  -5.801  1.00 73.48           O  \\nATOM   4167  N1   DG J 204       6.175 106.346  -4.840  1.00 73.48           N  \\nATOM   4168  C2   DG J 204       6.844 105.822  -3.761  1.00 73.48           C  \\nATOM   4169  N2   DG J 204       7.843 104.976  -4.062  1.00 73.48           N  \\nATOM   4170  N3   DG J 204       6.556 106.107  -2.493  1.00 73.48           N  \\nATOM   4171  C4   DG J 204       5.535 106.993  -2.393  1.00 73.48           C  \\nATOM   4172  P    DG J 205       6.511 108.178   3.857  1.00 64.48           P  \\nATOM   4173  OP1  DG J 205       6.135 108.158   5.294  1.00 64.48           O  \\nATOM   4174  OP2  DG J 205       6.244 109.389   3.023  1.00 64.48           O  \\nATOM   4175  O5'  DG J 205       8.050 107.777   3.778  1.00 48.62           O  \\nATOM   4176  C5'  DG J 205       8.434 106.436   3.449  1.00 48.62           C  \\nATOM   4177  C4'  DG J 205       9.508 106.450   2.390  1.00 48.62           C  \\nATOM   4178  O4'  DG J 205       9.012 106.861   1.094  1.00 48.62           O  \\nATOM   4179  C3'  DG J 205      10.643 107.411   2.711  1.00 48.62           C  \\nATOM   4180  O3'  DG J 205      11.819 106.810   2.248  1.00 48.62           O  \\nATOM   4181  C2'  DG J 205      10.360 108.607   1.825  1.00 48.62           C  \\nATOM   4182  C1'  DG J 205       9.845 107.904   0.600  1.00 48.62           C  \\nATOM   4183  N9   DG J 205       9.063 108.736  -0.305  1.00 61.32           N  \\nATOM   4184  C8   DG J 205       8.176 109.729   0.028  1.00 61.32           C  \\nATOM   4185  N7   DG J 205       7.615 110.282  -1.012  1.00 61.32           N  \\nATOM   4186  C5   DG J 205       8.169 109.616  -2.098  1.00 61.32           C  \\nATOM   4187  C6   DG J 205       7.934 109.769  -3.486  1.00 61.32           C  \\nATOM   4188  O6   DG J 205       7.160 110.541  -4.054  1.00 61.32           O  \\nATOM   4189  N1   DG J 205       8.710 108.894  -4.238  1.00 61.32           N  \\nATOM   4190  C2   DG J 205       9.602 107.988  -3.724  1.00 61.32           C  \\nATOM   4191  N2   DG J 205      10.277 107.253  -4.624  1.00 61.32           N  \\nATOM   4192  N3   DG J 205       9.819 107.822  -2.428  1.00 61.32           N  \\nATOM   4193  C4   DG J 205       9.072 108.667  -1.678  1.00 61.32           C  \\nATOM   4194  P    DC J 206      13.137 106.891   3.120  1.00 46.58           P  \\nATOM   4195  OP1  DC J 206      13.342 105.607   3.838  1.00 46.58           O  \\nATOM   4196  OP2  DC J 206      13.110 108.171   3.874  1.00 46.58           O  \\nATOM   4197  O5'  DC J 206      14.217 107.073   1.990  1.00 34.79           O  \\nATOM   4198  C5'  DC J 206      14.118 108.202   1.174  1.00 34.79           C  \\nATOM   4199  C4'  DC J 206      14.244 107.807  -0.267  1.00 34.79           C  \\nATOM   4200  O4'  DC J 206      13.061 108.266  -0.959  1.00 34.79           O  \\nATOM   4201  C3'  DC J 206      15.409 108.587  -0.841  1.00 34.79           C  \\nATOM   4202  O3'  DC J 206      16.149 107.808  -1.761  1.00 34.79           O  \\nATOM   4203  C2'  DC J 206      14.767 109.819  -1.448  1.00 34.79           C  \\nATOM   4204  C1'  DC J 206      13.374 109.351  -1.819  1.00 34.79           C  \\nATOM   4205  N1   DC J 206      12.356 110.395  -1.636  1.00 35.23           N  \\nATOM   4206  C2   DC J 206      11.755 110.941  -2.769  1.00 35.23           C  \\nATOM   4207  O2   DC J 206      12.082 110.522  -3.875  1.00 35.23           O  \\nATOM   4208  N3   DC J 206      10.828 111.911  -2.635  1.00 35.23           N  \\nATOM   4209  C4   DC J 206      10.476 112.337  -1.421  1.00 35.23           C  \\nATOM   4210  N4   DC J 206       9.525 113.283  -1.348  1.00 35.23           N  \\nATOM   4211  C5   DC J 206      11.077 111.804  -0.231  1.00 35.23           C  \\nATOM   4212  C6   DC J 206      12.005 110.838  -0.387  1.00 35.23           C  \\nATOM   4213  P    DA J 207      17.651 108.220  -2.080  1.00 32.96           P  \\nATOM   4214  OP1  DA J 207      18.466 106.987  -2.118  1.00 32.96           O  \\nATOM   4215  OP2  DA J 207      18.048 109.345  -1.191  1.00 32.96           O  \\nATOM   4216  O5'  DA J 207      17.540 108.775  -3.551  1.00 23.75           O  \\nATOM   4217  C5'  DA J 207      17.063 107.926  -4.569  1.00 23.75           C  \\nATOM   4218  C4'  DA J 207      16.820 108.704  -5.839  1.00 23.75           C  \\nATOM   4219  O4'  DA J 207      15.702 109.595  -5.639  1.00 23.75           O  \\nATOM   4220  C3'  DA J 207      17.982 109.562  -6.339  1.00 23.75           C  \\nATOM   4221  O3'  DA J 207      18.177 109.274  -7.723  1.00 23.75           O  \\nATOM   4222  C2'  DA J 207      17.558 110.997  -6.026  1.00 23.75           C  \\nATOM   4223  C1'  DA J 207      16.032 110.925  -5.986  1.00 23.75           C  \\nATOM   4224  N9   DA J 207      15.355 111.783  -5.014  1.00 28.89           N  \\nATOM   4225  C8   DA J 207      15.577 111.862  -3.673  1.00 28.89           C  \\nATOM   4226  N7   DA J 207      14.777 112.691  -3.052  1.00 28.89           N  \\nATOM   4227  C5   DA J 207      13.981 113.204  -4.061  1.00 28.89           C  \\nATOM   4228  C6   DA J 207      12.920 114.145  -4.059  1.00 28.89           C  \\nATOM   4229  N6   DA J 207      12.487 114.786  -2.959  1.00 28.89           N  \\nATOM   4230  N1   DA J 207      12.320 114.411  -5.241  1.00 28.89           N  \\nATOM   4231  C2   DA J 207      12.769 113.791  -6.340  1.00 28.89           C  \\nATOM   4232  N3   DA J 207      13.761 112.908  -6.468  1.00 28.89           N  \\nATOM   4233  C4   DA J 207      14.328 112.653  -5.277  1.00 28.89           C  \\nATOM   4234  P    DT J 208      19.314 110.028  -8.548  1.00 21.74           P  \\nATOM   4235  OP1  DT J 208      19.685 109.176  -9.712  1.00 21.74           O  \\nATOM   4236  OP2  DT J 208      20.360 110.575  -7.660  1.00 21.74           O  \\nATOM   4237  O5'  DT J 208      18.547 111.295  -9.089  1.00 28.53           O  \\nATOM   4238  C5'  DT J 208      17.431 111.129  -9.917  1.00 28.53           C  \\nATOM   4239  C4'  DT J 208      16.987 112.470 -10.428  1.00 28.53           C  \\nATOM   4240  O4'  DT J 208      16.269 113.223  -9.430  1.00 28.53           O  \\nATOM   4241  C3'  DT J 208      18.101 113.375 -10.934  1.00 28.53           C  \\nATOM   4242  O3'  DT J 208      17.608 113.851 -12.177  1.00 28.53           O  \\nATOM   4243  C2'  DT J 208      18.179 114.472  -9.878  1.00 28.53           C  \\nATOM   4244  C1'  DT J 208      16.746 114.554  -9.390  1.00 28.53           C  \\nATOM   4245  N1   DT J 208      16.531 115.025  -8.017  1.00 36.35           N  \\nATOM   4246  C2   DT J 208      15.433 115.837  -7.755  1.00 36.35           C  \\nATOM   4247  O2   DT J 208      14.679 116.265  -8.614  1.00 36.35           O  \\nATOM   4248  N3   DT J 208      15.246 116.127  -6.435  1.00 36.35           N  \\nATOM   4249  C4   DT J 208      16.014 115.708  -5.372  1.00 36.35           C  \\nATOM   4250  O4   DT J 208      15.667 116.005  -4.227  1.00 36.35           O  \\nATOM   4251  C5   DT J 208      17.185 114.913  -5.726  1.00 36.35           C  \\nATOM   4252  C7   DT J 208      18.120 114.464  -4.647  1.00 36.35           C  \\nATOM   4253  C6   DT J 208      17.379 114.620  -7.013  1.00 36.35           C  \\nATOM   4254  P    DG J 209      18.596 114.477 -13.260  1.00 46.23           P  \\nATOM   4255  OP1  DG J 209      18.109 114.026 -14.591  1.00 46.23           O  \\nATOM   4256  OP2  DG J 209      20.022 114.257 -12.875  1.00 46.23           O  \\nATOM   4257  O5'  DG J 209      18.217 116.009 -13.085  1.00 34.77           O  \\nATOM   4258  C5'  DG J 209      16.843 116.399 -12.994  1.00 34.77           C  \\nATOM   4259  C4'  DG J 209      16.741 117.863 -12.650  1.00 34.77           C  \\nATOM   4260  O4'  DG J 209      16.580 118.048 -11.230  1.00 34.77           O  \\nATOM   4261  C3'  DG J 209      17.959 118.683 -13.059  1.00 34.77           C  \\nATOM   4262  O3'  DG J 209      17.510 119.843 -13.752  1.00 34.77           O  \\nATOM   4263  C2'  DG J 209      18.647 118.995 -11.738  1.00 34.77           C  \\nATOM   4264  C1'  DG J 209      17.485 119.030 -10.768  1.00 34.77           C  \\nATOM   4265  N9   DG J 209      17.805 118.716  -9.377  1.00 42.96           N  \\nATOM   4266  C8   DG J 209      18.800 117.882  -8.915  1.00 42.96           C  \\nATOM   4267  N7   DG J 209      18.838 117.800  -7.609  1.00 42.96           N  \\nATOM   4268  C5   DG J 209      17.804 118.629  -7.178  1.00 42.96           C  \\nATOM   4269  C6   DG J 209      17.358 118.951  -5.857  1.00 42.96           C  \\nATOM   4270  O6   DG J 209      17.799 118.559  -4.771  1.00 42.96           O  \\nATOM   4271  N1   DG J 209      16.281 119.833  -5.881  1.00 42.96           N  \\nATOM   4272  C2   DG J 209      15.697 120.340  -7.015  1.00 42.96           C  \\nATOM   4273  N2   DG J 209      14.665 121.162  -6.804  1.00 42.96           N  \\nATOM   4274  N3   DG J 209      16.098 120.058  -8.250  1.00 42.96           N  \\nATOM   4275  C4   DG J 209      17.152 119.201  -8.256  1.00 42.96           C  \\nATOM   4276  P    DT J 210      18.561 120.961 -14.219  1.00 40.57           P  \\nATOM   4277  OP1  DT J 210      18.254 121.367 -15.623  1.00 40.57           O  \\nATOM   4278  OP2  DT J 210      19.938 120.516 -13.863  1.00 40.57           O  \\nATOM   4279  O5'  DT J 210      18.166 122.162 -13.261  1.00 65.84           O  \\nATOM   4280  C5'  DT J 210      16.798 122.395 -12.939  1.00 65.84           C  \\nATOM   4281  C4'  DT J 210      16.693 123.501 -11.921  1.00 65.84           C  \\nATOM   4282  O4'  DT J 210      16.844 122.964 -10.584  1.00 65.84           O  \\nATOM   4283  C3'  DT J 210      17.777 124.564 -12.094  1.00 65.84           C  \\nATOM   4284  O3'  DT J 210      17.216 125.866 -12.099  1.00 65.84           O  \\nATOM   4285  C2'  DT J 210      18.678 124.371 -10.888  1.00 65.84           C  \\nATOM   4286  C1'  DT J 210      17.736 123.782  -9.856  1.00 65.84           C  \\nATOM   4287  N1   DT J 210      18.402 122.951  -8.827  1.00 43.10           N  \\nATOM   4288  C2   DT J 210      17.978 123.076  -7.517  1.00 43.10           C  \\nATOM   4289  O2   DT J 210      17.032 123.781  -7.171  1.00 43.10           O  \\nATOM   4290  N3   DT J 210      18.703 122.335  -6.614  1.00 43.10           N  \\nATOM   4291  C4   DT J 210      19.758 121.488  -6.877  1.00 43.10           C  \\nATOM   4292  O4   DT J 210      20.304 120.899  -5.956  1.00 43.10           O  \\nATOM   4293  C5   DT J 210      20.124 121.376  -8.267  1.00 43.10           C  \\nATOM   4294  C7   DT J 210      21.252 120.467  -8.645  1.00 43.10           C  \\nATOM   4295  C6   DT J 210      19.435 122.099  -9.163  1.00 43.10           C  \\nATOM   4296  P    DT J 211      18.158 127.128 -12.403  1.00 74.60           P  \\nATOM   4297  OP1  DT J 211      17.500 127.932 -13.468  1.00 74.60           O  \\nATOM   4298  OP2  DT J 211      19.559 126.670 -12.583  1.00 74.60           O  \\nATOM   4299  O5'  DT J 211      18.089 127.921 -11.031  1.00 50.10           O  \\nATOM   4300  C5'  DT J 211      16.837 128.085 -10.380  1.00 50.10           C  \\nATOM   4301  C4'  DT J 211      17.042 128.674  -9.010  1.00 50.10           C  \\nATOM   4302  O4'  DT J 211      17.584 127.673  -8.123  1.00 50.10           O  \\nATOM   4303  C3'  DT J 211      18.018 129.847  -8.977  1.00 50.10           C  \\nATOM   4304  O3'  DT J 211      17.536 130.774  -8.023  1.00 50.10           O  \\nATOM   4305  C2'  DT J 211      19.296 129.227  -8.457  1.00 50.10           C  \\nATOM   4306  C1'  DT J 211      18.752 128.184  -7.504  1.00 50.10           C  \\nATOM   4307  N1   DT J 211      19.661 127.057  -7.261  1.00 37.44           N  \\nATOM   4308  C2   DT J 211      19.767 126.580  -5.978  1.00 37.44           C  \\nATOM   4309  O2   DT J 211      19.134 127.037  -5.052  1.00 37.44           O  \\nATOM   4310  N3   DT J 211      20.645 125.549  -5.818  1.00 37.44           N  \\nATOM   4311  C4   DT J 211      21.415 124.956  -6.793  1.00 37.44           C  \\nATOM   4312  O4   DT J 211      22.162 124.025  -6.490  1.00 37.44           O  \\nATOM   4313  C5   DT J 211      21.257 125.518  -8.132  1.00 37.44           C  \\nATOM   4314  C7   DT J 211      22.074 124.977  -9.262  1.00 37.44           C  \\nATOM   4315  C6   DT J 211      20.389 126.516  -8.292  1.00 37.44           C  \\nATOM   4316  P    DC J 212      18.023 132.300  -8.066  1.00 41.91           P  \\nATOM   4317  OP1  DC J 212      16.783 133.041  -7.730  1.00 41.91           O  \\nATOM   4318  OP2  DC J 212      18.768 132.615  -9.323  1.00 41.91           O  \\nATOM   4319  O5'  DC J 212      18.987 132.380  -6.803  1.00 48.54           O  \\nATOM   4320  C5'  DC J 212      18.517 131.899  -5.546  1.00 48.54           C  \\nATOM   4321  C4'  DC J 212      19.610 131.948  -4.507  1.00 48.54           C  \\nATOM   4322  O4'  DC J 212      20.329 130.692  -4.474  1.00 48.54           O  \\nATOM   4323  C3'  DC J 212      20.664 133.038  -4.680  1.00 48.54           C  \\nATOM   4324  O3'  DC J 212      20.925 133.619  -3.401  1.00 48.54           O  \\nATOM   4325  C2'  DC J 212      21.880 132.277  -5.187  1.00 48.54           C  \\nATOM   4326  C1'  DC J 212      21.722 130.936  -4.497  1.00 48.54           C  \\nATOM   4327  N1   DC J 212      22.354 129.814  -5.194  1.00 31.23           N  \\nATOM   4328  C2   DC J 212      22.712 128.656  -4.461  1.00 31.23           C  \\nATOM   4329  O2   DC J 212      22.477 128.605  -3.239  1.00 31.23           O  \\nATOM   4330  N3   DC J 212      23.308 127.623  -5.112  1.00 31.23           N  \\nATOM   4331  C4   DC J 212      23.547 127.711  -6.428  1.00 31.23           C  \\nATOM   4332  N4   DC J 212      24.144 126.671  -7.029  1.00 31.23           N  \\nATOM   4333  C5   DC J 212      23.187 128.868  -7.188  1.00 31.23           C  \\nATOM   4334  C6   DC J 212      22.599 129.883  -6.537  1.00 31.23           C  \\nATOM   4335  P    DA J 213      21.702 135.017  -3.305  1.00 38.14           P  \\nATOM   4336  OP1  DA J 213      20.853 135.990  -2.560  1.00 38.14           O  \\nATOM   4337  OP2  DA J 213      22.207 135.349  -4.665  1.00 38.14           O  \\nATOM   4338  O5'  DA J 213      22.956 134.674  -2.395  1.00 34.50           O  \\nATOM   4339  C5'  DA J 213      22.776 133.976  -1.172  1.00 34.50           C  \\nATOM   4340  C4'  DA J 213      24.077 133.356  -0.729  1.00 34.50           C  \\nATOM   4341  O4'  DA J 213      24.400 132.228  -1.566  1.00 34.50           O  \\nATOM   4342  C3'  DA J 213      25.283 134.292  -0.800  1.00 34.50           C  \\nATOM   4343  O3'  DA J 213      26.133 134.006   0.302  1.00 34.50           O  \\nATOM   4344  C2'  DA J 213      25.962 133.875  -2.086  1.00 34.50           C  \\nATOM   4345  C1'  DA J 213      25.717 132.387  -2.035  1.00 34.50           C  \\nATOM   4346  N9   DA J 213      25.819 131.707  -3.313  1.00 29.74           N  \\nATOM   4347  C8   DA J 213      25.643 132.193  -4.586  1.00 29.74           C  \\nATOM   4348  N7   DA J 213      25.877 131.305  -5.524  1.00 29.74           N  \\nATOM   4349  C5   DA J 213      26.219 130.158  -4.817  1.00 29.74           C  \\nATOM   4350  C6   DA J 213      26.590 128.878  -5.224  1.00 29.74           C  \\nATOM   4351  N6   DA J 213      26.739 128.526  -6.502  1.00 29.74           N  \\nATOM   4352  N1   DA J 213      26.825 127.958  -4.260  1.00 29.74           N  \\nATOM   4353  C2   DA J 213      26.723 128.325  -2.975  1.00 29.74           C  \\nATOM   4354  N3   DA J 213      26.410 129.503  -2.467  1.00 29.74           N  \\nATOM   4355  C4   DA J 213      26.164 130.386  -3.454  1.00 29.74           C  \\nATOM   4356  P    DG J 214      25.869 134.741   1.693  1.00 35.57           P  \\nATOM   4357  OP1  DG J 214      24.407 134.680   1.939  1.00 35.57           O  \\nATOM   4358  OP2  DG J 214      26.576 136.060   1.639  1.00 35.57           O  \\nATOM   4359  O5'  DG J 214      26.579 133.810   2.772  1.00 27.59           O  \\nATOM   4360  C5'  DG J 214      25.902 132.679   3.320  1.00 27.59           C  \\nATOM   4361  C4'  DG J 214      26.883 131.573   3.634  1.00 27.59           C  \\nATOM   4362  O4'  DG J 214      27.420 130.976   2.428  1.00 27.59           O  \\nATOM   4363  C3'  DG J 214      28.086 131.977   4.477  1.00 27.59           C  \\nATOM   4364  O3'  DG J 214      28.319 130.900   5.387  1.00 27.59           O  \\nATOM   4365  C2'  DG J 214      29.193 132.162   3.447  1.00 27.59           C  \\nATOM   4366  C1'  DG J 214      28.835 131.132   2.382  1.00 27.59           C  \\nATOM   4367  N9   DG J 214      29.161 131.481   1.008  1.00 33.74           N  \\nATOM   4368  C8   DG J 214      29.088 132.716   0.420  1.00 33.74           C  \\nATOM   4369  N7   DG J 214      29.286 132.681  -0.871  1.00 33.74           N  \\nATOM   4370  C5   DG J 214      29.544 131.348  -1.140  1.00 33.74           C  \\nATOM   4371  C6   DG J 214      29.804 130.697  -2.366  1.00 33.74           C  \\nATOM   4372  O6   DG J 214      29.824 131.178  -3.503  1.00 33.74           O  \\nATOM   4373  N1   DG J 214      30.029 129.333  -2.187  1.00 33.74           N  \\nATOM   4374  C2   DG J 214      29.972 128.674  -0.980  1.00 33.74           C  \\nATOM   4375  N2   DG J 214      30.189 127.342  -1.005  1.00 33.74           N  \\nATOM   4376  N3   DG J 214      29.713 129.274   0.170  1.00 33.74           N  \\nATOM   4377  C4   DG J 214      29.510 130.601   0.016  1.00 33.74           C  \\nATOM   4378  P    DC J 215      29.552 130.951   6.409  1.00 38.45           P  \\nATOM   4379  OP1  DC J 215      29.159 130.048   7.520  1.00 38.45           O  \\nATOM   4380  OP2  DC J 215      29.892 132.362   6.704  1.00 38.45           O  \\nATOM   4381  O5'  DC J 215      30.724 130.272   5.560  1.00 32.65           O  \\nATOM   4382  C5'  DC J 215      30.552 128.944   5.025  1.00 32.65           C  \\nATOM   4383  C4'  DC J 215      31.785 128.495   4.275  1.00 32.65           C  \\nATOM   4384  O4'  DC J 215      31.831 129.136   2.988  1.00 32.65           O  \\nATOM   4385  C3'  DC J 215      33.112 128.848   4.942  1.00 32.65           C  \\nATOM   4386  O3'  DC J 215      34.076 127.838   4.626  1.00 32.65           O  \\nATOM   4387  C2'  DC J 215      33.492 130.147   4.261  1.00 32.65           C  \\nATOM   4388  C1'  DC J 215      33.062 129.819   2.862  1.00 32.65           C  \\nATOM   4389  N1   DC J 215      32.842 130.968   2.011  1.00 30.55           N  \\nATOM   4390  C2   DC J 215      33.022 130.805   0.652  1.00 30.55           C  \\nATOM   4391  O2   DC J 215      33.336 129.679   0.228  1.00 30.55           O  \\nATOM   4392  N3   DC J 215      32.845 131.856  -0.169  1.00 30.55           N  \\nATOM   4393  C4   DC J 215      32.483 133.035   0.335  1.00 30.55           C  \\nATOM   4394  N4   DC J 215      32.317 134.053  -0.516  1.00 30.55           N  \\nATOM   4395  C5   DC J 215      32.275 133.225   1.734  1.00 30.55           C  \\nATOM   4396  C6   DC J 215      32.468 132.173   2.528  1.00 30.55           C  \\nATOM   4397  P    DT J 216      34.461 126.736   5.731  1.00 27.66           P  \\nATOM   4398  OP1  DT J 216      33.200 126.114   6.242  1.00 27.66           O  \\nATOM   4399  OP2  DT J 216      35.400 127.350   6.688  1.00 27.66           O  \\nATOM   4400  O5'  DT J 216      35.231 125.658   4.853  1.00 27.71           O  \\nATOM   4401  C5'  DT J 216      34.559 124.972   3.803  1.00 27.71           C  \\nATOM   4402  C4'  DT J 216      35.373 125.030   2.530  1.00 27.71           C  \\nATOM   4403  O4'  DT J 216      35.203 126.293   1.812  1.00 27.71           O  \\nATOM   4404  C3'  DT J 216      36.870 124.863   2.773  1.00 27.71           C  \\nATOM   4405  O3'  DT J 216      37.414 123.932   1.855  1.00 27.71           O  \\nATOM   4406  C2'  DT J 216      37.426 126.236   2.461  1.00 27.71           C  \\nATOM   4407  C1'  DT J 216      36.479 126.729   1.382  1.00 27.71           C  \\nATOM   4408  N1   DT J 216      36.466 128.206   1.213  1.00 41.33           N  \\nATOM   4409  C2   DT J 216      36.554 128.715  -0.071  1.00 41.33           C  \\nATOM   4410  O2   DT J 216      36.601 128.017  -1.070  1.00 41.33           O  \\nATOM   4411  N3   DT J 216      36.585 130.087  -0.141  1.00 41.33           N  \\nATOM   4412  C4   DT J 216      36.532 130.984   0.912  1.00 41.33           C  \\nATOM   4413  O4   DT J 216      36.559 132.194   0.687  1.00 41.33           O  \\nATOM   4414  C5   DT J 216      36.436 130.391   2.221  1.00 41.33           C  \\nATOM   4415  C7   DT J 216      36.384 131.291   3.413  1.00 41.33           C  \\nATOM   4416  C6   DT J 216      36.400 129.050   2.307  1.00 41.33           C  \\nATOM   4417  P    DG J 217      38.697 123.058   2.274  1.00 23.27           P  \\nATOM   4418  OP1  DG J 217      38.356 121.622   2.412  1.00 23.27           O  \\nATOM   4419  OP2  DG J 217      39.379 123.750   3.397  1.00 23.27           O  \\nATOM   4420  O5'  DG J 217      39.576 123.137   0.959  1.00 20.80           O  \\nATOM   4421  C5'  DG J 217      39.056 122.622  -0.255  1.00 20.80           C  \\nATOM   4422  C4'  DG J 217      39.581 123.410  -1.427  1.00 20.80           C  \\nATOM   4423  O4'  DG J 217      39.353 124.818  -1.177  1.00 20.80           O  \\nATOM   4424  C3'  DG J 217      41.076 123.256  -1.688  1.00 20.80           C  \\nATOM   4425  O3'  DG J 217      41.279 123.257  -3.097  1.00 20.80           O  \\nATOM   4426  C2'  DG J 217      41.673 124.493  -1.043  1.00 20.80           C  \\nATOM   4427  C1'  DG J 217      40.577 125.532  -1.217  1.00 20.80           C  \\nATOM   4428  N9   DG J 217      40.528 126.583  -0.197  1.00 30.27           N  \\nATOM   4429  C8   DG J 217      40.692 126.458   1.164  1.00 30.27           C  \\nATOM   4430  N7   DG J 217      40.613 127.598   1.806  1.00 30.27           N  \\nATOM   4431  C5   DG J 217      40.376 128.527   0.801  1.00 30.27           C  \\nATOM   4432  C6   DG J 217      40.209 129.943   0.872  1.00 30.27           C  \\nATOM   4433  O6   DG J 217      40.227 130.682   1.884  1.00 30.27           O  \\nATOM   4434  N1   DG J 217      40.007 130.492  -0.396  1.00 30.27           N  \\nATOM   4435  C2   DG J 217      39.975 129.773  -1.570  1.00 30.27           C  \\nATOM   4436  N2   DG J 217      39.790 130.484  -2.670  1.00 30.27           N  \\nATOM   4437  N3   DG J 217      40.119 128.466  -1.651  1.00 30.27           N  \\nATOM   4438  C4   DG J 217      40.318 127.910  -0.438  1.00 30.27           C  \\nATOM   4439  P    DA J 218      42.584 122.568  -3.725  1.00 32.10           P  \\nATOM   4440  OP1  DA J 218      42.133 121.545  -4.693  1.00 32.10           O  \\nATOM   4441  OP2  DA J 218      43.540 122.207  -2.640  1.00 32.10           O  \\nATOM   4442  O5'  DA J 218      43.225 123.751  -4.557  1.00 40.86           O  \\nATOM   4443  C5'  DA J 218      42.394 124.668  -5.246  1.00 40.86           C  \\nATOM   4444  C4'  DA J 218      43.097 125.996  -5.388  1.00 40.86           C  \\nATOM   4445  O4'  DA J 218      42.884 126.851  -4.238  1.00 40.86           O  \\nATOM   4446  C3'  DA J 218      44.612 125.878  -5.568  1.00 40.86           C  \\nATOM   4447  O3'  DA J 218      45.012 126.741  -6.627  1.00 40.86           O  \\nATOM   4448  C2'  DA J 218      45.166 126.362  -4.236  1.00 40.86           C  \\nATOM   4449  C1'  DA J 218      44.123 127.387  -3.833  1.00 40.86           C  \\nATOM   4450  N9   DA J 218      44.042 127.704  -2.410  1.00 35.93           N  \\nATOM   4451  C8   DA J 218      44.263 126.909  -1.305  1.00 35.93           C  \\nATOM   4452  N7   DA J 218      44.131 127.542  -0.160  1.00 35.93           N  \\nATOM   4453  C5   DA J 218      43.792 128.842  -0.541  1.00 35.93           C  \\nATOM   4454  C6   DA J 218      43.521 130.016   0.198  1.00 35.93           C  \\nATOM   4455  N6   DA J 218      43.549 130.076   1.535  1.00 35.93           N  \\nATOM   4456  N1   DA J 218      43.221 131.139  -0.494  1.00 35.93           N  \\nATOM   4457  C2   DA J 218      43.201 131.089  -1.831  1.00 35.93           C  \\nATOM   4458  N3   DA J 218      43.439 130.057  -2.638  1.00 35.93           N  \\nATOM   4459  C4   DA J 218      43.730 128.950  -1.922  1.00 35.93           C  \\nATOM   4460  P    DA J 219      46.307 126.390  -7.506  1.00 45.75           P  \\nATOM   4461  OP1  DA J 219      45.827 125.843  -8.811  1.00 45.75           O  \\nATOM   4462  OP2  DA J 219      47.273 125.624  -6.678  1.00 45.75           O  \\nATOM   4463  O5'  DA J 219      46.925 127.833  -7.728  1.00 50.38           O  \\nATOM   4464  C5'  DA J 219      46.053 128.933  -7.961  1.00 50.38           C  \\nATOM   4465  C4'  DA J 219      46.588 130.181  -7.303  1.00 50.38           C  \\nATOM   4466  O4'  DA J 219      46.170 130.322  -5.923  1.00 50.38           O  \\nATOM   4467  C3'  DA J 219      48.105 130.279  -7.312  1.00 50.38           C  \\nATOM   4468  O3'  DA J 219      48.469 131.460  -8.005  1.00 50.38           O  \\nATOM   4469  C2'  DA J 219      48.489 130.313  -5.839  1.00 50.38           C  \\nATOM   4470  C1'  DA J 219      47.237 130.833  -5.163  1.00 50.38           C  \\nATOM   4471  N9   DA J 219      47.069 130.351  -3.797  1.00 33.64           N  \\nATOM   4472  C8   DA J 219      47.183 129.054  -3.373  1.00 33.64           C  \\nATOM   4473  N7   DA J 219      47.059 128.908  -2.068  1.00 33.64           N  \\nATOM   4474  C5   DA J 219      46.832 130.200  -1.602  1.00 33.64           C  \\nATOM   4475  C6   DA J 219      46.634 130.738  -0.292  1.00 33.64           C  \\nATOM   4476  N6   DA J 219      46.669 130.029   0.835  1.00 33.64           N  \\nATOM   4477  N1   DA J 219      46.410 132.059  -0.188  1.00 33.64           N  \\nATOM   4478  C2   DA J 219      46.396 132.795  -1.305  1.00 33.64           C  \\nATOM   4479  N3   DA J 219      46.583 132.419  -2.578  1.00 33.64           N  \\nATOM   4480  C4   DA J 219      46.804 131.095  -2.662  1.00 33.64           C  \\nATOM   4481  P    DT J 220      49.989 131.687  -8.432  1.00 73.26           P  \\nATOM   4482  OP1  DT J 220      49.976 132.230  -9.812  1.00 73.26           O  \\nATOM   4483  OP2  DT J 220      50.790 130.471  -8.124  1.00 73.26           O  \\nATOM   4484  O5'  DT J 220      50.393 132.834  -7.416  1.00 58.76           O  \\nATOM   4485  C5'  DT J 220      49.484 133.896  -7.162  1.00 58.76           C  \\nATOM   4486  C4'  DT J 220      50.019 134.783  -6.069  1.00 58.76           C  \\nATOM   4487  O4'  DT J 220      49.607 134.291  -4.775  1.00 58.76           O  \\nATOM   4488  C3'  DT J 220      51.545 134.872  -6.035  1.00 58.76           C  \\nATOM   4489  O3'  DT J 220      51.959 136.241  -5.909  1.00 58.76           O  \\nATOM   4490  C2'  DT J 220      51.913 134.043  -4.816  1.00 58.76           C  \\nATOM   4491  C1'  DT J 220      50.722 134.287  -3.914  1.00 58.76           C  \\nATOM   4492  N1   DT J 220      50.499 133.267  -2.876  1.00 64.10           N  \\nATOM   4493  C2   DT J 220      50.165 133.696  -1.602  1.00 64.10           C  \\nATOM   4494  O2   DT J 220      50.048 134.874  -1.296  1.00 64.10           O  \\nATOM   4495  N3   DT J 220      49.976 132.683  -0.691  1.00 64.10           N  \\nATOM   4496  C4   DT J 220      50.090 131.316  -0.915  1.00 64.10           C  \\nATOM   4497  O4   DT J 220      49.876 130.524   0.009  1.00 64.10           O  \\nATOM   4498  C5   DT J 220      50.461 130.940  -2.266  1.00 64.10           C  \\nATOM   4499  C7   DT J 220      50.649 129.489  -2.590  1.00 64.10           C  \\nATOM   4500  C6   DT J 220      50.631 131.922  -3.169  1.00 64.10           C  \\nATOM   4501  P    DT J 221      53.527 136.624  -5.975  1.00 62.08           P  \\nATOM   4502  OP1  DT J 221      53.622 137.903  -6.735  1.00 62.08           O  \\nATOM   4503  OP2  DT J 221      54.350 135.453  -6.393  1.00 62.08           O  \\nATOM   4504  O5'  DT J 221      53.843 136.913  -4.447  1.00 55.20           O  \\nATOM   4505  C5'  DT J 221      52.959 137.724  -3.696  1.00 55.20           C  \\nATOM   4506  C4'  DT J 221      53.426 137.787  -2.269  1.00 55.20           C  \\nATOM   4507  O4'  DT J 221      53.044 136.590  -1.563  1.00 55.20           O  \\nATOM   4508  C3'  DT J 221      54.943 137.871  -2.148  1.00 55.20           C  \\nATOM   4509  O3'  DT J 221      55.265 138.720  -1.047  1.00 55.20           O  \\nATOM   4510  C2'  DT J 221      55.331 136.445  -1.811  1.00 55.20           C  \\nATOM   4511  C1'  DT J 221      54.184 136.094  -0.901  1.00 55.20           C  \\nATOM   4512  N1   DT J 221      53.972 134.674  -0.641  1.00 53.92           N  \\nATOM   4513  C2   DT J 221      53.690 134.309   0.657  1.00 53.92           C  \\nATOM   4514  O2   DT J 221      53.666 135.105   1.589  1.00 53.92           O  \\nATOM   4515  N3   DT J 221      53.447 132.972   0.832  1.00 53.92           N  \\nATOM   4516  C4   DT J 221      53.476 131.983  -0.130  1.00 53.92           C  \\nATOM   4517  O4   DT J 221      53.209 130.826   0.183  1.00 53.92           O  \\nATOM   4518  C5   DT J 221      53.820 132.431  -1.465  1.00 53.92           C  \\nATOM   4519  C7   DT J 221      53.920 131.425  -2.567  1.00 53.92           C  \\nATOM   4520  C6   DT J 221      54.039 133.741  -1.652  1.00 53.92           C  \\nATOM   4521  P    DC J 222      56.595 139.616  -1.093  1.00 76.40           P  \\nATOM   4522  OP1  DC J 222      56.187 141.022  -1.336  1.00 76.40           O  \\nATOM   4523  OP2  DC J 222      57.577 138.953  -2.001  1.00 76.40           O  \\nATOM   4524  O5'  DC J 222      57.122 139.538   0.399  1.00 95.23           O  \\nATOM   4525  C5'  DC J 222      56.204 139.363   1.469  1.00 95.23           C  \\nATOM   4526  C4'  DC J 222      56.850 138.571   2.579  1.00 95.23           C  \\nATOM   4527  O4'  DC J 222      56.426 137.186   2.532  1.00 95.23           O  \\nATOM   4528  C3'  DC J 222      58.379 138.539   2.520  1.00 95.23           C  \\nATOM   4529  O3'  DC J 222      58.870 138.571   3.857  1.00 95.23           O  \\nATOM   4530  C2'  DC J 222      58.667 137.176   1.923  1.00 95.23           C  \\nATOM   4531  C1'  DC J 222      57.584 136.383   2.605  1.00 95.23           C  \\nATOM   4532  N1   DC J 222      57.289 135.069   2.037  1.00 33.19           N  \\nATOM   4533  C2   DC J 222      56.807 134.090   2.895  1.00 33.19           C  \\nATOM   4534  O2   DC J 222      56.544 134.415   4.084  1.00 33.19           O  \\nATOM   4535  N3   DC J 222      56.631 132.827   2.426  1.00 33.19           N  \\nATOM   4536  C4   DC J 222      56.902 132.544   1.152  1.00 33.19           C  \\nATOM   4537  N4   DC J 222      56.766 131.274   0.747  1.00 33.19           N  \\nATOM   4538  C5   DC J 222      57.338 133.545   0.239  1.00 33.19           C  \\nATOM   4539  C6   DC J 222      57.514 134.786   0.719  1.00 33.19           C  \\nATOM   4540  P    DA J 223      60.362 139.078   4.159  1.00 77.49           P  \\nATOM   4541  OP1  DA J 223      60.371 140.561   4.087  1.00 77.49           O  \\nATOM   4542  OP2  DA J 223      61.311 138.284   3.325  1.00 77.49           O  \\nATOM   4543  O5'  DA J 223      60.555 138.659   5.677  1.00 71.91           O  \\nATOM   4544  C5'  DA J 223      59.467 138.762   6.599  1.00 71.91           C  \\nATOM   4545  C4'  DA J 223      59.547 137.650   7.616  1.00 71.91           C  \\nATOM   4546  O4'  DA J 223      59.204 136.384   6.994  1.00 71.91           O  \\nATOM   4547  C3'  DA J 223      60.957 137.488   8.167  1.00 71.91           C  \\nATOM   4548  O3'  DA J 223      60.914 137.210   9.560  1.00 71.91           O  \\nATOM   4549  C2'  DA J 223      61.524 136.331   7.361  1.00 71.91           C  \\nATOM   4550  C1'  DA J 223      60.299 135.485   7.047  1.00 71.91           C  \\nATOM   4551  N9   DA J 223      60.366 134.768   5.766  1.00 64.49           N  \\nATOM   4552  C8   DA J 223      60.904 135.204   4.573  1.00 64.49           C  \\nATOM   4553  N7   DA J 223      60.838 134.318   3.606  1.00 64.49           N  \\nATOM   4554  C5   DA J 223      60.209 133.228   4.194  1.00 64.49           C  \\nATOM   4555  C6   DA J 223      59.835 131.966   3.695  1.00 64.49           C  \\nATOM   4556  N6   DA J 223      60.052 131.570   2.439  1.00 64.49           N  \\nATOM   4557  N1   DA J 223      59.219 131.112   4.542  1.00 64.49           N  \\nATOM   4558  C2   DA J 223      58.990 131.508   5.800  1.00 64.49           C  \\nATOM   4559  N3   DA J 223      59.290 132.665   6.387  1.00 64.49           N  \\nATOM   4560  C4   DA J 223      59.906 133.492   5.521  1.00 64.49           C  \\nATOM   4561  P    DG J 224      62.121 137.692  10.503  1.00 77.45           P  \\nATOM   4562  OP1  DG J 224      61.863 139.091  10.930  1.00 77.45           O  \\nATOM   4563  OP2  DG J 224      63.395 137.361   9.797  1.00 77.45           O  \\nATOM   4564  O5'  DG J 224      61.959 136.757  11.791  1.00 44.18           O  \\nATOM   4565  C5'  DG J 224      60.743 136.035  12.028  1.00 44.18           C  \\nATOM   4566  C4'  DG J 224      60.960 134.544  11.865  1.00 44.18           C  \\nATOM   4567  O4'  DG J 224      61.163 134.137  10.489  1.00 44.18           O  \\nATOM   4568  C3'  DG J 224      62.102 133.909  12.647  1.00 44.18           C  \\nATOM   4569  O3'  DG J 224      61.602 132.685  13.120  1.00 44.18           O  \\nATOM   4570  C2'  DG J 224      63.148 133.607  11.585  1.00 44.18           C  \\nATOM   4571  C1'  DG J 224      62.284 133.257  10.391  1.00 44.18           C  \\nATOM   4572  N9   DG J 224      62.903 133.470   9.081  1.00 65.79           N  \\nATOM   4573  C8   DG J 224      63.629 134.570   8.699  1.00 65.79           C  \\nATOM   4574  N7   DG J 224      64.021 134.525   7.453  1.00 65.79           N  \\nATOM   4575  C5   DG J 224      63.532 133.317   6.980  1.00 65.79           C  \\nATOM   4576  C6   DG J 224      63.637 132.729   5.684  1.00 65.79           C  \\nATOM   4577  O6   DG J 224      64.196 133.190   4.663  1.00 65.79           O  \\nATOM   4578  N1   DG J 224      63.009 131.486   5.636  1.00 65.79           N  \\nATOM   4579  C2   DG J 224      62.371 130.890   6.693  1.00 65.79           C  \\nATOM   4580  N2   DG J 224      61.856 129.682   6.443  1.00 65.79           N  \\nATOM   4581  N3   DG J 224      62.253 131.432   7.900  1.00 65.79           N  \\nATOM   4582  C4   DG J 224      62.853 132.639   7.973  1.00 65.79           C  \\nATOM   4583  P    DC J 225      62.049 132.139  14.544  1.00 60.56           P  \\nATOM   4584  OP1  DC J 225      61.029 132.562  15.548  1.00 60.56           O  \\nATOM   4585  OP2  DC J 225      63.473 132.530  14.714  1.00 60.56           O  \\nATOM   4586  O5'  DC J 225      61.963 130.562  14.333  1.00 90.95           O  \\nATOM   4587  C5'  DC J 225      61.506 130.018  13.087  1.00 90.95           C  \\nATOM   4588  C4'  DC J 225      62.422 128.906  12.628  1.00 90.95           C  \\nATOM   4589  O4'  DC J 225      63.027 129.254  11.360  1.00 90.95           O  \\nATOM   4590  C3'  DC J 225      63.585 128.588  13.571  1.00 90.95           C  \\nATOM   4591  O3'  DC J 225      63.828 127.179  13.547  1.00 90.95           O  \\nATOM   4592  C2'  DC J 225      64.755 129.314  12.929  1.00 90.95           C  \\nATOM   4593  C1'  DC J 225      64.436 129.116  11.462  1.00 90.95           C  \\nATOM   4594  N1   DC J 225      65.060 130.067  10.533  1.00 88.80           N  \\nATOM   4595  C2   DC J 225      65.096 129.740   9.172  1.00 88.80           C  \\nATOM   4596  O2   DC J 225      64.601 128.666   8.802  1.00 88.80           O  \\nATOM   4597  N3   DC J 225      65.668 130.599   8.298  1.00 88.80           N  \\nATOM   4598  C4   DC J 225      66.192 131.750   8.739  1.00 88.80           C  \\nATOM   4599  N4   DC J 225      66.748 132.580   7.832  1.00 88.80           N  \\nATOM   4600  C5   DC J 225      66.169 132.106  10.126  1.00 88.80           C  \\nATOM   4601  C6   DC J 225      65.598 131.242  10.978  1.00 88.80           C  \\nATOM   4602  P    DT J 226      63.223 126.245  14.703  1.00 94.45           P  \\nATOM   4603  OP1  DT J 226      61.887 126.758  15.105  1.00 94.45           O  \\nATOM   4604  OP2  DT J 226      64.288 126.079  15.718  1.00 94.45           O  \\nATOM   4605  O5'  DT J 226      62.998 124.851  13.977  1.00 56.93           O  \\nATOM   4606  C5'  DT J 226      62.105 124.753  12.871  1.00 56.93           C  \\nATOM   4607  C4'  DT J 226      62.761 123.997  11.738  1.00 56.93           C  \\nATOM   4608  O4'  DT J 226      63.638 124.807  10.917  1.00 56.93           O  \\nATOM   4609  C3'  DT J 226      63.589 122.795  12.170  1.00 56.93           C  \\nATOM   4610  O3'  DT J 226      63.337 121.790  11.210  1.00 56.93           O  \\nATOM   4611  C2'  DT J 226      65.019 123.286  12.005  1.00 56.93           C  \\nATOM   4612  C1'  DT J 226      64.877 124.129  10.758  1.00 56.93           C  \\nATOM   4613  N1   DT J 226      65.926 125.141  10.522  1.00 56.58           N  \\nATOM   4614  C2   DT J 226      66.214 125.470   9.212  1.00 56.58           C  \\nATOM   4615  O2   DT J 226      65.702 124.912   8.249  1.00 56.58           O  \\nATOM   4616  N3   DT J 226      67.125 126.486   9.065  1.00 56.58           N  \\nATOM   4617  C4   DT J 226      67.753 127.195  10.060  1.00 56.58           C  \\nATOM   4618  O4   DT J 226      68.485 128.129   9.759  1.00 56.58           O  \\nATOM   4619  C5   DT J 226      67.450 126.763  11.408  1.00 56.58           C  \\nATOM   4620  C7   DT J 226      68.121 127.442  12.557  1.00 56.58           C  \\nATOM   4621  C6   DT J 226      66.569 125.764  11.570  1.00 56.58           C  \\nATOM   4622  P    DG J 227      63.360 120.253  11.623  1.00 40.43           P  \\nATOM   4623  OP1  DG J 227      61.987 119.841  11.997  1.00 40.43           O  \\nATOM   4624  OP2  DG J 227      64.502 119.961  12.543  1.00 40.43           O  \\nATOM   4625  O5'  DG J 227      63.693 119.617  10.221  1.00 38.42           O  \\nATOM   4626  C5'  DG J 227      64.946 119.042  10.022  1.00 38.42           C  \\nATOM   4627  C4'  DG J 227      65.549 119.519   8.729  1.00 38.42           C  \\nATOM   4628  O4'  DG J 227      66.049 120.870   8.862  1.00 38.42           O  \\nATOM   4629  C3'  DG J 227      66.768 118.653   8.469  1.00 38.42           C  \\nATOM   4630  O3'  DG J 227      66.885 118.326   7.109  1.00 38.42           O  \\nATOM   4631  C2'  DG J 227      67.933 119.480   8.955  1.00 38.42           C  \\nATOM   4632  C1'  DG J 227      67.464 120.883   8.665  1.00 38.42           C  \\nATOM   4633  N9   DG J 227      68.062 121.882   9.552  1.00 40.96           N  \\nATOM   4634  C8   DG J 227      67.912 122.009  10.918  1.00 40.96           C  \\nATOM   4635  N7   DG J 227      68.561 123.026  11.412  1.00 40.96           N  \\nATOM   4636  C5   DG J 227      69.177 123.602  10.305  1.00 40.96           C  \\nATOM   4637  C6   DG J 227      70.001 124.754  10.205  1.00 40.96           C  \\nATOM   4638  O6   DG J 227      70.350 125.538  11.101  1.00 40.96           O  \\nATOM   4639  N1   DG J 227      70.425 124.969   8.895  1.00 40.96           N  \\nATOM   4640  C2   DG J 227      70.096 124.180   7.821  1.00 40.96           C  \\nATOM   4641  N2   DG J 227      70.636 124.536   6.638  1.00 40.96           N  \\nATOM   4642  N3   DG J 227      69.308 123.119   7.898  1.00 40.96           N  \\nATOM   4643  C4   DG J 227      68.891 122.892   9.158  1.00 40.96           C  \\nATOM   4644  P    DA J 228      67.826 117.121   6.706  1.00 28.41           P  \\nATOM   4645  OP1  DA J 228      67.142 116.125   5.826  1.00 28.41           O  \\nATOM   4646  OP2  DA J 228      68.415 116.666   7.993  1.00 28.41           O  \\nATOM   4647  O5'  DA J 228      68.911 117.884   5.837  1.00 28.47           O  \\nATOM   4648  C5'  DA J 228      68.530 118.601   4.665  1.00 28.47           C  \\nATOM   4649  C4'  DA J 228      69.758 119.114   3.946  1.00 28.47           C  \\nATOM   4650  O4'  DA J 228      70.360 120.190   4.710  1.00 28.47           O  \\nATOM   4651  C3'  DA J 228      70.856 118.072   3.724  1.00 28.47           C  \\nATOM   4652  O3'  DA J 228      71.423 118.254   2.420  1.00 28.47           O  \\nATOM   4653  C2'  DA J 228      71.833 118.343   4.854  1.00 28.47           C  \\nATOM   4654  C1'  DA J 228      71.642 119.827   5.171  1.00 28.47           C  \\nATOM   4655  N9   DA J 228      71.686 120.137   6.595  1.00 30.07           N  \\nATOM   4656  C8   DA J 228      71.134 119.426   7.636  1.00 30.07           C  \\nATOM   4657  N7   DA J 228      71.369 119.946   8.826  1.00 30.07           N  \\nATOM   4658  C5   DA J 228      72.121 121.079   8.546  1.00 30.07           C  \\nATOM   4659  C6   DA J 228      72.701 122.059   9.375  1.00 30.07           C  \\nATOM   4660  N6   DA J 228      72.612 122.062  10.705  1.00 30.07           N  \\nATOM   4661  N1   DA J 228      73.394 123.050   8.776  1.00 30.07           N  \\nATOM   4662  C2   DA J 228      73.495 123.055   7.430  1.00 30.07           C  \\nATOM   4663  N3   DA J 228      72.999 122.192   6.542  1.00 30.07           N  \\nATOM   4664  C4   DA J 228      72.316 121.214   7.171  1.00 30.07           C  \\nATOM   4665  P    DA J 229      72.459 117.176   1.818  1.00 33.93           P  \\nATOM   4666  OP1  DA J 229      72.202 117.082   0.356  1.00 33.93           O  \\nATOM   4667  OP2  DA J 229      72.473 115.939   2.649  1.00 33.93           O  \\nATOM   4668  O5'  DA J 229      73.858 117.903   2.032  1.00 33.59           O  \\nATOM   4669  C5'  DA J 229      74.062 119.229   1.532  1.00 33.59           C  \\nATOM   4670  C4'  DA J 229      75.363 119.804   2.044  1.00 33.59           C  \\nATOM   4671  O4'  DA J 229      75.231 120.242   3.417  1.00 33.59           O  \\nATOM   4672  C3'  DA J 229      76.577 118.872   1.995  1.00 33.59           C  \\nATOM   4673  O3'  DA J 229      77.688 119.578   1.409  1.00 33.59           O  \\nATOM   4674  C2'  DA J 229      76.813 118.533   3.459  1.00 33.59           C  \\nATOM   4675  C1'  DA J 229      76.324 119.774   4.174  1.00 33.59           C  \\nATOM   4676  N9   DA J 229      75.853 119.559   5.536  1.00 48.40           N  \\nATOM   4677  C8   DA J 229      75.087 118.524   6.005  1.00 48.40           C  \\nATOM   4678  N7   DA J 229      74.807 118.605   7.285  1.00 48.40           N  \\nATOM   4679  C5   DA J 229      75.438 119.773   7.691  1.00 48.40           C  \\nATOM   4680  C6   DA J 229      75.529 120.424   8.945  1.00 48.40           C  \\nATOM   4681  N6   DA J 229      74.971 119.970  10.070  1.00 48.40           N  \\nATOM   4682  N1   DA J 229      76.232 121.575   9.002  1.00 48.40           N  \\nATOM   4683  C2   DA J 229      76.808 122.033   7.882  1.00 48.40           C  \\nATOM   4684  N3   DA J 229      76.800 121.514   6.651  1.00 48.40           N  \\nATOM   4685  C4   DA J 229      76.087 120.372   6.621  1.00 48.40           C  \\nATOM   4686  P    DC J 230      79.014 118.782   0.934  1.00 36.79           P  \\nATOM   4687  OP1  DC J 230      79.545 119.471  -0.271  1.00 36.79           O  \\nATOM   4688  OP2  DC J 230      78.677 117.339   0.845  1.00 36.79           O  \\nATOM   4689  O5'  DC J 230      80.022 119.061   2.146  1.00 32.06           O  \\nATOM   4690  C5'  DC J 230      80.065 120.357   2.756  1.00 32.06           C  \\nATOM   4691  C4'  DC J 230      81.101 120.424   3.858  1.00 32.06           C  \\nATOM   4692  O4'  DC J 230      80.425 120.503   5.141  1.00 32.06           O  \\nATOM   4693  C3'  DC J 230      82.112 119.271   3.963  1.00 32.06           C  \\nATOM   4694  O3'  DC J 230      83.453 119.764   4.164  1.00 32.06           O  \\nATOM   4695  C2'  DC J 230      81.669 118.524   5.207  1.00 32.06           C  \\nATOM   4696  C1'  DC J 230      81.034 119.614   6.060  1.00 32.06           C  \\nATOM   4697  N1   DC J 230      79.999 119.111   7.001  1.00 49.38           N  \\nATOM   4698  C2   DC J 230      79.786 119.789   8.218  1.00 49.38           C  \\nATOM   4699  O2   DC J 230      80.381 120.852   8.432  1.00 49.38           O  \\nATOM   4700  N3   DC J 230      78.929 119.267   9.125  1.00 49.38           N  \\nATOM   4701  C4   DC J 230      78.277 118.134   8.856  1.00 49.38           C  \\nATOM   4702  N4   DC J 230      77.473 117.641   9.803  1.00 49.38           N  \\nATOM   4703  C5   DC J 230      78.427 117.454   7.611  1.00 49.38           C  \\nATOM   4704  C6   DC J 230      79.287 117.974   6.719  1.00 49.38           C  \\nATOM   4705  P    DA J 231      84.715 118.915   3.614  1.00 72.18           P  \\nATOM   4706  OP1  DA J 231      84.891 119.184   2.161  1.00 72.18           O  \\nATOM   4707  OP2  DA J 231      84.583 117.508   4.085  1.00 72.18           O  \\nATOM   4708  O5'  DA J 231      85.948 119.562   4.381  1.00146.67           O  \\nATOM   4709  C5'  DA J 231      85.764 120.623   5.320  1.00146.67           C  \\nATOM   4710  C4'  DA J 231      86.351 120.231   6.655  1.00146.67           C  \\nATOM   4711  O4'  DA J 231      85.300 119.805   7.563  1.00146.67           O  \\nATOM   4712  C3'  DA J 231      87.339 119.062   6.557  1.00146.67           C  \\nATOM   4713  O3'  DA J 231      88.519 119.267   7.346  1.00146.67           O  \\nATOM   4714  C2'  DA J 231      86.550 117.889   7.108  1.00146.67           C  \\nATOM   4715  C1'  DA J 231      85.672 118.565   8.141  1.00146.67           C  \\nATOM   4716  N9   DA J 231      84.466 117.801   8.457  1.00119.90           N  \\nATOM   4717  C8   DA J 231      83.766 116.963   7.622  1.00119.90           C  \\nATOM   4718  N7   DA J 231      82.776 116.337   8.210  1.00119.90           N  \\nATOM   4719  C5   DA J 231      82.813 116.810   9.514  1.00119.90           C  \\nATOM   4720  C6   DA J 231      82.034 116.516  10.644  1.00119.90           C  \\nATOM   4721  N6   DA J 231      81.028 115.636  10.635  1.00119.90           N  \\nATOM   4722  N1   DA J 231      82.328 117.161  11.797  1.00119.90           N  \\nATOM   4723  C2   DA J 231      83.344 118.038  11.801  1.00119.90           C  \\nATOM   4724  N3   DA J 231      84.155 118.392  10.804  1.00119.90           N  \\nATOM   4725  C4   DA J 231      83.834 117.731   9.675  1.00119.90           C  \\nATOM   4726  P    DT J 232      89.673 118.137   7.363  1.00158.32           P  \\nATOM   4727  OP1  DT J 232      90.991 118.819   7.341  1.00158.32           O  \\nATOM   4728  OP2  DT J 232      89.362 117.116   6.328  1.00158.32           O  \\nATOM   4729  O5'  DT J 232      89.492 117.444   8.784  1.00193.87           O  \\nATOM   4730  C5'  DT J 232      90.047 116.158   9.051  1.00193.87           C  \\nATOM   4731  C4'  DT J 232      89.746 115.754  10.476  1.00193.87           C  \\nATOM   4732  O4'  DT J 232      88.310 115.746  10.686  1.00193.87           O  \\nATOM   4733  C3'  DT J 232      90.241 114.361  10.871  1.00193.87           C  \\nATOM   4734  O3'  DT J 232      90.722 114.383  12.221  1.00193.87           O  \\nATOM   4735  C2'  DT J 232      88.985 113.510  10.788  1.00193.87           C  \\nATOM   4736  C1'  DT J 232      87.917 114.494  11.231  1.00193.87           C  \\nATOM   4737  N1   DT J 232      86.544 114.185  10.765  1.00169.77           N  \\nATOM   4738  C2   DT J 232      85.539 114.123  11.709  1.00169.77           C  \\nATOM   4739  O2   DT J 232      85.716 114.350  12.896  1.00169.77           O  \\nATOM   4740  N3   DT J 232      84.308 113.789  11.206  1.00169.77           N  \\nATOM   4741  C4   DT J 232      83.979 113.536   9.888  1.00169.77           C  \\nATOM   4742  O4   DT J 232      82.826 113.245   9.596  1.00169.77           O  \\nATOM   4743  C5   DT J 232      85.068 113.642   8.949  1.00169.77           C  \\nATOM   4744  C7   DT J 232      84.799 113.402   7.495  1.00169.77           C  \\nATOM   4745  C6   DT J 232      86.283 113.954   9.428  1.00169.77           C  \\nATOM   4746  P    DG J 233      92.066 113.589  12.609  1.00169.02           P  \\nATOM   4747  OP1  DG J 233      93.235 114.394  12.168  1.00169.02           O  \\nATOM   4748  OP2  DG J 233      91.922 112.186  12.135  1.00169.02           O  \\nATOM   4749  O5'  DG J 233      92.038 113.571  14.202  1.00153.54           O  \\nATOM   4750  C5'  DG J 233      91.798 114.763  14.956  1.00153.54           C  \\nATOM   4751  C4'  DG J 233      90.940 114.447  16.160  1.00153.54           C  \\nATOM   4752  O4'  DG J 233      89.591 114.156  15.724  1.00153.54           O  \\nATOM   4753  C3'  DG J 233      91.400 113.215  16.939  1.00153.54           C  \\nATOM   4754  O3'  DG J 233      91.152 113.381  18.339  1.00153.54           O  \\nATOM   4755  C2'  DG J 233      90.551 112.099  16.359  1.00153.54           C  \\nATOM   4756  C1'  DG J 233      89.245 112.807  16.036  1.00153.54           C  \\nATOM   4757  N9   DG J 233      88.556 112.247  14.878  1.00186.84           N  \\nATOM   4758  C8   DG J 233      89.089 112.052  13.626  1.00186.84           C  \\nATOM   4759  N7   DG J 233      88.236 111.548  12.777  1.00186.84           N  \\nATOM   4760  C5   DG J 233      87.067 111.397  13.510  1.00186.84           C  \\nATOM   4761  C6   DG J 233      85.801 110.905  13.117  1.00186.84           C  \\nATOM   4762  O6   DG J 233      85.439 110.512  12.003  1.00186.84           O  \\nATOM   4763  N1   DG J 233      84.901 110.903  14.175  1.00186.84           N  \\nATOM   4764  C2   DG J 233      85.178 111.332  15.450  1.00186.84           C  \\nATOM   4765  N2   DG J 233      84.172 111.233  16.330  1.00186.84           N  \\nATOM   4766  N3   DG J 233      86.353 111.814  15.829  1.00186.84           N  \\nATOM   4767  C4   DG J 233      87.247 111.815  14.814  1.00186.84           C  \\nATOM   4768  P    DC J 234      91.317 112.126  19.336  1.00139.25           P  \\nATOM   4769  OP1  DC J 234      91.414 112.662  20.719  1.00139.25           O  \\nATOM   4770  OP2  DC J 234      92.373 111.213  18.819  1.00139.25           O  \\nATOM   4771  O5'  DC J 234      89.921 111.372  19.215  1.00158.75           O  \\nATOM   4772  C5'  DC J 234      88.696 112.080  19.384  1.00158.75           C  \\nATOM   4773  C4'  DC J 234      87.643 111.161  19.952  1.00158.75           C  \\nATOM   4774  O4'  DC J 234      87.129 110.321  18.896  1.00158.75           O  \\nATOM   4775  C3'  DC J 234      88.159 110.210  21.025  1.00158.75           C  \\nATOM   4776  O3'  DC J 234      87.127 109.987  21.982  1.00158.75           O  \\nATOM   4777  C2'  DC J 234      88.495 108.950  20.247  1.00158.75           C  \\nATOM   4778  C1'  DC J 234      87.491 108.962  19.105  1.00158.75           C  \\nATOM   4779  N1   DC J 234      88.027 108.463  17.830  1.00135.04           N  \\nATOM   4780  C2   DC J 234      87.161 108.342  16.733  1.00135.04           C  \\nATOM   4781  O2   DC J 234      85.954 108.615  16.880  1.00135.04           O  \\nATOM   4782  N3   DC J 234      87.657 107.933  15.545  1.00135.04           N  \\nATOM   4783  C4   DC J 234      88.954 107.652  15.426  1.00135.04           C  \\nATOM   4784  N4   DC J 234      89.405 107.296  14.224  1.00135.04           N  \\nATOM   4785  C5   DC J 234      89.849 107.736  16.530  1.00135.04           C  \\nATOM   4786  C6   DC J 234      89.348 108.140  17.702  1.00135.04           C  \\nATOM   4787  P    DC J 235      87.307 108.854  23.100  1.00 81.09           P  \\nATOM   4788  OP1  DC J 235      87.101 109.454  24.443  1.00 81.09           O  \\nATOM   4789  OP2  DC J 235      88.550 108.088  22.804  1.00 81.09           O  \\nATOM   4790  O5'  DC J 235      86.081 107.888  22.836  1.00113.21           O  \\nATOM   4791  C5'  DC J 235      84.767 108.407  22.714  1.00113.21           C  \\nATOM   4792  C4'  DC J 235      83.858 107.328  22.185  1.00113.21           C  \\nATOM   4793  O4'  DC J 235      84.361 106.906  20.893  1.00113.21           O  \\nATOM   4794  C3'  DC J 235      83.853 106.077  23.063  1.00113.21           C  \\nATOM   4795  O3'  DC J 235      82.540 105.517  23.095  1.00113.21           O  \\nATOM   4796  C2'  DC J 235      84.850 105.155  22.381  1.00113.21           C  \\nATOM   4797  C1'  DC J 235      84.696 105.526  20.920  1.00113.21           C  \\nATOM   4798  N1   DC J 235      85.906 105.340  20.105  1.00108.11           N  \\nATOM   4799  C2   DC J 235      85.793 105.424  18.715  1.00108.11           C  \\nATOM   4800  O2   DC J 235      84.686 105.670  18.218  1.00108.11           O  \\nATOM   4801  N3   DC J 235      86.887 105.242  17.947  1.00108.11           N  \\nATOM   4802  C4   DC J 235      88.063 104.997  18.517  1.00108.11           C  \\nATOM   4803  N4   DC J 235      89.109 104.834  17.715  1.00108.11           N  \\nATOM   4804  C5   DC J 235      88.214 104.911  19.934  1.00108.11           C  \\nATOM   4805  C6   DC J 235      87.118 105.086  20.683  1.00108.11           C  \\nATOM   4806  P    DT J 236      82.297 104.077  23.757  1.00131.18           P  \\nATOM   4807  OP1  DT J 236      81.208 104.223  24.756  1.00131.18           O  \\nATOM   4808  OP2  DT J 236      83.605 103.503  24.170  1.00131.18           O  \\nATOM   4809  O5'  DT J 236      81.752 103.230  22.527  1.00143.00           O  \\nATOM   4810  C5'  DT J 236      80.977 103.866  21.513  1.00143.00           C  \\nATOM   4811  C4'  DT J 236      80.921 103.016  20.264  1.00143.00           C  \\nATOM   4812  O4'  DT J 236      82.209 102.960  19.600  1.00143.00           O  \\nATOM   4813  C3'  DT J 236      80.472 101.568  20.453  1.00143.00           C  \\nATOM   4814  O3'  DT J 236      79.564 101.246  19.404  1.00143.00           O  \\nATOM   4815  C2'  DT J 236      81.758 100.773  20.298  1.00143.00           C  \\nATOM   4816  C1'  DT J 236      82.546 101.612  19.307  1.00143.00           C  \\nATOM   4817  N1   DT J 236      84.014 101.476  19.424  1.00104.25           N  \\nATOM   4818  C2   DT J 236      84.750 101.245  18.279  1.00104.25           C  \\nATOM   4819  O2   DT J 236      84.258 101.145  17.168  1.00104.25           O  \\nATOM   4820  N3   DT J 236      86.099 101.132  18.487  1.00104.25           N  \\nATOM   4821  C4   DT J 236      86.778 101.231  19.686  1.00104.25           C  \\nATOM   4822  O4   DT J 236      88.001 101.115  19.701  1.00104.25           O  \\nATOM   4823  C5   DT J 236      85.947 101.470  20.848  1.00104.25           C  \\nATOM   4824  C7   DT J 236      86.587 101.577  22.198  1.00104.25           C  \\nATOM   4825  C6   DT J 236      84.625 101.580  20.659  1.00104.25           C  \\nATOM   4826  P    DT J 237      78.643  99.938  19.504  1.00 52.64           P  \\nATOM   4827  OP1  DT J 237      77.236 100.385  19.606  1.00 52.64           O  \\nATOM   4828  OP2  DT J 237      79.198  99.015  20.527  1.00 52.64           O  \\nATOM   4829  O5'  DT J 237      78.859  99.289  18.075  1.00 37.64           O  \\nATOM   4830  C5'  DT J 237      79.003 100.140  16.946  1.00 37.64           C  \\nATOM   4831  C4'  DT J 237      79.780  99.447  15.855  1.00 37.64           C  \\nATOM   4832  O4'  DT J 237      81.185  99.394  16.200  1.00 37.64           O  \\nATOM   4833  C3'  DT J 237      79.343  98.008  15.581  1.00 37.64           C  \\nATOM   4834  O3'  DT J 237      79.174  97.832  14.176  1.00 37.64           O  \\nATOM   4835  C2'  DT J 237      80.496  97.178  16.116  1.00 37.64           C  \\nATOM   4836  C1'  DT J 237      81.679  98.103  15.903  1.00 37.64           C  \\nATOM   4837  N1   DT J 237      82.823  97.838  16.790  1.00 54.88           N  \\nATOM   4838  C2   DT J 237      84.085  97.652  16.243  1.00 54.88           C  \\nATOM   4839  O2   DT J 237      84.325  97.709  15.044  1.00 54.88           O  \\nATOM   4840  N3   DT J 237      85.063  97.395  17.166  1.00 54.88           N  \\nATOM   4841  C4   DT J 237      84.920  97.317  18.535  1.00 54.88           C  \\nATOM   4842  O4   DT J 237      85.897  97.089  19.236  1.00 54.88           O  \\nATOM   4843  C5   DT J 237      83.581  97.523  19.033  1.00 54.88           C  \\nATOM   4844  C7   DT J 237      83.331  97.453  20.507  1.00 54.88           C  \\nATOM   4845  C6   DT J 237      82.614  97.770  18.146  1.00 54.88           C  \\nATOM   4846  P    DT J 238      79.090  96.355  13.556  1.00 30.33           P  \\nATOM   4847  OP1  DT J 238      78.319  96.332  12.268  1.00 30.33           O  \\nATOM   4848  OP2  DT J 238      78.749  95.393  14.645  1.00 30.33           O  \\nATOM   4849  O5'  DT J 238      80.590  96.107  13.132  1.00 48.10           O  \\nATOM   4850  C5'  DT J 238      80.901  94.992  12.356  1.00 48.10           C  \\nATOM   4851  C4'  DT J 238      82.245  95.168  11.710  1.00 48.10           C  \\nATOM   4852  O4'  DT J 238      83.199  95.644  12.695  1.00 48.10           O  \\nATOM   4853  C3'  DT J 238      82.716  93.798  11.264  1.00 48.10           C  \\nATOM   4854  O3'  DT J 238      83.238  93.828   9.943  1.00 48.10           O  \\nATOM   4855  C2'  DT J 238      83.687  93.359  12.348  1.00 48.10           C  \\nATOM   4856  C1'  DT J 238      84.167  94.650  12.999  1.00 48.10           C  \\nATOM   4857  N1   DT J 238      84.265  94.546  14.477  1.00 68.29           N  \\nATOM   4858  C2   DT J 238      85.512  94.381  15.059  1.00 68.29           C  \\nATOM   4859  O2   DT J 238      86.554  94.314  14.419  1.00 68.29           O  \\nATOM   4860  N3   DT J 238      85.493  94.289  16.434  1.00 68.29           N  \\nATOM   4861  C4   DT J 238      84.388  94.341  17.262  1.00 68.29           C  \\nATOM   4862  O4   DT J 238      84.530  94.259  18.482  1.00 68.29           O  \\nATOM   4863  C5   DT J 238      83.122  94.500  16.588  1.00 68.29           C  \\nATOM   4864  C7   DT J 238      81.871  94.537  17.407  1.00 68.29           C  \\nATOM   4865  C6   DT J 238      83.124  94.601  15.250  1.00 68.29           C  \\nATOM   4866  P    DT J 239      83.331  92.458   9.106  1.00 76.19           P  \\nATOM   4867  OP1  DT J 239      83.166  92.771   7.657  1.00 76.19           O  \\nATOM   4868  OP2  DT J 239      82.436  91.464   9.755  1.00 76.19           O  \\nATOM   4869  O5'  DT J 239      84.832  92.012   9.384  1.00 70.92           O  \\nATOM   4870  C5'  DT J 239      85.481  92.456  10.567  1.00 70.92           C  \\nATOM   4871  C4'  DT J 239      86.783  91.729  10.759  1.00 70.92           C  \\nATOM   4872  O4'  DT J 239      87.098  91.843  12.160  1.00 70.92           O  \\nATOM   4873  C3'  DT J 239      86.690  90.233  10.481  1.00 70.92           C  \\nATOM   4874  O3'  DT J 239      87.967  89.754  10.032  1.00 70.92           O  \\nATOM   4875  C2'  DT J 239      86.300  89.656  11.828  1.00 70.92           C  \\nATOM   4876  C1'  DT J 239      87.024  90.575  12.786  1.00 70.92           C  \\nATOM   4877  N1   DT J 239      86.319  90.764  14.039  1.00 92.50           N  \\nATOM   4878  C2   DT J 239      87.003  90.572  15.210  1.00 92.50           C  \\nATOM   4879  O2   DT J 239      88.171  90.213  15.260  1.00 92.50           O  \\nATOM   4880  N3   DT J 239      86.267  90.812  16.333  1.00 92.50           N  \\nATOM   4881  C4   DT J 239      84.952  91.209  16.403  1.00 92.50           C  \\nATOM   4882  O4   DT J 239      84.438  91.394  17.490  1.00 92.50           O  \\nATOM   4883  C5   DT J 239      84.292  91.375  15.135  1.00 92.50           C  \\nATOM   4884  C7   DT J 239      82.858  91.796  15.110  1.00 92.50           C  \\nATOM   4885  C6   DT J 239      85.000  91.144  14.029  1.00 92.50           C  \\nATOM   4886  P    DG J 240      88.100  88.269   9.443  1.00114.93           P  \\nATOM   4887  OP1  DG J 240      89.535  87.902   9.515  1.00114.93           O  \\nATOM   4888  OP2  DG J 240      87.390  88.204   8.137  1.00114.93           O  \\nATOM   4889  O5'  DG J 240      87.296  87.398  10.510  1.00154.49           O  \\nATOM   4890  C5'  DG J 240      87.736  86.099  10.879  1.00154.49           C  \\nATOM   4891  C4'  DG J 240      88.874  86.200  11.867  1.00154.49           C  \\nATOM   4892  O4'  DG J 240      88.495  87.042  12.981  1.00154.49           O  \\nATOM   4893  C3'  DG J 240      89.285  84.859  12.471  1.00154.49           C  \\nATOM   4894  O3'  DG J 240      90.700  84.800  12.631  1.00154.49           O  \\nATOM   4895  C2'  DG J 240      88.609  84.860  13.825  1.00154.49           C  \\nATOM   4896  C1'  DG J 240      88.641  86.327  14.198  1.00154.49           C  \\nATOM   4897  N9   DG J 240      87.538  86.699  15.069  1.00108.40           N  \\nATOM   4898  C8   DG J 240      86.232  86.913  14.702  1.00108.40           C  \\nATOM   4899  N7   DG J 240      85.463  87.207  15.710  1.00108.40           N  \\nATOM   4900  C5   DG J 240      86.314  87.191  16.808  1.00108.40           C  \\nATOM   4901  C6   DG J 240      86.046  87.429  18.175  1.00108.40           C  \\nATOM   4902  O6   DG J 240      84.974  87.714  18.707  1.00108.40           O  \\nATOM   4903  N1   DG J 240      87.192  87.307  18.955  1.00108.40           N  \\nATOM   4904  C2   DG J 240      88.444  86.998  18.480  1.00108.40           C  \\nATOM   4905  N2   DG J 240      89.425  86.928  19.404  1.00108.40           N  \\nATOM   4906  N3   DG J 240      88.709  86.775  17.199  1.00108.40           N  \\nATOM   4907  C4   DG J 240      87.600  86.886  16.427  1.00108.40           C  \\nATOM   4908  P    DA J 241      91.418  83.374  12.794  1.00121.92           P  \\nATOM   4909  OP1  DA J 241      92.716  83.440  12.083  1.00121.92           O  \\nATOM   4910  OP2  DA J 241      90.439  82.318  12.428  1.00121.92           O  \\nATOM   4911  O5'  DA J 241      91.689  83.257  14.359  1.00114.59           O  \\nATOM   4912  C5'  DA J 241      91.769  81.983  14.975  1.00114.59           C  \\nATOM   4913  C4'  DA J 241      91.998  82.120  16.461  1.00114.59           C  \\nATOM   4914  O4'  DA J 241      91.033  83.064  16.994  1.00114.59           O  \\nATOM   4915  C3'  DA J 241      91.763  80.799  17.198  1.00114.59           C  \\nATOM   4916  O3'  DA J 241      92.652  80.611  18.304  1.00114.59           O  \\nATOM   4917  C2'  DA J 241      90.336  80.925  17.690  1.00114.59           C  \\nATOM   4918  C1'  DA J 241      90.211  82.415  17.956  1.00114.59           C  \\nATOM   4919  N9   DA J 241      88.840  82.884  17.785  1.00103.90           N  \\nATOM   4920  C8   DA J 241      88.147  83.124  16.623  1.00103.90           C  \\nATOM   4921  N7   DA J 241      86.904  83.486  16.818  1.00103.90           N  \\nATOM   4922  C5   DA J 241      86.778  83.496  18.199  1.00103.90           C  \\nATOM   4923  C6   DA J 241      85.707  83.793  19.036  1.00103.90           C  \\nATOM   4924  N6   DA J 241      84.509  84.152  18.585  1.00103.90           N  \\nATOM   4925  N1   DA J 241      85.905  83.708  20.369  1.00103.90           N  \\nATOM   4926  C2   DA J 241      87.114  83.348  20.814  1.00103.90           C  \\nATOM   4927  N3   DA J 241      88.201  83.046  20.124  1.00103.90           N  \\nATOM   4928  C4   DA J 241      87.963  83.140  18.805  1.00103.90           C  \\nATOM   4929  P    DT J 242      92.362  79.424  19.351  1.00135.22           P  \\nATOM   4930  OP1  DT J 242      93.547  79.246  20.222  1.00135.22           O  \\nATOM   4931  OP2  DT J 242      91.823  78.266  18.592  1.00135.22           O  \\nATOM   4932  O5'  DT J 242      91.186  80.000  20.249  1.00118.22           O  \\nATOM   4933  C5'  DT J 242      91.460  80.617  21.499  1.00118.22           C  \\nATOM   4934  C4'  DT J 242      90.583  80.007  22.563  1.00118.22           C  \\nATOM   4935  O4'  DT J 242      89.199  80.356  22.307  1.00118.22           O  \\nATOM   4936  C3'  DT J 242      90.628  78.480  22.585  1.00118.22           C  \\nATOM   4937  O3'  DT J 242      90.475  78.041  23.932  1.00118.22           O  \\nATOM   4938  C2'  DT J 242      89.411  78.087  21.767  1.00118.22           C  \\nATOM   4939  C1'  DT J 242      88.427  79.172  22.165  1.00118.22           C  \\nATOM   4940  N1   DT J 242      87.364  79.437  21.186  1.00 76.38           N  \\nATOM   4941  C2   DT J 242      86.208  80.037  21.632  1.00 76.38           C  \\nATOM   4942  O2   DT J 242      86.043  80.395  22.793  1.00 76.38           O  \\nATOM   4943  N3   DT J 242      85.248  80.215  20.663  1.00 76.38           N  \\nATOM   4944  C4   DT J 242      85.339  79.882  19.323  1.00 76.38           C  \\nATOM   4945  O4   DT J 242      84.398  80.102  18.574  1.00 76.38           O  \\nATOM   4946  C5   DT J 242      86.587  79.280  18.923  1.00 76.38           C  \\nATOM   4947  C7   DT J 242      86.782  78.907  17.488  1.00 76.38           C  \\nATOM   4948  C6   DT J 242      87.524  79.084  19.863  1.00 76.38           C  \\nATOM   4949  P    DG J 243      90.379  76.478  24.256  1.00104.97           P  \\nATOM   4950  OP1  DG J 243      91.777  75.974  24.192  1.00104.97           O  \\nATOM   4951  OP2  DG J 243      89.347  75.874  23.373  1.00104.97           O  \\nATOM   4952  O5'  DG J 243      89.862  76.467  25.769  1.00104.53           O  \\nATOM   4953  C5'  DG J 243      88.888  75.519  26.233  1.00104.53           C  \\nATOM   4954  C4'  DG J 243      87.756  76.228  26.949  1.00104.53           C  \\nATOM   4955  O4'  DG J 243      87.065  77.096  26.018  1.00104.53           O  \\nATOM   4956  C3'  DG J 243      86.673  75.320  27.538  1.00104.53           C  \\nATOM   4957  O3'  DG J 243      86.147  75.898  28.740  1.00104.53           O  \\nATOM   4958  C2'  DG J 243      85.609  75.298  26.460  1.00104.53           C  \\nATOM   4959  C1'  DG J 243      85.708  76.689  25.859  1.00104.53           C  \\nATOM   4960  N9   DG J 243      85.403  76.719  24.431  1.00105.48           N  \\nATOM   4961  C8   DG J 243      86.165  76.197  23.408  1.00105.48           C  \\nATOM   4962  N7   DG J 243      85.636  76.377  22.229  1.00105.48           N  \\nATOM   4963  C5   DG J 243      84.454  77.060  22.486  1.00105.48           C  \\nATOM   4964  C6   DG J 243      83.455  77.534  21.598  1.00105.48           C  \\nATOM   4965  O6   DG J 243      83.418  77.462  20.360  1.00105.48           O  \\nATOM   4966  N1   DG J 243      82.417  78.155  22.285  1.00105.48           N  \\nATOM   4967  C2   DG J 243      82.357  78.322  23.653  1.00105.48           C  \\nATOM   4968  N2   DG J 243      81.276  78.953  24.129  1.00105.48           N  \\nATOM   4969  N3   DG J 243      83.289  77.899  24.489  1.00105.48           N  \\nATOM   4970  C4   DG J 243      84.297  77.277  23.844  1.00105.48           C  \\nATOM   4971  P    DG J 244      85.138  75.049  29.664  1.00102.73           P  \\nATOM   4972  OP1  DG J 244      85.008  75.731  30.986  1.00102.73           O  \\nATOM   4973  OP2  DG J 244      85.551  73.617  29.613  1.00102.73           O  \\nATOM   4974  O5'  DG J 244      83.741  75.181  28.908  1.00 91.84           O  \\nATOM   4975  C5'  DG J 244      82.836  76.248  29.213  1.00 91.84           C  \\nATOM   4976  C4'  DG J 244      81.464  75.947  28.656  1.00 91.84           C  \\nATOM   4977  O4'  DG J 244      81.511  75.956  27.213  1.00 91.84           O  \\nATOM   4978  C3'  DG J 244      80.915  74.576  29.046  1.00 91.84           C  \\nATOM   4979  O3'  DG J 244      79.493  74.650  29.130  1.00 91.84           O  \\nATOM   4980  C2'  DG J 244      81.309  73.709  27.864  1.00 91.84           C  \\nATOM   4981  C1'  DG J 244      81.140  74.680  26.712  1.00 91.84           C  \\nATOM   4982  N9   DG J 244      81.966  74.412  25.541  1.00 85.05           N  \\nATOM   4983  C8   DG J 244      83.237  73.896  25.513  1.00 85.05           C  \\nATOM   4984  N7   DG J 244      83.722  73.798  24.306  1.00 85.05           N  \\nATOM   4985  C5   DG J 244      82.705  74.269  23.491  1.00 85.05           C  \\nATOM   4986  C6   DG J 244      82.649  74.404  22.095  1.00 85.05           C  \\nATOM   4987  O6   DG J 244      83.514  74.123  21.266  1.00 85.05           O  \\nATOM   4988  N1   DG J 244      81.431  74.934  21.681  1.00 85.05           N  \\nATOM   4989  C2   DG J 244      80.405  75.292  22.514  1.00 85.05           C  \\nATOM   4990  N2   DG J 244      79.323  75.806  21.922  1.00 85.05           N  \\nATOM   4991  N3   DG J 244      80.441  75.162  23.820  1.00 85.05           N  \\nATOM   4992  C4   DG J 244      81.614  74.650  24.239  1.00 85.05           C  \\nATOM   4993  P    DA J 245      78.779  74.958  30.538  1.00103.71           P  \\nATOM   4994  OP1  DA J 245      79.530  76.025  31.254  1.00103.71           O  \\nATOM   4995  OP2  DA J 245      78.506  73.658  31.217  1.00103.71           O  \\nATOM   4996  O5'  DA J 245      77.378  75.569  30.096  1.00 83.07           O  \\nATOM   4997  C5'  DA J 245      77.322  76.807  29.388  1.00 83.07           C  \\nATOM   4998  C4'  DA J 245      76.353  76.731  28.226  1.00 83.07           C  \\nATOM   4999  O4'  DA J 245      76.913  76.040  27.087  1.00 83.07           O  \\nATOM   5000  C3'  DA J 245      74.992  76.094  28.492  1.00 83.07           C  \\nATOM   5001  O3'  DA J 245      73.996  76.910  27.871  1.00 83.07           O  \\nATOM   5002  C2'  DA J 245      75.109  74.726  27.835  1.00 83.07           C  \\nATOM   5003  C1'  DA J 245      76.072  74.971  26.679  1.00 83.07           C  \\nATOM   5004  N9   DA J 245      76.954  73.851  26.340  1.00 67.02           N  \\nATOM   5005  C8   DA J 245      77.576  72.979  27.203  1.00 67.02           C  \\nATOM   5006  N7   DA J 245      78.395  72.141  26.611  1.00 67.02           N  \\nATOM   5007  C5   DA J 245      78.294  72.468  25.266  1.00 67.02           C  \\nATOM   5008  C6   DA J 245      78.931  71.967  24.124  1.00 67.02           C  \\nATOM   5009  N6   DA J 245      79.860  71.006  24.150  1.00 67.02           N  \\nATOM   5010  N1   DA J 245      78.589  72.502  22.934  1.00 67.02           N  \\nATOM   5011  C2   DA J 245      77.680  73.478  22.903  1.00 67.02           C  \\nATOM   5012  N3   DA J 245      77.028  74.049  23.904  1.00 67.02           N  \\nATOM   5013  C4   DA J 245      77.385  73.496  25.079  1.00 67.02           C  \\nATOM   5014  P    DG J 246      72.455  76.760  28.285  1.00 65.37           P  \\nATOM   5015  OP1  DG J 246      71.944  77.980  28.970  1.00 65.37           O  \\nATOM   5016  OP2  DG J 246      72.302  75.433  28.945  1.00 65.37           O  \\nATOM   5017  O5'  DG J 246      71.768  76.697  26.858  1.00 47.97           O  \\nATOM   5018  C5'  DG J 246      70.941  75.608  26.524  1.00 47.97           C  \\nATOM   5019  C4'  DG J 246      71.270  75.091  25.146  1.00 47.97           C  \\nATOM   5020  O4'  DG J 246      72.578  74.458  25.116  1.00 47.97           O  \\nATOM   5021  C3'  DG J 246      70.273  74.005  24.760  1.00 47.97           C  \\nATOM   5022  O3'  DG J 246      69.876  74.148  23.416  1.00 47.97           O  \\nATOM   5023  C2'  DG J 246      71.038  72.715  24.944  1.00 47.97           C  \\nATOM   5024  C1'  DG J 246      72.442  73.136  24.594  1.00 47.97           C  \\nATOM   5025  N9   DG J 246      73.442  72.265  25.206  1.00 75.80           N  \\nATOM   5026  C8   DG J 246      73.622  72.008  26.547  1.00 75.80           C  \\nATOM   5027  N7   DG J 246      74.593  71.167  26.783  1.00 75.80           N  \\nATOM   5028  C5   DG J 246      75.089  70.856  25.523  1.00 75.80           C  \\nATOM   5029  C6   DG J 246      76.165  70.011  25.141  1.00 75.80           C  \\nATOM   5030  O6   DG J 246      76.922  69.354  25.868  1.00 75.80           O  \\nATOM   5031  N1   DG J 246      76.324  69.981  23.755  1.00 75.80           N  \\nATOM   5032  C2   DG J 246      75.547  70.678  22.859  1.00 75.80           C  \\nATOM   5033  N2   DG J 246      75.845  70.517  21.566  1.00 75.80           N  \\nATOM   5034  N3   DG J 246      74.551  71.475  23.204  1.00 75.80           N  \\nATOM   5035  C4   DG J 246      74.381  71.519  24.540  1.00 75.80           C  \\nATOM   5036  P    DC J 247      68.324  74.235  23.082  1.00 44.36           P  \\nATOM   5037  OP1  DC J 247      67.890  75.509  23.667  1.00 44.36           O  \\nATOM   5038  OP2  DC J 247      67.651  72.979  23.486  1.00 44.36           O  \\nATOM   5039  O5'  DC J 247      68.325  74.348  21.505  1.00 61.15           O  \\nATOM   5040  C5'  DC J 247      69.513  74.731  20.834  1.00 61.15           C  \\nATOM   5041  C4'  DC J 247      69.944  73.643  19.880  1.00 61.15           C  \\nATOM   5042  O4'  DC J 247      70.872  72.735  20.521  1.00 61.15           O  \\nATOM   5043  C3'  DC J 247      68.812  72.779  19.330  1.00 61.15           C  \\nATOM   5044  O3'  DC J 247      69.039  72.597  17.931  1.00 61.15           O  \\nATOM   5045  C2'  DC J 247      68.932  71.482  20.118  1.00 61.15           C  \\nATOM   5046  C1'  DC J 247      70.428  71.391  20.371  1.00 61.15           C  \\nATOM   5047  N1   DC J 247      70.828  70.655  21.586  1.00 56.36           N  \\nATOM   5048  C2   DC J 247      72.074  69.990  21.602  1.00 56.36           C  \\nATOM   5049  O2   DC J 247      72.775  69.978  20.566  1.00 56.36           O  \\nATOM   5050  N3   DC J 247      72.478  69.377  22.740  1.00 56.36           N  \\nATOM   5051  C4   DC J 247      71.695  69.393  23.820  1.00 56.36           C  \\nATOM   5052  N4   DC J 247      72.148  68.801  24.923  1.00 56.36           N  \\nATOM   5053  C5   DC J 247      70.414  70.023  23.818  1.00 56.36           C  \\nATOM   5054  C6   DC J 247      70.024  70.635  22.692  1.00 56.36           C  \\nATOM   5055  P    DA J 248      68.050  71.680  17.066  1.00 54.49           P  \\nATOM   5056  OP1  DA J 248      67.611  72.425  15.859  1.00 54.49           O  \\nATOM   5057  OP2  DA J 248      67.034  71.053  17.978  1.00 54.49           O  \\nATOM   5058  O5'  DA J 248      69.003  70.506  16.588  1.00 82.84           O  \\nATOM   5059  C5'  DA J 248      68.464  69.227  16.347  1.00 82.84           C  \\nATOM   5060  C4'  DA J 248      69.458  68.148  16.698  1.00 82.84           C  \\nATOM   5061  O4'  DA J 248      69.913  68.252  18.071  1.00 82.84           O  \\nATOM   5062  C3'  DA J 248      68.774  66.795  16.588  1.00 82.84           C  \\nATOM   5063  O3'  DA J 248      69.618  65.874  15.946  1.00 82.84           O  \\nATOM   5064  C2'  DA J 248      68.518  66.387  18.021  1.00 82.84           C  \\nATOM   5065  C1'  DA J 248      69.682  67.018  18.735  1.00 82.84           C  \\nATOM   5066  N9   DA J 248      69.363  67.282  20.133  1.00 83.86           N  \\nATOM   5067  C8   DA J 248      68.316  68.007  20.646  1.00 83.86           C  \\nATOM   5068  N7   DA J 248      68.240  67.974  21.954  1.00 83.86           N  \\nATOM   5069  C5   DA J 248      69.324  67.191  22.329  1.00 83.86           C  \\nATOM   5070  C6   DA J 248      69.793  66.757  23.584  1.00 83.86           C  \\nATOM   5071  N6   DA J 248      69.191  67.050  24.745  1.00 83.86           N  \\nATOM   5072  N1   DA J 248      70.913  65.994  23.604  1.00 83.86           N  \\nATOM   5073  C2   DA J 248      71.507  65.688  22.438  1.00 83.86           C  \\nATOM   5074  N3   DA J 248      71.155  66.026  21.202  1.00 83.86           N  \\nATOM   5075  C4   DA J 248      70.041  66.783  21.217  1.00 83.86           C  \\nATOM   5076  P    DG J 249      69.026  64.978  14.771  1.00 73.61           P  \\nATOM   5077  OP1  DG J 249      68.577  65.873  13.672  1.00 73.61           O  \\nATOM   5078  OP2  DG J 249      68.066  64.007  15.374  1.00 73.61           O  \\nATOM   5079  O5'  DG J 249      70.304  64.175  14.300  1.00106.31           O  \\nATOM   5080  C5'  DG J 249      70.214  62.789  14.156  1.00106.31           C  \\nATOM   5081  C4'  DG J 249      70.919  62.088  15.289  1.00106.31           C  \\nATOM   5082  O4'  DG J 249      70.786  62.759  16.572  1.00106.31           O  \\nATOM   5083  C3'  DG J 249      70.289  60.716  15.459  1.00106.31           C  \\nATOM   5084  O3'  DG J 249      71.248  59.689  15.312  1.00106.31           O  \\nATOM   5085  C2'  DG J 249      69.625  60.752  16.829  1.00106.31           C  \\nATOM   5086  C1'  DG J 249      70.415  61.809  17.567  1.00106.31           C  \\nATOM   5087  N9   DG J 249      69.675  62.500  18.628  1.00 92.68           N  \\nATOM   5088  C8   DG J 249      68.736  63.493  18.477  1.00 92.68           C  \\nATOM   5089  N7   DG J 249      68.285  63.955  19.614  1.00 92.68           N  \\nATOM   5090  C5   DG J 249      68.958  63.218  20.579  1.00 92.68           C  \\nATOM   5091  C6   DG J 249      68.900  63.287  22.004  1.00 92.68           C  \\nATOM   5092  O6   DG J 249      68.244  64.053  22.719  1.00 92.68           O  \\nATOM   5093  N1   DG J 249      69.729  62.344  22.597  1.00 92.68           N  \\nATOM   5094  C2   DG J 249      70.524  61.458  21.919  1.00 92.68           C  \\nATOM   5095  N2   DG J 249      71.246  60.621  22.683  1.00 92.68           N  \\nATOM   5096  N3   DG J 249      70.605  61.394  20.595  1.00 92.68           N  \\nATOM   5097  C4   DG J 249      69.801  62.298  19.992  1.00 92.68           C  \\nATOM   5098  P    DT J 250      70.738  58.206  15.035  1.00109.16           P  \\nATOM   5099  OP1  DT J 250      71.882  57.438  14.491  1.00109.16           O  \\nATOM   5100  OP2  DT J 250      69.457  58.264  14.274  1.00109.16           O  \\nATOM   5101  O5'  DT J 250      70.448  57.722  16.515  1.00 82.94           O  \\nATOM   5102  C5'  DT J 250      71.410  57.981  17.533  1.00 82.94           C  \\nATOM   5103  C4'  DT J 250      71.049  57.225  18.783  1.00 82.94           C  \\nATOM   5104  O4'  DT J 250      70.408  58.100  19.737  1.00 82.94           O  \\nATOM   5105  C3'  DT J 250      70.076  56.076  18.525  1.00 82.94           C  \\nATOM   5106  O3'  DT J 250      70.505  54.923  19.243  1.00 82.94           O  \\nATOM   5107  C2'  DT J 250      68.753  56.607  19.052  1.00 82.94           C  \\nATOM   5108  C1'  DT J 250      69.216  57.492  20.193  1.00 82.94           C  \\nATOM   5109  N1   DT J 250      68.293  58.563  20.600  1.00 87.36           N  \\nATOM   5110  C2   DT J 250      68.176  58.825  21.947  1.00 87.36           C  \\nATOM   5111  O2   DT J 250      68.801  58.226  22.802  1.00 87.36           O  \\nATOM   5112  N3   DT J 250      67.298  59.818  22.261  1.00 87.36           N  \\nATOM   5113  C4   DT J 250      66.539  60.564  21.388  1.00 87.36           C  \\nATOM   5114  O4   DT J 250      65.783  61.421  21.825  1.00 87.36           O  \\nATOM   5115  C5   DT J 250      66.715  60.246  19.987  1.00 87.36           C  \\nATOM   5116  C7   DT J 250      65.936  61.009  18.962  1.00 87.36           C  \\nATOM   5117  C6   DT J 250      67.574  59.273  19.667  1.00 87.36           C  \\nATOM   5118  P    DT J 251      69.815  53.509  18.950  1.00130.75           P  \\nATOM   5119  OP1  DT J 251      70.874  52.542  18.566  1.00130.75           O  \\nATOM   5120  OP2  DT J 251      68.668  53.749  18.037  1.00130.75           O  \\nATOM   5121  O5'  DT J 251      69.244  53.103  20.374  1.00107.80           O  \\nATOM   5122  C5'  DT J 251      70.076  53.171  21.525  1.00107.80           C  \\nATOM   5123  C4'  DT J 251      69.264  52.891  22.764  1.00107.80           C  \\nATOM   5124  O4'  DT J 251      68.540  54.076  23.181  1.00107.80           O  \\nATOM   5125  C3'  DT J 251      68.221  51.793  22.567  1.00107.80           C  \\nATOM   5126  O3'  DT J 251      68.243  50.899  23.678  1.00107.80           O  \\nATOM   5127  C2'  DT J 251      66.909  52.557  22.466  1.00107.80           C  \\nATOM   5128  C1'  DT J 251      67.167  53.767  23.347  1.00107.80           C  \\nATOM   5129  N1   DT J 251      66.381  54.972  23.003  1.00 93.28           N  \\nATOM   5130  C2   DT J 251      66.044  55.837  24.021  1.00 93.28           C  \\nATOM   5131  O2   DT J 251      66.367  55.658  25.182  1.00 93.28           O  \\nATOM   5132  N3   DT J 251      65.310  56.927  23.626  1.00 93.28           N  \\nATOM   5133  C4   DT J 251      64.898  57.239  22.348  1.00 93.28           C  \\nATOM   5134  O4   DT J 251      64.258  58.267  22.151  1.00 93.28           O  \\nATOM   5135  C5   DT J 251      65.280  56.288  21.328  1.00 93.28           C  \\nATOM   5136  C7   DT J 251      64.863  56.534  19.913  1.00 93.28           C  \\nATOM   5137  C6   DT J 251      65.996  55.217  21.701  1.00 93.28           C  \\nATOM   5138  P    DT J 252      67.052  49.845  23.875  1.00 85.03           P  \\nATOM   5139  OP1  DT J 252      67.645  48.580  24.395  1.00 85.03           O  \\nATOM   5140  OP2  DT J 252      66.209  49.818  22.644  1.00 85.03           O  \\nATOM   5141  O5'  DT J 252      66.206  50.525  25.031  1.00 79.65           O  \\nATOM   5142  C5'  DT J 252      66.862  51.191  26.109  1.00 79.65           C  \\nATOM   5143  C4'  DT J 252      65.843  51.633  27.129  1.00 79.65           C  \\nATOM   5144  O4'  DT J 252      65.199  52.864  26.714  1.00 79.65           O  \\nATOM   5145  C3'  DT J 252      64.732  50.607  27.314  1.00 79.65           C  \\nATOM   5146  O3'  DT J 252      64.429  50.466  28.696  1.00 79.65           O  \\nATOM   5147  C2'  DT J 252      63.568  51.182  26.518  1.00 79.65           C  \\nATOM   5148  C1'  DT J 252      63.790  52.685  26.622  1.00 79.65           C  \\nATOM   5149  N1   DT J 252      63.304  53.494  25.471  1.00 78.34           N  \\nATOM   5150  C2   DT J 252      62.618  54.663  25.741  1.00 78.34           C  \\nATOM   5151  O2   DT J 252      62.345  55.034  26.872  1.00 78.34           O  \\nATOM   5152  N3   DT J 252      62.258  55.386  24.628  1.00 78.34           N  \\nATOM   5153  C4   DT J 252      62.499  55.063  23.302  1.00 78.34           C  \\nATOM   5154  O4   DT J 252      62.137  55.823  22.407  1.00 78.34           O  \\nATOM   5155  C5   DT J 252      63.187  53.813  23.090  1.00 78.34           C  \\nATOM   5156  C7   DT J 252      63.466  53.371  21.687  1.00 78.34           C  \\nATOM   5157  C6   DT J 252      63.550  53.099  24.169  1.00 78.34           C  \\nATOM   5158  P    DC J 253      63.213  49.531  29.139  1.00 85.52           P  \\nATOM   5159  OP1  DC J 253      63.518  49.051  30.510  1.00 85.52           O  \\nATOM   5160  OP2  DC J 253      62.942  48.553  28.045  1.00 85.52           O  \\nATOM   5161  O5'  DC J 253      61.985  50.538  29.211  1.00109.10           O  \\nATOM   5162  C5'  DC J 253      62.007  51.657  30.094  1.00109.10           C  \\nATOM   5163  C4'  DC J 253      60.597  52.023  30.489  1.00109.10           C  \\nATOM   5164  O4'  DC J 253      59.994  52.808  29.435  1.00109.10           O  \\nATOM   5165  C3'  DC J 253      59.691  50.810  30.667  1.00109.10           C  \\nATOM   5166  O3'  DC J 253      58.723  51.095  31.672  1.00109.10           O  \\nATOM   5167  C2'  DC J 253      59.050  50.650  29.300  1.00109.10           C  \\nATOM   5168  C1'  DC J 253      58.945  52.081  28.804  1.00109.10           C  \\nATOM   5169  N1   DC J 253      59.141  52.209  27.356  1.00 81.34           N  \\nATOM   5170  C2   DC J 253      58.574  53.299  26.693  1.00 81.34           C  \\nATOM   5171  O2   DC J 253      57.897  54.114  27.343  1.00 81.34           O  \\nATOM   5172  N3   DC J 253      58.778  53.441  25.362  1.00 81.34           N  \\nATOM   5173  C4   DC J 253      59.511  52.543  24.701  1.00 81.34           C  \\nATOM   5174  N4   DC J 253      59.694  52.722  23.391  1.00 81.34           N  \\nATOM   5175  C5   DC J 253      60.091  51.417  25.353  1.00 81.34           C  \\nATOM   5176  C6   DC J 253      59.880  51.288  26.667  1.00 81.34           C  \\nATOM   5177  P    DC J 254      57.514  50.073  31.935  1.00114.20           P  \\nATOM   5178  OP1  DC J 254      57.893  49.157  33.038  1.00114.20           O  \\nATOM   5179  OP2  DC J 254      57.058  49.508  30.633  1.00114.20           O  \\nATOM   5180  O5'  DC J 254      56.383  51.044  32.479  1.00 92.13           O  \\nATOM   5181  C5'  DC J 254      56.707  52.387  32.822  1.00 92.13           C  \\nATOM   5182  C4'  DC J 254      55.682  53.336  32.248  1.00 92.13           C  \\nATOM   5183  O4'  DC J 254      55.848  53.460  30.812  1.00 92.13           O  \\nATOM   5184  C3'  DC J 254      54.223  52.929  32.470  1.00 92.13           C  \\nATOM   5185  O3'  DC J 254      53.472  54.119  32.704  1.00 92.13           O  \\nATOM   5186  C2'  DC J 254      53.825  52.343  31.127  1.00 92.13           C  \\nATOM   5187  C1'  DC J 254      54.586  53.257  30.193  1.00 92.13           C  \\nATOM   5188  N1   DC J 254      54.802  52.756  28.826  1.00 67.33           N  \\nATOM   5189  C2   DC J 254      54.587  53.631  27.757  1.00 67.33           C  \\nATOM   5190  O2   DC J 254      54.261  54.803  27.996  1.00 67.33           O  \\nATOM   5191  N3   DC J 254      54.747  53.189  26.498  1.00 67.33           N  \\nATOM   5192  C4   DC J 254      55.120  51.935  26.276  1.00 67.33           C  \\nATOM   5193  N4   DC J 254      55.254  51.551  25.012  1.00 67.33           N  \\nATOM   5194  C5   DC J 254      55.367  51.020  27.343  1.00 67.33           C  \\nATOM   5195  C6   DC J 254      55.195  51.468  28.592  1.00 67.33           C  \\nATOM   5196  P    DA J 255      52.018  54.045  33.381  1.00 76.17           P  \\nATOM   5197  OP1  DA J 255      52.234  54.052  34.847  1.00 76.17           O  \\nATOM   5198  OP2  DA J 255      51.200  52.964  32.764  1.00 76.17           O  \\nATOM   5199  O5'  DA J 255      51.384  55.447  32.959  1.00 80.39           O  \\nATOM   5200  C5'  DA J 255      52.222  56.599  32.783  1.00 80.39           C  \\nATOM   5201  C4'  DA J 255      51.656  57.528  31.732  1.00 80.39           C  \\nATOM   5202  O4'  DA J 255      51.706  56.917  30.424  1.00 80.39           O  \\nATOM   5203  C3'  DA J 255      50.199  57.916  31.951  1.00 80.39           C  \\nATOM   5204  O3'  DA J 255      49.998  59.272  31.549  1.00 80.39           O  \\nATOM   5205  C2'  DA J 255      49.437  56.937  31.076  1.00 80.39           C  \\nATOM   5206  C1'  DA J 255      50.394  56.670  29.931  1.00 80.39           C  \\nATOM   5207  N9   DA J 255      50.372  55.284  29.492  1.00 75.08           N  \\nATOM   5208  C8   DA J 255      50.120  54.167  30.246  1.00 75.08           C  \\nATOM   5209  N7   DA J 255      50.267  53.045  29.589  1.00 75.08           N  \\nATOM   5210  C5   DA J 255      50.623  53.452  28.311  1.00 75.08           C  \\nATOM   5211  C6   DA J 255      50.948  52.740  27.143  1.00 75.08           C  \\nATOM   5212  N6   DA J 255      50.999  51.410  27.070  1.00 75.08           N  \\nATOM   5213  N1   DA J 255      51.240  53.456  26.037  1.00 75.08           N  \\nATOM   5214  C2   DA J 255      51.220  54.792  26.112  1.00 75.08           C  \\nATOM   5215  N3   DA J 255      50.950  55.572  27.153  1.00 75.08           N  \\nATOM   5216  C4   DA J 255      50.659  54.831  28.233  1.00 75.08           C  \\nATOM   5217  P    DA J 256      48.508  59.827  31.347  1.00102.07           P  \\nATOM   5218  OP1  DA J 256      48.572  61.295  31.556  1.00102.07           O  \\nATOM   5219  OP2  DA J 256      47.572  59.008  32.158  1.00102.07           O  \\nATOM   5220  O5'  DA J 256      48.224  59.524  29.811  1.00 77.02           O  \\nATOM   5221  C5'  DA J 256      49.107  60.030  28.813  1.00 77.02           C  \\nATOM   5222  C4'  DA J 256      48.566  59.732  27.438  1.00 77.02           C  \\nATOM   5223  O4'  DA J 256      48.740  58.334  27.135  1.00 77.02           O  \\nATOM   5224  C3'  DA J 256      47.072  60.008  27.263  1.00 77.02           C  \\nATOM   5225  O3'  DA J 256      46.848  60.402  25.908  1.00 77.02           O  \\nATOM   5226  C2'  DA J 256      46.463  58.640  27.483  1.00 77.02           C  \\nATOM   5227  C1'  DA J 256      47.489  57.806  26.761  1.00 77.02           C  \\nATOM   5228  N9   DA J 256      47.497  56.396  27.083  1.00 74.09           N  \\nATOM   5229  C8   DA J 256      47.218  55.761  28.260  1.00 74.09           C  \\nATOM   5230  N7   DA J 256      47.324  54.458  28.189  1.00 74.09           N  \\nATOM   5231  C5   DA J 256      47.701  54.229  26.874  1.00 74.09           C  \\nATOM   5232  C6   DA J 256      47.981  53.057  26.164  1.00 74.09           C  \\nATOM   5233  N6   DA J 256      47.916  51.836  26.704  1.00 74.09           N  \\nATOM   5234  N1   DA J 256      48.334  53.182  24.861  1.00 74.09           N  \\nATOM   5235  C2   DA J 256      48.397  54.413  24.327  1.00 74.09           C  \\nATOM   5236  N3   DA J 256      48.158  55.586  24.898  1.00 74.09           N  \\nATOM   5237  C4   DA J 256      47.811  55.417  26.185  1.00 74.09           C  \\nATOM   5238  P    DA J 257      45.461  61.087  25.488  1.00 55.44           P  \\nATOM   5239  OP1  DA J 257      45.675  62.569  25.491  1.00 55.44           O  \\nATOM   5240  OP2  DA J 257      44.370  60.482  26.296  1.00 55.44           O  \\nATOM   5241  O5'  DA J 257      45.253  60.594  23.996  1.00 45.93           O  \\nATOM   5242  C5'  DA J 257      46.361  60.516  23.116  1.00 45.93           C  \\nATOM   5243  C4'  DA J 257      46.092  59.489  22.045  1.00 45.93           C  \\nATOM   5244  O4'  DA J 257      46.323  58.139  22.519  1.00 45.93           O  \\nATOM   5245  C3'  DA J 257      44.657  59.533  21.537  1.00 45.93           C  \\nATOM   5246  O3'  DA J 257      44.649  59.502  20.125  1.00 45.93           O  \\nATOM   5247  C2'  DA J 257      44.029  58.278  22.107  1.00 45.93           C  \\nATOM   5248  C1'  DA J 257      45.203  57.326  22.238  1.00 45.93           C  \\nATOM   5249  N9   DA J 257      45.054  56.389  23.351  1.00 63.46           N  \\nATOM   5250  C8   DA J 257      44.648  56.661  24.638  1.00 63.46           C  \\nATOM   5251  N7   DA J 257      44.594  55.607  25.412  1.00 63.46           N  \\nATOM   5252  C5   DA J 257      44.997  54.569  24.584  1.00 63.46           C  \\nATOM   5253  C6   DA J 257      45.148  53.196  24.805  1.00 63.46           C  \\nATOM   5254  N6   DA J 257      44.925  52.608  25.984  1.00 63.46           N  \\nATOM   5255  N1   DA J 257      45.549  52.433  23.762  1.00 63.46           N  \\nATOM   5256  C2   DA J 257      45.794  53.026  22.584  1.00 63.46           C  \\nATOM   5257  N3   DA J 257      45.701  54.310  22.256  1.00 63.46           N  \\nATOM   5258  C4   DA J 257      45.288  55.037  23.312  1.00 63.46           C  \\nATOM   5259  P    DT J 258      43.294  59.800  19.354  1.00 49.05           P  \\nATOM   5260  OP1  DT J 258      43.511  60.827  18.317  1.00 49.05           O  \\nATOM   5261  OP2  DT J 258      42.260  60.016  20.398  1.00 49.05           O  \\nATOM   5262  O5'  DT J 258      43.031  58.408  18.656  1.00 58.61           O  \\nATOM   5263  C5'  DT J 258      43.453  57.234  19.314  1.00 58.61           C  \\nATOM   5264  C4'  DT J 258      43.772  56.158  18.311  1.00 58.61           C  \\nATOM   5265  O4'  DT J 258      44.016  54.978  19.091  1.00 58.61           O  \\nATOM   5266  C3'  DT J 258      42.574  55.821  17.437  1.00 58.61           C  \\nATOM   5267  O3'  DT J 258      43.004  55.179  16.228  1.00 58.61           O  \\nATOM   5268  C2'  DT J 258      41.773  54.908  18.336  1.00 58.61           C  \\nATOM   5269  C1'  DT J 258      42.831  54.219  19.184  1.00 58.61           C  \\nATOM   5270  N1   DT J 258      42.477  54.179  20.592  1.00 53.19           N  \\nATOM   5271  C2   DT J 258      42.628  52.988  21.247  1.00 53.19           C  \\nATOM   5272  O2   DT J 258      43.027  51.976  20.702  1.00 53.19           O  \\nATOM   5273  N3   DT J 258      42.302  53.019  22.569  1.00 53.19           N  \\nATOM   5274  C4   DT J 258      41.872  54.109  23.296  1.00 53.19           C  \\nATOM   5275  O4   DT J 258      41.658  53.983  24.496  1.00 53.19           O  \\nATOM   5276  C5   DT J 258      41.721  55.341  22.537  1.00 53.19           C  \\nATOM   5277  C7   DT J 258      41.247  56.578  23.233  1.00 53.19           C  \\nATOM   5278  C6   DT J 258      42.021  55.308  21.235  1.00 53.19           C  \\nATOM   5279  P    DA J 259      41.954  54.921  15.032  1.00119.77           P  \\nATOM   5280  OP1  DA J 259      42.730  54.661  13.786  1.00119.77           O  \\nATOM   5281  OP2  DA J 259      40.936  56.005  15.054  1.00119.77           O  \\nATOM   5282  O5'  DA J 259      41.249  53.551  15.437  1.00110.54           O  \\nATOM   5283  C5'  DA J 259      41.949  52.312  15.326  1.00110.54           C  \\nATOM   5284  C4'  DA J 259      41.051  51.166  15.728  1.00110.54           C  \\nATOM   5285  O4'  DA J 259      40.834  51.184  17.159  1.00110.54           O  \\nATOM   5286  C3'  DA J 259      39.661  51.183  15.090  1.00110.54           C  \\nATOM   5287  O3'  DA J 259      39.274  49.849  14.749  1.00110.54           O  \\nATOM   5288  C2'  DA J 259      38.775  51.725  16.198  1.00110.54           C  \\nATOM   5289  C1'  DA J 259      39.443  51.149  17.430  1.00110.54           C  \\nATOM   5290  N9   DA J 259      39.203  51.887  18.670  1.00116.92           N  \\nATOM   5291  C8   DA J 259      38.977  53.233  18.834  1.00116.92           C  \\nATOM   5292  N7   DA J 259      38.790  53.590  20.083  1.00116.92           N  \\nATOM   5293  C5   DA J 259      38.899  52.398  20.789  1.00116.92           C  \\nATOM   5294  C6   DA J 259      38.791  52.095  22.158  1.00116.92           C  \\nATOM   5295  N6   DA J 259      38.536  53.004  23.100  1.00116.92           N  \\nATOM   5296  N1   DA J 259      38.954  50.804  22.531  1.00116.92           N  \\nATOM   5297  C2   DA J 259      39.200  49.892  21.587  1.00116.92           C  \\nATOM   5298  N3   DA J 259      39.318  50.051  20.272  1.00116.92           N  \\nATOM   5299  C4   DA J 259      39.155  51.343  19.933  1.00116.92           C  \\nATOM   5300  P    DC J 260      37.956  49.595  13.864  1.00123.13           P  \\nATOM   5301  OP1  DC J 260      38.383  48.912  12.614  1.00123.13           O  \\nATOM   5302  OP2  DC J 260      37.158  50.850  13.784  1.00123.13           O  \\nATOM   5303  O5'  DC J 260      37.148  48.550  14.746  1.00102.32           O  \\nATOM   5304  C5'  DC J 260      37.800  47.820  15.783  1.00102.32           C  \\nATOM   5305  C4'  DC J 260      36.773  47.179  16.683  1.00102.32           C  \\nATOM   5306  O4'  DC J 260      36.763  47.869  17.959  1.00102.32           O  \\nATOM   5307  C3'  DC J 260      35.350  47.282  16.131  1.00102.32           C  \\nATOM   5308  O3'  DC J 260      34.618  46.076  16.383  1.00102.32           O  \\nATOM   5309  C2'  DC J 260      34.767  48.461  16.886  1.00102.32           C  \\nATOM   5310  C1'  DC J 260      35.457  48.351  18.235  1.00102.32           C  \\nATOM   5311  N1   DC J 260      35.569  49.629  18.962  1.00103.69           N  \\nATOM   5312  C2   DC J 260      35.549  49.619  20.365  1.00103.69           C  \\nATOM   5313  O2   DC J 260      35.496  48.533  20.955  1.00103.69           O  \\nATOM   5314  N3   DC J 260      35.591  50.796  21.038  1.00103.69           N  \\nATOM   5315  C4   DC J 260      35.673  51.948  20.364  1.00103.69           C  \\nATOM   5316  N4   DC J 260      35.704  53.088  21.066  1.00103.69           N  \\nATOM   5317  C5   DC J 260      35.723  51.985  18.938  1.00103.69           C  \\nATOM   5318  C6   DC J 260      35.671  50.814  18.284  1.00103.69           C  \\nATOM   5319  P    DA J 261      33.093  45.947  15.882  1.00122.34           P  \\nATOM   5320  OP1  DA J 261      32.892  44.562  15.398  1.00122.34           O  \\nATOM   5321  OP2  DA J 261      32.781  47.089  14.981  1.00122.34           O  \\nATOM   5322  O5'  DA J 261      32.246  46.124  17.219  1.00124.59           O  \\nATOM   5323  C5'  DA J 261      32.494  45.299  18.359  1.00124.59           C  \\nATOM   5324  C4'  DA J 261      31.456  45.558  19.426  1.00124.59           C  \\nATOM   5325  O4'  DA J 261      31.682  46.845  20.050  1.00124.59           O  \\nATOM   5326  C3'  DA J 261      30.027  45.593  18.890  1.00124.59           C  \\nATOM   5327  O3'  DA J 261      29.138  44.977  19.821  1.00124.59           O  \\nATOM   5328  C2'  DA J 261      29.730  47.079  18.771  1.00124.59           C  \\nATOM   5329  C1'  DA J 261      30.521  47.662  19.931  1.00124.59           C  \\nATOM   5330  N9   DA J 261      30.956  49.053  19.746  1.00123.90           N  \\nATOM   5331  C8   DA J 261      31.046  49.757  18.567  1.00123.90           C  \\nATOM   5332  N7   DA J 261      31.485  50.985  18.715  1.00123.90           N  \\nATOM   5333  C5   DA J 261      31.694  51.103  20.082  1.00123.90           C  \\nATOM   5334  C6   DA J 261      32.158  52.170  20.886  1.00123.90           C  \\nATOM   5335  N6   DA J 261      32.515  53.368  20.408  1.00123.90           N  \\nATOM   5336  N1   DA J 261      32.244  51.958  22.219  1.00123.90           N  \\nATOM   5337  C2   DA J 261      31.886  50.762  22.703  1.00123.90           C  \\nATOM   5338  N3   DA J 261      31.437  49.688  22.054  1.00123.90           N  \\nATOM   5339  C4   DA J 261      31.365  49.924  20.731  1.00123.90           C  \\nATOM   5340  P    DC J 262      27.902  44.104  19.281  1.00157.91           P  \\nATOM   5341  OP1  DC J 262      28.242  42.667  19.440  1.00157.91           O  \\nATOM   5342  OP2  DC J 262      27.514  44.625  17.942  1.00157.91           O  \\nATOM   5343  O5'  DC J 262      26.734  44.462  20.298  1.00106.91           O  \\nATOM   5344  C5'  DC J 262      26.358  45.819  20.507  1.00106.91           C  \\nATOM   5345  C4'  DC J 262      26.264  46.117  21.985  1.00106.91           C  \\nATOM   5346  O4'  DC J 262      27.243  47.136  22.316  1.00106.91           O  \\nATOM   5347  C3'  DC J 262      24.904  46.683  22.385  1.00106.91           C  \\nATOM   5348  O3'  DC J 262      24.494  46.207  23.669  1.00106.91           O  \\nATOM   5349  C2'  DC J 262      25.130  48.182  22.397  1.00106.91           C  \\nATOM   5350  C1'  DC J 262      26.599  48.320  22.771  1.00106.91           C  \\nATOM   5351  N1   DC J 262      27.237  49.475  22.110  1.00131.93           N  \\nATOM   5352  C2   DC J 262      27.926  50.416  22.887  1.00131.93           C  \\nATOM   5353  O2   DC J 262      28.026  50.231  24.108  1.00131.93           O  \\nATOM   5354  N3   DC J 262      28.461  51.503  22.284  1.00131.93           N  \\nATOM   5355  C4   DC J 262      28.332  51.667  20.965  1.00131.93           C  \\nATOM   5356  N4   DC J 262      28.846  52.771  20.416  1.00131.93           N  \\nATOM   5357  C5   DC J 262      27.664  50.712  20.149  1.00131.93           C  \\nATOM   5358  C6   DC J 262      27.139  49.640  20.756  1.00131.93           C  \\nATOM   5359  P    DT J 263      23.082  46.685  24.273  1.00109.70           P  \\nATOM   5360  OP1  DT J 263      22.660  45.757  25.360  1.00109.70           O  \\nATOM   5361  OP2  DT J 263      22.165  46.961  23.133  1.00109.70           O  \\nATOM   5362  O5'  DT J 263      23.431  48.085  24.936  1.00104.51           O  \\nATOM   5363  C5'  DT J 263      24.277  48.158  26.078  1.00104.51           C  \\nATOM   5364  C4'  DT J 263      24.020  49.447  26.817  1.00104.51           C  \\nATOM   5365  O4'  DT J 263      24.651  50.566  26.147  1.00104.51           O  \\nATOM   5366  C3'  DT J 263      22.536  49.779  26.892  1.00104.51           C  \\nATOM   5367  O3'  DT J 263      22.242  50.278  28.187  1.00104.51           O  \\nATOM   5368  C2'  DT J 263      22.337  50.813  25.792  1.00104.51           C  \\nATOM   5369  C1'  DT J 263      23.681  51.525  25.738  1.00104.51           C  \\nATOM   5370  N1   DT J 263      24.086  52.030  24.397  1.00 92.57           N  \\nATOM   5371  C2   DT J 263      24.580  53.321  24.292  1.00 92.57           C  \\nATOM   5372  O2   DT J 263      24.664  54.095  25.235  1.00 92.57           O  \\nATOM   5373  N3   DT J 263      24.974  53.678  23.024  1.00 92.57           N  \\nATOM   5374  C4   DT J 263      24.929  52.905  21.883  1.00 92.57           C  \\nATOM   5375  O4   DT J 263      25.363  53.358  20.830  1.00 92.57           O  \\nATOM   5376  C5   DT J 263      24.366  51.585  22.052  1.00 92.57           C  \\nATOM   5377  C7   DT J 263      24.227  50.696  20.856  1.00 92.57           C  \\nATOM   5378  C6   DT J 263      23.984  51.216  23.285  1.00 92.57           C  \\nATOM   5379  P    DT J 264      20.935  51.160  28.409  1.00110.00           P  \\nATOM   5380  OP1  DT J 264      20.635  51.161  29.867  1.00110.00           O  \\nATOM   5381  OP2  DT J 264      19.914  50.686  27.439  1.00110.00           O  \\nATOM   5382  O5'  DT J 264      21.421  52.612  27.976  1.00110.10           O  \\nATOM   5383  C5'  DT J 264      22.552  53.214  28.609  1.00110.10           C  \\nATOM   5384  C4'  DT J 264      22.559  54.705  28.365  1.00110.10           C  \\nATOM   5385  O4'  DT J 264      22.973  55.003  27.012  1.00110.10           O  \\nATOM   5386  C3'  DT J 264      21.198  55.371  28.546  1.00110.10           C  \\nATOM   5387  O3'  DT J 264      21.380  56.649  29.127  1.00110.10           O  \\nATOM   5388  C2'  DT J 264      20.693  55.530  27.125  1.00110.10           C  \\nATOM   5389  C1'  DT J 264      21.978  55.779  26.361  1.00110.10           C  \\nATOM   5390  N1   DT J 264      21.926  55.355  24.951  1.00 74.83           N  \\nATOM   5391  C2   DT J 264      22.336  56.247  23.986  1.00 74.83           C  \\nATOM   5392  O2   DT J 264      22.777  57.361  24.242  1.00 74.83           O  \\nATOM   5393  N3   DT J 264      22.224  55.787  22.702  1.00 74.83           N  \\nATOM   5394  C4   DT J 264      21.781  54.547  22.291  1.00 74.83           C  \\nATOM   5395  O4   DT J 264      21.747  54.280  21.098  1.00 74.83           O  \\nATOM   5396  C5   DT J 264      21.388  53.650  23.357  1.00 74.83           C  \\nATOM   5397  C7   DT J 264      20.913  52.273  23.015  1.00 74.83           C  \\nATOM   5398  C6   DT J 264      21.471  54.096  24.615  1.00 74.83           C  \\nATOM   5399  P    DT J 265      20.209  57.301  30.005  1.00106.78           P  \\nATOM   5400  OP1  DT J 265      20.247  56.690  31.360  1.00106.78           O  \\nATOM   5401  OP2  DT J 265      18.948  57.269  29.211  1.00106.78           O  \\nATOM   5402  O5'  DT J 265      20.685  58.813  30.111  1.00 95.80           O  \\nATOM   5403  C5'  DT J 265      22.063  59.145  29.935  1.00 95.80           C  \\nATOM   5404  C4'  DT J 265      22.219  60.277  28.945  1.00 95.80           C  \\nATOM   5405  O4'  DT J 265      22.088  59.825  27.573  1.00 95.80           O  \\nATOM   5406  C3'  DT J 265      21.230  61.430  29.114  1.00 95.80           C  \\nATOM   5407  O3'  DT J 265      21.951  62.660  29.137  1.00 95.80           O  \\nATOM   5408  C2'  DT J 265      20.337  61.327  27.885  1.00 95.80           C  \\nATOM   5409  C1'  DT J 265      21.287  60.750  26.859  1.00 95.80           C  \\nATOM   5410  N1   DT J 265      20.669  60.045  25.716  1.00106.48           N  \\nATOM   5411  C2   DT J 265      20.661  60.683  24.494  1.00106.48           C  \\nATOM   5412  O2   DT J 265      21.089  61.808  24.330  1.00106.48           O  \\nATOM   5413  N3   DT J 265      20.126  59.953  23.464  1.00106.48           N  \\nATOM   5414  C4   DT J 265      19.593  58.686  23.530  1.00106.48           C  \\nATOM   5415  O4   DT J 265      19.170  58.152  22.507  1.00106.48           O  \\nATOM   5416  C5   DT J 265      19.597  58.083  24.852  1.00106.48           C  \\nATOM   5417  C7   DT J 265      19.006  56.719  25.034  1.00106.48           C  \\nATOM   5418  C6   DT J 265      20.134  58.785  25.863  1.00106.48           C  \\nATOM   5419  P    DT J 266      21.183  64.036  28.856  1.00 67.86           P  \\nATOM   5420  OP1  DT J 266      22.006  65.143  29.428  1.00 67.86           O  \\nATOM   5421  OP2  DT J 266      19.761  63.871  29.264  1.00 67.86           O  \\nATOM   5422  O5'  DT J 266      21.224  64.137  27.273  1.00 63.87           O  \\nATOM   5423  C5'  DT J 266      22.471  64.170  26.589  1.00 63.87           C  \\nATOM   5424  C4'  DT J 266      22.352  65.055  25.377  1.00 63.87           C  \\nATOM   5425  O4'  DT J 266      21.437  64.448  24.435  1.00 63.87           O  \\nATOM   5426  C3'  DT J 266      21.762  66.422  25.701  1.00 63.87           C  \\nATOM   5427  O3'  DT J 266      22.284  67.359  24.783  1.00 63.87           O  \\nATOM   5428  C2'  DT J 266      20.292  66.239  25.395  1.00 63.87           C  \\nATOM   5429  C1'  DT J 266      20.356  65.328  24.186  1.00 63.87           C  \\nATOM   5430  N1   DT J 266      19.140  64.522  23.981  1.00101.50           N  \\nATOM   5431  C2   DT J 266      19.029  63.741  22.847  1.00101.50           C  \\nATOM   5432  O2   DT J 266      19.902  63.651  22.003  1.00101.50           O  \\nATOM   5433  N3   DT J 266      17.845  63.063  22.739  1.00101.50           N  \\nATOM   5434  C4   DT J 266      16.786  63.084  23.629  1.00101.50           C  \\nATOM   5435  O4   DT J 266      15.780  62.430  23.389  1.00101.50           O  \\nATOM   5436  C5   DT J 266      16.977  63.913  24.803  1.00101.50           C  \\nATOM   5437  C7   DT J 266      15.891  63.999  25.830  1.00101.50           C  \\nATOM   5438  C6   DT J 266      18.129  64.576  24.916  1.00101.50           C  \\nATOM   5439  P    DG J 267      22.216  68.918  25.114  1.00 70.98           P  \\nATOM   5440  OP1  DG J 267      23.492  69.255  25.811  1.00 70.98           O  \\nATOM   5441  OP2  DG J 267      20.905  69.223  25.751  1.00 70.98           O  \\nATOM   5442  O5'  DG J 267      22.227  69.574  23.669  1.00 56.67           O  \\nATOM   5443  C5'  DG J 267      23.064  69.036  22.654  1.00 56.67           C  \\nATOM   5444  C4'  DG J 267      22.330  68.999  21.334  1.00 56.67           C  \\nATOM   5445  O4'  DG J 267      21.183  68.123  21.418  1.00 56.67           O  \\nATOM   5446  C3'  DG J 267      21.798  70.342  20.836  1.00 56.67           C  \\nATOM   5447  O3'  DG J 267      21.983  70.401  19.423  1.00 56.67           O  \\nATOM   5448  C2'  DG J 267      20.320  70.276  21.161  1.00 56.67           C  \\nATOM   5449  C1'  DG J 267      20.028  68.804  20.964  1.00 56.67           C  \\nATOM   5450  N9   DG J 267      18.891  68.305  21.728  1.00 61.99           N  \\nATOM   5451  C8   DG J 267      18.442  68.758  22.948  1.00 61.99           C  \\nATOM   5452  N7   DG J 267      17.403  68.104  23.384  1.00 61.99           N  \\nATOM   5453  C5   DG J 267      17.153  67.163  22.394  1.00 61.99           C  \\nATOM   5454  C6   DG J 267      16.152  66.163  22.310  1.00 61.99           C  \\nATOM   5455  O6   DG J 267      15.256  65.904  23.129  1.00 61.99           O  \\nATOM   5456  N1   DG J 267      16.263  65.424  21.128  1.00 61.99           N  \\nATOM   5457  C2   DG J 267      17.218  65.624  20.164  1.00 61.99           C  \\nATOM   5458  N2   DG J 267      17.165  64.808  19.116  1.00 61.99           N  \\nATOM   5459  N3   DG J 267      18.152  66.552  20.230  1.00 61.99           N  \\nATOM   5460  C4   DG J 267      18.062  67.280  21.364  1.00 61.99           C  \\nATOM   5461  P    DG J 268      21.789  71.792  18.646  1.00 42.33           P  \\nATOM   5462  OP1  DG J 268      23.080  72.167  18.013  1.00 42.33           O  \\nATOM   5463  OP2  DG J 268      21.126  72.738  19.582  1.00 42.33           O  \\nATOM   5464  O5'  DG J 268      20.771  71.402  17.485  1.00 47.23           O  \\nATOM   5465  C5'  DG J 268      21.143  70.447  16.486  1.00 47.23           C  \\nATOM   5466  C4'  DG J 268      19.939  70.035  15.672  1.00 47.23           C  \\nATOM   5467  O4'  DG J 268      19.063  69.252  16.517  1.00 47.23           O  \\nATOM   5468  C3'  DG J 268      19.106  71.205  15.150  1.00 47.23           C  \\nATOM   5469  O3'  DG J 268      18.724  71.021  13.789  1.00 47.23           O  \\nATOM   5470  C2'  DG J 268      17.898  71.246  16.070  1.00 47.23           C  \\nATOM   5471  C1'  DG J 268      17.771  69.820  16.566  1.00 47.23           C  \\nATOM   5472  N9   DG J 268      17.314  69.747  17.945  1.00 92.18           N  \\nATOM   5473  C8   DG J 268      17.806  70.429  19.030  1.00 92.18           C  \\nATOM   5474  N7   DG J 268      17.141  70.188  20.125  1.00 92.18           N  \\nATOM   5475  C5   DG J 268      16.165  69.285  19.735  1.00 92.18           C  \\nATOM   5476  C6   DG J 268      15.130  68.673  20.479  1.00 92.18           C  \\nATOM   5477  O6   DG J 268      14.854  68.814  21.687  1.00 92.18           O  \\nATOM   5478  N1   DG J 268      14.363  67.827  19.677  1.00 92.18           N  \\nATOM   5479  C2   DG J 268      14.581  67.595  18.339  1.00 92.18           C  \\nATOM   5480  N2   DG J 268      13.761  66.739  17.728  1.00 92.18           N  \\nATOM   5481  N3   DG J 268      15.535  68.165  17.644  1.00 92.18           N  \\nATOM   5482  C4   DG J 268      16.278  68.994  18.396  1.00 92.18           C  \\nATOM   5483  P    DT J 269      17.673  72.037  13.120  1.00 65.24           P  \\nATOM   5484  OP1  DT J 269      17.927  72.091  11.654  1.00 65.24           O  \\nATOM   5485  OP2  DT J 269      17.622  73.304  13.905  1.00 65.24           O  \\nATOM   5486  O5'  DT J 269      16.285  71.307  13.385  1.00 82.97           O  \\nATOM   5487  C5'  DT J 269      16.025  70.009  12.853  1.00 82.97           C  \\nATOM   5488  C4'  DT J 269      14.537  69.780  12.810  1.00 82.97           C  \\nATOM   5489  O4'  DT J 269      14.059  69.534  14.155  1.00 82.97           O  \\nATOM   5490  C3'  DT J 269      13.790  71.018  12.306  1.00 82.97           C  \\nATOM   5491  O3'  DT J 269      12.635  70.626  11.568  1.00 82.97           O  \\nATOM   5492  C2'  DT J 269      13.353  71.695  13.592  1.00 82.97           C  \\nATOM   5493  C1'  DT J 269      13.065  70.494  14.480  1.00 82.97           C  \\nATOM   5494  N1   DT J 269      13.098  70.744  15.946  1.00 81.21           N  \\nATOM   5495  C2   DT J 269      12.552  69.785  16.784  1.00 81.21           C  \\nATOM   5496  O2   DT J 269      12.114  68.717  16.384  1.00 81.21           O  \\nATOM   5497  N3   DT J 269      12.549  70.117  18.116  1.00 81.21           N  \\nATOM   5498  C4   DT J 269      13.056  71.262  18.692  1.00 81.21           C  \\nATOM   5499  O4   DT J 269      12.989  71.409  19.910  1.00 81.21           O  \\nATOM   5500  C5   DT J 269      13.642  72.213  17.763  1.00 81.21           C  \\nATOM   5501  C7   DT J 269      14.228  73.482  18.294  1.00 81.21           C  \\nATOM   5502  C6   DT J 269      13.633  71.910  16.456  1.00 81.21           C  \\nATOM   5503  P    DA J 270      12.550  70.892   9.981  1.00111.66           P  \\nATOM   5504  OP1  DA J 270      13.517  69.997   9.282  1.00111.66           O  \\nATOM   5505  OP2  DA J 270      12.586  72.357   9.729  1.00111.66           O  \\nATOM   5506  O5'  DA J 270      11.081  70.381   9.649  1.00188.00           O  \\nATOM   5507  C5'  DA J 270      10.652  69.091  10.085  1.00188.00           C  \\nATOM   5508  C4'  DA J 270       9.410  69.193  10.946  1.00188.00           C  \\nATOM   5509  O4'  DA J 270       9.721  69.516  12.331  1.00188.00           O  \\nATOM   5510  C3'  DA J 270       8.351  70.208  10.491  1.00188.00           C  \\nATOM   5511  O3'  DA J 270       7.049  69.600  10.444  1.00188.00           O  \\nATOM   5512  C2'  DA J 270       8.378  71.257  11.590  1.00188.00           C  \\nATOM   5513  C1'  DA J 270       8.728  70.414  12.800  1.00188.00           C  \\nATOM   5514  N9   DA J 270       9.237  71.155  13.961  1.00107.08           N  \\nATOM   5515  C8   DA J 270      10.056  72.261  13.978  1.00107.08           C  \\nATOM   5516  N7   DA J 270      10.276  72.742  15.182  1.00107.08           N  \\nATOM   5517  C5   DA J 270       9.568  71.886  16.018  1.00107.08           C  \\nATOM   5518  C6   DA J 270       9.392  71.853  17.423  1.00107.08           C  \\nATOM   5519  N6   DA J 270       9.933  72.738  18.264  1.00107.08           N  \\nATOM   5520  N1   DA J 270       8.627  70.865  17.938  1.00107.08           N  \\nATOM   5521  C2   DA J 270       8.082  69.975  17.099  1.00107.08           C  \\nATOM   5522  N3   DA J 270       8.171  69.900  15.768  1.00107.08           N  \\nATOM   5523  C4   DA J 270       8.936  70.895  15.282  1.00107.08           C  \\nATOM   5524  P    DG J 271       5.808  70.408   9.802  1.00132.56           P  \\nATOM   5525  OP1  DG J 271       4.929  69.435   9.098  1.00132.56           O  \\nATOM   5526  OP2  DG J 271       6.354  71.573   9.058  1.00132.56           O  \\nATOM   5527  O5'  DG J 271       5.012  70.947  11.074  1.00135.63           O  \\nATOM   5528  C5'  DG J 271       4.185  70.067  11.834  1.00135.63           C  \\nATOM   5529  C4'  DG J 271       3.329  70.843  12.809  1.00135.63           C  \\nATOM   5530  O4'  DG J 271       4.129  71.300  13.929  1.00135.63           O  \\nATOM   5531  C3'  DG J 271       2.623  72.082  12.244  1.00135.63           C  \\nATOM   5532  O3'  DG J 271       1.239  72.078  12.639  1.00135.63           O  \\nATOM   5533  C2'  DG J 271       3.382  73.238  12.875  1.00135.63           C  \\nATOM   5534  C1'  DG J 271       3.810  72.652  14.206  1.00135.63           C  \\nATOM   5535  N9   DG J 271       4.976  73.293  14.809  1.00 98.15           N  \\nATOM   5536  C8   DG J 271       5.929  74.045  14.162  1.00 98.15           C  \\nATOM   5537  N7   DG J 271       6.842  74.523  14.968  1.00 98.15           N  \\nATOM   5538  C5   DG J 271       6.476  74.053  16.224  1.00 98.15           C  \\nATOM   5539  C6   DG J 271       7.086  74.250  17.495  1.00 98.15           C  \\nATOM   5540  O6   DG J 271       8.111  74.890  17.770  1.00 98.15           O  \\nATOM   5541  N1   DG J 271       6.377  73.606  18.506  1.00 98.15           N  \\nATOM   5542  C2   DG J 271       5.243  72.859  18.321  1.00 98.15           C  \\nATOM   5543  N2   DG J 271       4.725  72.325  19.429  1.00 98.15           N  \\nATOM   5544  N3   DG J 271       4.668  72.657  17.146  1.00 98.15           N  \\nATOM   5545  C4   DG J 271       5.330  73.285  16.146  1.00 98.15           C  \\nATOM   5546  P    DA J 272       0.313  73.381  12.400  1.00169.15           P  \\nATOM   5547  OP1  DA J 272      -0.960  72.938  11.772  1.00169.15           O  \\nATOM   5548  OP2  DA J 272       1.107  74.462  11.765  1.00169.15           O  \\nATOM   5549  O5'  DA J 272      -0.013  73.841  13.884  1.00158.59           O  \\nATOM   5550  C5'  DA J 272      -0.226  72.859  14.886  1.00158.59           C  \\nATOM   5551  C4'  DA J 272      -0.230  73.490  16.255  1.00158.59           C  \\nATOM   5552  O4'  DA J 272       1.110  73.842  16.682  1.00158.59           O  \\nATOM   5553  C3'  DA J 272      -1.073  74.757  16.368  1.00158.59           C  \\nATOM   5554  O3'  DA J 272      -1.878  74.641  17.537  1.00158.59           O  \\nATOM   5555  C2'  DA J 272      -0.037  75.866  16.496  1.00158.59           C  \\nATOM   5556  C1'  DA J 272       1.111  75.161  17.203  1.00158.59           C  \\nATOM   5557  N9   DA J 272       2.446  75.735  16.993  1.00137.45           N  \\nATOM   5558  C8   DA J 272       2.994  76.189  15.816  1.00137.45           C  \\nATOM   5559  N7   DA J 272       4.216  76.652  15.945  1.00137.45           N  \\nATOM   5560  C5   DA J 272       4.496  76.495  17.296  1.00137.45           C  \\nATOM   5561  C6   DA J 272       5.636  76.799  18.073  1.00137.45           C  \\nATOM   5562  N6   DA J 272       6.750  77.346  17.578  1.00137.45           N  \\nATOM   5563  N1   DA J 272       5.591  76.518  19.392  1.00137.45           N  \\nATOM   5564  C2   DA J 272       4.476  75.969  19.891  1.00137.45           C  \\nATOM   5565  N3   DA J 272       3.343  75.638  19.268  1.00137.45           N  \\nATOM   5566  C4   DA J 272       3.417  75.930  17.956  1.00137.45           C  \\nATOM   5567  P    DA J 273      -3.066  75.679  17.799  1.00138.61           P  \\nATOM   5568  OP1  DA J 273      -4.324  74.914  18.018  1.00138.61           O  \\nATOM   5569  OP2  DA J 273      -3.015  76.725  16.745  1.00138.61           O  \\nATOM   5570  O5'  DA J 273      -2.616  76.326  19.177  1.00174.73           O  \\nATOM   5571  C5'  DA J 273      -1.976  75.525  20.172  1.00174.73           C  \\nATOM   5572  C4'  DA J 273      -1.333  76.410  21.210  1.00174.73           C  \\nATOM   5573  O4'  DA J 273       0.042  76.722  20.862  1.00174.73           O  \\nATOM   5574  C3'  DA J 273      -2.061  77.744  21.350  1.00174.73           C  \\nATOM   5575  O3'  DA J 273      -2.281  78.068  22.719  1.00174.73           O  \\nATOM   5576  C2'  DA J 273      -1.124  78.740  20.687  1.00174.73           C  \\nATOM   5577  C1'  DA J 273       0.243  78.127  20.935  1.00174.73           C  \\nATOM   5578  N9   DA J 273       1.261  78.512  19.948  1.00168.57           N  \\nATOM   5579  C8   DA J 273       1.115  78.614  18.584  1.00168.57           C  \\nATOM   5580  N7   DA J 273       2.197  79.019  17.963  1.00168.57           N  \\nATOM   5581  C5   DA J 273       3.124  79.190  18.983  1.00168.57           C  \\nATOM   5582  C6   DA J 273       4.472  79.610  18.981  1.00168.57           C  \\nATOM   5583  N6   DA J 273       5.145  79.948  17.880  1.00168.57           N  \\nATOM   5584  N1   DA J 273       5.112  79.673  20.169  1.00168.57           N  \\nATOM   5585  C2   DA J 273       4.439  79.335  21.276  1.00168.57           C  \\nATOM   5586  N3   DA J 273       3.175  78.927  21.408  1.00168.57           N  \\nATOM   5587  C4   DA J 273       2.565  78.874  20.211  1.00168.57           C  \\nATOM   5588  P    DT J 274      -3.119  79.385  23.096  1.00154.52           P  \\nATOM   5589  OP1  DT J 274      -4.100  78.999  24.143  1.00154.52           O  \\nATOM   5590  OP2  DT J 274      -3.598  80.027  21.840  1.00154.52           O  \\nATOM   5591  O5'  DT J 274      -2.010  80.312  23.763  1.00157.35           O  \\nATOM   5592  C5'  DT J 274      -1.106  79.769  24.727  1.00157.35           C  \\nATOM   5593  C4'  DT J 274      -0.081  80.802  25.130  1.00157.35           C  \\nATOM   5594  O4'  DT J 274       0.953  80.923  24.120  1.00157.35           O  \\nATOM   5595  C3'  DT J 274      -0.666  82.202  25.320  1.00157.35           C  \\nATOM   5596  O3'  DT J 274      -0.101  82.821  26.474  1.00157.35           O  \\nATOM   5597  C2'  DT J 274      -0.220  82.938  24.070  1.00157.35           C  \\nATOM   5598  C1'  DT J 274       1.130  82.296  23.815  1.00157.35           C  \\nATOM   5599  N1   DT J 274       1.637  82.418  22.429  1.00114.06           N  \\nATOM   5600  C2   DT J 274       3.005  82.485  22.246  1.00114.06           C  \\nATOM   5601  O2   DT J 274       3.811  82.386  23.165  1.00114.06           O  \\nATOM   5602  N3   DT J 274       3.398  82.671  20.937  1.00114.06           N  \\nATOM   5603  C4   DT J 274       2.581  82.773  19.822  1.00114.06           C  \\nATOM   5604  O4   DT J 274       3.084  82.943  18.711  1.00114.06           O  \\nATOM   5605  C5   DT J 274       1.159  82.667  20.088  1.00114.06           C  \\nATOM   5606  C7   DT J 274       0.196  82.756  18.946  1.00114.06           C  \\nATOM   5607  C6   DT J 274       0.766  82.495  21.358  1.00114.06           C  \\nATOM   5608  P    DC J 275      -0.907  83.993  27.222  1.00145.29           P  \\nATOM   5609  OP1  DC J 275      -1.769  83.360  28.251  1.00145.29           O  \\nATOM   5610  OP2  DC J 275      -1.522  84.867  26.187  1.00145.29           O  \\nATOM   5611  O5'  DC J 275       0.244  84.808  27.966  1.00117.02           O  \\nATOM   5612  C5'  DC J 275       1.101  85.685  27.234  1.00117.02           C  \\nATOM   5613  C4'  DC J 275       2.530  85.191  27.268  1.00117.02           C  \\nATOM   5614  O4'  DC J 275       2.871  84.632  25.974  1.00117.02           O  \\nATOM   5615  C3'  DC J 275       3.532  86.315  27.514  1.00117.02           C  \\nATOM   5616  O3'  DC J 275       4.639  85.877  28.300  1.00117.02           O  \\nATOM   5617  C2'  DC J 275       3.979  86.709  26.122  1.00117.02           C  \\nATOM   5618  C1'  DC J 275       3.858  85.422  25.325  1.00117.02           C  \\nATOM   5619  N1   DC J 275       3.400  85.685  23.954  1.00 96.21           N  \\nATOM   5620  C2   DC J 275       4.278  86.316  23.064  1.00 96.21           C  \\nATOM   5621  O2   DC J 275       5.435  86.578  23.442  1.00 96.21           O  \\nATOM   5622  N3   DC J 275       3.849  86.619  21.813  1.00 96.21           N  \\nATOM   5623  C4   DC J 275       2.612  86.298  21.434  1.00 96.21           C  \\nATOM   5624  N4   DC J 275       2.244  86.615  20.194  1.00 96.21           N  \\nATOM   5625  C5   DC J 275       1.705  85.636  22.311  1.00 96.21           C  \\nATOM   5626  C6   DC J 275       2.138  85.350  23.552  1.00 96.21           C  \\nATOM   5627  P    DT J 276       5.422  86.948  29.204  1.00104.64           P  \\nATOM   5628  OP1  DT J 276       6.595  86.291  29.846  1.00104.64           O  \\nATOM   5629  OP2  DT J 276       4.412  87.640  30.045  1.00104.64           O  \\nATOM   5630  O5'  DT J 276       5.962  88.006  28.145  1.00 55.96           O  \\nATOM   5631  C5'  DT J 276       7.217  87.820  27.500  1.00 55.96           C  \\nATOM   5632  C4'  DT J 276       7.497  88.967  26.558  1.00 55.96           C  \\nATOM   5633  O4'  DT J 276       6.733  88.822  25.333  1.00 55.96           O  \\nATOM   5634  C3'  DT J 276       7.195  90.373  27.097  1.00 55.96           C  \\nATOM   5635  O3'  DT J 276       8.293  91.252  26.827  1.00 55.96           O  \\nATOM   5636  C2'  DT J 276       6.021  90.822  26.234  1.00 55.96           C  \\nATOM   5637  C1'  DT J 276       6.347  90.119  24.933  1.00 55.96           C  \\nATOM   5638  N1   DT J 276       5.300  90.020  23.878  1.00 85.97           N  \\nATOM   5639  C2   DT J 276       5.589  90.566  22.635  1.00 85.97           C  \\nATOM   5640  O2   DT J 276       6.661  91.077  22.359  1.00 85.97           O  \\nATOM   5641  N3   DT J 276       4.572  90.477  21.718  1.00 85.97           N  \\nATOM   5642  C4   DT J 276       3.338  89.894  21.894  1.00 85.97           C  \\nATOM   5643  O4   DT J 276       2.531  89.894  20.975  1.00 85.97           O  \\nATOM   5644  C5   DT J 276       3.107  89.317  23.198  1.00 85.97           C  \\nATOM   5645  C7   DT J 276       1.802  88.632  23.461  1.00 85.97           C  \\nATOM   5646  C6   DT J 276       4.083  89.416  24.119  1.00 85.97           C  \\nATOM   5647  P    DG J 277       9.377  91.592  27.973  1.00 50.99           P  \\nATOM   5648  OP1  DG J 277       9.464  90.532  29.006  1.00 50.99           O  \\nATOM   5649  OP2  DG J 277       9.136  92.990  28.388  1.00 50.99           O  \\nATOM   5650  O5'  DG J 277      10.752  91.551  27.174  1.00 40.72           O  \\nATOM   5651  C5'  DG J 277      11.489  92.742  26.933  1.00 40.72           C  \\nATOM   5652  C4'  DG J 277      11.895  92.834  25.479  1.00 40.72           C  \\nATOM   5653  O4'  DG J 277      10.778  92.511  24.617  1.00 40.72           O  \\nATOM   5654  C3'  DG J 277      12.277  94.267  25.142  1.00 40.72           C  \\nATOM   5655  O3'  DG J 277      13.310  94.345  24.190  1.00 40.72           O  \\nATOM   5656  C2'  DG J 277      11.009  94.847  24.562  1.00 40.72           C  \\nATOM   5657  C1'  DG J 277      10.388  93.658  23.872  1.00 40.72           C  \\nATOM   5658  N9   DG J 277       8.938  93.745  23.917  1.00 61.53           N  \\nATOM   5659  C8   DG J 277       8.156  93.851  25.039  1.00 61.53           C  \\nATOM   5660  N7   DG J 277       6.883  93.912  24.770  1.00 61.53           N  \\nATOM   5661  C5   DG J 277       6.823  93.841  23.387  1.00 61.53           C  \\nATOM   5662  C6   DG J 277       5.705  93.843  22.518  1.00 61.53           C  \\nATOM   5663  O6   DG J 277       4.503  93.892  22.808  1.00 61.53           O  \\nATOM   5664  N1   DG J 277       6.090  93.761  21.183  1.00 61.53           N  \\nATOM   5665  C2   DG J 277       7.390  93.678  20.740  1.00 61.53           C  \\nATOM   5666  N2   DG J 277       7.558  93.618  19.402  1.00 61.53           N  \\nATOM   5667  N3   DG J 277       8.445  93.658  21.546  1.00 61.53           N  \\nATOM   5668  C4   DG J 277       8.086  93.743  22.847  1.00 61.53           C  \\nATOM   5669  P    DC J 278      14.012  95.755  23.939  1.00 49.82           P  \\nATOM   5670  OP1  DC J 278      15.449  95.467  23.742  1.00 49.82           O  \\nATOM   5671  OP2  DC J 278      13.583  96.697  25.010  1.00 49.82           O  \\nATOM   5672  O5'  DC J 278      13.383  96.253  22.568  1.00 46.57           O  \\nATOM   5673  C5'  DC J 278      12.496  95.419  21.828  1.00 46.57           C  \\nATOM   5674  C4'  DC J 278      11.752  96.231  20.794  1.00 46.57           C  \\nATOM   5675  O4'  DC J 278      10.337  96.142  21.066  1.00 46.57           O  \\nATOM   5676  C3'  DC J 278      12.072  97.727  20.772  1.00 46.57           C  \\nATOM   5677  O3'  DC J 278      11.946  98.219  19.433  1.00 46.57           O  \\nATOM   5678  C2'  DC J 278      10.984  98.328  21.645  1.00 46.57           C  \\nATOM   5679  C1'  DC J 278       9.804  97.442  21.298  1.00 46.57           C  \\nATOM   5680  N1   DC J 278       8.775  97.320  22.339  1.00 53.85           N  \\nATOM   5681  C2   DC J 278       7.459  97.145  21.935  1.00 53.85           C  \\nATOM   5682  O2   DC J 278       7.202  97.159  20.727  1.00 53.85           O  \\nATOM   5683  N3   DC J 278       6.500  96.970  22.862  1.00 53.85           N  \\nATOM   5684  C4   DC J 278       6.815  96.986  24.160  1.00 53.85           C  \\nATOM   5685  N4   DC J 278       5.829  96.799  25.040  1.00 53.85           N  \\nATOM   5686  C5   DC J 278       8.155  97.194  24.608  1.00 53.85           C  \\nATOM   5687  C6   DC J 278       9.094  97.356  23.671  1.00 53.85           C  \\nATOM   5688  P    DA J 279      13.039  99.243  18.847  1.00 51.99           P  \\nATOM   5689  OP1  DA J 279      14.359  98.583  18.985  1.00 51.99           O  \\nATOM   5690  OP2  DA J 279      12.836 100.604  19.415  1.00 51.99           O  \\nATOM   5691  O5'  DA J 279      12.672  99.307  17.306  1.00 71.89           O  \\nATOM   5692  C5'  DA J 279      12.176  98.159  16.632  1.00 71.89           C  \\nATOM   5693  C4'  DA J 279      10.942  98.533  15.850  1.00 71.89           C  \\nATOM   5694  O4'  DA J 279       9.779  98.598  16.713  1.00 71.89           O  \\nATOM   5695  C3'  DA J 279      11.067  99.906  15.204  1.00 71.89           C  \\nATOM   5696  O3'  DA J 279      10.452  99.888  13.923  1.00 71.89           O  \\nATOM   5697  C2'  DA J 279      10.333 100.822  16.167  1.00 71.89           C  \\nATOM   5698  C1'  DA J 279       9.258  99.921  16.753  1.00 71.89           C  \\nATOM   5699  N9   DA J 279       8.940 100.219  18.148  1.00 58.53           N  \\nATOM   5700  C8   DA J 279       9.783 100.703  19.116  1.00 58.53           C  \\nATOM   5701  N7   DA J 279       9.216 100.847  20.287  1.00 58.53           N  \\nATOM   5702  C5   DA J 279       7.908 100.444  20.071  1.00 58.53           C  \\nATOM   5703  C6   DA J 279       6.790 100.383  20.915  1.00 58.53           C  \\nATOM   5704  N6   DA J 279       6.807 100.749  22.196  1.00 58.53           N  \\nATOM   5705  N1   DA J 279       5.635  99.938  20.390  1.00 58.53           N  \\nATOM   5706  C2   DA J 279       5.610  99.590  19.098  1.00 58.53           C  \\nATOM   5707  N3   DA J 279       6.590  99.611  18.202  1.00 58.53           N  \\nATOM   5708  C4   DA J 279       7.726 100.054  18.759  1.00 58.53           C  \\nATOM   5709  P    DG J 280      10.617 101.144  12.953  1.00 63.68           P  \\nATOM   5710  OP1  DG J 280      11.405 100.748  11.759  1.00 63.68           O  \\nATOM   5711  OP2  DG J 280      11.054 102.314  13.778  1.00 63.68           O  \\nATOM   5712  O5'  DG J 280       9.124 101.389  12.494  1.00 82.78           O  \\nATOM   5713  C5'  DG J 280       8.644 102.701  12.385  1.00 82.78           C  \\nATOM   5714  C4'  DG J 280       7.270 102.806  12.991  1.00 82.78           C  \\nATOM   5715  O4'  DG J 280       7.303 102.411  14.391  1.00 82.78           O  \\nATOM   5716  C3'  DG J 280       6.814 104.259  12.955  1.00 82.78           C  \\nATOM   5717  O3'  DG J 280       5.521 104.394  12.377  1.00 82.78           O  \\nATOM   5718  C2'  DG J 280       6.874 104.718  14.400  1.00 82.78           C  \\nATOM   5719  C1'  DG J 280       6.771 103.442  15.214  1.00 82.78           C  \\nATOM   5720  N9   DG J 280       7.558 103.528  16.448  1.00 69.68           N  \\nATOM   5721  C8   DG J 280       8.924 103.655  16.562  1.00 69.68           C  \\nATOM   5722  N7   DG J 280       9.327 103.808  17.795  1.00 69.68           N  \\nATOM   5723  C5   DG J 280       8.164 103.758  18.539  1.00 69.68           C  \\nATOM   5724  C6   DG J 280       7.976 103.873  19.924  1.00 69.68           C  \\nATOM   5725  O6   DG J 280       8.832 104.071  20.800  1.00 69.68           O  \\nATOM   5726  N1   DG J 280       6.626 103.742  20.267  1.00 69.68           N  \\nATOM   5727  C2   DG J 280       5.600 103.536  19.371  1.00 69.68           C  \\nATOM   5728  N2   DG J 280       4.377 103.419  19.888  1.00 69.68           N  \\nATOM   5729  N3   DG J 280       5.768 103.447  18.071  1.00 69.68           N  \\nATOM   5730  C4   DG J 280       7.065 103.563  17.725  1.00 69.68           C  \\nATOM   5731  P    DG J 281       5.117 105.778  11.678  1.00 94.51           P  \\nATOM   5732  OP1  DG J 281       4.474 105.452  10.381  1.00 94.51           O  \\nATOM   5733  OP2  DG J 281       6.303 106.677  11.699  1.00 94.51           O  \\nATOM   5734  O5'  DG J 281       4.027 106.360  12.683  1.00135.91           O  \\nATOM   5735  C5'  DG J 281       3.013 105.518  13.241  1.00135.91           C  \\nATOM   5736  C4'  DG J 281       2.247 106.274  14.301  1.00135.91           C  \\nATOM   5737  O4'  DG J 281       2.790 106.013  15.623  1.00135.91           O  \\nATOM   5738  C3'  DG J 281       2.319 107.784  14.083  1.00135.91           C  \\nATOM   5739  O3'  DG J 281       1.034 108.404  14.087  1.00135.91           O  \\nATOM   5740  C2'  DG J 281       3.212 108.287  15.206  1.00135.91           C  \\nATOM   5741  C1'  DG J 281       3.109 107.228  16.296  1.00135.91           C  \\nATOM   5742  N9   DG J 281       4.392 107.043  16.978  1.00 63.55           N  \\nATOM   5743  C8   DG J 281       5.597 106.841  16.356  1.00 63.55           C  \\nATOM   5744  N7   DG J 281       6.603 106.757  17.184  1.00 63.55           N  \\nATOM   5745  C5   DG J 281       6.035 106.902  18.435  1.00 63.55           C  \\nATOM   5746  C6   DG J 281       6.647 106.905  19.706  1.00 63.55           C  \\nATOM   5747  O6   DG J 281       7.854 106.786  19.974  1.00 63.55           O  \\nATOM   5748  N1   DG J 281       5.711 107.070  20.726  1.00 63.55           N  \\nATOM   5749  C2   DG J 281       4.358 107.215  20.536  1.00 63.55           C  \\nATOM   5750  N2   DG J 281       3.631 107.347  21.659  1.00 63.55           N  \\nATOM   5751  N3   DG J 281       3.768 107.227  19.341  1.00 63.55           N  \\nATOM   5752  C4   DG J 281       4.664 107.066  18.338  1.00 63.55           C  \\nATOM   5753  P    DT J 282       0.865 109.875  13.455  1.00128.78           P  \\nATOM   5754  OP1  DT J 282      -0.492 109.962  12.853  1.00128.78           O  \\nATOM   5755  OP2  DT J 282       2.055 110.170  12.615  1.00128.78           O  \\nATOM   5756  O5'  DT J 282       0.938 110.813  14.738  1.00138.13           O  \\nATOM   5757  C5'  DT J 282       1.600 110.370  15.924  1.00138.13           C  \\nATOM   5758  C4'  DT J 282       0.890 110.899  17.147  1.00138.13           C  \\nATOM   5759  O4'  DT J 282       1.519 110.357  18.333  1.00138.13           O  \\nATOM   5760  C3'  DT J 282       0.967 112.417  17.275  1.00138.13           C  \\nATOM   5761  O3'  DT J 282      -0.278 112.969  17.707  1.00138.13           O  \\nATOM   5762  C2'  DT J 282       2.080 112.653  18.280  1.00138.13           C  \\nATOM   5763  C1'  DT J 282       2.111 111.385  19.119  1.00138.13           C  \\nATOM   5764  N1   DT J 282       3.495 110.971  19.430  1.00 69.49           N  \\nATOM   5765  C2   DT J 282       3.850 110.760  20.742  1.00 69.49           C  \\nATOM   5766  O2   DT J 282       3.076 110.896  21.672  1.00 69.49           O  \\nATOM   5767  N3   DT J 282       5.161 110.386  20.924  1.00 69.49           N  \\nATOM   5768  C4   DT J 282       6.126 110.209  19.939  1.00 69.49           C  \\nATOM   5769  O4   DT J 282       7.263 109.861  20.247  1.00 69.49           O  \\nATOM   5770  C5   DT J 282       5.684 110.459  18.591  1.00 69.49           C  \\nATOM   5771  C7   DT J 282       6.665 110.322  17.471  1.00 69.49           C  \\nATOM   5772  C6   DT J 282       4.409 110.814  18.406  1.00 69.49           C  \\nATOM   5773  P    DG J 283      -0.450 114.564  17.794  1.00130.65           P  \\nATOM   5774  OP1  DG J 283      -1.902 114.883  17.771  1.00130.65           O  \\nATOM   5775  OP2  DG J 283       0.454 115.188  16.791  1.00130.65           O  \\nATOM   5776  O5'  DG J 283       0.134 114.890  19.236  1.00125.50           O  \\nATOM   5777  C5'  DG J 283      -0.338 114.200  20.395  1.00125.50           C  \\nATOM   5778  C4'  DG J 283       0.315 114.788  21.619  1.00125.50           C  \\nATOM   5779  O4'  DG J 283       1.686 114.328  21.669  1.00125.50           O  \\nATOM   5780  C3'  DG J 283       0.380 116.309  21.498  1.00125.50           C  \\nATOM   5781  O3'  DG J 283       0.227 116.968  22.750  1.00125.50           O  \\nATOM   5782  C2'  DG J 283       1.761 116.562  20.937  1.00125.50           C  \\nATOM   5783  C1'  DG J 283       2.570 115.427  21.528  1.00125.50           C  \\nATOM   5784  N9   DG J 283       3.660 115.026  20.647  1.00113.99           N  \\nATOM   5785  C8   DG J 283       3.700 115.131  19.273  1.00113.99           C  \\nATOM   5786  N7   DG J 283       4.845 114.767  18.764  1.00113.99           N  \\nATOM   5787  C5   DG J 283       5.601 114.379  19.865  1.00113.99           C  \\nATOM   5788  C6   DG J 283       6.937 113.903  19.944  1.00113.99           C  \\nATOM   5789  O6   DG J 283       7.751 113.730  19.024  1.00113.99           O  \\nATOM   5790  N1   DG J 283       7.305 113.628  21.265  1.00113.99           N  \\nATOM   5791  C2   DG J 283       6.498 113.797  22.366  1.00113.99           C  \\nATOM   5792  N2   DG J 283       7.051 113.480  23.552  1.00113.99           N  \\nATOM   5793  N3   DG J 283       5.252 114.243  22.306  1.00113.99           N  \\nATOM   5794  C4   DG J 283       4.873 114.515  21.034  1.00113.99           C  \\nATOM   5795  P    DG J 284       0.057 118.566  22.782  1.00150.25           P  \\nATOM   5796  OP1  DG J 284      -1.338 118.895  23.184  1.00150.25           O  \\nATOM   5797  OP2  DG J 284       0.603 119.101  21.507  1.00150.25           O  \\nATOM   5798  O5'  DG J 284       1.040 119.009  23.946  1.00125.01           O  \\nATOM   5799  C5'  DG J 284       1.343 118.117  25.007  1.00125.01           C  \\nATOM   5800  C4'  DG J 284       2.799 118.243  25.368  1.00125.01           C  \\nATOM   5801  O4'  DG J 284       3.636 117.572  24.391  1.00125.01           O  \\nATOM   5802  C3'  DG J 284       3.260 119.700  25.387  1.00125.01           C  \\nATOM   5803  O3'  DG J 284       4.145 119.895  26.478  1.00125.01           O  \\nATOM   5804  C2'  DG J 284       4.037 119.838  24.092  1.00125.01           C  \\nATOM   5805  C1'  DG J 284       4.674 118.467  24.029  1.00125.01           C  \\nATOM   5806  N9   DG J 284       5.250 118.061  22.745  1.00 92.97           N  \\nATOM   5807  C8   DG J 284       4.740 118.268  21.479  1.00 92.97           C  \\nATOM   5808  N7   DG J 284       5.536 117.844  20.529  1.00 92.97           N  \\nATOM   5809  C5   DG J 284       6.634 117.313  21.206  1.00 92.97           C  \\nATOM   5810  C6   DG J 284       7.847 116.712  20.708  1.00 92.97           C  \\nATOM   5811  O6   DG J 284       8.202 116.524  19.530  1.00 92.97           O  \\nATOM   5812  N1   DG J 284       8.682 116.314  21.753  1.00 92.97           N  \\nATOM   5813  C2   DG J 284       8.399 116.455  23.092  1.00 92.97           C  \\nATOM   5814  N2   DG J 284       9.326 115.978  23.930  1.00 92.97           N  \\nATOM   5815  N3   DG J 284       7.294 117.012  23.566  1.00 92.97           N  \\nATOM   5816  C4   DG J 284       6.463 117.420  22.575  1.00 92.97           C  \\nATOM   5817  P    DA J 285       4.140 121.293  27.246  1.00165.61           P  \\nATOM   5818  OP1  DA J 285       2.930 121.324  28.104  1.00165.61           O  \\nATOM   5819  OP2  DA J 285       4.332 122.339  26.209  1.00165.61           O  \\nATOM   5820  O5'  DA J 285       5.432 121.213  28.174  1.00125.20           O  \\nATOM   5821  C5'  DA J 285       5.655 120.081  29.012  1.00125.20           C  \\nATOM   5822  C4'  DA J 285       7.093 119.630  28.911  1.00125.20           C  \\nATOM   5823  O4'  DA J 285       7.369 119.191  27.552  1.00125.20           O  \\nATOM   5824  C3'  DA J 285       8.133 120.714  29.224  1.00125.20           C  \\nATOM   5825  O3'  DA J 285       9.224 120.160  29.975  1.00125.20           O  \\nATOM   5826  C2'  DA J 285       8.627 121.126  27.850  1.00125.20           C  \\nATOM   5827  C1'  DA J 285       8.581 119.799  27.123  1.00125.20           C  \\nATOM   5828  N9   DA J 285       8.592 119.884  25.659  1.00104.16           N  \\nATOM   5829  C8   DA J 285       7.606 120.328  24.812  1.00104.16           C  \\nATOM   5830  N7   DA J 285       7.949 120.309  23.543  1.00104.16           N  \\nATOM   5831  C5   DA J 285       9.249 119.811  23.551  1.00104.16           C  \\nATOM   5832  C6   DA J 285      10.187 119.550  22.513  1.00104.16           C  \\nATOM   5833  N6   DA J 285       9.956 119.774  21.213  1.00104.16           N  \\nATOM   5834  N1   DA J 285      11.389 119.044  22.868  1.00104.16           N  \\nATOM   5835  C2   DA J 285      11.633 118.825  24.168  1.00104.16           C  \\nATOM   5836  N3   DA J 285      10.847 119.036  25.226  1.00104.16           N  \\nATOM   5837  C4   DA J 285       9.654 119.535  24.847  1.00104.16           C  \\nATOM   5838  P    DT J 286      10.556 121.036  30.221  1.00153.15           P  \\nATOM   5839  OP1  DT J 286      11.292 120.449  31.371  1.00153.15           O  \\nATOM   5840  OP2  DT J 286      10.180 122.476  30.245  1.00153.15           O  \\nATOM   5841  O5'  DT J 286      11.445 120.768  28.927  1.00170.64           O  \\nATOM   5842  C5'  DT J 286      12.171 119.548  28.788  1.00170.64           C  \\nATOM   5843  C4'  DT J 286      13.501 119.790  28.111  1.00170.64           C  \\nATOM   5844  O4'  DT J 286      13.337 119.989  26.684  1.00170.64           O  \\nATOM   5845  C3'  DT J 286      14.316 120.981  28.619  1.00170.64           C  \\nATOM   5846  O3'  DT J 286      15.677 120.558  28.802  1.00170.64           O  \\nATOM   5847  C2'  DT J 286      14.153 122.022  27.517  1.00170.64           C  \\nATOM   5848  C1'  DT J 286      14.026 121.163  26.269  1.00170.64           C  \\nATOM   5849  N1   DT J 286      13.286 121.744  25.113  1.00 55.99           N  \\nATOM   5850  C2   DT J 286      13.802 121.520  23.843  1.00 55.99           C  \\nATOM   5851  O2   DT J 286      14.852 120.923  23.640  1.00 55.99           O  \\nATOM   5852  N3   DT J 286      13.037 122.017  22.814  1.00 55.99           N  \\nATOM   5853  C4   DT J 286      11.844 122.694  22.914  1.00 55.99           C  \\nATOM   5854  O4   DT J 286      11.261 123.053  21.893  1.00 55.99           O  \\nATOM   5855  C5   DT J 286      11.371 122.916  24.265  1.00 55.99           C  \\nATOM   5856  C7   DT J 286      10.078 123.645  24.459  1.00 55.99           C  \\nATOM   5857  C6   DT J 286      12.111 122.448  25.287  1.00 55.99           C  \\nATOM   5858  P    DA J 287      16.874 121.631  28.784  1.00122.19           P  \\nATOM   5859  OP1  DA J 287      18.080 121.011  29.395  1.00122.19           O  \\nATOM   5860  OP2  DA J 287      16.391 122.945  29.283  1.00122.19           O  \\nATOM   5861  O5'  DA J 287      17.164 121.801  27.234  1.00 91.86           O  \\nATOM   5862  C5'  DA J 287      18.398 122.325  26.787  1.00 91.86           C  \\nATOM   5863  C4'  DA J 287      18.842 121.598  25.543  1.00 91.86           C  \\nATOM   5864  O4'  DA J 287      17.774 121.592  24.565  1.00 91.86           O  \\nATOM   5865  C3'  DA J 287      20.013 122.302  24.886  1.00 91.86           C  \\nATOM   5866  O3'  DA J 287      20.930 121.360  24.351  1.00 91.86           O  \\nATOM   5867  C2'  DA J 287      19.366 123.176  23.824  1.00 91.86           C  \\nATOM   5868  C1'  DA J 287      18.080 122.443  23.462  1.00 91.86           C  \\nATOM   5869  N9   DA J 287      16.931 123.338  23.254  1.00 62.59           N  \\nATOM   5870  C8   DA J 287      16.216 123.995  24.227  1.00 62.59           C  \\nATOM   5871  N7   DA J 287      15.218 124.710  23.764  1.00 62.59           N  \\nATOM   5872  C5   DA J 287      15.279 124.521  22.393  1.00 62.59           C  \\nATOM   5873  C6   DA J 287      14.488 125.006  21.339  1.00 62.59           C  \\nATOM   5874  N6   DA J 287      13.440 125.808  21.504  1.00 62.59           N  \\nATOM   5875  N1   DA J 287      14.815 124.633  20.090  1.00 62.59           N  \\nATOM   5876  C2   DA J 287      15.861 123.825  19.916  1.00 62.59           C  \\nATOM   5877  N3   DA J 287      16.680 123.297  20.821  1.00 62.59           N  \\nATOM   5878  C4   DA J 287      16.333 123.687  22.059  1.00 62.59           C  \\nATOM   5879  P    DT J 288      22.325 121.884  23.766  1.00131.99           P  \\nATOM   5880  OP1  DT J 288      23.242 120.727  23.592  1.00131.99           O  \\nATOM   5881  OP2  DT J 288      22.748 123.038  24.602  1.00131.99           O  \\nATOM   5882  O5'  DT J 288      21.907 122.434  22.332  1.00 62.74           O  \\nATOM   5883  C5'  DT J 288      21.388 121.552  21.343  1.00 62.74           C  \\nATOM   5884  C4'  DT J 288      21.367 122.249  20.010  1.00 62.74           C  \\nATOM   5885  O4'  DT J 288      20.197 123.080  19.874  1.00 62.74           O  \\nATOM   5886  C3'  DT J 288      22.556 123.180  19.815  1.00 62.74           C  \\nATOM   5887  O3'  DT J 288      22.864 123.181  18.431  1.00 62.74           O  \\nATOM   5888  C2'  DT J 288      21.988 124.533  20.202  1.00 62.74           C  \\nATOM   5889  C1'  DT J 288      20.601 124.416  19.613  1.00 62.74           C  \\nATOM   5890  N1   DT J 288      19.562 125.313  20.150  1.00 56.26           N  \\nATOM   5891  C2   DT J 288      18.540 125.654  19.293  1.00 56.26           C  \\nATOM   5892  O2   DT J 288      18.504 125.309  18.125  1.00 56.26           O  \\nATOM   5893  N3   DT J 288      17.559 126.416  19.850  1.00 56.26           N  \\nATOM   5894  C4   DT J 288      17.485 126.868  21.139  1.00 56.26           C  \\nATOM   5895  O4   DT J 288      16.499 127.516  21.483  1.00 56.26           O  \\nATOM   5896  C5   DT J 288      18.617 126.509  21.986  1.00 56.26           C  \\nATOM   5897  C7   DT J 288      18.649 126.973  23.403  1.00 56.26           C  \\nATOM   5898  C6   DT J 288      19.588 125.766  21.451  1.00 56.26           C  \\nATOM   5899  P    DT J 289      24.382 123.317  17.949  1.00 56.91           P  \\nATOM   5900  OP1  DT J 289      24.966 121.970  17.665  1.00 56.91           O  \\nATOM   5901  OP2  DT J 289      25.073 124.248  18.877  1.00 56.91           O  \\nATOM   5902  O5'  DT J 289      24.200 124.109  16.597  1.00 41.19           O  \\nATOM   5903  C5'  DT J 289      23.774 125.448  16.659  1.00 41.19           C  \\nATOM   5904  C4'  DT J 289      22.742 125.713  15.597  1.00 41.19           C  \\nATOM   5905  O4'  DT J 289      21.487 126.041  16.242  1.00 41.19           O  \\nATOM   5906  C3'  DT J 289      23.151 126.940  14.798  1.00 41.19           C  \\nATOM   5907  O3'  DT J 289      22.995 126.755  13.397  1.00 41.19           O  \\nATOM   5908  C2'  DT J 289      22.322 128.072  15.375  1.00 41.19           C  \\nATOM   5909  C1'  DT J 289      21.105 127.385  15.956  1.00 41.19           C  \\nATOM   5910  N1   DT J 289      20.627 128.011  17.212  1.00 33.86           N  \\nATOM   5911  C2   DT J 289      19.453 128.741  17.167  1.00 33.86           C  \\nATOM   5912  O2   DT J 289      18.793 128.893  16.147  1.00 33.86           O  \\nATOM   5913  N3   DT J 289      19.076 129.288  18.367  1.00 33.86           N  \\nATOM   5914  C4   DT J 289      19.723 129.169  19.587  1.00 33.86           C  \\nATOM   5915  O4   DT J 289      19.235 129.705  20.588  1.00 33.86           O  \\nATOM   5916  C5   DT J 289      20.952 128.388  19.563  1.00 33.86           C  \\nATOM   5917  C7   DT J 289      21.723 128.197  20.829  1.00 33.86           C  \\nATOM   5918  C6   DT J 289      21.337 127.864  18.392  1.00 33.86           C  \\nATOM   5919  P    DG J 290      23.937 127.587  12.406  1.00 41.87           P  \\nATOM   5920  OP1  DG J 290      24.003 126.934  11.087  1.00 41.87           O  \\nATOM   5921  OP2  DG J 290      25.186 127.891  13.142  1.00 41.87           O  \\nATOM   5922  O5'  DG J 290      23.164 128.971  12.251  1.00 47.43           O  \\nATOM   5923  C5'  DG J 290      21.866 129.018  11.657  1.00 47.43           C  \\nATOM   5924  C4'  DG J 290      21.292 130.410  11.767  1.00 47.43           C  \\nATOM   5925  O4'  DG J 290      20.840 130.665  13.118  1.00 47.43           O  \\nATOM   5926  C3'  DG J 290      22.280 131.526  11.427  1.00 47.43           C  \\nATOM   5927  O3'  DG J 290      21.622 132.527  10.649  1.00 47.43           O  \\nATOM   5928  C2'  DG J 290      22.664 132.072  12.789  1.00 47.43           C  \\nATOM   5929  C1'  DG J 290      21.390 131.878  13.575  1.00 47.43           C  \\nATOM   5930  N9   DG J 290      21.599 131.747  15.001  1.00 39.78           N  \\nATOM   5931  C8   DG J 290      22.684 131.205  15.632  1.00 39.78           C  \\nATOM   5932  N7   DG J 290      22.594 131.244  16.934  1.00 39.78           N  \\nATOM   5933  C5   DG J 290      21.366 131.841  17.170  1.00 39.78           C  \\nATOM   5934  C6   DG J 290      20.715 132.157  18.397  1.00 39.78           C  \\nATOM   5935  O6   DG J 290      21.103 131.930  19.560  1.00 39.78           O  \\nATOM   5936  N1   DG J 290      19.497 132.794  18.177  1.00 39.78           N  \\nATOM   5937  C2   DG J 290      18.971 133.074  16.939  1.00 39.78           C  \\nATOM   5938  N2   DG J 290      17.806 133.724  16.936  1.00 39.78           N  \\nATOM   5939  N3   DG J 290      19.549 132.756  15.791  1.00 39.78           N  \\nATOM   5940  C4   DG J 290      20.741 132.155  15.983  1.00 39.78           C  \\nATOM   5941  P    DA J 291      22.482 133.644   9.886  1.00 59.35           P  \\nATOM   5942  OP1  DA J 291      22.549 133.260   8.454  1.00 59.35           O  \\nATOM   5943  OP2  DA J 291      23.748 133.881  10.646  1.00 59.35           O  \\nATOM   5944  O5'  DA J 291      21.520 134.908   9.976  1.00 75.17           O  \\nATOM   5945  C5'  DA J 291      20.131 134.771   9.672  1.00 75.17           C  \\nATOM   5946  C4'  DA J 291      19.311 135.754  10.477  1.00 75.17           C  \\nATOM   5947  O4'  DA J 291      19.312 135.389  11.882  1.00 75.17           O  \\nATOM   5948  C3'  DA J 291      19.804 137.198  10.406  1.00 75.17           C  \\nATOM   5949  O3'  DA J 291      18.700 138.101  10.224  1.00 75.17           O  \\nATOM   5950  C2'  DA J 291      20.480 137.410  11.748  1.00 75.17           C  \\nATOM   5951  C1'  DA J 291      19.705 136.494  12.677  1.00 75.17           C  \\nATOM   5952  N9   DA J 291      20.548 135.999  13.764  1.00 43.24           N  \\nATOM   5953  C8   DA J 291      21.725 135.305  13.625  1.00 43.24           C  \\nATOM   5954  N7   DA J 291      22.344 135.069  14.764  1.00 43.24           N  \\nATOM   5955  C5   DA J 291      21.511 135.629  15.719  1.00 43.24           C  \\nATOM   5956  C6   DA J 291      21.617 135.732  17.113  1.00 43.24           C  \\nATOM   5957  N6   DA J 291      22.652 135.271  17.815  1.00 43.24           N  \\nATOM   5958  N1   DA J 291      20.610 136.341  17.776  1.00 43.24           N  \\nATOM   5959  C2   DA J 291      19.575 136.811  17.079  1.00 43.24           C  \\nATOM   5960  N3   DA J 291      19.360 136.784  15.763  1.00 43.24           N  \\nATOM   5961  C4   DA J 291      20.382 136.177  15.125  1.00 43.24           C  \\nATOM   5962  P    DT J 292      18.974 139.663   9.900  1.00 56.82           P  \\nATOM   5963  OP1  DT J 292      17.736 140.208   9.261  1.00 56.82           O  \\nATOM   5964  OP2  DT J 292      20.293 139.806   9.214  1.00 56.82           O  \\nATOM   5965  O5'  DT J 292      19.103 140.302  11.349  1.00 53.78           O  \\nATOM   5966  C5'  DT J 292      18.017 140.236  12.268  1.00 53.78           C  \\nATOM   5967  C4'  DT J 292      18.365 141.010  13.514  1.00 53.78           C  \\nATOM   5968  O4'  DT J 292      19.230 140.233  14.382  1.00 53.78           O  \\nATOM   5969  C3'  DT J 292      19.120 142.312  13.224  1.00 53.78           C  \\nATOM   5970  O3'  DT J 292      18.687 143.321  14.148  1.00 53.78           O  \\nATOM   5971  C2'  DT J 292      20.564 141.936  13.521  1.00 53.78           C  \\nATOM   5972  C1'  DT J 292      20.365 141.014  14.708  1.00 53.78           C  \\nATOM   5973  N1   DT J 292      21.484 140.113  15.065  1.00 57.75           N  \\nATOM   5974  C2   DT J 292      21.561 139.712  16.382  1.00 57.75           C  \\nATOM   5975  O2   DT J 292      20.740 140.037  17.223  1.00 57.75           O  \\nATOM   5976  N3   DT J 292      22.638 138.918  16.683  1.00 57.75           N  \\nATOM   5977  C4   DT J 292      23.630 138.482  15.815  1.00 57.75           C  \\nATOM   5978  O4   DT J 292      24.554 137.785  16.235  1.00 57.75           O  \\nATOM   5979  C5   DT J 292      23.480 138.918  14.436  1.00 57.75           C  \\nATOM   5980  C7   DT J 292      24.497 138.483  13.423  1.00 57.75           C  \\nATOM   5981  C6   DT J 292      22.425 139.702  14.134  1.00 57.75           C  \\nTER    5982       DT J 292                                                      \\nATOM   5983  N   PRO A  38      85.595 127.850  -1.418  1.00106.36           N  \\nATOM   5984  CA  PRO A  38      85.568 126.379  -1.251  1.00106.36           C  \\nATOM   5985  C   PRO A  38      84.377 125.749  -1.958  1.00106.36           C  \\nATOM   5986  O   PRO A  38      83.423 126.432  -2.347  1.00106.36           O  \\nATOM   5987  CB  PRO A  38      85.480 126.088   0.245  1.00 84.25           C  \\nATOM   5988  CG  PRO A  38      86.020 127.374   0.845  1.00 84.25           C  \\nATOM   5989  CD  PRO A  38      85.506 128.487  -0.093  1.00 84.25           C  \\nATOM   5990  N   HIS A  39      84.440 124.431  -2.107  1.00129.33           N  \\nATOM   5991  CA  HIS A  39      83.372 123.689  -2.750  1.00129.33           C  \\nATOM   5992  C   HIS A  39      82.356 123.251  -1.727  1.00129.33           C  \\nATOM   5993  O   HIS A  39      82.700 122.844  -0.616  1.00129.33           O  \\nATOM   5994  CB  HIS A  39      83.901 122.454  -3.458  1.00 81.91           C  \\nATOM   5995  CG  HIS A  39      82.864 121.746  -4.270  1.00 81.91           C  \\nATOM   5996  ND1 HIS A  39      82.075 120.740  -3.755  1.00 81.91           N  \\nATOM   5997  CD2 HIS A  39      82.497 121.892  -5.566  1.00 81.91           C  \\nATOM   5998  CE1 HIS A  39      81.271 120.293  -4.703  1.00 81.91           C  \\nATOM   5999  NE2 HIS A  39      81.507 120.975  -5.810  1.00 81.91           N  \\nATOM   6000  N   ARG A  40      81.103 123.249  -2.148  1.00 69.13           N  \\nATOM   6001  CA  ARG A  40      80.028 122.874  -1.257  1.00 69.13           C  \\nATOM   6002  C   ARG A  40      78.762 122.563  -2.063  1.00 69.13           C  \\nATOM   6003  O   ARG A  40      78.324 123.360  -2.894  1.00 69.13           O  \\nATOM   6004  CB  ARG A  40      79.796 124.027  -0.270  1.00 55.90           C  \\nATOM   6005  CG  ARG A  40      79.092 123.647   1.003  1.00 55.90           C  \\nATOM   6006  CD  ARG A  40      78.797 124.873   1.812  1.00 55.90           C  \\nATOM   6007  NE  ARG A  40      77.690 124.648   2.730  1.00 55.90           N  \\nATOM   6008  CZ  ARG A  40      77.779 123.935   3.843  1.00 55.90           C  \\nATOM   6009  NH1 ARG A  40      78.924 123.369   4.186  1.00 55.90           N  \\nATOM   6010  NH2 ARG A  40      76.726 123.825   4.635  1.00 55.90           N  \\nATOM   6011  N   TYR A  41      78.239 121.357  -1.871  1.00 59.40           N  \\nATOM   6012  CA  TYR A  41      77.023 120.897  -2.546  1.00 59.40           C  \\nATOM   6013  C   TYR A  41      75.761 121.511  -1.896  1.00 59.40           C  \\nATOM   6014  O   TYR A  41      75.711 121.695  -0.672  1.00 59.40           O  \\nATOM   6015  CB  TYR A  41      76.977 119.356  -2.519  1.00 37.17           C  \\nATOM   6016  CG  TYR A  41      77.894 118.667  -3.528  1.00 37.17           C  \\nATOM   6017  CD1 TYR A  41      77.617 118.732  -4.896  1.00 37.17           C  \\nATOM   6018  CD2 TYR A  41      79.025 117.943  -3.118  1.00 37.17           C  \\nATOM   6019  CE1 TYR A  41      78.437 118.095  -5.843  1.00 37.17           C  \\nATOM   6020  CE2 TYR A  41      79.865 117.300  -4.065  1.00 37.17           C  \\nATOM   6021  CZ  TYR A  41      79.560 117.384  -5.430  1.00 37.17           C  \\nATOM   6022  OH  TYR A  41      80.359 116.797  -6.404  1.00 37.17           O  \\nATOM   6023  N   ARG A  42      74.755 121.833  -2.713  1.00 50.55           N  \\nATOM   6024  CA  ARG A  42      73.515 122.447  -2.219  1.00 50.55           C  \\nATOM   6025  C   ARG A  42      72.647 121.528  -1.367  1.00 50.55           C  \\nATOM   6026  O   ARG A  42      72.639 120.311  -1.565  1.00 50.55           O  \\nATOM   6027  CB  ARG A  42      72.690 123.029  -3.368  1.00 81.38           C  \\nATOM   6028  CG  ARG A  42      73.298 124.271  -3.970  1.00 81.38           C  \\nATOM   6029  CD  ARG A  42      72.321 124.990  -4.865  1.00 81.38           C  \\nATOM   6030  NE  ARG A  42      73.002 125.963  -5.713  1.00 81.38           N  \\nATOM   6031  CZ  ARG A  42      72.679 126.213  -6.984  1.00 81.38           C  \\nATOM   6032  NH1 ARG A  42      71.661 125.569  -7.553  1.00 81.38           N  \\nATOM   6033  NH2 ARG A  42      73.445 127.022  -7.725  1.00 81.38           N  \\nATOM   6034  N   PRO A  43      71.890 122.100  -0.406  1.00 42.50           N  \\nATOM   6035  CA  PRO A  43      71.054 121.233   0.426  1.00 42.50           C  \\nATOM   6036  C   PRO A  43      70.061 120.426  -0.408  1.00 42.50           C  \\nATOM   6037  O   PRO A  43      69.377 120.968  -1.290  1.00 42.50           O  \\nATOM   6038  CB  PRO A  43      70.402 122.212   1.410  1.00 52.35           C  \\nATOM   6039  CG  PRO A  43      70.406 123.518   0.683  1.00 52.35           C  \\nATOM   6040  CD  PRO A  43      71.735 123.516  -0.021  1.00 52.35           C  \\nATOM   6041  N   GLY A  44      70.126 119.107  -0.218  1.00 40.87           N  \\nATOM   6042  CA  GLY A  44      69.264 118.184  -0.930  1.00 40.87           C  \\nATOM   6043  C   GLY A  44      69.949 117.423  -2.055  1.00 40.87           C  \\nATOM   6044  O   GLY A  44      69.379 116.459  -2.578  1.00 40.87           O  \\nATOM   6045  N   THR A  45      71.164 117.827  -2.430  1.00 38.61           N  \\nATOM   6046  CA  THR A  45      71.890 117.162  -3.520  1.00 38.61           C  \\nATOM   6047  C   THR A  45      72.576 115.888  -3.085  1.00 38.61           C  \\nATOM   6048  O   THR A  45      72.438 114.860  -3.730  1.00 38.61           O  \\nATOM   6049  CB  THR A  45      72.935 118.086  -4.182  1.00 42.13           C  \\nATOM   6050  OG1 THR A  45      72.275 119.223  -4.745  1.00 42.13           O  \\nATOM   6051  CG2 THR A  45      73.662 117.353  -5.299  1.00 42.13           C  \\nATOM   6052  N   VAL A  46      73.362 115.972  -2.023  1.00 38.80           N  \\nATOM   6053  CA  VAL A  46      74.047 114.799  -1.504  1.00 38.80           C  \\nATOM   6054  C   VAL A  46      72.987 113.755  -1.109  1.00 38.80           C  \\nATOM   6055  O   VAL A  46      73.125 112.575  -1.431  1.00 38.80           O  \\nATOM   6056  CB  VAL A  46      74.952 115.171  -0.302  1.00 50.21           C  \\nATOM   6057  CG1 VAL A  46      75.609 113.938   0.292  1.00 50.21           C  \\nATOM   6058  CG2 VAL A  46      76.014 116.148  -0.757  1.00 50.21           C  \\nATOM   6059  N   ALA A  47      71.902 114.217  -0.485  1.00 43.20           N  \\nATOM   6060  CA  ALA A  47      70.791 113.346  -0.075  1.00 43.20           C  \\nATOM   6061  C   ALA A  47      70.265 112.594  -1.295  1.00 43.20           C  \\nATOM   6062  O   ALA A  47      70.002 111.392  -1.244  1.00 43.20           O  \\nATOM   6063  CB  ALA A  47      69.650 114.176   0.545  1.00  7.11           C  \\nATOM   6064  N   LEU A  48      70.122 113.319  -2.397  1.00 29.41           N  \\nATOM   6065  CA  LEU A  48      69.647 112.750  -3.647  1.00 29.41           C  \\nATOM   6066  C   LEU A  48      70.531 111.580  -4.122  1.00 29.41           C  \\nATOM   6067  O   LEU A  48      70.033 110.487  -4.366  1.00 29.41           O  \\nATOM   6068  CB  LEU A  48      69.558 113.854  -4.710  1.00 42.76           C  \\nATOM   6069  CG  LEU A  48      68.243 114.033  -5.480  1.00 42.76           C  \\nATOM   6070  CD1 LEU A  48      67.070 113.820  -4.560  1.00 42.76           C  \\nATOM   6071  CD2 LEU A  48      68.177 115.423  -6.101  1.00 42.76           C  \\nATOM   6072  N   ARG A  49      71.841 111.776  -4.216  1.00 34.24           N  \\nATOM   6073  CA  ARG A  49      72.687 110.675  -4.668  1.00 34.24           C  \\nATOM   6074  C   ARG A  49      72.774 109.519  -3.655  1.00 34.24           C  \\nATOM   6075  O   ARG A  49      73.093 108.389  -4.017  1.00 34.24           O  \\nATOM   6076  CB  ARG A  49      74.065 111.167  -5.116  1.00 43.06           C  \\nATOM   6077  CG  ARG A  49      75.001 111.613  -4.008  1.00 43.06           C  \\nATOM   6078  CD  ARG A  49      76.418 111.847  -4.576  1.00 43.06           C  \\nATOM   6079  NE  ARG A  49      77.182 112.798  -3.772  1.00 43.06           N  \\nATOM   6080  CZ  ARG A  49      77.421 114.060  -4.121  1.00 43.06           C  \\nATOM   6081  NH1 ARG A  49      76.985 114.550  -5.289  1.00 43.06           N  \\nATOM   6082  NH2 ARG A  49      77.970 114.870  -3.224  1.00 43.06           N  \\nATOM   6083  N   GLU A  50      72.524 109.821  -2.386  1.00 21.20           N  \\nATOM   6084  CA  GLU A  50      72.494 108.806  -1.345  1.00 21.20           C  \\nATOM   6085  C   GLU A  50      71.278 107.914  -1.619  1.00 21.20           C  \\nATOM   6086  O   GLU A  50      71.327 106.697  -1.436  1.00 21.20           O  \\nATOM   6087  CB  GLU A  50      72.344 109.444   0.027  1.00 31.05           C  \\nATOM   6088  CG  GLU A  50      73.598 110.035   0.584  1.00 31.05           C  \\nATOM   6089  CD  GLU A  50      73.391 110.568   1.993  1.00 31.05           C  \\nATOM   6090  OE1 GLU A  50      72.900 109.827   2.876  1.00 31.05           O  \\nATOM   6091  OE2 GLU A  50      73.700 111.752   2.227  1.00 31.05           O  \\nATOM   6092  N   ILE A  51      70.169 108.534  -2.010  1.00 20.69           N  \\nATOM   6093  CA  ILE A  51      68.962 107.786  -2.342  1.00 20.69           C  \\nATOM   6094  C   ILE A  51      69.353 106.880  -3.489  1.00 20.69           C  \\nATOM   6095  O   ILE A  51      69.295 105.669  -3.370  1.00 20.69           O  \\nATOM   6096  CB  ILE A  51      67.800 108.745  -2.732  1.00  9.99           C  \\nATOM   6097  CG1 ILE A  51      67.312 109.466  -1.477  1.00  9.99           C  \\nATOM   6098  CG2 ILE A  51      66.642 108.014  -3.377  1.00  9.99           C  \\nATOM   6099  CD1 ILE A  51      66.251 110.456  -1.750  1.00  9.99           C  \\nATOM   6100  N   ARG A  52      69.889 107.461  -4.547  1.00 18.39           N  \\nATOM   6101  CA  ARG A  52      70.304 106.663  -5.680  1.00 18.39           C  \\nATOM   6102  C   ARG A  52      71.193 105.472  -5.298  1.00 18.39           C  \\nATOM   6103  O   ARG A  52      70.942 104.352  -5.770  1.00 18.39           O  \\nATOM   6104  CB  ARG A  52      70.915 107.553  -6.759  1.00 59.59           C  \\nATOM   6105  CG  ARG A  52      69.859 108.512  -7.256  1.00 59.59           C  \\nATOM   6106  CD  ARG A  52      70.253 109.442  -8.388  1.00 59.59           C  \\nATOM   6107  NE  ARG A  52      69.254 110.514  -8.481  1.00 59.59           N  \\nATOM   6108  CZ  ARG A  52      69.471 111.702  -9.031  1.00 59.59           C  \\nATOM   6109  NH1 ARG A  52      70.648 111.975  -9.565  1.00 59.59           N  \\nATOM   6110  NH2 ARG A  52      68.547 112.649  -8.959  1.00 59.59           N  \\nATOM   6111  N   ARG A  53      72.160 105.689  -4.400  1.00 34.07           N  \\nATOM   6112  CA  ARG A  53      73.072 104.627  -3.944  1.00 34.07           C  \\nATOM   6113  C   ARG A  53      72.417 103.530  -3.100  1.00 34.07           C  \\nATOM   6114  O   ARG A  53      72.595 102.335  -3.369  1.00 34.07           O  \\nATOM   6115  CB  ARG A  53      74.244 105.210  -3.151  1.00 50.84           C  \\nATOM   6116  CG  ARG A  53      75.073 104.171  -2.370  1.00 50.84           C  \\nATOM   6117  CD  ARG A  53      75.897 104.856  -1.297  1.00 50.84           C  \\nATOM   6118  NE  ARG A  53      76.464 106.101  -1.829  1.00 50.84           N  \\nATOM   6119  CZ  ARG A  53      76.654 107.231  -1.141  1.00 50.84           C  \\nATOM   6120  NH1 ARG A  53      76.337 107.309   0.148  1.00 50.84           N  \\nATOM   6121  NH2 ARG A  53      77.127 108.311  -1.764  1.00 50.84           N  \\nATOM   6122  N   TYR A  54      71.695 103.929  -2.058  1.00 27.70           N  \\nATOM   6123  CA  TYR A  54      71.058 102.961  -1.191  1.00 27.70           C  \\nATOM   6124  C   TYR A  54      69.964 102.185  -1.880  1.00 27.70           C  \\nATOM   6125  O   TYR A  54      69.709 101.035  -1.533  1.00 27.70           O  \\nATOM   6126  CB  TYR A  54      70.553 103.626   0.069  1.00 34.70           C  \\nATOM   6127  CG  TYR A  54      71.679 104.107   0.919  1.00 34.70           C  \\nATOM   6128  CD1 TYR A  54      72.706 103.239   1.304  1.00 34.70           C  \\nATOM   6129  CD2 TYR A  54      71.761 105.441   1.305  1.00 34.70           C  \\nATOM   6130  CE1 TYR A  54      73.802 103.697   2.055  1.00 34.70           C  \\nATOM   6131  CE2 TYR A  54      72.841 105.914   2.059  1.00 34.70           C  \\nATOM   6132  CZ  TYR A  54      73.855 105.038   2.425  1.00 34.70           C  \\nATOM   6133  OH  TYR A  54      74.903 105.526   3.163  1.00 34.70           O  \\nATOM   6134  N   GLN A  55      69.289 102.808  -2.834  1.00 25.84           N  \\nATOM   6135  CA  GLN A  55      68.255 102.087  -3.559  1.00 25.84           C  \\nATOM   6136  C   GLN A  55      68.874 100.981  -4.421  1.00 25.84           C  \\nATOM   6137  O   GLN A  55      68.318  99.883  -4.517  1.00 25.84           O  \\nATOM   6138  CB  GLN A  55      67.388 103.047  -4.370  1.00 37.88           C  \\nATOM   6139  CG  GLN A  55      66.524 103.909  -3.456  1.00 37.88           C  \\nATOM   6140  CD  GLN A  55      65.351 104.563  -4.165  1.00 37.88           C  \\nATOM   6141  OE1 GLN A  55      65.374 104.757  -5.384  1.00 37.88           O  \\nATOM   6142  NE2 GLN A  55      64.303 104.888  -3.406  1.00 37.88           N  \\nATOM   6143  N   LYS A  56      70.067 101.253  -4.957  1.00 32.05           N  \\nATOM   6144  CA  LYS A  56      70.814 100.307  -5.795  1.00 32.05           C  \\nATOM   6145  C   LYS A  56      71.347  99.095  -5.025  1.00 32.05           C  \\nATOM   6146  O   LYS A  56      71.294  97.966  -5.523  1.00 32.05           O  \\nATOM   6147  CB  LYS A  56      71.981 101.013  -6.502  1.00 92.65           C  \\nATOM   6148  CG  LYS A  56      71.563 102.003  -7.577  1.00 92.65           C  \\nATOM   6149  CD  LYS A  56      72.765 102.748  -8.168  1.00 92.65           C  \\nATOM   6150  CE  LYS A  56      72.328 103.780  -9.225  1.00 92.65           C  \\nATOM   6151  NZ  LYS A  56      73.454 104.621  -9.752  1.00 92.65           N  \\nATOM   6152  N   SER A  57      71.893  99.338  -3.835  1.00 27.56           N  \\nATOM   6153  CA  SER A  57      72.446  98.271  -3.011  1.00 27.56           C  \\nATOM   6154  C   SER A  57      71.381  97.528  -2.196  1.00 27.56           C  \\nATOM   6155  O   SER A  57      70.183  97.839  -2.305  1.00 27.56           O  \\nATOM   6156  CB  SER A  57      73.524  98.840  -2.098  1.00 27.72           C  \\nATOM   6157  OG  SER A  57      73.004  99.866  -1.272  1.00 27.72           O  \\nATOM   6158  N   THR A  58      71.820  96.539  -1.400  1.00 20.76           N  \\nATOM   6159  CA  THR A  58      70.920  95.737  -0.563  1.00 20.76           C  \\nATOM   6160  C   THR A  58      71.471  95.419   0.824  1.00 20.76           C  \\nATOM   6161  O   THR A  58      70.818  94.754   1.614  1.00 20.76           O  \\nATOM   6162  CB  THR A  58      70.580  94.381  -1.214  1.00 18.87           C  \\nATOM   6163  OG1 THR A  58      71.745  93.555  -1.211  1.00 18.87           O  \\nATOM   6164  CG2 THR A  58      70.065  94.550  -2.664  1.00 18.87           C  \\nATOM   6165  N   GLU A  59      72.678  95.880   1.112  1.00 20.79           N  \\nATOM   6166  CA  GLU A  59      73.324  95.633   2.406  1.00 20.79           C  \\nATOM   6167  C   GLU A  59      72.454  96.142   3.550  1.00 20.79           C  \\nATOM   6168  O   GLU A  59      71.641  97.037   3.348  1.00 20.79           O  \\nATOM   6169  CB  GLU A  59      74.700  96.315   2.442  1.00 49.37           C  \\nATOM   6170  CG  GLU A  59      75.028  97.245   1.234  1.00 49.37           C  \\nATOM   6171  CD  GLU A  59      74.631  98.718   1.438  1.00 49.37           C  \\nATOM   6172  OE1 GLU A  59      74.040  99.042   2.484  1.00 49.37           O  \\nATOM   6173  OE2 GLU A  59      74.933  99.567   0.564  1.00 49.37           O  \\nATOM   6174  N   LEU A  60      72.551  95.538   4.725  1.00 23.94           N  \\nATOM   6175  CA  LEU A  60      71.750  96.025   5.846  1.00 23.94           C  \\nATOM   6176  C   LEU A  60      72.263  97.420   6.185  1.00 23.94           C  \\nATOM   6177  O   LEU A  60      73.340  97.785   5.749  1.00 23.94           O  \\nATOM   6178  CB  LEU A  60      71.865  95.091   7.041  1.00 28.99           C  \\nATOM   6179  CG  LEU A  60      71.216  93.731   6.795  1.00 28.99           C  \\nATOM   6180  CD1 LEU A  60      71.326  92.877   8.048  1.00 28.99           C  \\nATOM   6181  CD2 LEU A  60      69.763  93.939   6.406  1.00 28.99           C  \\nATOM   6182  N   LEU A  61      71.541  98.205   6.971  1.00 16.11           N  \\nATOM   6183  CA  LEU A  61      72.008  99.557   7.224  1.00 16.11           C  \\nATOM   6184  C   LEU A  61      72.103  99.932   8.673  1.00 16.11           C  \\nATOM   6185  O   LEU A  61      72.622 100.999   9.002  1.00 16.11           O  \\nATOM   6186  CB  LEU A  61      71.143 100.568   6.468  1.00 17.45           C  \\nATOM   6187  CG  LEU A  61      70.920 100.289   4.977  1.00 17.45           C  \\nATOM   6188  CD1 LEU A  61      69.761 101.117   4.432  1.00 17.45           C  \\nATOM   6189  CD2 LEU A  61      72.177 100.545   4.206  1.00 17.45           C  \\nATOM   6190  N   ILE A  62      71.555  99.108   9.546  1.00 25.59           N  \\nATOM   6191  CA  ILE A  62      71.679  99.393  10.966  1.00 25.59           C  \\nATOM   6192  C   ILE A  62      72.970  98.666  11.392  1.00 25.59           C  \\nATOM   6193  O   ILE A  62      73.379  97.677  10.773  1.00 25.59           O  \\nATOM   6194  CB  ILE A  62      70.468  98.855  11.772  1.00 20.19           C  \\nATOM   6195  CG1 ILE A  62      69.156  99.387  11.202  1.00 20.19           C  \\nATOM   6196  CG2 ILE A  62      70.543  99.332  13.212  1.00 20.19           C  \\nATOM   6197  CD1 ILE A  62      67.957  98.734  11.839  1.00 20.19           C  \\nATOM   6198  N   ARG A  63      73.672  99.167  12.391  1.00 57.10           N  \\nATOM   6199  CA  ARG A  63      74.872  98.447  12.780  1.00 57.10           C  \\nATOM   6200  C   ARG A  63      74.501  97.161  13.559  1.00 57.10           C  \\nATOM   6201  O   ARG A  63      73.710  97.183  14.503  1.00 57.10           O  \\nATOM   6202  CB  ARG A  63      75.852  99.382  13.501  1.00 79.09           C  \\nATOM   6203  CG  ARG A  63      76.911  99.974  12.547  1.00 79.09           C  \\nATOM   6204  CD  ARG A  63      77.401 101.371  12.934  1.00 79.09           C  \\nATOM   6205  NE  ARG A  63      77.537 101.579  14.379  1.00 79.09           N  \\nATOM   6206  CZ  ARG A  63      76.774 102.417  15.084  1.00 79.09           C  \\nATOM   6207  NH1 ARG A  63      75.829 103.125  14.466  1.00 79.09           N  \\nATOM   6208  NH2 ARG A  63      76.932 102.536  16.401  1.00 79.09           N  \\nATOM   6209  N   LYS A  64      75.016  96.031  13.078  1.00 31.58           N  \\nATOM   6210  CA  LYS A  64      74.749  94.700  13.647  1.00 31.58           C  \\nATOM   6211  C   LYS A  64      74.779  94.511  15.172  1.00 31.58           C  \\nATOM   6212  O   LYS A  64      73.833  93.991  15.744  1.00 31.58           O  \\nATOM   6213  CB  LYS A  64      75.627  93.652  12.955  1.00 55.38           C  \\nATOM   6214  CG  LYS A  64      75.503  93.675  11.442  1.00 55.38           C  \\nATOM   6215  CD  LYS A  64      75.417  92.275  10.869  1.00 55.38           C  \\nATOM   6216  CE  LYS A  64      74.725  92.287   9.513  1.00 55.38           C  \\nATOM   6217  NZ  LYS A  64      74.675  90.932   8.899  1.00 55.38           N  \\nATOM   6218  N   LEU A  65      75.856  94.901  15.839  1.00 45.79           N  \\nATOM   6219  CA  LEU A  65      75.911  94.741  17.289  1.00 45.79           C  \\nATOM   6220  C   LEU A  65      74.819  95.515  18.024  1.00 45.79           C  \\nATOM   6221  O   LEU A  65      74.118  94.942  18.845  1.00 45.79           O  \\nATOM   6222  CB  LEU A  65      77.287  95.121  17.845  1.00 68.84           C  \\nATOM   6223  CG  LEU A  65      77.401  95.152  19.375  1.00 68.84           C  \\nATOM   6224  CD1 LEU A  65      77.065  93.780  19.970  1.00 68.84           C  \\nATOM   6225  CD2 LEU A  65      78.796  95.603  19.771  1.00 68.84           C  \\nATOM   6226  N   PRO A  66      74.652  96.825  17.736  1.00 51.32           N  \\nATOM   6227  CA  PRO A  66      73.598  97.573  18.442  1.00 51.32           C  \\nATOM   6228  C   PRO A  66      72.262  96.841  18.304  1.00 51.32           C  \\nATOM   6229  O   PRO A  66      71.535  96.652  19.276  1.00 51.32           O  \\nATOM   6230  CB  PRO A  66      73.552  98.902  17.688  1.00 24.78           C  \\nATOM   6231  CG  PRO A  66      74.937  99.048  17.106  1.00 24.78           C  \\nATOM   6232  CD  PRO A  66      75.300  97.652  16.694  1.00 24.78           C  \\nATOM   6233  N   PHE A  67      71.967  96.405  17.081  1.00 27.70           N  \\nATOM   6234  CA  PHE A  67      70.743  95.685  16.794  1.00 27.70           C  \\nATOM   6235  C   PHE A  67      70.685  94.388  17.615  1.00 27.70           C  \\nATOM   6236  O   PHE A  67      69.668  94.085  18.244  1.00 27.70           O  \\nATOM   6237  CB  PHE A  67      70.667  95.403  15.301  1.00 39.08           C  \\nATOM   6238  CG  PHE A  67      69.338  94.894  14.860  1.00 39.08           C  \\nATOM   6239  CD1 PHE A  67      68.307  95.773  14.597  1.00 39.08           C  \\nATOM   6240  CD2 PHE A  67      69.096  93.529  14.766  1.00 39.08           C  \\nATOM   6241  CE1 PHE A  67      67.053  95.298  14.258  1.00 39.08           C  \\nATOM   6242  CE2 PHE A  67      67.840  93.048  14.426  1.00 39.08           C  \\nATOM   6243  CZ  PHE A  67      66.818  93.931  14.175  1.00 39.08           C  \\nATOM   6244  N   GLN A  68      71.798  93.650  17.618  1.00 28.04           N  \\nATOM   6245  CA  GLN A  68      71.955  92.406  18.367  1.00 28.04           C  \\nATOM   6246  C   GLN A  68      71.547  92.682  19.798  1.00 28.04           C  \\nATOM   6247  O   GLN A  68      70.645  92.058  20.331  1.00 28.04           O  \\nATOM   6248  CB  GLN A  68      73.418  92.004  18.365  1.00 61.85           C  \\nATOM   6249  CG  GLN A  68      73.695  90.694  19.029  1.00 61.85           C  \\nATOM   6250  CD  GLN A  68      73.596  89.551  18.054  1.00 61.85           C  \\nATOM   6251  OE1 GLN A  68      73.947  89.695  16.881  1.00 61.85           O  \\nATOM   6252  NE2 GLN A  68      73.120  88.406  18.524  1.00 61.85           N  \\nATOM   6253  N   ARG A  69      72.178  93.691  20.381  1.00 24.75           N  \\nATOM   6254  CA  ARG A  69      71.933  94.108  21.760  1.00 24.75           C  \\nATOM   6255  C   ARG A  69      70.483  94.488  22.034  1.00 24.75           C  \\nATOM   6256  O   ARG A  69      69.936  94.127  23.073  1.00 24.75           O  \\nATOM   6257  CB  ARG A  69      72.854  95.280  22.119  1.00 53.70           C  \\nATOM   6258  CG  ARG A  69      73.504  95.171  23.491  1.00 53.70           C  \\nATOM   6259  CD  ARG A  69      74.324  96.416  23.826  1.00 53.70           C  \\nATOM   6260  NE  ARG A  69      75.365  96.685  22.841  1.00 53.70           N  \\nATOM   6261  CZ  ARG A  69      75.457  97.803  22.126  1.00 53.70           C  \\nATOM   6262  NH1 ARG A  69      74.568  98.784  22.273  1.00 53.70           N  \\nATOM   6263  NH2 ARG A  69      76.453  97.941  21.265  1.00 53.70           N  \\nATOM   6264  N   LEU A  70      69.887  95.245  21.111  1.00 42.28           N  \\nATOM   6265  CA  LEU A  70      68.498  95.675  21.225  1.00 42.28           C  \\nATOM   6266  C   LEU A  70      67.534  94.481  21.235  1.00 42.28           C  \\nATOM   6267  O   LEU A  70      66.696  94.362  22.129  1.00 42.28           O  \\nATOM   6268  CB  LEU A  70      68.162  96.628  20.090  1.00 24.78           C  \\nATOM   6269  CG  LEU A  70      66.775  97.262  20.145  1.00 24.78           C  \\nATOM   6270  CD1 LEU A  70      66.501  97.859  21.510  1.00 24.78           C  \\nATOM   6271  CD2 LEU A  70      66.716  98.341  19.100  1.00 24.78           C  \\nATOM   6272  N   VAL A  71      67.676  93.591  20.255  1.00 16.88           N  \\nATOM   6273  CA  VAL A  71      66.863  92.379  20.170  1.00 16.88           C  \\nATOM   6274  C   VAL A  71      66.921  91.603  21.512  1.00 16.88           C  \\nATOM   6275  O   VAL A  71      65.892  91.286  22.128  1.00 16.88           O  \\nATOM   6276  CB  VAL A  71      67.381  91.485  19.020  1.00 29.66           C  \\nATOM   6277  CG1 VAL A  71      66.870  90.065  19.169  1.00 29.66           C  \\nATOM   6278  CG2 VAL A  71      66.967  92.057  17.684  1.00 29.66           C  \\nATOM   6279  N   ARG A  72      68.138  91.327  21.978  1.00 33.20           N  \\nATOM   6280  CA  ARG A  72      68.346  90.613  23.239  1.00 33.20           C  \\nATOM   6281  C   ARG A  72      67.722  91.303  24.439  1.00 33.20           C  \\nATOM   6282  O   ARG A  72      67.181  90.627  25.310  1.00 33.20           O  \\nATOM   6283  CB  ARG A  72      69.829  90.404  23.487  1.00 31.62           C  \\nATOM   6284  CG  ARG A  72      70.449  89.476  22.505  1.00 31.62           C  \\nATOM   6285  CD  ARG A  72      71.908  89.411  22.741  1.00 31.62           C  \\nATOM   6286  NE  ARG A  72      72.546  88.669  21.671  1.00 31.62           N  \\nATOM   6287  CZ  ARG A  72      72.569  87.346  21.625  1.00 31.62           C  \\nATOM   6288  NH1 ARG A  72      71.990  86.649  22.610  1.00 31.62           N  \\nATOM   6289  NH2 ARG A  72      73.129  86.721  20.588  1.00 31.62           N  \\nATOM   6290  N   GLU A  73      67.825  92.637  24.492  1.00 34.93           N  \\nATOM   6291  CA  GLU A  73      67.256  93.422  25.583  1.00 34.93           C  \\nATOM   6292  C   GLU A  73      65.762  93.216  25.658  1.00 34.93           C  \\nATOM   6293  O   GLU A  73      65.236  92.946  26.740  1.00 34.93           O  \\nATOM   6294  CB  GLU A  73      67.542  94.916  25.424  1.00 61.50           C  \\nATOM   6295  CG  GLU A  73      66.894  95.772  26.525  1.00 61.50           C  \\nATOM   6296  CD  GLU A  73      66.830  97.256  26.183  1.00 61.50           C  \\nATOM   6297  OE1 GLU A  73      67.829  97.965  26.424  1.00 61.50           O  \\nATOM   6298  OE2 GLU A  73      65.779  97.719  25.679  1.00 61.50           O  \\nATOM   6299  N   ILE A  74      65.080  93.339  24.515  1.00 41.09           N  \\nATOM   6300  CA  ILE A  74      63.625  93.166  24.455  1.00 41.09           C  \\nATOM   6301  C   ILE A  74      63.215  91.752  24.831  1.00 41.09           C  \\nATOM   6302  O   ILE A  74      62.276  91.551  25.616  1.00 41.09           O  \\nATOM   6303  CB  ILE A  74      63.071  93.422  23.058  1.00 17.06           C  \\nATOM   6304  CG1 ILE A  74      63.276  94.876  22.640  1.00 17.06           C  \\nATOM   6305  CG2 ILE A  74      61.607  93.080  23.012  1.00 17.06           C  \\nATOM   6306  CD1 ILE A  74      63.088  95.090  21.146  1.00 17.06           C  \\nATOM   6307  N   ALA A  75      63.897  90.771  24.245  1.00 20.97           N  \\nATOM   6308  CA  ALA A  75      63.611  89.367  24.523  1.00 20.97           C  \\nATOM   6309  C   ALA A  75      63.674  88.985  26.019  1.00 20.97           C  \\nATOM   6310  O   ALA A  75      62.897  88.147  26.483  1.00 20.97           O  \\nATOM   6311  CB  ALA A  75      64.529  88.493  23.699  1.00 12.53           C  \\nATOM   6312  N   GLN A  76      64.618  89.570  26.759  1.00 41.77           N  \\nATOM   6313  CA  GLN A  76      64.766  89.309  28.197  1.00 41.77           C  \\nATOM   6314  C   GLN A  76      63.467  89.557  28.973  1.00 41.77           C  \\nATOM   6315  O   GLN A  76      63.231  88.919  30.007  1.00 41.77           O  \\nATOM   6316  CB  GLN A  76      65.890  90.169  28.785  1.00 57.41           C  \\nATOM   6317  CG  GLN A  76      66.298  89.801  30.217  1.00 57.41           C  \\nATOM   6318  CD  GLN A  76      67.035  88.474  30.318  1.00 57.41           C  \\nATOM   6319  OE1 GLN A  76      67.027  87.646  29.398  1.00 57.41           O  \\nATOM   6320  NE2 GLN A  76      67.665  88.263  31.451  1.00 57.41           N  \\nATOM   6321  N   ASP A  77      62.656  90.506  28.489  1.00 36.47           N  \\nATOM   6322  CA  ASP A  77      61.368  90.830  29.101  1.00 36.47           C  \\nATOM   6323  C   ASP A  77      60.439  89.652  28.950  1.00 36.47           C  \\nATOM   6324  O   ASP A  77      59.582  89.446  29.786  1.00 36.47           O  \\nATOM   6325  CB  ASP A  77      60.708  92.025  28.416  1.00 84.41           C  \\nATOM   6326  CG  ASP A  77      61.380  93.331  28.742  1.00 84.41           C  \\nATOM   6327  OD1 ASP A  77      61.716  93.549  29.929  1.00 84.41           O  \\nATOM   6328  OD2 ASP A  77      61.553  94.147  27.808  1.00 84.41           O  \\nATOM   6329  N   PHE A  78      60.623  88.882  27.877  1.00 30.32           N  \\nATOM   6330  CA  PHE A  78      59.786  87.713  27.579  1.00 30.32           C  \\nATOM   6331  C   PHE A  78      60.191  86.393  28.264  1.00 30.32           C  \\nATOM   6332  O   PHE A  78      59.342  85.599  28.685  1.00 30.32           O  \\nATOM   6333  CB  PHE A  78      59.683  87.542  26.055  1.00 44.69           C  \\nATOM   6334  CG  PHE A  78      59.082  88.744  25.342  1.00 44.69           C  \\nATOM   6335  CD1 PHE A  78      58.019  89.462  25.914  1.00 44.69           C  \\nATOM   6336  CD2 PHE A  78      59.576  89.154  24.103  1.00 44.69           C  \\nATOM   6337  CE1 PHE A  78      57.463  90.565  25.268  1.00 44.69           C  \\nATOM   6338  CE2 PHE A  78      59.026  90.256  23.449  1.00 44.69           C  \\nATOM   6339  CZ  PHE A  78      57.967  90.964  24.034  1.00 44.69           C  \\nATOM   6340  N   LYS A  79      61.486  86.124  28.286  1.00 35.07           N  \\nATOM   6341  CA  LYS A  79      62.014  84.939  28.942  1.00 35.07           C  \\nATOM   6342  C   LYS A  79      63.497  85.162  29.162  1.00 35.07           C  \\nATOM   6343  O   LYS A  79      64.196  85.686  28.287  1.00 35.07           O  \\nATOM   6344  CB  LYS A  79      61.788  83.686  28.123  1.00 56.97           C  \\nATOM   6345  CG  LYS A  79      62.194  82.452  28.884  1.00 56.97           C  \\nATOM   6346  CD  LYS A  79      62.137  81.215  28.028  1.00 56.97           C  \\nATOM   6347  CE  LYS A  79      62.841  80.065  28.712  1.00 56.97           C  \\nATOM   6348  NZ  LYS A  79      62.923  78.913  27.775  1.00 56.97           N  \\nATOM   6349  N   THR A  80      63.971  84.800  30.348  1.00 52.81           N  \\nATOM   6350  CA  THR A  80      65.369  84.992  30.695  1.00 52.81           C  \\nATOM   6351  C   THR A  80      66.318  83.876  30.313  1.00 52.81           C  \\nATOM   6352  O   THR A  80      65.929  82.706  30.183  1.00 52.81           O  \\nATOM   6353  CB  THR A  80      65.527  85.259  32.170  1.00 41.91           C  \\nATOM   6354  OG1 THR A  80      64.689  84.353  32.898  1.00 41.91           O  \\nATOM   6355  CG2 THR A  80      65.149  86.678  32.483  1.00 41.91           C  \\nATOM   6356  N   ASP A  81      67.583  84.277  30.186  1.00 52.49           N  \\nATOM   6357  CA  ASP A  81      68.700  83.412  29.816  1.00 52.49           C  \\nATOM   6358  C   ASP A  81      68.443  82.743  28.487  1.00 52.49           C  \\nATOM   6359  O   ASP A  81      68.246  81.531  28.398  1.00 52.49           O  \\nATOM   6360  CB  ASP A  81      69.004  82.376  30.897  1.00 67.39           C  \\nATOM   6361  CG  ASP A  81      70.358  81.721  30.704  1.00 67.39           C  \\nATOM   6362  OD1 ASP A  81      71.208  82.262  29.942  1.00 67.39           O  \\nATOM   6363  OD2 ASP A  81      70.568  80.661  31.326  1.00 67.39           O  \\nATOM   6364  N   LEU A  82      68.440  83.565  27.451  1.00 26.75           N  \\nATOM   6365  CA  LEU A  82      68.190  83.083  26.109  1.00 26.75           C  \\nATOM   6366  C   LEU A  82      69.355  83.200  25.136  1.00 26.75           C  \\nATOM   6367  O   LEU A  82      70.113  84.166  25.154  1.00 26.75           O  \\nATOM   6368  CB  LEU A  82      66.966  83.793  25.525  1.00 39.45           C  \\nATOM   6369  CG  LEU A  82      65.602  83.325  26.016  1.00 39.45           C  \\nATOM   6370  CD1 LEU A  82      64.508  84.165  25.413  1.00 39.45           C  \\nATOM   6371  CD2 LEU A  82      65.423  81.884  25.619  1.00 39.45           C  \\nATOM   6372  N   ARG A  83      69.542  82.164  24.338  1.00 31.29           N  \\nATOM   6373  CA  ARG A  83      70.579  82.218  23.342  1.00 31.29           C  \\nATOM   6374  C   ARG A  83      69.841  82.498  22.035  1.00 31.29           C  \\nATOM   6375  O   ARG A  83      68.650  82.173  21.893  1.00 31.29           O  \\nATOM   6376  CB  ARG A  83      71.367  80.909  23.266  1.00112.49           C  \\nATOM   6377  CG  ARG A  83      72.220  80.602  24.491  1.00112.49           C  \\nATOM   6378  CD  ARG A  83      73.280  79.563  24.162  1.00112.49           C  \\nATOM   6379  NE  ARG A  83      72.724  78.471  23.361  1.00112.49           N  \\nATOM   6380  CZ  ARG A  83      73.440  77.547  22.721  1.00112.49           C  \\nATOM   6381  NH1 ARG A  83      74.768  77.556  22.769  1.00112.49           N  \\nATOM   6382  NH2 ARG A  83      72.814  76.617  22.012  1.00112.49           N  \\nATOM   6383  N   PHE A  84      70.525  83.178  21.123  1.00 50.30           N  \\nATOM   6384  CA  PHE A  84      69.979  83.519  19.820  1.00 50.30           C  \\nATOM   6385  C   PHE A  84      70.843  82.973  18.692  1.00 50.30           C  \\nATOM   6386  O   PHE A  84      72.015  83.341  18.509  1.00 50.30           O  \\nATOM   6387  CB  PHE A  84      69.845  85.036  19.659  1.00 38.50           C  \\nATOM   6388  CG  PHE A  84      68.523  85.580  20.094  1.00 38.50           C  \\nATOM   6389  CD1 PHE A  84      67.467  85.666  19.197  1.00 38.50           C  \\nATOM   6390  CD2 PHE A  84      68.323  86.001  21.402  1.00 38.50           C  \\nATOM   6391  CE1 PHE A  84      66.227  86.164  19.602  1.00 38.50           C  \\nATOM   6392  CE2 PHE A  84      67.087  86.498  21.814  1.00 38.50           C  \\nATOM   6393  CZ  PHE A  84      66.040  86.576  20.911  1.00 38.50           C  \\nATOM   6394  N   GLN A  85      70.232  82.107  17.912  1.00 24.04           N  \\nATOM   6395  CA  GLN A  85      70.878  81.515  16.774  1.00 24.04           C  \\nATOM   6396  C   GLN A  85      71.339  82.711  15.892  1.00 24.04           C  \\nATOM   6397  O   GLN A  85      70.632  83.709  15.752  1.00 24.04           O  \\nATOM   6398  CB  GLN A  85      69.822  80.641  16.100  1.00 24.74           C  \\nATOM   6399  CG  GLN A  85      70.326  79.677  15.121  1.00 24.74           C  \\nATOM   6400  CD  GLN A  85      69.406  78.488  14.987  1.00 24.74           C  \\nATOM   6401  OE1 GLN A  85      68.503  78.487  14.141  1.00 24.74           O  \\nATOM   6402  NE2 GLN A  85      69.619  77.460  15.828  1.00 24.74           N  \\nATOM   6403  N   SER A  86      72.562  82.666  15.382  1.00 27.51           N  \\nATOM   6404  CA  SER A  86      73.084  83.748  14.537  1.00 27.51           C  \\nATOM   6405  C   SER A  86      72.109  84.077  13.430  1.00 27.51           C  \\nATOM   6406  O   SER A  86      71.916  85.238  13.089  1.00 27.51           O  \\nATOM   6407  CB  SER A  86      74.405  83.337  13.907  1.00 49.92           C  \\nATOM   6408  OG  SER A  86      74.630  84.078  12.726  1.00 49.92           O  \\nATOM   6409  N   SER A  87      71.508  83.031  12.868  1.00 30.54           N  \\nATOM   6410  CA  SER A  87      70.528  83.167  11.783  1.00 30.54           C  \\nATOM   6411  C   SER A  87      69.203  83.804  12.237  1.00 30.54           C  \\nATOM   6412  O   SER A  87      68.555  84.501  11.453  1.00 30.54           O  \\nATOM   6413  CB  SER A  87      70.283  81.815  11.083  1.00 37.41           C  \\nATOM   6414  OG  SER A  87      70.703  80.707  11.869  1.00 37.41           O  \\nATOM   6415  N   ALA A  88      68.822  83.595  13.503  1.00 25.82           N  \\nATOM   6416  CA  ALA A  88      67.592  84.187  14.053  1.00 25.82           C  \\nATOM   6417  C   ALA A  88      67.713  85.704  14.044  1.00 25.82           C  \\nATOM   6418  O   ALA A  88      66.801  86.410  13.613  1.00 25.82           O  \\nATOM   6419  CB  ALA A  88      67.346  83.707  15.463  1.00 18.97           C  \\nATOM   6420  N   VAL A  89      68.863  86.196  14.496  1.00 20.15           N  \\nATOM   6421  CA  VAL A  89      69.108  87.629  14.522  1.00 20.15           C  \\nATOM   6422  C   VAL A  89      69.189  88.248  13.126  1.00 20.15           C  \\nATOM   6423  O   VAL A  89      68.607  89.299  12.884  1.00 20.15           O  \\nATOM   6424  CB  VAL A  89      70.339  87.986  15.337  1.00 10.54           C  \\nATOM   6425  CG1 VAL A  89      70.506  89.498  15.345  1.00 10.54           C  \\nATOM   6426  CG2 VAL A  89      70.171  87.477  16.758  1.00 10.54           C  \\nATOM   6427  N   MET A  90      69.918  87.619  12.211  1.00 38.44           N  \\nATOM   6428  CA  MET A  90      69.983  88.138  10.856  1.00 38.44           C  \\nATOM   6429  C   MET A  90      68.547  88.230  10.304  1.00 38.44           C  \\nATOM   6430  O   MET A  90      68.169  89.232   9.706  1.00 38.44           O  \\nATOM   6431  CB  MET A  90      70.825  87.226   9.975  1.00 62.99           C  \\nATOM   6432  CG  MET A  90      72.263  87.649   9.807  1.00 62.99           C  \\nATOM   6433  SD  MET A  90      73.044  86.567   8.584  1.00 62.99           S  \\nATOM   6434  CE  MET A  90      72.411  87.289   6.968  1.00 62.99           C  \\nATOM   6435  N   ALA A  91      67.736  87.198  10.528  1.00 51.18           N  \\nATOM   6436  CA  ALA A  91      66.348  87.205  10.068  1.00 51.18           C  \\nATOM   6437  C   ALA A  91      65.600  88.426  10.606  1.00 51.18           C  \\nATOM   6438  O   ALA A  91      65.034  89.190   9.826  1.00 51.18           O  \\nATOM   6439  CB  ALA A  91      65.652  85.936  10.491  1.00 13.60           C  \\nATOM   6440  N   LEU A  92      65.597  88.605  11.930  1.00 26.26           N  \\nATOM   6441  CA  LEU A  92      64.940  89.758  12.544  1.00 26.26           C  \\nATOM   6442  C   LEU A  92      65.439  91.075  11.953  1.00 26.26           C  \\nATOM   6443  O   LEU A  92      64.641  91.963  11.679  1.00 26.26           O  \\nATOM   6444  CB  LEU A  92      65.154  89.775  14.052  1.00 18.67           C  \\nATOM   6445  CG  LEU A  92      64.309  88.820  14.910  1.00 18.67           C  \\nATOM   6446  CD1 LEU A  92      64.851  88.762  16.311  1.00 18.67           C  \\nATOM   6447  CD2 LEU A  92      62.872  89.267  14.943  1.00 18.67           C  \\nATOM   6448  N   GLN A  93      66.744  91.209  11.730  1.00  9.93           N  \\nATOM   6449  CA  GLN A  93      67.235  92.434  11.150  1.00  9.93           C  \\nATOM   6450  C   GLN A  93      66.741  92.622   9.738  1.00  9.93           C  \\nATOM   6451  O   GLN A  93      66.317  93.706   9.371  1.00  9.93           O  \\nATOM   6452  CB  GLN A  93      68.743  92.519  11.194  1.00 20.57           C  \\nATOM   6453  CG  GLN A  93      69.252  93.842  10.666  1.00 20.57           C  \\nATOM   6454  CD  GLN A  93      70.608  94.210  11.210  1.00 20.57           C  \\nATOM   6455  OE1 GLN A  93      71.150  93.526  12.088  1.00 20.57           O  \\nATOM   6456  NE2 GLN A  93      71.169  95.307  10.695  1.00 20.57           N  \\nATOM   6457  N   GLU A  94      66.772  91.574   8.938  1.00 19.06           N  \\nATOM   6458  CA  GLU A  94      66.267  91.664   7.580  1.00 19.06           C  \\nATOM   6459  C   GLU A  94      64.806  92.124   7.586  1.00 19.06           C  \\nATOM   6460  O   GLU A  94      64.454  93.082   6.902  1.00 19.06           O  \\nATOM   6461  CB  GLU A  94      66.346  90.301   6.921  1.00 27.58           C  \\nATOM   6462  CG  GLU A  94      67.725  89.903   6.486  1.00 27.58           C  \\nATOM   6463  CD  GLU A  94      68.116  90.502   5.155  1.00 27.58           C  \\nATOM   6464  OE1 GLU A  94      67.246  90.769   4.297  1.00 27.58           O  \\nATOM   6465  OE2 GLU A  94      69.324  90.703   4.954  1.00 27.58           O  \\nATOM   6466  N   ALA A  95      63.970  91.453   8.376  1.00 29.50           N  \\nATOM   6467  CA  ALA A  95      62.560  91.793   8.474  1.00 29.50           C  \\nATOM   6468  C   ALA A  95      62.331  93.220   8.943  1.00 29.50           C  \\nATOM   6469  O   ALA A  95      61.551  93.950   8.347  1.00 29.50           O  \\nATOM   6470  CB  ALA A  95      61.847  90.834   9.387  1.00  5.00           C  \\nATOM   6471  N   SER A  96      63.011  93.624  10.007  1.00 13.19           N  \\nATOM   6472  CA  SER A  96      62.874  94.976  10.552  1.00 13.19           C  \\nATOM   6473  C   SER A  96      63.195  96.053   9.544  1.00 13.19           C  \\nATOM   6474  O   SER A  96      62.379  96.906   9.263  1.00 13.19           O  \\nATOM   6475  CB  SER A  96      63.753  95.134  11.779  1.00 21.66           C  \\nATOM   6476  OG  SER A  96      63.344  94.210  12.778  1.00 21.66           O  \\nATOM   6477  N   GLU A  97      64.373  95.989   8.946  1.00 12.43           N  \\nATOM   6478  CA  GLU A  97      64.730  96.983   7.951  1.00 12.43           C  \\nATOM   6479  C   GLU A  97      63.745  96.973   6.785  1.00 12.43           C  \\nATOM   6480  O   GLU A  97      63.277  98.015   6.373  1.00 12.43           O  \\nATOM   6481  CB  GLU A  97      66.151  96.759   7.480  1.00 29.48           C  \\nATOM   6482  CG  GLU A  97      67.163  96.996   8.574  1.00 29.48           C  \\nATOM   6483  CD  GLU A  97      68.542  97.184   8.016  1.00 29.48           C  \\nATOM   6484  OE1 GLU A  97      68.636  97.710   6.881  1.00 29.48           O  \\nATOM   6485  OE2 GLU A  97      69.523  96.805   8.695  1.00 29.48           O  \\nATOM   6486  N   ALA A  98      63.421  95.796   6.266  1.00 17.19           N  \\nATOM   6487  CA  ALA A  98      62.460  95.683   5.176  1.00 17.19           C  \\nATOM   6488  C   ALA A  98      61.197  96.444   5.566  1.00 17.19           C  \\nATOM   6489  O   ALA A  98      60.623  97.178   4.758  1.00 17.19           O  \\nATOM   6490  CB  ALA A  98      62.126  94.205   4.922  1.00 10.58           C  \\nATOM   6491  N   TYR A  99      60.801  96.284   6.826  1.00 27.15           N  \\nATOM   6492  CA  TYR A  99      59.629  96.936   7.387  1.00 27.15           C  \\nATOM   6493  C   TYR A  99      59.754  98.453   7.415  1.00 27.15           C  \\nATOM   6494  O   TYR A  99      58.868  99.156   6.939  1.00 27.15           O  \\nATOM   6495  CB  TYR A  99      59.383  96.403   8.792  1.00 16.67           C  \\nATOM   6496  CG  TYR A  99      58.404  97.226   9.558  1.00 16.67           C  \\nATOM   6497  CD1 TYR A  99      57.062  97.272   9.192  1.00 16.67           C  \\nATOM   6498  CD2 TYR A  99      58.806  97.991  10.626  1.00 16.67           C  \\nATOM   6499  CE1 TYR A  99      56.143  98.063   9.876  1.00 16.67           C  \\nATOM   6500  CE2 TYR A  99      57.892  98.788  11.314  1.00 16.67           C  \\nATOM   6501  CZ  TYR A  99      56.568  98.812  10.931  1.00 16.67           C  \\nATOM   6502  OH  TYR A  99      55.683  99.590  11.630  1.00 16.67           O  \\nATOM   6503  N   LEU A 100      60.835  98.942   8.009  1.00 12.09           N  \\nATOM   6504  CA  LEU A 100      61.103 100.365   8.104  1.00 12.09           C  \\nATOM   6505  C   LEU A 100      61.220 101.048   6.759  1.00 12.09           C  \\nATOM   6506  O   LEU A 100      60.610 102.080   6.534  1.00 12.09           O  \\nATOM   6507  CB  LEU A 100      62.368 100.614   8.905  1.00 17.79           C  \\nATOM   6508  CG  LEU A 100      62.141 100.291  10.384  1.00 17.79           C  \\nATOM   6509  CD1 LEU A 100      63.400 100.532  11.188  1.00 17.79           C  \\nATOM   6510  CD2 LEU A 100      60.998 101.154  10.909  1.00 17.79           C  \\nATOM   6511  N   VAL A 101      61.987 100.476   5.848  1.00 26.76           N  \\nATOM   6512  CA  VAL A 101      62.138 101.076   4.539  1.00 26.76           C  \\nATOM   6513  C   VAL A 101      60.795 101.375   3.902  1.00 26.76           C  \\nATOM   6514  O   VAL A 101      60.593 102.488   3.418  1.00 26.76           O  \\nATOM   6515  CB  VAL A 101      62.944 100.176   3.603  1.00  7.17           C  \\nATOM   6516  CG1 VAL A 101      62.840 100.678   2.162  1.00  7.17           C  \\nATOM   6517  CG2 VAL A 101      64.395 100.130   4.071  1.00  7.17           C  \\nATOM   6518  N   ALA A 102      59.880 100.396   3.920  1.00 17.92           N  \\nATOM   6519  CA  ALA A 102      58.535 100.551   3.328  1.00 17.92           C  \\nATOM   6520  C   ALA A 102      57.679 101.560   4.075  1.00 17.92           C  \\nATOM   6521  O   ALA A 102      56.903 102.303   3.478  1.00 17.92           O  \\nATOM   6522  CB  ALA A 102      57.845  99.239   3.261  1.00  5.00           C  \\nATOM   6523  N   LEU A 103      57.798 101.563   5.390  1.00 15.01           N  \\nATOM   6524  CA  LEU A 103      57.069 102.539   6.178  1.00 15.01           C  \\nATOM   6525  C   LEU A 103      57.550 103.929   5.740  1.00 15.01           C  \\nATOM   6526  O   LEU A 103      56.753 104.861   5.650  1.00 15.01           O  \\nATOM   6527  CB  LEU A 103      57.292 102.322   7.685  1.00 12.43           C  \\nATOM   6528  CG  LEU A 103      56.518 103.267   8.608  1.00 12.43           C  \\nATOM   6529  CD1 LEU A 103      55.013 103.117   8.422  1.00 12.43           C  \\nATOM   6530  CD2 LEU A 103      56.901 102.992  10.028  1.00 12.43           C  \\nATOM   6531  N   PHE A 104      58.850 104.072   5.473  1.00 20.53           N  \\nATOM   6532  CA  PHE A 104      59.382 105.350   4.993  1.00 20.53           C  \\nATOM   6533  C   PHE A 104      58.804 105.659   3.598  1.00 20.53           C  \\nATOM   6534  O   PHE A 104      58.569 106.806   3.273  1.00 20.53           O  \\nATOM   6535  CB  PHE A 104      60.920 105.366   5.000  1.00 11.05           C  \\nATOM   6536  CG  PHE A 104      61.535 105.626   6.378  1.00 11.05           C  \\nATOM   6537  CD1 PHE A 104      61.223 106.779   7.102  1.00 11.05           C  \\nATOM   6538  CD2 PHE A 104      62.409 104.711   6.958  1.00 11.05           C  \\nATOM   6539  CE1 PHE A 104      61.755 107.016   8.379  1.00 11.05           C  \\nATOM   6540  CE2 PHE A 104      62.951 104.946   8.244  1.00 11.05           C  \\nATOM   6541  CZ  PHE A 104      62.616 106.106   8.946  1.00 11.05           C  \\nATOM   6542  N   GLU A 105      58.495 104.642   2.799  1.00 22.12           N  \\nATOM   6543  CA  GLU A 105      57.896 104.886   1.483  1.00 22.12           C  \\nATOM   6544  C   GLU A 105      56.550 105.546   1.670  1.00 22.12           C  \\nATOM   6545  O   GLU A 105      56.316 106.666   1.224  1.00 22.12           O  \\nATOM   6546  CB  GLU A 105      57.701 103.585   0.719  1.00 35.59           C  \\nATOM   6547  CG  GLU A 105      58.994 102.997   0.231  1.00 35.59           C  \\nATOM   6548  CD  GLU A 105      58.832 101.681  -0.493  1.00 35.59           C  \\nATOM   6549  OE1 GLU A 105      57.776 101.451  -1.135  1.00 35.59           O  \\nATOM   6550  OE2 GLU A 105      59.788 100.881  -0.431  1.00 35.59           O  \\nATOM   6551  N   ASP A 106      55.679 104.853   2.380  1.00 30.69           N  \\nATOM   6552  CA  ASP A 106      54.348 105.355   2.636  1.00 30.69           C  \\nATOM   6553  C   ASP A 106      54.414 106.720   3.287  1.00 30.69           C  \\nATOM   6554  O   ASP A 106      53.724 107.645   2.855  1.00 30.69           O  \\nATOM   6555  CB  ASP A 106      53.585 104.382   3.526  1.00 26.48           C  \\nATOM   6556  CG  ASP A 106      53.364 103.029   2.861  1.00 26.48           C  \\nATOM   6557  OD1 ASP A 106      53.423 102.938   1.599  1.00 26.48           O  \\nATOM   6558  OD2 ASP A 106      53.137 102.059   3.621  1.00 26.48           O  \\nATOM   6559  N   THR A 107      55.249 106.845   4.322  1.00 19.57           N  \\nATOM   6560  CA  THR A 107      55.429 108.111   5.053  1.00 19.57           C  \\nATOM   6561  C   THR A 107      55.712 109.250   4.061  1.00 19.57           C  \\nATOM   6562  O   THR A 107      55.131 110.333   4.150  1.00 19.57           O  \\nATOM   6563  CB  THR A 107      56.603 108.013   6.065  1.00 10.91           C  \\nATOM   6564  OG1 THR A 107      56.327 107.010   7.059  1.00 10.91           O  \\nATOM   6565  CG2 THR A 107      56.857 109.353   6.727  1.00 10.91           C  \\nATOM   6566  N   ASN A 108      56.560 108.970   3.075  1.00 23.14           N  \\nATOM   6567  CA  ASN A 108      56.913 109.957   2.083  1.00 23.14           C  \\nATOM   6568  C   ASN A 108      55.690 110.432   1.355  1.00 23.14           C  \\nATOM   6569  O   ASN A 108      55.487 111.631   1.216  1.00 23.14           O  \\nATOM   6570  CB  ASN A 108      57.919 109.401   1.088  1.00 20.45           C  \\nATOM   6571  CG  ASN A 108      58.955 110.426   0.705  1.00 20.45           C  \\nATOM   6572  OD1 ASN A 108      59.286 111.294   1.511  1.00 20.45           O  \\nATOM   6573  ND2 ASN A 108      59.471 110.345  -0.514  1.00 20.45           N  \\nATOM   6574  N   LEU A 109      54.883 109.491   0.880  1.00 19.44           N  \\nATOM   6575  CA  LEU A 109      53.647 109.823   0.167  1.00 19.44           C  \\nATOM   6576  C   LEU A 109      52.735 110.725   0.996  1.00 19.44           C  \\nATOM   6577  O   LEU A 109      52.092 111.621   0.463  1.00 19.44           O  \\nATOM   6578  CB  LEU A 109      52.897 108.556  -0.219  1.00 14.09           C  \\nATOM   6579  CG  LEU A 109      53.730 107.628  -1.096  1.00 14.09           C  \\nATOM   6580  CD1 LEU A 109      52.976 106.341  -1.385  1.00 14.09           C  \\nATOM   6581  CD2 LEU A 109      54.083 108.370  -2.394  1.00 14.09           C  \\nATOM   6582  N   CYS A 110      52.648 110.463   2.291  1.00 14.96           N  \\nATOM   6583  CA  CYS A 110      51.836 111.292   3.147  1.00 14.96           C  \\nATOM   6584  C   CYS A 110      52.346 112.728   3.156  1.00 14.96           C  \\nATOM   6585  O   CYS A 110      51.579 113.671   2.930  1.00 14.96           O  \\nATOM   6586  CB  CYS A 110      51.823 110.741   4.560  1.00 17.45           C  \\nATOM   6587  SG  CYS A 110      50.854 109.266   4.653  1.00 17.45           S  \\nATOM   6588  N   ALA A 111      53.641 112.892   3.418  1.00 22.03           N  \\nATOM   6589  CA  ALA A 111      54.258 114.213   3.445  1.00 22.03           C  \\nATOM   6590  C   ALA A 111      54.025 114.943   2.130  1.00 22.03           C  \\nATOM   6591  O   ALA A 111      53.649 116.115   2.096  1.00 22.03           O  \\nATOM   6592  CB  ALA A 111      55.716 114.075   3.702  1.00  9.33           C  \\nATOM   6593  N   ILE A 112      54.249 114.242   1.039  1.00 15.55           N  \\nATOM   6594  CA  ILE A 112      54.047 114.820  -0.263  1.00 15.55           C  \\nATOM   6595  C   ILE A 112      52.575 115.141  -0.454  1.00 15.55           C  \\nATOM   6596  O   ILE A 112      52.214 116.174  -1.033  1.00 15.55           O  \\nATOM   6597  CB  ILE A 112      54.533 113.853  -1.334  1.00 14.57           C  \\nATOM   6598  CG1 ILE A 112      55.991 113.492  -1.031  1.00 14.57           C  \\nATOM   6599  CG2 ILE A 112      54.396 114.462  -2.714  1.00 14.57           C  \\nATOM   6600  CD1 ILE A 112      56.612 112.611  -2.047  1.00 14.57           C  \\nATOM   6601  N   HIS A 113      51.714 114.271   0.051  1.00 26.92           N  \\nATOM   6602  CA  HIS A 113      50.287 114.498  -0.068  1.00 26.92           C  \\nATOM   6603  C   HIS A 113      49.970 115.866   0.524  1.00 26.92           C  \\nATOM   6604  O   HIS A 113      49.105 116.602   0.031  1.00 26.92           O  \\nATOM   6605  CB  HIS A 113      49.518 113.429   0.694  1.00 18.28           C  \\nATOM   6606  CG  HIS A 113      48.040 113.498   0.482  1.00 18.28           C  \\nATOM   6607  ND1 HIS A 113      47.159 113.831   1.490  1.00 18.28           N  \\nATOM   6608  CD2 HIS A 113      47.287 113.271  -0.619  1.00 18.28           C  \\nATOM   6609  CE1 HIS A 113      45.925 113.806   1.021  1.00 18.28           C  \\nATOM   6610  NE2 HIS A 113      45.975 113.468  -0.256  1.00 18.28           N  \\nATOM   6611  N   ALA A 114      50.656 116.167   1.616  1.00 18.46           N  \\nATOM   6612  CA  ALA A 114      50.484 117.423   2.296  1.00 18.46           C  \\nATOM   6613  C   ALA A 114      51.389 118.533   1.750  1.00 18.46           C  \\nATOM   6614  O   ALA A 114      51.749 119.488   2.458  1.00 18.46           O  \\nATOM   6615  CB  ALA A 114      50.667 117.233   3.770  1.00  5.00           C  \\nATOM   6616  N   LYS A 115      51.701 118.433   0.464  1.00 30.35           N  \\nATOM   6617  CA  LYS A 115      52.512 119.429  -0.209  1.00 30.35           C  \\nATOM   6618  C   LYS A 115      53.854 119.669   0.466  1.00 30.35           C  \\nATOM   6619  O   LYS A 115      54.358 120.789   0.482  1.00 30.35           O  \\nATOM   6620  CB  LYS A 115      51.734 120.740  -0.335  1.00 79.74           C  \\nATOM   6621  CG  LYS A 115      50.431 120.607  -1.105  1.00 79.74           C  \\nATOM   6622  CD  LYS A 115      49.632 121.889  -1.049  1.00 79.74           C  \\nATOM   6623  CE  LYS A 115      48.333 121.758  -1.810  1.00 79.74           C  \\nATOM   6624  NZ  LYS A 115      47.567 123.040  -1.824  1.00 79.74           N  \\nATOM   6625  N   ARG A 116      54.415 118.630   1.075  1.00 18.65           N  \\nATOM   6626  CA  ARG A 116      55.720 118.767   1.708  1.00 18.65           C  \\nATOM   6627  C   ARG A 116      56.756 117.887   1.022  1.00 18.65           C  \\nATOM   6628  O   ARG A 116      56.468 117.196   0.048  1.00 18.65           O  \\nATOM   6629  CB  ARG A 116      55.651 118.486   3.221  1.00 31.71           C  \\nATOM   6630  CG  ARG A 116      55.060 119.629   4.030  1.00 31.71           C  \\nATOM   6631  CD  ARG A 116      55.110 119.369   5.510  1.00 31.71           C  \\nATOM   6632  NE  ARG A 116      54.019 118.509   5.969  1.00 31.71           N  \\nATOM   6633  CZ  ARG A 116      54.157 117.248   6.390  1.00 31.71           C  \\nATOM   6634  NH1 ARG A 116      55.343 116.658   6.406  1.00 31.71           N  \\nATOM   6635  NH2 ARG A 116      53.107 116.580   6.851  1.00 31.71           N  \\nATOM   6636  N   VAL A 117      57.970 117.968   1.544  1.00 27.74           N  \\nATOM   6637  CA  VAL A 117      59.135 117.250   1.059  1.00 27.74           C  \\nATOM   6638  C   VAL A 117      59.861 116.659   2.277  1.00 27.74           C  \\nATOM   6639  O   VAL A 117      60.673 115.720   2.175  1.00 27.74           O  \\nATOM   6640  CB  VAL A 117      60.054 118.250   0.352  1.00 18.19           C  \\nATOM   6641  CG1 VAL A 117      61.434 117.680   0.217  1.00 18.19           C  \\nATOM   6642  CG2 VAL A 117      59.481 118.597  -1.009  1.00 18.19           C  \\nATOM   6643  N   THR A 118      59.610 117.306   3.409  1.00 32.53           N  \\nATOM   6644  CA  THR A 118      60.149 116.930   4.703  1.00 32.53           C  \\nATOM   6645  C   THR A 118      59.166 116.028   5.452  1.00 32.53           C  \\nATOM   6646  O   THR A 118      58.083 116.474   5.831  1.00 32.53           O  \\nATOM   6647  CB  THR A 118      60.344 118.190   5.577  1.00 15.25           C  \\nATOM   6648  OG1 THR A 118      60.900 119.248   4.783  1.00 15.25           O  \\nATOM   6649  CG2 THR A 118      61.234 117.885   6.779  1.00 15.25           C  \\nATOM   6650  N   ILE A 119      59.542 114.776   5.688  1.00 27.40           N  \\nATOM   6651  CA  ILE A 119      58.667 113.876   6.431  1.00 27.40           C  \\nATOM   6652  C   ILE A 119      58.766 114.183   7.928  1.00 27.40           C  \\nATOM   6653  O   ILE A 119      59.848 114.447   8.445  1.00 27.40           O  \\nATOM   6654  CB  ILE A 119      59.027 112.414   6.216  1.00 10.86           C  \\nATOM   6655  CG1 ILE A 119      60.459 112.170   6.677  1.00 10.86           C  \\nATOM   6656  CG2 ILE A 119      58.805 112.038   4.768  1.00 10.86           C  \\nATOM   6657  CD1 ILE A 119      60.823 110.703   6.963  1.00 10.86           C  \\nATOM   6658  N   MET A 120      57.624 114.178   8.604  1.00 16.70           N  \\nATOM   6659  CA  MET A 120      57.551 114.455  10.030  1.00 16.70           C  \\nATOM   6660  C   MET A 120      56.793 113.336  10.731  1.00 16.70           C  \\nATOM   6661  O   MET A 120      56.288 112.417  10.085  1.00 16.70           O  \\nATOM   6662  CB  MET A 120      56.841 115.801  10.293  1.00 26.53           C  \\nATOM   6663  CG  MET A 120      56.733 116.726   9.093  1.00 26.53           C  \\nATOM   6664  SD  MET A 120      56.342 118.427   9.514  1.00 26.53           S  \\nATOM   6665  CE  MET A 120      57.586 119.235   8.455  1.00 26.53           C  \\nATOM   6666  N   PRO A 121      56.719 113.392  12.072  1.00 25.85           N  \\nATOM   6667  CA  PRO A 121      56.009 112.364  12.828  1.00 25.85           C  \\nATOM   6668  C   PRO A 121      54.567 112.168  12.332  1.00 25.85           C  \\nATOM   6669  O   PRO A 121      54.118 111.022  12.197  1.00 25.85           O  \\nATOM   6670  CB  PRO A 121      56.054 112.918  14.251  1.00 45.14           C  \\nATOM   6671  CG  PRO A 121      57.362 113.631  14.274  1.00 45.14           C  \\nATOM   6672  CD  PRO A 121      57.317 114.382  12.988  1.00 45.14           C  \\nATOM   6673  N   LYS A 122      53.863 113.276  12.042  1.00 23.23           N  \\nATOM   6674  CA  LYS A 122      52.483 113.225  11.539  1.00 23.23           C  \\nATOM   6675  C   LYS A 122      52.385 112.195  10.409  1.00 23.23           C  \\nATOM   6676  O   LYS A 122      51.424 111.432  10.337  1.00 23.23           O  \\nATOM   6677  CB  LYS A 122      52.041 114.529  10.877  1.00 44.36           C  \\nATOM   6678  CG  LYS A 122      52.497 115.860  11.389  1.00 44.36           C  \\nATOM   6679  CD  LYS A 122      52.104 116.852  10.284  1.00 44.36           C  \\nATOM   6680  CE  LYS A 122      52.160 118.314  10.703  1.00 44.36           C  \\nATOM   6681  NZ  LYS A 122      51.937 119.212   9.501  1.00 44.36           N  \\nATOM   6682  N   ASP A 123      53.350 112.250   9.488  1.00 16.39           N  \\nATOM   6683  CA  ASP A 123      53.404 111.356   8.350  1.00 16.39           C  \\nATOM   6684  C   ASP A 123      53.564 109.909   8.760  1.00 16.39           C  \\nATOM   6685  O   ASP A 123      52.856 109.057   8.241  1.00 16.39           O  \\nATOM   6686  CB  ASP A 123      54.515 111.779   7.414  1.00 34.42           C  \\nATOM   6687  CG  ASP A 123      54.382 113.220   6.992  1.00 34.42           C  \\nATOM   6688  OD1 ASP A 123      53.390 113.570   6.342  1.00 34.42           O  \\nATOM   6689  OD2 ASP A 123      55.246 114.030   7.319  1.00 34.42           O  \\nATOM   6690  N   ILE A 124      54.467 109.593   9.682  1.00 20.35           N  \\nATOM   6691  CA  ILE A 124      54.573 108.190  10.090  1.00 20.35           C  \\nATOM   6692  C   ILE A 124      53.247 107.747  10.719  1.00 20.35           C  \\nATOM   6693  O   ILE A 124      52.676 106.744  10.321  1.00 20.35           O  \\nATOM   6694  CB  ILE A 124      55.729 107.918  11.079  1.00 32.31           C  \\nATOM   6695  CG1 ILE A 124      57.068 107.944  10.350  1.00 32.31           C  \\nATOM   6696  CG2 ILE A 124      55.584 106.531  11.714  1.00 32.31           C  \\nATOM   6697  CD1 ILE A 124      58.243 107.789  11.298  1.00 32.31           C  \\nATOM   6698  N   GLN A 125      52.721 108.552  11.636  1.00 29.36           N  \\nATOM   6699  CA  GLN A 125      51.467 108.257  12.332  1.00 29.36           C  \\nATOM   6700  C   GLN A 125      50.283 107.986  11.427  1.00 29.36           C  \\nATOM   6701  O   GLN A 125      49.596 106.991  11.593  1.00 29.36           O  \\nATOM   6702  CB  GLN A 125      51.145 109.393  13.277  1.00 45.90           C  \\nATOM   6703  CG  GLN A 125      52.205 109.564  14.331  1.00 45.90           C  \\nATOM   6704  CD  GLN A 125      52.073 110.856  15.066  1.00 45.90           C  \\nATOM   6705  OE1 GLN A 125      51.162 111.642  14.805  1.00 45.90           O  \\nATOM   6706  NE2 GLN A 125      52.993 111.104  15.985  1.00 45.90           N  \\nATOM   6707  N   LEU A 126      50.037 108.878  10.478  1.00 11.90           N  \\nATOM   6708  CA  LEU A 126      48.952 108.713   9.533  1.00 11.90           C  \\nATOM   6709  C   LEU A 126      49.120 107.358   8.852  1.00 11.90           C  \\nATOM   6710  O   LEU A 126      48.228 106.509   8.916  1.00 11.90           O  \\nATOM   6711  CB  LEU A 126      48.974 109.838   8.481  1.00  5.00           C  \\nATOM   6712  CG  LEU A 126      47.983 109.707   7.310  1.00  5.00           C  \\nATOM   6713  CD1 LEU A 126      46.577 109.841   7.865  1.00  5.00           C  \\nATOM   6714  CD2 LEU A 126      48.220 110.709   6.177  1.00  5.00           C  \\nATOM   6715  N   ALA A 127      50.285 107.135   8.244  1.00 16.60           N  \\nATOM   6716  CA  ALA A 127      50.547 105.879   7.559  1.00 16.60           C  \\nATOM   6717  C   ALA A 127      50.285 104.672   8.476  1.00 16.60           C  \\nATOM   6718  O   ALA A 127      49.551 103.778   8.121  1.00 16.60           O  \\nATOM   6719  CB  ALA A 127      51.947 105.873   7.005  1.00  5.00           C  \\nATOM   6720  N   ARG A 128      50.810 104.664   9.684  1.00 17.84           N  \\nATOM   6721  CA  ARG A 128      50.522 103.548  10.557  1.00 17.84           C  \\nATOM   6722  C   ARG A 128      49.009 103.394  10.791  1.00 17.84           C  \\nATOM   6723  O   ARG A 128      48.510 102.275  10.813  1.00 17.84           O  \\nATOM   6724  CB  ARG A 128      51.301 103.659  11.867  1.00 21.08           C  \\nATOM   6725  CG  ARG A 128      52.791 103.404  11.676  1.00 21.08           C  \\nATOM   6726  CD  ARG A 128      53.514 103.273  12.986  1.00 21.08           C  \\nATOM   6727  NE  ARG A 128      53.180 102.051  13.708  1.00 21.08           N  \\nATOM   6728  CZ  ARG A 128      52.955 102.003  15.021  1.00 21.08           C  \\nATOM   6729  NH1 ARG A 128      53.015 103.106  15.752  1.00 21.08           N  \\nATOM   6730  NH2 ARG A 128      52.742 100.846  15.633  1.00 21.08           N  \\nATOM   6731  N   ARG A 129      48.269 104.498  10.938  1.00 18.14           N  \\nATOM   6732  CA  ARG A 129      46.806 104.425  11.115  1.00 18.14           C  \\nATOM   6733  C   ARG A 129      46.124 103.710   9.942  1.00 18.14           C  \\nATOM   6734  O   ARG A 129      45.473 102.684  10.106  1.00 18.14           O  \\nATOM   6735  CB  ARG A 129      46.218 105.815  11.275  1.00126.87           C  \\nATOM   6736  CG  ARG A 129      46.757 106.506  12.478  1.00126.87           C  \\nATOM   6737  CD  ARG A 129      46.477 107.976  12.433  1.00126.87           C  \\nATOM   6738  NE  ARG A 129      47.159 108.662  13.524  1.00126.87           N  \\nATOM   6739  CZ  ARG A 129      46.633 109.663  14.220  1.00126.87           C  \\nATOM   6740  NH1 ARG A 129      45.410 110.104  13.940  1.00126.87           N  \\nATOM   6741  NH2 ARG A 129      47.333 110.218  15.200  1.00126.87           N  \\nATOM   6742  N   ILE A 130      46.348 104.213   8.741  1.00 20.19           N  \\nATOM   6743  CA  ILE A 130      45.743 103.630   7.566  1.00 20.19           C  \\nATOM   6744  C   ILE A 130      46.187 102.187   7.341  1.00 20.19           C  \\nATOM   6745  O   ILE A 130      45.417 101.372   6.837  1.00 20.19           O  \\nATOM   6746  CB  ILE A 130      46.015 104.517   6.354  1.00 12.22           C  \\nATOM   6747  CG1 ILE A 130      45.465 105.905   6.641  1.00 12.22           C  \\nATOM   6748  CG2 ILE A 130      45.333 103.976   5.082  1.00 12.22           C  \\nATOM   6749  CD1 ILE A 130      45.771 106.859   5.532  1.00 12.22           C  \\nATOM   6750  N   ARG A 131      47.426 101.884   7.720  1.00 30.25           N  \\nATOM   6751  CA  ARG A 131      48.001 100.546   7.606  1.00 30.25           C  \\nATOM   6752  C   ARG A 131      47.337  99.534   8.540  1.00 30.25           C  \\nATOM   6753  O   ARG A 131      47.445  98.320   8.339  1.00 30.25           O  \\nATOM   6754  CB  ARG A 131      49.478 100.604   7.943  1.00 24.89           C  \\nATOM   6755  CG  ARG A 131      50.382 100.895   6.776  1.00 24.89           C  \\nATOM   6756  CD  ARG A 131      51.806 100.801   7.287  1.00 24.89           C  \\nATOM   6757  NE  ARG A 131      52.837 100.745   6.255  1.00 24.89           N  \\nATOM   6758  CZ  ARG A 131      53.976 100.079   6.390  1.00 24.89           C  \\nATOM   6759  NH1 ARG A 131      54.228  99.387   7.503  1.00 24.89           N  \\nATOM   6760  NH2 ARG A 131      54.887 100.154   5.428  1.00 24.89           N  \\nATOM   6761  N   GLY A 132      46.710 100.046   9.595  1.00 24.85           N  \\nATOM   6762  CA  GLY A 132      46.026  99.202  10.547  1.00 24.85           C  \\nATOM   6763  C   GLY A 132      46.820  98.915  11.799  1.00 24.85           C  \\nATOM   6764  O   GLY A 132      46.341  98.218  12.685  1.00 24.85           O  \\nATOM   6765  N   GLU A 133      47.983  99.534  11.942  1.00 48.90           N  \\nATOM   6766  CA  GLU A 133      48.834  99.284  13.099  1.00 48.90           C  \\nATOM   6767  C   GLU A 133      48.501 100.218  14.263  1.00 48.90           C  \\nATOM   6768  O   GLU A 133      48.916  99.986  15.406  1.00 48.90           O  \\nATOM   6769  CB  GLU A 133      50.305  99.426  12.684  1.00 38.49           C  \\nATOM   6770  CG  GLU A 133      50.688  98.567  11.457  1.00 38.49           C  \\nATOM   6771  CD  GLU A 133      52.002  98.970  10.798  1.00 38.49           C  \\nATOM   6772  OE1 GLU A 133      52.811  99.660  11.456  1.00 38.49           O  \\nATOM   6773  OE2 GLU A 133      52.228  98.594   9.619  1.00 38.49           O  \\nATOM   6774  N   ARG A 134      47.720 101.255  13.967  1.00106.93           N  \\nATOM   6775  CA  ARG A 134      47.310 102.250  14.958  1.00106.93           C  \\nATOM   6776  C   ARG A 134      45.788 102.448  14.960  1.00106.93           C  \\nATOM   6777  O   ARG A 134      45.195 102.723  16.005  1.00106.93           O  \\nATOM   6778  CB  ARG A 134      47.977 103.589  14.643  1.00104.85           C  \\nATOM   6779  CG  ARG A 134      48.931 104.111  15.684  1.00104.85           C  \\nATOM   6780  CD  ARG A 134      49.533 105.415  15.184  1.00104.85           C  \\nATOM   6781  NE  ARG A 134      50.582 105.925  16.064  1.00104.85           N  \\nATOM   6782  CZ  ARG A 134      51.814 106.237  15.665  1.00104.85           C  \\nATOM   6783  NH1 ARG A 134      52.166 106.086  14.392  1.00104.85           N  \\nATOM   6784  NH2 ARG A 134      52.694 106.703  16.545  1.00104.85           N  \\nATOM   6785  N   ALA A 135      45.172 102.353  13.781  1.00111.01           N  \\nATOM   6786  CA  ALA A 135      43.726 102.533  13.643  1.00111.01           C  \\nATOM   6787  C   ALA A 135      43.000 101.199  13.511  1.00111.01           C  \\nATOM   6788  O   ALA A 135      42.049 100.971  14.289  1.00155.71           O  \\nATOM   6789  CB  ALA A 135      43.406 103.441  12.440  1.00155.71           C  \\nATOM   6790  OXT ALA A 135      43.390 100.394  12.636  1.00155.71           O  \\nTER    6791      ALA A 135                                                      \\nATOM   6792  N   LYS B  20      80.171 110.516  27.125  1.00137.95           N  \\nATOM   6793  CA  LYS B  20      79.905 109.494  26.071  1.00137.95           C  \\nATOM   6794  C   LYS B  20      80.444 108.117  26.468  1.00137.95           C  \\nATOM   6795  O   LYS B  20      81.617 107.807  26.233  1.00137.95           O  \\nATOM   6796  CB  LYS B  20      80.510 109.936  24.728  1.00111.72           C  \\nATOM   6797  CG  LYS B  20      80.126 109.033  23.557  1.00111.72           C  \\nATOM   6798  CD  LYS B  20      80.729 109.479  22.227  1.00111.72           C  \\nATOM   6799  CE  LYS B  20      80.265 108.553  21.103  1.00111.72           C  \\nATOM   6800  NZ  LYS B  20      80.860 108.887  19.779  1.00111.72           N  \\nATOM   6801  N   VAL B  21      79.581 107.315  27.092  1.00162.32           N  \\nATOM   6802  CA  VAL B  21      79.910 105.954  27.537  1.00162.32           C  \\nATOM   6803  C   VAL B  21      78.655 105.162  27.958  1.00162.32           C  \\nATOM   6804  O   VAL B  21      78.349 104.110  27.391  1.00162.32           O  \\nATOM   6805  CB  VAL B  21      80.951 105.934  28.727  1.00139.26           C  \\nATOM   6806  CG1 VAL B  21      82.392 105.831  28.199  1.00139.26           C  \\nATOM   6807  CG2 VAL B  21      80.789 107.171  29.626  1.00139.26           C  \\nATOM   6808  N   LEU B  22      77.914 105.716  28.915  1.00115.40           N  \\nATOM   6809  CA  LEU B  22      76.700 105.112  29.484  1.00115.40           C  \\nATOM   6810  C   LEU B  22      75.513 105.173  28.520  1.00115.40           C  \\nATOM   6811  O   LEU B  22      74.654 106.050  28.627  1.00115.40           O  \\nATOM   6812  CB  LEU B  22      76.348 105.836  30.789  1.00120.13           C  \\nATOM   6813  CG  LEU B  22      77.491 106.656  31.412  1.00120.13           C  \\nATOM   6814  CD1 LEU B  22      76.950 107.641  32.434  1.00120.13           C  \\nATOM   6815  CD2 LEU B  22      78.560 105.737  32.010  1.00120.13           C  \\nATOM   6816  N   ARG B  23      75.442 104.192  27.626  1.00124.86           N  \\nATOM   6817  CA  ARG B  23      74.400 104.128  26.604  1.00124.86           C  \\nATOM   6818  C   ARG B  23      73.157 103.291  26.877  1.00124.86           C  \\nATOM   6819  O   ARG B  23      73.131 102.439  27.772  1.00124.86           O  \\nATOM   6820  CB  ARG B  23      75.012 103.636  25.294  1.00 93.82           C  \\nATOM   6821  CG  ARG B  23      75.344 104.713  24.290  1.00 93.82           C  \\nATOM   6822  CD  ARG B  23      76.230 104.123  23.201  1.00 93.82           C  \\nATOM   6823  NE  ARG B  23      76.000 104.727  21.890  1.00 93.82           N  \\nATOM   6824  CZ  ARG B  23      75.390 104.112  20.880  1.00 93.82           C  \\nATOM   6825  NH1 ARG B  23      74.944 102.873  21.033  1.00 93.82           N  \\nATOM   6826  NH2 ARG B  23      75.233 104.726  19.714  1.00 93.82           N  \\nATOM   6827  N   ASP B  24      72.135 103.564  26.064  1.00 60.17           N  \\nATOM   6828  CA  ASP B  24      70.857 102.856  26.086  1.00 60.17           C  \\nATOM   6829  C   ASP B  24      70.813 102.156  24.726  1.00 60.17           C  \\nATOM   6830  O   ASP B  24      71.234 102.726  23.714  1.00 60.17           O  \\nATOM   6831  CB  ASP B  24      69.684 103.825  26.234  1.00104.31           C  \\nATOM   6832  CG  ASP B  24      68.462 103.160  26.842  1.00104.31           C  \\nATOM   6833  OD1 ASP B  24      67.962 102.163  26.263  1.00104.31           O  \\nATOM   6834  OD2 ASP B  24      68.020 103.627  27.915  1.00104.31           O  \\nATOM   6835  N   ASN B  25      70.277 100.941  24.699  1.00 36.20           N  \\nATOM   6836  CA  ASN B  25      70.252 100.125  23.484  1.00 36.20           C  \\nATOM   6837  C   ASN B  25      69.468 100.569  22.263  1.00 36.20           C  \\nATOM   6838  O   ASN B  25      69.966 100.458  21.132  1.00 36.20           O  \\nATOM   6839  CB  ASN B  25      69.927  98.692  23.858  1.00 39.32           C  \\nATOM   6840  CG  ASN B  25      70.992  98.104  24.734  1.00 39.32           C  \\nATOM   6841  OD1 ASN B  25      72.177  98.299  24.477  1.00 39.32           O  \\nATOM   6842  ND2 ASN B  25      70.593  97.473  25.819  1.00 39.32           N  \\nATOM   6843  N   ILE B  26      68.251 101.061  22.487  1.00 44.14           N  \\nATOM   6844  CA  ILE B  26      67.417 101.554  21.396  1.00 44.14           C  \\nATOM   6845  C   ILE B  26      68.086 102.812  20.808  1.00 44.14           C  \\nATOM   6846  O   ILE B  26      67.937 103.123  19.623  1.00 44.14           O  \\nATOM   6847  CB  ILE B  26      66.018 101.884  21.899  1.00 31.25           C  \\nATOM   6848  CG1 ILE B  26      65.107 102.257  20.721  1.00 31.25           C  \\nATOM   6849  CG2 ILE B  26      66.094 103.000  22.918  1.00 31.25           C  \\nATOM   6850  CD1 ILE B  26      64.767 101.108  19.773  1.00 31.25           C  \\nATOM   6851  N   GLN B  27      68.839 103.513  21.657  1.00 29.81           N  \\nATOM   6852  CA  GLN B  27      69.592 104.700  21.259  1.00 29.81           C  \\nATOM   6853  C   GLN B  27      70.782 104.249  20.424  1.00 29.81           C  \\nATOM   6854  O   GLN B  27      71.458 105.066  19.791  1.00 29.81           O  \\nATOM   6855  CB  GLN B  27      70.076 105.480  22.484  1.00 41.60           C  \\nATOM   6856  CG  GLN B  27      68.965 106.173  23.281  1.00 41.60           C  \\nATOM   6857  CD  GLN B  27      68.082 107.054  22.415  1.00 41.60           C  \\nATOM   6858  OE1 GLN B  27      68.558 107.714  21.489  1.00 41.60           O  \\nATOM   6859  NE2 GLN B  27      66.782 107.055  22.705  1.00 41.60           N  \\nATOM   6860  N   GLY B  28      70.993 102.930  20.418  1.00 42.84           N  \\nATOM   6861  CA  GLY B  28      72.063 102.298  19.662  1.00 42.84           C  \\nATOM   6862  C   GLY B  28      71.750 102.309  18.184  1.00 42.84           C  \\nATOM   6863  O   GLY B  28      72.652 102.178  17.343  1.00 42.84           O  \\nATOM   6864  N   ILE B  29      70.455 102.415  17.875  1.00 35.71           N  \\nATOM   6865  CA  ILE B  29      69.985 102.496  16.496  1.00 35.71           C  \\nATOM   6866  C   ILE B  29      70.164 103.984  16.226  1.00 35.71           C  \\nATOM   6867  O   ILE B  29      69.310 104.790  16.593  1.00 35.71           O  \\nATOM   6868  CB  ILE B  29      68.503 102.157  16.396  1.00 22.51           C  \\nATOM   6869  CG1 ILE B  29      68.168 100.924  17.249  1.00 22.51           C  \\nATOM   6870  CG2 ILE B  29      68.128 101.970  14.937  1.00 22.51           C  \\nATOM   6871  CD1 ILE B  29      68.853  99.664  16.833  1.00 22.51           C  \\nATOM   6872  N   THR B  30      71.317 104.329  15.653  1.00 52.84           N  \\nATOM   6873  CA  THR B  30      71.717 105.717  15.407  1.00 52.84           C  \\nATOM   6874  C   THR B  30      71.069 106.513  14.298  1.00 52.84           C  \\nATOM   6875  O   THR B  30      70.551 105.960  13.331  1.00 52.84           O  \\nATOM   6876  CB  THR B  30      73.260 105.824  15.223  1.00 31.69           C  \\nATOM   6877  OG1 THR B  30      73.671 105.148  14.019  1.00 31.69           O  \\nATOM   6878  CG2 THR B  30      73.976 105.225  16.426  1.00 31.69           C  \\nATOM   6879  N   LYS B  31      71.161 107.835  14.432  1.00 37.51           N  \\nATOM   6880  CA  LYS B  31      70.625 108.758  13.438  1.00 37.51           C  \\nATOM   6881  C   LYS B  31      71.101 108.478  11.996  1.00 37.51           C  \\nATOM   6882  O   LYS B  31      70.289 108.419  11.089  1.00 37.51           O  \\nATOM   6883  CB  LYS B  31      70.915 110.208  13.837  1.00 34.80           C  \\nATOM   6884  CG  LYS B  31      70.790 111.199  12.693  1.00 34.80           C  \\nATOM   6885  CD  LYS B  31      70.947 112.619  13.184  1.00 34.80           C  \\nATOM   6886  CE  LYS B  31      70.822 113.626  12.050  1.00 34.80           C  \\nATOM   6887  NZ  LYS B  31      70.754 115.012  12.597  1.00 34.80           N  \\nATOM   6888  N   PRO B  32      72.416 108.322  11.760  1.00 28.54           N  \\nATOM   6889  CA  PRO B  32      72.841 108.047  10.372  1.00 28.54           C  \\nATOM   6890  C   PRO B  32      72.289 106.727   9.819  1.00 28.54           C  \\nATOM   6891  O   PRO B  32      72.054 106.599   8.610  1.00 28.54           O  \\nATOM   6892  CB  PRO B  32      74.362 108.033  10.470  1.00 36.76           C  \\nATOM   6893  CG  PRO B  32      74.607 107.677  11.932  1.00 36.76           C  \\nATOM   6894  CD  PRO B  32      73.579 108.481  12.645  1.00 36.76           C  \\nATOM   6895  N   ALA B  33      72.090 105.742  10.703  1.00 34.01           N  \\nATOM   6896  CA  ALA B  33      71.519 104.449  10.293  1.00 34.01           C  \\nATOM   6897  C   ALA B  33      70.071 104.665   9.870  1.00 34.01           C  \\nATOM   6898  O   ALA B  33      69.651 104.267   8.784  1.00 34.01           O  \\nATOM   6899  CB  ALA B  33      71.587 103.458  11.424  1.00 25.17           C  \\nATOM   6900  N   ILE B  34      69.307 105.300  10.746  1.00 22.01           N  \\nATOM   6901  CA  ILE B  34      67.922 105.609  10.431  1.00 22.01           C  \\nATOM   6902  C   ILE B  34      67.889 106.473   9.162  1.00 22.01           C  \\nATOM   6903  O   ILE B  34      67.036 106.294   8.296  1.00 22.01           O  \\nATOM   6904  CB  ILE B  34      67.250 106.379  11.567  1.00  5.92           C  \\nATOM   6905  CG1 ILE B  34      67.182 105.524  12.837  1.00  5.92           C  \\nATOM   6906  CG2 ILE B  34      65.891 106.853  11.130  1.00  5.92           C  \\nATOM   6907  CD1 ILE B  34      66.586 106.268  14.007  1.00  5.92           C  \\nATOM   6908  N   ARG B  35      68.818 107.411   9.055  1.00 34.93           N  \\nATOM   6909  CA  ARG B  35      68.886 108.259   7.886  1.00 34.93           C  \\nATOM   6910  C   ARG B  35      69.086 107.368   6.651  1.00 34.93           C  \\nATOM   6911  O   ARG B  35      68.404 107.555   5.645  1.00 34.93           O  \\nATOM   6912  CB  ARG B  35      70.005 109.286   8.041  1.00 68.42           C  \\nATOM   6913  CG  ARG B  35      70.243 110.156   6.824  1.00 68.42           C  \\nATOM   6914  CD  ARG B  35      71.082 111.360   7.183  1.00 68.42           C  \\nATOM   6915  NE  ARG B  35      70.347 112.253   8.079  1.00 68.42           N  \\nATOM   6916  CZ  ARG B  35      70.034 113.521   7.802  1.00 68.42           C  \\nATOM   6917  NH1 ARG B  35      70.397 114.072   6.644  1.00 68.42           N  \\nATOM   6918  NH2 ARG B  35      69.269 114.211   8.644  1.00 68.42           N  \\nATOM   6919  N   ARG B  36      69.988 106.382   6.720  1.00 22.76           N  \\nATOM   6920  CA  ARG B  36      70.202 105.475   5.582  1.00 22.76           C  \\nATOM   6921  C   ARG B  36      68.918 104.723   5.183  1.00 22.76           C  \\nATOM   6922  O   ARG B  36      68.590 104.594   3.999  1.00 22.76           O  \\nATOM   6923  CB  ARG B  36      71.318 104.475   5.890  1.00 30.75           C  \\nATOM   6924  CG  ARG B  36      72.718 105.055   5.849  1.00 30.75           C  \\nATOM   6925  CD  ARG B  36      73.766 103.942   5.817  1.00 30.75           C  \\nATOM   6926  NE  ARG B  36      73.912 103.277   7.109  1.00 30.75           N  \\nATOM   6927  CZ  ARG B  36      74.522 103.820   8.161  1.00 30.75           C  \\nATOM   6928  NH1 ARG B  36      75.051 105.045   8.080  1.00 30.75           N  \\nATOM   6929  NH2 ARG B  36      74.554 103.153   9.310  1.00 30.75           N  \\nATOM   6930  N   LEU B  37      68.197 104.216   6.180  1.00 28.37           N  \\nATOM   6931  CA  LEU B  37      66.941 103.513   5.942  1.00 28.37           C  \\nATOM   6932  C   LEU B  37      65.999 104.396   5.132  1.00 28.37           C  \\nATOM   6933  O   LEU B  37      65.594 104.043   4.025  1.00 28.37           O  \\nATOM   6934  CB  LEU B  37      66.324 103.120   7.274  1.00 10.93           C  \\nATOM   6935  CG  LEU B  37      67.060 101.872   7.770  1.00 10.93           C  \\nATOM   6936  CD1 LEU B  37      66.720 101.557   9.201  1.00 10.93           C  \\nATOM   6937  CD2 LEU B  37      66.745 100.678   6.848  1.00 10.93           C  \\nATOM   6938  N   ALA B  38      65.739 105.590   5.660  1.00 25.13           N  \\nATOM   6939  CA  ALA B  38      64.887 106.589   5.007  1.00 25.13           C  \\nATOM   6940  C   ALA B  38      65.253 106.804   3.536  1.00 25.13           C  \\nATOM   6941  O   ALA B  38      64.386 106.880   2.680  1.00 25.13           O  \\nATOM   6942  CB  ALA B  38      64.983 107.908   5.759  1.00  5.00           C  \\nATOM   6943  N   ARG B  39      66.543 106.949   3.261  1.00 25.01           N  \\nATOM   6944  CA  ARG B  39      67.024 107.160   1.905  1.00 25.01           C  \\nATOM   6945  C   ARG B  39      66.643 106.028   0.969  1.00 25.01           C  \\nATOM   6946  O   ARG B  39      66.250 106.276  -0.171  1.00 25.01           O  \\nATOM   6947  CB  ARG B  39      68.533 107.382   1.902  1.00 29.79           C  \\nATOM   6948  CG  ARG B  39      68.978 108.655   2.623  1.00 29.79           C  \\nATOM   6949  CD  ARG B  39      68.987 109.881   1.702  1.00 29.79           C  \\nATOM   6950  NE  ARG B  39      69.561 111.047   2.371  1.00 29.79           N  \\nATOM   6951  CZ  ARG B  39      68.889 111.836   3.205  1.00 29.79           C  \\nATOM   6952  NH1 ARG B  39      67.618 111.597   3.477  1.00 29.79           N  \\nATOM   6953  NH2 ARG B  39      69.470 112.890   3.760  1.00 29.79           N  \\nATOM   6954  N   ARG B  40      66.784 104.788   1.431  1.00 33.70           N  \\nATOM   6955  CA  ARG B  40      66.414 103.627   0.617  1.00 33.70           C  \\nATOM   6956  C   ARG B  40      64.901 103.713   0.342  1.00 33.70           C  \\nATOM   6957  O   ARG B  40      64.403 103.225  -0.692  1.00 33.70           O  \\nATOM   6958  CB  ARG B  40      66.771 102.347   1.359  1.00 29.79           C  \\nATOM   6959  CG  ARG B  40      66.703 101.105   0.506  1.00 29.79           C  \\nATOM   6960  CD  ARG B  40      67.395  99.919   1.171  1.00 29.79           C  \\nATOM   6961  NE  ARG B  40      68.771  99.710   0.702  1.00 29.79           N  \\nATOM   6962  CZ  ARG B  40      69.690  99.009   1.362  1.00 29.79           C  \\nATOM   6963  NH1 ARG B  40      69.396  98.442   2.528  1.00 29.79           N  \\nATOM   6964  NH2 ARG B  40      70.914  98.884   0.875  1.00 29.79           N  \\nATOM   6965  N   GLY B  41      64.186 104.331   1.295  1.00 32.71           N  \\nATOM   6966  CA  GLY B  41      62.751 104.561   1.177  1.00 32.71           C  \\nATOM   6967  C   GLY B  41      62.411 105.751   0.271  1.00 32.71           C  \\nATOM   6968  O   GLY B  41      61.245 106.030   0.008  1.00 32.71           O  \\nATOM   6969  N   GLY B  42      63.432 106.466  -0.193  1.00 16.73           N  \\nATOM   6970  CA  GLY B  42      63.225 107.594  -1.079  1.00 16.73           C  \\nATOM   6971  C   GLY B  42      62.995 108.965  -0.455  1.00 16.73           C  \\nATOM   6972  O   GLY B  42      62.558 109.886  -1.163  1.00 16.73           O  \\nATOM   6973  N   VAL B  43      63.252 109.094   0.848  1.00 31.31           N  \\nATOM   6974  CA  VAL B  43      63.087 110.356   1.583  1.00 31.31           C  \\nATOM   6975  C   VAL B  43      64.279 111.304   1.325  1.00 31.31           C  \\nATOM   6976  O   VAL B  43      65.435 110.878   1.389  1.00 31.31           O  \\nATOM   6977  CB  VAL B  43      62.971 110.069   3.091  1.00 13.12           C  \\nATOM   6978  CG1 VAL B  43      62.828 111.336   3.870  1.00 13.12           C  \\nATOM   6979  CG2 VAL B  43      61.820 109.122   3.356  1.00 13.12           C  \\nATOM   6980  N   LYS B  44      63.991 112.584   1.066  1.00 29.43           N  \\nATOM   6981  CA  LYS B  44      65.025 113.577   0.772  1.00 29.43           C  \\nATOM   6982  C   LYS B  44      65.387 114.507   1.935  1.00 29.43           C  \\nATOM   6983  O   LYS B  44      66.563 114.812   2.161  1.00 29.43           O  \\nATOM   6984  CB  LYS B  44      64.603 114.408  -0.430  1.00 46.92           C  \\nATOM   6985  CG  LYS B  44      65.566 115.527  -0.802  1.00 46.92           C  \\nATOM   6986  CD  LYS B  44      65.024 116.340  -1.969  1.00 46.92           C  \\nATOM   6987  CE  LYS B  44      66.026 117.355  -2.471  1.00 46.92           C  \\nATOM   6988  NZ  LYS B  44      65.510 117.996  -3.716  1.00 46.92           N  \\nATOM   6989  N   ARG B  45      64.376 115.013   2.631  1.00 21.86           N  \\nATOM   6990  CA  ARG B  45      64.581 115.907   3.767  1.00 21.86           C  \\nATOM   6991  C   ARG B  45      63.868 115.232   4.956  1.00 21.86           C  \\nATOM   6992  O   ARG B  45      62.769 114.676   4.791  1.00 21.86           O  \\nATOM   6993  CB  ARG B  45      63.992 117.281   3.430  1.00 42.28           C  \\nATOM   6994  CG  ARG B  45      64.574 118.432   4.212  1.00 42.28           C  \\nATOM   6995  CD  ARG B  45      64.265 119.772   3.551  1.00 42.28           C  \\nATOM   6996  NE  ARG B  45      64.981 120.864   4.202  1.00 42.28           N  \\nATOM   6997  CZ  ARG B  45      64.555 121.508   5.288  1.00 42.28           C  \\nATOM   6998  NH1 ARG B  45      63.395 121.188   5.857  1.00 42.28           N  \\nATOM   6999  NH2 ARG B  45      65.308 122.473   5.819  1.00 42.28           N  \\nATOM   7000  N   ILE B  46      64.498 115.264   6.139  1.00 27.20           N  \\nATOM   7001  CA  ILE B  46      63.963 114.618   7.343  1.00 27.20           C  \\nATOM   7002  C   ILE B  46      63.875 115.494   8.599  1.00 27.20           C  \\nATOM   7003  O   ILE B  46      64.889 115.959   9.104  1.00 27.20           O  \\nATOM   7004  CB  ILE B  46      64.843 113.399   7.686  1.00  9.84           C  \\nATOM   7005  CG1 ILE B  46      64.863 112.408   6.507  1.00  9.84           C  \\nATOM   7006  CG2 ILE B  46      64.385 112.737   8.983  1.00  9.84           C  \\nATOM   7007  CD1 ILE B  46      65.955 111.332   6.607  1.00  9.84           C  \\nATOM   7008  N   SER B  47      62.672 115.634   9.149  1.00 29.26           N  \\nATOM   7009  CA  SER B  47      62.447 116.414  10.370  1.00 29.26           C  \\nATOM   7010  C   SER B  47      63.256 115.864  11.547  1.00 29.26           C  \\nATOM   7011  O   SER B  47      63.369 114.642  11.731  1.00 29.26           O  \\nATOM   7012  CB  SER B  47      60.950 116.429  10.741  1.00 27.36           C  \\nATOM   7013  OG  SER B  47      60.729 116.713  12.125  1.00 27.36           O  \\nATOM   7014  N   GLY B  48      63.719 116.777  12.397  1.00 30.03           N  \\nATOM   7015  CA  GLY B  48      64.512 116.391  13.542  1.00 30.03           C  \\nATOM   7016  C   GLY B  48      63.854 115.398  14.468  1.00 30.03           C  \\nATOM   7017  O   GLY B  48      64.535 114.623  15.133  1.00 30.03           O  \\nATOM   7018  N   LEU B  49      62.529 115.343  14.447  1.00 29.92           N  \\nATOM   7019  CA  LEU B  49      61.804 114.445  15.346  1.00 29.92           C  \\nATOM   7020  C   LEU B  49      61.573 113.013  14.872  1.00 29.92           C  \\nATOM   7021  O   LEU B  49      61.085 112.157  15.636  1.00 29.92           O  \\nATOM   7022  CB  LEU B  49      60.488 115.092  15.725  1.00 35.14           C  \\nATOM   7023  CG  LEU B  49      60.790 116.405  16.426  1.00 35.14           C  \\nATOM   7024  CD1 LEU B  49      59.529 117.216  16.550  1.00 35.14           C  \\nATOM   7025  CD2 LEU B  49      61.433 116.104  17.780  1.00 35.14           C  \\nATOM   7026  N   ILE B  50      61.986 112.735  13.639  1.00 23.59           N  \\nATOM   7027  CA  ILE B  50      61.813 111.406  13.065  1.00 23.59           C  \\nATOM   7028  C   ILE B  50      62.586 110.280  13.755  1.00 23.59           C  \\nATOM   7029  O   ILE B  50      62.085 109.176  13.864  1.00 23.59           O  \\nATOM   7030  CB  ILE B  50      62.134 111.415  11.558  1.00 14.73           C  \\nATOM   7031  CG1 ILE B  50      60.996 112.108  10.786  1.00 14.73           C  \\nATOM   7032  CG2 ILE B  50      62.443 110.004  11.062  1.00 14.73           C  \\nATOM   7033  CD1 ILE B  50      59.628 111.408  10.854  1.00 14.73           C  \\nATOM   7034  N   TYR B  51      63.754 110.588  14.306  1.00 29.80           N  \\nATOM   7035  CA  TYR B  51      64.575 109.560  14.943  1.00 29.80           C  \\nATOM   7036  C   TYR B  51      63.931 108.930  16.151  1.00 29.80           C  \\nATOM   7037  O   TYR B  51      63.844 107.707  16.239  1.00 29.80           O  \\nATOM   7038  CB  TYR B  51      65.976 110.098  15.235  1.00 22.15           C  \\nATOM   7039  CG  TYR B  51      66.520 110.820  14.015  1.00 22.15           C  \\nATOM   7040  CD1 TYR B  51      67.014 110.117  12.899  1.00 22.15           C  \\nATOM   7041  CD2 TYR B  51      66.411 112.203  13.919  1.00 22.15           C  \\nATOM   7042  CE1 TYR B  51      67.368 110.802  11.725  1.00 22.15           C  \\nATOM   7043  CE2 TYR B  51      66.756 112.876  12.763  1.00 22.15           C  \\nATOM   7044  CZ  TYR B  51      67.226 112.189  11.679  1.00 22.15           C  \\nATOM   7045  OH  TYR B  51      67.510 112.931  10.557  1.00 22.15           O  \\nATOM   7046  N   GLU B  52      63.401 109.754  17.044  1.00 40.91           N  \\nATOM   7047  CA  GLU B  52      62.755 109.203  18.216  1.00 40.91           C  \\nATOM   7048  C   GLU B  52      61.502 108.490  17.786  1.00 40.91           C  \\nATOM   7049  O   GLU B  52      61.246 107.369  18.211  1.00 40.91           O  \\nATOM   7050  CB  GLU B  52      62.463 110.279  19.254  1.00 53.48           C  \\nATOM   7051  CG  GLU B  52      63.634 110.504  20.187  1.00 53.48           C  \\nATOM   7052  CD  GLU B  52      63.944 109.282  21.055  1.00 53.48           C  \\nATOM   7053  OE1 GLU B  52      63.297 109.154  22.120  1.00 53.48           O  \\nATOM   7054  OE2 GLU B  52      64.826 108.463  20.688  1.00 53.48           O  \\nATOM   7055  N   GLU B  53      60.769 109.098  16.866  1.00 29.91           N  \\nATOM   7056  CA  GLU B  53      59.546 108.482  16.381  1.00 29.91           C  \\nATOM   7057  C   GLU B  53      59.858 107.080  15.824  1.00 29.91           C  \\nATOM   7058  O   GLU B  53      59.257 106.092  16.251  1.00 29.91           O  \\nATOM   7059  CB  GLU B  53      58.880 109.399  15.330  1.00 36.25           C  \\nATOM   7060  CG  GLU B  53      57.416 109.082  14.965  1.00 36.25           C  \\nATOM   7061  CD  GLU B  53      56.444 109.147  16.148  1.00 36.25           C  \\nATOM   7062  OE1 GLU B  53      56.681 109.930  17.098  1.00 36.25           O  \\nATOM   7063  OE2 GLU B  53      55.432 108.404  16.131  1.00 36.25           O  \\nATOM   7064  N   THR B  54      60.869 106.998  14.959  1.00 20.76           N  \\nATOM   7065  CA  THR B  54      61.287 105.743  14.323  1.00 20.76           C  \\nATOM   7066  C   THR B  54      61.722 104.692  15.344  1.00 20.76           C  \\nATOM   7067  O   THR B  54      61.387 103.506  15.222  1.00 20.76           O  \\nATOM   7068  CB  THR B  54      62.455 105.960  13.305  1.00 14.31           C  \\nATOM   7069  OG1 THR B  54      62.197 107.109  12.488  1.00 14.31           O  \\nATOM   7070  CG2 THR B  54      62.611 104.757  12.394  1.00 14.31           C  \\nATOM   7071  N   ARG B  55      62.493 105.107  16.340  1.00 34.75           N  \\nATOM   7072  CA  ARG B  55      62.934 104.160  17.356  1.00 34.75           C  \\nATOM   7073  C   ARG B  55      61.735 103.506  18.023  1.00 34.75           C  \\nATOM   7074  O   ARG B  55      61.721 102.313  18.242  1.00 34.75           O  \\nATOM   7075  CB  ARG B  55      63.848 104.834  18.378  1.00 28.55           C  \\nATOM   7076  CG  ARG B  55      65.198 105.211  17.800  1.00 28.55           C  \\nATOM   7077  CD  ARG B  55      66.259 105.507  18.873  1.00 28.55           C  \\nATOM   7078  NE  ARG B  55      67.406 106.105  18.205  1.00 28.55           N  \\nATOM   7079  CZ  ARG B  55      67.628 107.410  18.127  1.00 28.55           C  \\nATOM   7080  NH1 ARG B  55      66.821 108.272  18.724  1.00 28.55           N  \\nATOM   7081  NH2 ARG B  55      68.516 107.856  17.255  1.00 28.55           N  \\nATOM   7082  N   GLY B  56      60.687 104.279  18.245  1.00 17.78           N  \\nATOM   7083  CA  GLY B  56      59.494 103.740  18.868  1.00 17.78           C  \\nATOM   7084  C   GLY B  56      58.750 102.740  18.014  1.00 17.78           C  \\nATOM   7085  O   GLY B  56      58.153 101.787  18.529  1.00 17.78           O  \\nATOM   7086  N   VAL B  57      58.718 103.003  16.714  1.00 32.52           N  \\nATOM   7087  CA  VAL B  57      58.072 102.106  15.769  1.00 32.52           C  \\nATOM   7088  C   VAL B  57      58.850 100.798  15.798  1.00 32.52           C  \\nATOM   7089  O   VAL B  57      58.267  99.726  15.933  1.00 32.52           O  \\nATOM   7090  CB  VAL B  57      58.140 102.665  14.318  1.00 16.43           C  \\nATOM   7091  CG1 VAL B  57      57.605 101.651  13.316  1.00 16.43           C  \\nATOM   7092  CG2 VAL B  57      57.381 103.949  14.207  1.00 16.43           C  \\nATOM   7093  N   LEU B  58      60.175 100.898  15.701  1.00 25.14           N  \\nATOM   7094  CA  LEU B  58      61.013  99.708  15.686  1.00 25.14           C  \\nATOM   7095  C   LEU B  58      60.870  98.870  16.929  1.00 25.14           C  \\nATOM   7096  O   LEU B  58      60.908  97.652  16.856  1.00 25.14           O  \\nATOM   7097  CB  LEU B  58      62.476 100.060  15.451  1.00 22.90           C  \\nATOM   7098  CG  LEU B  58      63.386  98.837  15.269  1.00 22.90           C  \\nATOM   7099  CD1 LEU B  58      62.875  97.913  14.185  1.00 22.90           C  \\nATOM   7100  CD2 LEU B  58      64.765  99.327  14.924  1.00 22.90           C  \\nATOM   7101  N   LYS B  59      60.741  99.522  18.071  1.00 29.02           N  \\nATOM   7102  CA  LYS B  59      60.554  98.813  19.320  1.00 29.02           C  \\nATOM   7103  C   LYS B  59      59.249  98.003  19.273  1.00 29.02           C  \\nATOM   7104  O   LYS B  59      59.257  96.816  19.606  1.00 29.02           O  \\nATOM   7105  CB  LYS B  59      60.528  99.786  20.487  1.00 44.35           C  \\nATOM   7106  CG  LYS B  59      60.800  99.130  21.810  1.00 44.35           C  \\nATOM   7107  CD  LYS B  59      60.772 100.146  22.928  1.00 44.35           C  \\nATOM   7108  CE  LYS B  59      61.110  99.511  24.259  1.00 44.35           C  \\nATOM   7109  NZ  LYS B  59      60.348 100.179  25.343  1.00 44.35           N  \\nATOM   7110  N   VAL B  60      58.140  98.622  18.842  1.00 17.05           N  \\nATOM   7111  CA  VAL B  60      56.859  97.914  18.739  1.00 17.05           C  \\nATOM   7112  C   VAL B  60      57.024  96.765  17.750  1.00 17.05           C  \\nATOM   7113  O   VAL B  60      56.601  95.647  18.029  1.00 17.05           O  \\nATOM   7114  CB  VAL B  60      55.715  98.849  18.306  1.00 26.72           C  \\nATOM   7115  CG1 VAL B  60      54.497  98.057  17.933  1.00 26.72           C  \\nATOM   7116  CG2 VAL B  60      55.358  99.798  19.432  1.00 26.72           C  \\nATOM   7117  N   PHE B  61      57.697  97.012  16.630  1.00 17.06           N  \\nATOM   7118  CA  PHE B  61      57.922  95.946  15.665  1.00 17.06           C  \\nATOM   7119  C   PHE B  61      58.606  94.750  16.333  1.00 17.06           C  \\nATOM   7120  O   PHE B  61      58.029  93.655  16.411  1.00 17.06           O  \\nATOM   7121  CB  PHE B  61      58.767  96.415  14.467  1.00 14.75           C  \\nATOM   7122  CG  PHE B  61      58.818  95.398  13.327  1.00 14.75           C  \\nATOM   7123  CD1 PHE B  61      57.808  95.358  12.362  1.00 14.75           C  \\nATOM   7124  CD2 PHE B  61      59.823  94.424  13.275  1.00 14.75           C  \\nATOM   7125  CE1 PHE B  61      57.793  94.364  11.373  1.00 14.75           C  \\nATOM   7126  CE2 PHE B  61      59.809  93.422  12.282  1.00 14.75           C  \\nATOM   7127  CZ  PHE B  61      58.795  93.395  11.335  1.00 14.75           C  \\nATOM   7128  N   LEU B  62      59.810  94.970  16.854  1.00 15.90           N  \\nATOM   7129  CA  LEU B  62      60.567  93.913  17.507  1.00 15.90           C  \\nATOM   7130  C   LEU B  62      59.797  93.239  18.633  1.00 15.90           C  \\nATOM   7131  O   LEU B  62      59.708  92.017  18.639  1.00 15.90           O  \\nATOM   7132  CB  LEU B  62      61.924  94.438  17.979  1.00 21.23           C  \\nATOM   7133  CG  LEU B  62      62.823  94.861  16.805  1.00 21.23           C  \\nATOM   7134  CD1 LEU B  62      64.070  95.545  17.295  1.00 21.23           C  \\nATOM   7135  CD2 LEU B  62      63.180  93.659  15.959  1.00 21.23           C  \\nATOM   7136  N   GLU B  63      59.176  94.021  19.528  1.00  8.40           N  \\nATOM   7137  CA  GLU B  63      58.373  93.477  20.647  1.00  8.40           C  \\nATOM   7138  C   GLU B  63      57.364  92.463  20.146  1.00  8.40           C  \\nATOM   7139  O   GLU B  63      57.449  91.293  20.497  1.00  8.40           O  \\nATOM   7140  CB  GLU B  63      57.646  94.590  21.421  1.00 23.16           C  \\nATOM   7141  CG  GLU B  63      58.594  95.525  22.196  1.00 23.16           C  \\nATOM   7142  CD  GLU B  63      57.892  96.600  23.039  1.00 23.16           C  \\nATOM   7143  OE1 GLU B  63      56.671  96.783  22.863  1.00 23.16           O  \\nATOM   7144  OE2 GLU B  63      58.565  97.267  23.877  1.00 23.16           O  \\nATOM   7145  N   ASN B  64      56.495  92.877  19.230  1.00 23.87           N  \\nATOM   7146  CA  ASN B  64      55.478  91.974  18.684  1.00 23.87           C  \\nATOM   7147  C   ASN B  64      56.027  90.675  18.134  1.00 23.87           C  \\nATOM   7148  O   ASN B  64      55.586  89.592  18.543  1.00 23.87           O  \\nATOM   7149  CB  ASN B  64      54.650  92.647  17.591  1.00 41.03           C  \\nATOM   7150  CG  ASN B  64      53.732  93.712  18.131  1.00 41.03           C  \\nATOM   7151  OD1 ASN B  64      53.460  93.773  19.344  1.00 41.03           O  \\nATOM   7152  ND2 ASN B  64      53.249  94.570  17.237  1.00 41.03           N  \\nATOM   7153  N   VAL B  65      57.002  90.783  17.230  1.00 27.49           N  \\nATOM   7154  CA  VAL B  65      57.603  89.606  16.601  1.00 27.49           C  \\nATOM   7155  C   VAL B  65      58.312  88.685  17.600  1.00 27.49           C  \\nATOM   7156  O   VAL B  65      58.048  87.478  17.636  1.00 27.49           O  \\nATOM   7157  CB  VAL B  65      58.612  89.994  15.484  1.00 22.96           C  \\nATOM   7158  CG1 VAL B  65      58.901  88.804  14.597  1.00 22.96           C  \\nATOM   7159  CG2 VAL B  65      58.076  91.109  14.647  1.00 22.96           C  \\nATOM   7160  N   ILE B  66      59.179  89.259  18.435  1.00 24.75           N  \\nATOM   7161  CA  ILE B  66      59.942  88.477  19.408  1.00 24.75           C  \\nATOM   7162  C   ILE B  66      59.034  87.793  20.393  1.00 24.75           C  \\nATOM   7163  O   ILE B  66      59.297  86.661  20.761  1.00 24.75           O  \\nATOM   7164  CB  ILE B  66      61.018  89.324  20.165  1.00 16.46           C  \\nATOM   7165  CG1 ILE B  66      62.037  89.888  19.153  1.00 16.46           C  \\nATOM   7166  CG2 ILE B  66      61.699  88.466  21.254  1.00 16.46           C  \\nATOM   7167  CD1 ILE B  66      62.985  90.952  19.690  1.00 16.46           C  \\nATOM   7168  N   ARG B  67      57.962  88.469  20.803  1.00 28.78           N  \\nATOM   7169  CA  ARG B  67      57.026  87.868  21.736  1.00 28.78           C  \\nATOM   7170  C   ARG B  67      56.569  86.534  21.183  1.00 28.78           C  \\nATOM   7171  O   ARG B  67      56.581  85.535  21.892  1.00 28.78           O  \\nATOM   7172  CB  ARG B  67      55.814  88.746  21.973  1.00 53.98           C  \\nATOM   7173  CG  ARG B  67      54.950  88.200  23.090  1.00 53.98           C  \\nATOM   7174  CD  ARG B  67      53.636  88.935  23.235  1.00 53.98           C  \\nATOM   7175  NE  ARG B  67      53.826  90.378  23.333  1.00 53.98           N  \\nATOM   7176  CZ  ARG B  67      53.553  91.229  22.345  1.00 53.98           C  \\nATOM   7177  NH1 ARG B  67      53.065  90.775  21.184  1.00 53.98           N  \\nATOM   7178  NH2 ARG B  67      53.814  92.528  22.493  1.00 53.98           N  \\nATOM   7179  N   ASP B  68      56.177  86.520  19.913  1.00 22.59           N  \\nATOM   7180  CA  ASP B  68      55.732  85.289  19.280  1.00 22.59           C  \\nATOM   7181  C   ASP B  68      56.876  84.281  19.113  1.00 22.59           C  \\nATOM   7182  O   ASP B  68      56.723  83.101  19.459  1.00 22.59           O  \\nATOM   7183  CB  ASP B  68      55.059  85.579  17.941  1.00 22.38           C  \\nATOM   7184  CG  ASP B  68      53.685  86.217  18.093  1.00 22.38           C  \\nATOM   7185  OD1 ASP B  68      53.308  86.668  19.209  1.00 22.38           O  \\nATOM   7186  OD2 ASP B  68      52.974  86.267  17.071  1.00 22.38           O  \\nATOM   7187  N   ALA B  69      58.017  84.737  18.588  1.00 15.96           N  \\nATOM   7188  CA  ALA B  69      59.188  83.867  18.416  1.00 15.96           C  \\nATOM   7189  C   ALA B  69      59.514  83.172  19.749  1.00 15.96           C  \\nATOM   7190  O   ALA B  69      59.477  81.957  19.854  1.00 15.96           O  \\nATOM   7191  CB  ALA B  69      60.383  84.672  17.933  1.00 37.17           C  \\nATOM   7192  N   VAL B  70      59.764  83.947  20.790  1.00 21.46           N  \\nATOM   7193  CA  VAL B  70      60.044  83.359  22.087  1.00 21.46           C  \\nATOM   7194  C   VAL B  70      58.926  82.399  22.544  1.00 21.46           C  \\nATOM   7195  O   VAL B  70      59.217  81.382  23.160  1.00 21.46           O  \\nATOM   7196  CB  VAL B  70      60.328  84.438  23.137  1.00 11.71           C  \\nATOM   7197  CG1 VAL B  70      60.367  83.838  24.509  1.00 11.71           C  \\nATOM   7198  CG2 VAL B  70      61.657  85.093  22.843  1.00 11.71           C  \\nATOM   7199  N   THR B  71      57.665  82.702  22.224  1.00 15.44           N  \\nATOM   7200  CA  THR B  71      56.544  81.818  22.563  1.00 15.44           C  \\nATOM   7201  C   THR B  71      56.740  80.497  21.844  1.00 15.44           C  \\nATOM   7202  O   THR B  71      56.430  79.439  22.373  1.00 15.44           O  \\nATOM   7203  CB  THR B  71      55.173  82.429  22.181  1.00 25.57           C  \\nATOM   7204  OG1 THR B  71      54.472  82.761  23.377  1.00 25.57           O  \\nATOM   7205  CG2 THR B  71      54.308  81.452  21.401  1.00 25.57           C  \\nATOM   7206  N   TYR B  72      57.209  80.552  20.609  1.00 15.76           N  \\nATOM   7207  CA  TYR B  72      57.456  79.321  19.894  1.00 15.76           C  \\nATOM   7208  C   TYR B  72      58.634  78.624  20.558  1.00 15.76           C  \\nATOM   7209  O   TYR B  72      58.596  77.425  20.766  1.00 15.76           O  \\nATOM   7210  CB  TYR B  72      57.777  79.606  18.447  1.00 18.40           C  \\nATOM   7211  CG  TYR B  72      56.575  79.863  17.561  1.00 18.40           C  \\nATOM   7212  CD1 TYR B  72      55.608  78.881  17.375  1.00 18.40           C  \\nATOM   7213  CD2 TYR B  72      56.465  81.046  16.825  1.00 18.40           C  \\nATOM   7214  CE1 TYR B  72      54.568  79.061  16.469  1.00 18.40           C  \\nATOM   7215  CE2 TYR B  72      55.432  81.240  15.919  1.00 18.40           C  \\nATOM   7216  CZ  TYR B  72      54.482  80.242  15.737  1.00 18.40           C  \\nATOM   7217  OH  TYR B  72      53.461  80.398  14.814  1.00 18.40           O  \\nATOM   7218  N   THR B  73      59.664  79.387  20.930  1.00 33.08           N  \\nATOM   7219  CA  THR B  73      60.843  78.820  21.582  1.00 33.08           C  \\nATOM   7220  C   THR B  73      60.419  78.034  22.796  1.00 33.08           C  \\nATOM   7221  O   THR B  73      60.690  76.846  22.875  1.00 33.08           O  \\nATOM   7222  CB  THR B  73      61.852  79.891  22.038  1.00  8.96           C  \\nATOM   7223  OG1 THR B  73      62.249  80.680  20.910  1.00  8.96           O  \\nATOM   7224  CG2 THR B  73      63.089  79.225  22.627  1.00  8.96           C  \\nATOM   7225  N   GLU B  74      59.735  78.699  23.722  1.00 26.40           N  \\nATOM   7226  CA  GLU B  74      59.271  78.073  24.958  1.00 26.40           C  \\nATOM   7227  C   GLU B  74      58.488  76.797  24.653  1.00 26.40           C  \\nATOM   7228  O   GLU B  74      58.776  75.736  25.190  1.00 26.40           O  \\nATOM   7229  CB  GLU B  74      58.389  79.033  25.780  1.00 92.82           C  \\nATOM   7230  CG  GLU B  74      59.125  80.055  26.668  1.00 92.82           C  \\nATOM   7231  CD  GLU B  74      58.166  80.946  27.481  1.00 92.82           C  \\nATOM   7232  OE1 GLU B  74      57.186  80.422  28.055  1.00 92.82           O  \\nATOM   7233  OE2 GLU B  74      58.386  82.176  27.550  1.00 92.82           O  \\nATOM   7234  N   HIS B  75      57.506  76.878  23.770  1.00 44.41           N  \\nATOM   7235  CA  HIS B  75      56.748  75.689  23.463  1.00 44.41           C  \\nATOM   7236  C   HIS B  75      57.640  74.546  22.999  1.00 44.41           C  \\nATOM   7237  O   HIS B  75      57.383  73.393  23.307  1.00 44.41           O  \\nATOM   7238  CB  HIS B  75      55.708  75.977  22.408  1.00 29.94           C  \\nATOM   7239  CG  HIS B  75      54.769  74.841  22.199  1.00 29.94           C  \\nATOM   7240  ND1 HIS B  75      54.937  73.916  21.196  1.00 29.94           N  \\nATOM   7241  CD2 HIS B  75      53.684  74.443  22.902  1.00 29.94           C  \\nATOM   7242  CE1 HIS B  75      53.997  72.994  21.286  1.00 29.94           C  \\nATOM   7243  NE2 HIS B  75      53.224  73.292  22.313  1.00 29.94           N  \\nATOM   7244  N   ALA B  76      58.671  74.869  22.231  1.00 44.71           N  \\nATOM   7245  CA  ALA B  76      59.604  73.871  21.726  1.00 44.71           C  \\nATOM   7246  C   ALA B  76      60.531  73.358  22.821  1.00 44.71           C  \\nATOM   7247  O   ALA B  76      61.466  72.603  22.542  1.00 44.71           O  \\nATOM   7248  CB  ALA B  76      60.420  74.455  20.593  1.00 15.73           C  \\nATOM   7249  N   LYS B  77      60.275  73.786  24.057  1.00 37.32           N  \\nATOM   7250  CA  LYS B  77      61.063  73.394  25.224  1.00 37.32           C  \\nATOM   7251  C   LYS B  77      62.540  73.807  25.095  1.00 37.32           C  \\nATOM   7252  O   LYS B  77      63.387  73.272  25.814  1.00 37.32           O  \\nATOM   7253  CB  LYS B  77      60.951  71.875  25.459  1.00 75.40           C  \\nATOM   7254  CG  LYS B  77      59.533  71.369  25.709  1.00 75.40           C  \\nATOM   7255  CD  LYS B  77      59.470  69.846  25.787  1.00 75.40           C  \\nATOM   7256  CE  LYS B  77      58.064  69.380  26.178  1.00 75.40           C  \\nATOM   7257  NZ  LYS B  77      57.974  67.913  26.429  1.00 75.40           N  \\nATOM   7258  N   ARG B  78      62.837  74.766  24.207  1.00 40.18           N  \\nATOM   7259  CA  ARG B  78      64.210  75.241  23.978  1.00 40.18           C  \\nATOM   7260  C   ARG B  78      64.592  76.501  24.744  1.00 40.18           C  \\nATOM   7261  O   ARG B  78      63.732  77.289  25.132  1.00 40.18           O  \\nATOM   7262  CB  ARG B  78      64.467  75.480  22.491  1.00 43.03           C  \\nATOM   7263  CG  ARG B  78      64.825  74.237  21.721  1.00 43.03           C  \\nATOM   7264  CD  ARG B  78      65.046  74.535  20.260  1.00 43.03           C  \\nATOM   7265  NE  ARG B  78      63.797  74.777  19.543  1.00 43.03           N  \\nATOM   7266  CZ  ARG B  78      63.254  75.981  19.372  1.00 43.03           C  \\nATOM   7267  NH1 ARG B  78      63.842  77.068  19.869  1.00 43.03           N  \\nATOM   7268  NH2 ARG B  78      62.125  76.110  18.692  1.00 43.03           N  \\nATOM   7269  N   LYS B  79      65.897  76.680  24.939  1.00 28.50           N  \\nATOM   7270  CA  LYS B  79      66.462  77.825  25.636  1.00 28.50           C  \\nATOM   7271  C   LYS B  79      67.177  78.727  24.611  1.00 28.50           C  \\nATOM   7272  O   LYS B  79      67.835  79.716  24.971  1.00 28.50           O  \\nATOM   7273  CB  LYS B  79      67.434  77.345  26.707  1.00 82.66           C  \\nATOM   7274  CG  LYS B  79      67.296  78.116  27.985  1.00 82.66           C  \\nATOM   7275  CD  LYS B  79      68.323  77.698  28.998  1.00 82.66           C  \\nATOM   7276  CE  LYS B  79      68.248  78.594  30.223  1.00 82.66           C  \\nATOM   7277  NZ  LYS B  79      69.389  78.339  31.140  1.00 82.66           N  \\nATOM   7278  N   THR B  80      66.982  78.413  23.325  1.00 28.17           N  \\nATOM   7279  CA  THR B  80      67.590  79.169  22.233  1.00 28.17           C  \\nATOM   7280  C   THR B  80      66.588  79.456  21.133  1.00 28.17           C  \\nATOM   7281  O   THR B  80      65.979  78.533  20.578  1.00 28.17           O  \\nATOM   7282  CB  THR B  80      68.749  78.394  21.582  1.00 46.58           C  \\nATOM   7283  OG1 THR B  80      69.734  78.062  22.570  1.00 46.58           O  \\nATOM   7284  CG2 THR B  80      69.394  79.238  20.482  1.00 46.58           C  \\nATOM   7285  N   VAL B  81      66.494  80.729  20.755  1.00 23.08           N  \\nATOM   7286  CA  VAL B  81      65.567  81.167  19.709  1.00 23.08           C  \\nATOM   7287  C   VAL B  81      66.102  80.830  18.315  1.00 23.08           C  \\nATOM   7288  O   VAL B  81      67.113  81.374  17.877  1.00 23.08           O  \\nATOM   7289  CB  VAL B  81      65.312  82.676  19.815  1.00 15.28           C  \\nATOM   7290  CG1 VAL B  81      64.297  83.113  18.782  1.00 15.28           C  \\nATOM   7291  CG2 VAL B  81      64.842  83.019  21.207  1.00 15.28           C  \\nATOM   7292  N   THR B  82      65.436  79.927  17.614  1.00 16.08           N  \\nATOM   7293  CA  THR B  82      65.915  79.558  16.289  1.00 16.08           C  \\nATOM   7294  C   THR B  82      65.401  80.465  15.195  1.00 16.08           C  \\nATOM   7295  O   THR B  82      64.405  81.138  15.372  1.00 16.08           O  \\nATOM   7296  CB  THR B  82      65.552  78.114  15.951  1.00 21.76           C  \\nATOM   7297  OG1 THR B  82      64.148  78.011  15.681  1.00 21.76           O  \\nATOM   7298  CG2 THR B  82      65.926  77.213  17.136  1.00 21.76           C  \\nATOM   7299  N   ALA B  83      66.090  80.487  14.059  1.00 27.09           N  \\nATOM   7300  CA  ALA B  83      65.659  81.304  12.937  1.00 27.09           C  \\nATOM   7301  C   ALA B  83      64.253  80.839  12.590  1.00 27.09           C  \\nATOM   7302  O   ALA B  83      63.407  81.644  12.246  1.00 27.09           O  \\nATOM   7303  CB  ALA B  83      66.572  81.110  11.764  1.00 33.80           C  \\nATOM   7304  N   MET B  84      63.991  79.540  12.749  1.00 10.33           N  \\nATOM   7305  CA  MET B  84      62.674  78.982  12.477  1.00 10.33           C  \\nATOM   7306  C   MET B  84      61.636  79.693  13.301  1.00 10.33           C  \\nATOM   7307  O   MET B  84      60.631  80.164  12.771  1.00 10.33           O  \\nATOM   7308  CB  MET B  84      62.648  77.499  12.787  1.00 52.77           C  \\nATOM   7309  CG  MET B  84      63.310  76.710  11.706  1.00 52.77           C  \\nATOM   7310  SD  MET B  84      62.752  77.371  10.127  1.00 52.77           S  \\nATOM   7311  CE  MET B  84      61.591  76.132   9.599  1.00 52.77           C  \\nATOM   7312  N   ASP B  85      61.899  79.821  14.595  1.00 18.96           N  \\nATOM   7313  CA  ASP B  85      60.954  80.496  15.481  1.00 18.96           C  \\nATOM   7314  C   ASP B  85      60.679  81.903  14.975  1.00 18.96           C  \\nATOM   7315  O   ASP B  85      59.540  82.324  14.945  1.00 18.96           O  \\nATOM   7316  CB  ASP B  85      61.448  80.532  16.940  1.00 24.55           C  \\nATOM   7317  CG  ASP B  85      61.768  79.146  17.504  1.00 24.55           C  \\nATOM   7318  OD1 ASP B  85      61.227  78.131  17.009  1.00 24.55           O  \\nATOM   7319  OD2 ASP B  85      62.579  79.070  18.448  1.00 24.55           O  \\nATOM   7320  N   VAL B  86      61.712  82.614  14.533  1.00 21.48           N  \\nATOM   7321  CA  VAL B  86      61.537  83.977  14.017  1.00 21.48           C  \\nATOM   7322  C   VAL B  86      60.691  84.021  12.743  1.00 21.48           C  \\nATOM   7323  O   VAL B  86      59.833  84.882  12.576  1.00 21.48           O  \\nATOM   7324  CB  VAL B  86      62.877  84.623  13.750  1.00 13.43           C  \\nATOM   7325  CG1 VAL B  86      62.693  85.964  13.089  1.00 13.43           C  \\nATOM   7326  CG2 VAL B  86      63.620  84.755  15.054  1.00 13.43           C  \\nATOM   7327  N   VAL B  87      60.942  83.076  11.851  1.00 17.90           N  \\nATOM   7328  CA  VAL B  87      60.209  82.961  10.604  1.00 17.90           C  \\nATOM   7329  C   VAL B  87      58.743  82.672  10.800  1.00 17.90           C  \\nATOM   7330  O   VAL B  87      57.907  83.282  10.148  1.00 17.90           O  \\nATOM   7331  CB  VAL B  87      60.789  81.864   9.742  1.00 17.42           C  \\nATOM   7332  CG1 VAL B  87      59.869  81.589   8.567  1.00 17.42           C  \\nATOM   7333  CG2 VAL B  87      62.172  82.292   9.255  1.00 17.42           C  \\nATOM   7334  N   TYR B  88      58.449  81.687  11.638  1.00 27.78           N  \\nATOM   7335  CA  TYR B  88      57.079  81.303  11.949  1.00 27.78           C  \\nATOM   7336  C   TYR B  88      56.315  82.495  12.533  1.00 27.78           C  \\nATOM   7337  O   TYR B  88      55.146  82.692  12.214  1.00 27.78           O  \\nATOM   7338  CB  TYR B  88      57.076  80.165  12.970  1.00 30.89           C  \\nATOM   7339  CG  TYR B  88      57.596  78.834  12.480  1.00 30.89           C  \\nATOM   7340  CD1 TYR B  88      57.437  78.447  11.156  1.00 30.89           C  \\nATOM   7341  CD2 TYR B  88      58.171  77.927  13.365  1.00 30.89           C  \\nATOM   7342  CE1 TYR B  88      57.818  77.194  10.721  1.00 30.89           C  \\nATOM   7343  CE2 TYR B  88      58.555  76.665  12.945  1.00 30.89           C  \\nATOM   7344  CZ  TYR B  88      58.365  76.303  11.618  1.00 30.89           C  \\nATOM   7345  OH  TYR B  88      58.637  75.019  11.198  1.00 30.89           O  \\nATOM   7346  N   ALA B  89      56.963  83.254  13.424  1.00 26.47           N  \\nATOM   7347  CA  ALA B  89      56.364  84.441  14.053  1.00 26.47           C  \\nATOM   7348  C   ALA B  89      56.050  85.501  13.009  1.00 26.47           C  \\nATOM   7349  O   ALA B  89      55.024  86.160  13.100  1.00 26.47           O  \\nATOM   7350  CB  ALA B  89      57.292  85.016  15.108  1.00 21.23           C  \\nATOM   7351  N   LEU B  90      56.973  85.717  12.073  1.00 15.46           N  \\nATOM   7352  CA  LEU B  90      56.758  86.666  11.001  1.00 15.46           C  \\nATOM   7353  C   LEU B  90      55.559  86.242  10.137  1.00 15.46           C  \\nATOM   7354  O   LEU B  90      54.677  87.059   9.852  1.00 15.46           O  \\nATOM   7355  CB  LEU B  90      58.021  86.816  10.148  1.00 18.59           C  \\nATOM   7356  CG  LEU B  90      59.194  87.607  10.765  1.00 18.59           C  \\nATOM   7357  CD1 LEU B  90      60.437  87.509   9.934  1.00 18.59           C  \\nATOM   7358  CD2 LEU B  90      58.823  89.056  10.924  1.00 18.59           C  \\nATOM   7359  N   LYS B  91      55.487  84.974   9.739  1.00 23.84           N  \\nATOM   7360  CA  LYS B  91      54.350  84.540   8.921  1.00 23.84           C  \\nATOM   7361  C   LYS B  91      53.018  84.895   9.567  1.00 23.84           C  \\nATOM   7362  O   LYS B  91      52.077  85.251   8.865  1.00 23.84           O  \\nATOM   7363  CB  LYS B  91      54.402  83.056   8.582  1.00 36.83           C  \\nATOM   7364  CG  LYS B  91      53.411  82.699   7.494  1.00 36.83           C  \\nATOM   7365  CD  LYS B  91      53.923  81.633   6.551  1.00 36.83           C  \\nATOM   7366  CE  LYS B  91      54.307  80.382   7.318  1.00 36.83           C  \\nATOM   7367  NZ  LYS B  91      55.274  79.488   6.582  1.00 36.83           N  \\nATOM   7368  N   ARG B  92      52.942  84.773  10.893  1.00 36.26           N  \\nATOM   7369  CA  ARG B  92      51.738  85.126  11.641  1.00 36.26           C  \\nATOM   7370  C   ARG B  92      51.522  86.618  11.621  1.00 36.26           C  \\nATOM   7371  O   ARG B  92      50.385  87.063  11.710  1.00 36.26           O  \\nATOM   7372  CB  ARG B  92      51.841  84.766  13.108  1.00 34.11           C  \\nATOM   7373  CG  ARG B  92      51.906  83.336  13.440  1.00 34.11           C  \\nATOM   7374  CD  ARG B  92      51.678  83.222  14.919  1.00 34.11           C  \\nATOM   7375  NE  ARG B  92      50.278  83.461  15.212  1.00 34.11           N  \\nATOM   7376  CZ  ARG B  92      49.804  84.524  15.843  1.00 34.11           C  \\nATOM   7377  NH1 ARG B  92      50.623  85.479  16.262  1.00 34.11           N  \\nATOM   7378  NH2 ARG B  92      48.497  84.631  16.038  1.00 34.11           N  \\nATOM   7379  N   GLN B  93      52.601  87.393  11.705  1.00 24.43           N  \\nATOM   7380  CA  GLN B  93      52.443  88.844  11.661  1.00 24.43           C  \\nATOM   7381  C   GLN B  93      51.985  89.228  10.253  1.00 24.43           C  \\nATOM   7382  O   GLN B  93      51.521  90.338  10.023  1.00 24.43           O  \\nATOM   7383  CB  GLN B  93      53.757  89.591  11.980  1.00 38.51           C  \\nATOM   7384  CG  GLN B  93      54.376  89.367  13.346  1.00 38.51           C  \\nATOM   7385  CD  GLN B  93      53.352  89.262  14.457  1.00 38.51           C  \\nATOM   7386  OE1 GLN B  93      52.666  90.223  14.793  1.00 38.51           O  \\nATOM   7387  NE2 GLN B  93      53.236  88.074  15.025  1.00 38.51           N  \\nATOM   7388  N   GLY B  94      52.122  88.302   9.313  1.00 18.83           N  \\nATOM   7389  CA  GLY B  94      51.752  88.587   7.943  1.00 18.83           C  \\nATOM   7390  C   GLY B  94      52.955  89.293   7.359  1.00 18.83           C  \\nATOM   7391  O   GLY B  94      52.830  90.139   6.472  1.00 18.83           O  \\nATOM   7392  N   ARG B  95      54.124  88.950   7.905  1.00 24.27           N  \\nATOM   7393  CA  ARG B  95      55.398  89.507   7.507  1.00 24.27           C  \\nATOM   7394  C   ARG B  95      56.306  88.490   6.851  1.00 24.27           C  \\nATOM   7395  O   ARG B  95      57.516  88.656   6.874  1.00 24.27           O  \\nATOM   7396  CB  ARG B  95      56.094  90.082   8.725  1.00 49.19           C  \\nATOM   7397  CG  ARG B  95      55.546  91.405   9.135  1.00 49.19           C  \\nATOM   7398  CD  ARG B  95      56.169  92.481   8.313  1.00 49.19           C  \\nATOM   7399  NE  ARG B  95      55.212  93.519   7.974  1.00 49.19           N  \\nATOM   7400  CZ  ARG B  95      54.460  94.186   8.853  1.00 49.19           C  \\nATOM   7401  NH1 ARG B  95      54.541  93.929  10.161  1.00 49.19           N  \\nATOM   7402  NH2 ARG B  95      53.616  95.126   8.414  1.00 49.19           N  \\nATOM   7403  N   THR B  96      55.720  87.472   6.232  1.00 34.74           N  \\nATOM   7404  CA  THR B  96      56.452  86.398   5.561  1.00 34.74           C  \\nATOM   7405  C   THR B  96      57.837  86.749   5.000  1.00 34.74           C  \\nATOM   7406  O   THR B  96      57.944  87.631   4.137  1.00 34.74           O  \\nATOM   7407  CB  THR B  96      55.595  85.820   4.423  1.00 21.96           C  \\nATOM   7408  OG1 THR B  96      54.549  85.025   4.979  1.00 21.96           O  \\nATOM   7409  CG2 THR B  96      56.435  84.969   3.444  1.00 21.96           C  \\nATOM   7410  N   LEU B  97      58.872  86.002   5.433  1.00 27.88           N  \\nATOM   7411  CA  LEU B  97      60.274  86.207   4.986  1.00 27.88           C  \\nATOM   7412  C   LEU B  97      60.949  85.026   4.250  1.00 27.88           C  \\nATOM   7413  O   LEU B  97      61.016  83.923   4.774  1.00 27.88           O  \\nATOM   7414  CB  LEU B  97      61.135  86.581   6.196  1.00 17.85           C  \\nATOM   7415  CG  LEU B  97      62.643  86.850   6.029  1.00 17.85           C  \\nATOM   7416  CD1 LEU B  97      62.883  88.183   5.316  1.00 17.85           C  \\nATOM   7417  CD2 LEU B  97      63.330  86.821   7.409  1.00 17.85           C  \\nATOM   7418  N   TYR B  98      61.516  85.267   3.072  1.00 27.30           N  \\nATOM   7419  CA  TYR B  98      62.186  84.181   2.349  1.00 27.30           C  \\nATOM   7420  C   TYR B  98      63.686  84.207   2.637  1.00 27.30           C  \\nATOM   7421  O   TYR B  98      64.284  85.279   2.739  1.00 27.30           O  \\nATOM   7422  CB  TYR B  98      61.989  84.292   0.831  1.00 18.12           C  \\nATOM   7423  CG  TYR B  98      60.620  83.934   0.273  1.00 18.12           C  \\nATOM   7424  CD1 TYR B  98      59.597  83.419   1.080  1.00 18.12           C  \\nATOM   7425  CD2 TYR B  98      60.350  84.126  -1.073  1.00 18.12           C  \\nATOM   7426  CE1 TYR B  98      58.339  83.105   0.549  1.00 18.12           C  \\nATOM   7427  CE2 TYR B  98      59.109  83.820  -1.612  1.00 18.12           C  \\nATOM   7428  CZ  TYR B  98      58.114  83.308  -0.802  1.00 18.12           C  \\nATOM   7429  OH  TYR B  98      56.919  82.975  -1.392  1.00 18.12           O  \\nATOM   7430  N   GLY B  99      64.293  83.027   2.755  1.00 24.18           N  \\nATOM   7431  CA  GLY B  99      65.723  82.947   2.996  1.00 24.18           C  \\nATOM   7432  C   GLY B  99      66.207  82.331   4.285  1.00 24.18           C  \\nATOM   7433  O   GLY B  99      67.404  82.160   4.487  1.00 24.18           O  \\nATOM   7434  N   PHE B 100      65.300  82.001   5.179  1.00 28.64           N  \\nATOM   7435  CA  PHE B 100      65.747  81.423   6.426  1.00 28.64           C  \\nATOM   7436  C   PHE B 100      65.023  80.113   6.752  1.00 28.64           C  \\nATOM   7437  O   PHE B 100      64.891  79.740   7.917  1.00 28.64           O  \\nATOM   7438  CB  PHE B 100      65.636  82.461   7.551  1.00 33.11           C  \\nATOM   7439  CG  PHE B 100      66.460  83.718   7.309  1.00 33.11           C  \\nATOM   7440  CD1 PHE B 100      65.998  84.731   6.475  1.00 33.11           C  \\nATOM   7441  CD2 PHE B 100      67.716  83.880   7.898  1.00 33.11           C  \\nATOM   7442  CE1 PHE B 100      66.780  85.882   6.230  1.00 33.11           C  \\nATOM   7443  CE2 PHE B 100      68.500  85.035   7.654  1.00 33.11           C  \\nATOM   7444  CZ  PHE B 100      68.027  86.026   6.822  1.00 33.11           C  \\nATOM   7445  N   GLY B 101      64.601  79.404   5.705  1.00102.38           N  \\nATOM   7446  CA  GLY B 101      63.911  78.138   5.881  1.00102.38           C  \\nATOM   7447  C   GLY B 101      62.921  77.813   4.772  1.00102.38           C  \\nATOM   7448  O   GLY B 101      63.289  77.679   3.596  1.00102.38           O  \\nATOM   7449  N   GLY B 102      61.655  77.668   5.160  1.00133.12           N  \\nATOM   7450  CA  GLY B 102      60.604  77.353   4.210  1.00133.12           C  \\nATOM   7451  C   GLY B 102      59.275  77.025   4.873  1.00133.12           C  \\nATOM   7452  O   GLY B 102      58.222  77.405   4.315  1.00129.84           O  \\nATOM   7453  OXT GLY B 102      59.275  76.385   5.948  1.00129.84           O  \\nTER    7454      GLY B 102                                                      \\nATOM   7455  N   GLY C   4      31.804  39.350  28.925  1.00123.40           N  \\nATOM   7456  CA  GLY C   4      32.039  40.417  29.944  1.00123.40           C  \\nATOM   7457  C   GLY C   4      31.229  41.687  29.725  1.00123.40           C  \\nATOM   7458  O   GLY C   4      31.620  42.760  30.194  1.00123.40           O  \\nATOM   7459  N   LYS C   5      30.097  41.569  29.027  1.00147.93           N  \\nATOM   7460  CA  LYS C   5      29.225  42.718  28.751  1.00147.93           C  \\nATOM   7461  C   LYS C   5      28.214  42.948  29.875  1.00147.93           C  \\nATOM   7462  O   LYS C   5      27.151  43.539  29.659  1.00147.93           O  \\nATOM   7463  CB  LYS C   5      28.484  42.547  27.414  1.00103.49           C  \\nATOM   7464  CG  LYS C   5      29.395  42.346  26.199  1.00103.49           C  \\nATOM   7465  CD  LYS C   5      30.268  43.559  25.924  1.00103.49           C  \\nATOM   7466  CE  LYS C   5      31.540  43.154  25.200  1.00103.49           C  \\nATOM   7467  NZ  LYS C   5      32.438  42.342  26.076  1.00103.49           N  \\nATOM   7468  N   GLN C   6      28.564  42.487  31.076  1.00150.26           N  \\nATOM   7469  CA  GLN C   6      27.715  42.646  32.254  1.00150.26           C  \\nATOM   7470  C   GLN C   6      27.709  44.115  32.702  1.00150.26           C  \\nATOM   7471  O   GLN C   6      26.865  44.523  33.504  1.00150.26           O  \\nATOM   7472  CB  GLN C   6      28.192  41.716  33.395  1.00114.92           C  \\nATOM   7473  CG  GLN C   6      29.133  42.331  34.471  1.00114.92           C  \\nATOM   7474  CD  GLN C   6      30.586  42.493  34.028  1.00114.92           C  \\nATOM   7475  OE1 GLN C   6      31.153  41.623  33.365  1.00114.92           O  \\nATOM   7476  NE2 GLN C   6      31.205  43.595  34.438  1.00114.92           N  \\nATOM   7477  N   GLY C   7      28.638  44.899  32.149  1.00160.45           N  \\nATOM   7478  CA  GLY C   7      28.758  46.311  32.482  1.00160.45           C  \\nATOM   7479  C   GLY C   7      27.754  47.264  31.849  1.00160.45           C  \\nATOM   7480  O   GLY C   7      27.507  48.341  32.398  1.00160.45           O  \\nATOM   7481  N   GLY C   8      27.188  46.892  30.699  1.00116.43           N  \\nATOM   7482  CA  GLY C   8      26.214  47.746  30.036  1.00116.43           C  \\nATOM   7483  C   GLY C   8      24.813  47.575  30.601  1.00116.43           C  \\nATOM   7484  O   GLY C   8      23.888  47.225  29.862  1.00116.43           O  \\nATOM   7485  N   LYS C   9      24.663  47.827  31.906  1.00164.89           N  \\nATOM   7486  CA  LYS C   9      23.382  47.699  32.614  1.00164.89           C  \\nATOM   7487  C   LYS C   9      23.210  48.645  33.829  1.00164.89           C  \\nATOM   7488  O   LYS C   9      23.826  49.715  33.878  1.00164.89           O  \\nATOM   7489  CB  LYS C   9      23.141  46.235  33.022  1.00101.49           C  \\nATOM   7490  CG  LYS C   9      22.698  45.323  31.872  1.00101.49           C  \\nATOM   7491  CD  LYS C   9      22.515  43.887  32.330  1.00101.49           C  \\nATOM   7492  CE  LYS C   9      22.051  42.995  31.194  1.00101.49           C  \\nATOM   7493  NZ  LYS C   9      21.907  41.591  31.665  1.00101.49           N  \\nATOM   7494  N   THR C  10      22.380  48.235  34.797  1.00200.00           N  \\nATOM   7495  CA  THR C  10      22.051  49.016  36.009  1.00200.00           C  \\nATOM   7496  C   THR C  10      23.173  49.645  36.852  1.00200.00           C  \\nATOM   7497  O   THR C  10      24.352  49.305  36.710  1.00200.00           O  \\nATOM   7498  CB  THR C  10      21.132  48.214  36.983  1.00117.52           C  \\nATOM   7499  OG1 THR C  10      21.803  47.022  37.408  1.00117.52           O  \\nATOM   7500  CG2 THR C  10      19.800  47.851  36.318  1.00117.52           C  \\nATOM   7501  N   ARG C  11      22.761  50.556  37.740  1.00190.26           N  \\nATOM   7502  CA  ARG C  11      23.634  51.295  38.664  1.00190.26           C  \\nATOM   7503  C   ARG C  11      24.693  52.218  38.029  1.00190.26           C  \\nATOM   7504  O   ARG C  11      25.054  52.055  36.858  1.00190.26           O  \\nATOM   7505  CB  ARG C  11      24.263  50.351  39.706  1.00136.27           C  \\nATOM   7506  CG  ARG C  11      23.264  49.788  40.719  1.00136.27           C  \\nATOM   7507  CD  ARG C  11      23.962  49.052  41.856  1.00136.27           C  \\nATOM   7508  NE  ARG C  11      23.006  48.549  42.841  1.00136.27           N  \\nATOM   7509  CZ  ARG C  11      23.014  48.863  44.136  1.00136.27           C  \\nATOM   7510  NH1 ARG C  11      23.932  49.687  44.628  1.00136.27           N  \\nATOM   7511  NH2 ARG C  11      22.095  48.355  44.943  1.00136.27           N  \\nATOM   7512  N   ALA C  12      25.156  53.196  38.818  1.00182.74           N  \\nATOM   7513  CA  ALA C  12      26.159  54.200  38.416  1.00182.74           C  \\nATOM   7514  C   ALA C  12      25.575  55.315  37.536  1.00182.74           C  \\nATOM   7515  O   ALA C  12      25.199  56.378  38.040  1.00182.74           O  \\nATOM   7516  CB  ALA C  12      27.373  53.535  37.725  1.00 59.54           C  \\nATOM   7517  N   LYS C  13      25.518  55.059  36.228  1.00160.17           N  \\nATOM   7518  CA  LYS C  13      24.982  55.982  35.218  1.00160.17           C  \\nATOM   7519  C   LYS C  13      25.815  57.219  34.829  1.00160.17           C  \\nATOM   7520  O   LYS C  13      26.339  57.944  35.681  1.00160.17           O  \\nATOM   7521  CB  LYS C  13      23.522  56.341  35.530  1.00117.36           C  \\nATOM   7522  CG  LYS C  13      22.558  55.135  35.428  1.00117.36           C  \\nATOM   7523  CD  LYS C  13      22.536  54.518  34.013  1.00117.36           C  \\nATOM   7524  CE  LYS C  13      21.549  53.352  33.888  1.00117.36           C  \\nATOM   7525  NZ  LYS C  13      21.404  52.918  32.470  1.00117.36           N  \\nATOM   7526  N   ALA C  14      25.886  57.437  33.513  1.00122.68           N  \\nATOM   7527  CA  ALA C  14      26.642  58.509  32.854  1.00122.68           C  \\nATOM   7528  C   ALA C  14      26.756  59.908  33.462  1.00122.68           C  \\nATOM   7529  O   ALA C  14      26.083  60.268  34.428  1.00122.68           O  \\nATOM   7530  CB  ALA C  14      26.207  58.618  31.383  1.00 51.52           C  \\nATOM   7531  N   LYS C  15      27.628  60.692  32.838  1.00 63.03           N  \\nATOM   7532  CA  LYS C  15      27.919  62.055  33.239  1.00 63.03           C  \\nATOM   7533  C   LYS C  15      28.709  62.687  32.091  1.00 63.03           C  \\nATOM   7534  O   LYS C  15      29.737  62.154  31.662  1.00 63.03           O  \\nATOM   7535  CB  LYS C  15      28.753  62.038  34.514  1.00 82.58           C  \\nATOM   7536  CG  LYS C  15      28.933  63.388  35.122  1.00 82.58           C  \\nATOM   7537  CD  LYS C  15      29.278  63.278  36.588  1.00 82.58           C  \\nATOM   7538  CE  LYS C  15      29.318  64.657  37.228  1.00 82.58           C  \\nATOM   7539  NZ  LYS C  15      29.686  64.630  38.673  1.00 82.58           N  \\nATOM   7540  N   THR C  16      28.214  63.805  31.574  1.00 36.52           N  \\nATOM   7541  CA  THR C  16      28.885  64.465  30.462  1.00 36.52           C  \\nATOM   7542  C   THR C  16      30.253  65.009  30.835  1.00 36.52           C  \\nATOM   7543  O   THR C  16      30.524  65.341  31.990  1.00 36.52           O  \\nATOM   7544  CB  THR C  16      28.063  65.628  29.863  1.00 36.53           C  \\nATOM   7545  OG1 THR C  16      27.672  66.530  30.910  1.00 36.53           O  \\nATOM   7546  CG2 THR C  16      26.853  65.110  29.087  1.00 36.53           C  \\nATOM   7547  N   ARG C  17      31.094  65.147  29.816  1.00 44.30           N  \\nATOM   7548  CA  ARG C  17      32.439  65.653  30.002  1.00 44.30           C  \\nATOM   7549  C   ARG C  17      32.444  67.141  30.314  1.00 44.30           C  \\nATOM   7550  O   ARG C  17      33.344  67.637  30.996  1.00 44.30           O  \\nATOM   7551  CB  ARG C  17      33.294  65.337  28.786  1.00 35.38           C  \\nATOM   7552  CG  ARG C  17      33.516  63.837  28.604  1.00 35.38           C  \\nATOM   7553  CD  ARG C  17      34.701  63.541  27.705  1.00 35.38           C  \\nATOM   7554  NE  ARG C  17      34.368  63.615  26.292  1.00 35.38           N  \\nATOM   7555  CZ  ARG C  17      35.242  63.931  25.346  1.00 35.38           C  \\nATOM   7556  NH1 ARG C  17      36.515  64.212  25.664  1.00 35.38           N  \\nATOM   7557  NH2 ARG C  17      34.849  63.898  24.078  1.00 35.38           N  \\nATOM   7558  N   SER C  18      31.425  67.859  29.844  1.00 27.18           N  \\nATOM   7559  CA  SER C  18      31.349  69.280  30.153  1.00 27.18           C  \\nATOM   7560  C   SER C  18      31.086  69.326  31.644  1.00 27.18           C  \\nATOM   7561  O   SER C  18      31.701  70.096  32.354  1.00 27.18           O  \\nATOM   7562  CB  SER C  18      30.236  69.946  29.366  1.00 24.08           C  \\nATOM   7563  OG  SER C  18      30.425  69.682  27.991  1.00 24.08           O  \\nATOM   7564  N   SER C  19      30.225  68.425  32.110  1.00 34.32           N  \\nATOM   7565  CA  SER C  19      29.887  68.304  33.523  1.00 34.32           C  \\nATOM   7566  C   SER C  19      31.161  68.104  34.372  1.00 34.32           C  \\nATOM   7567  O   SER C  19      31.388  68.791  35.388  1.00 34.32           O  \\nATOM   7568  CB  SER C  19      28.932  67.128  33.684  1.00 56.76           C  \\nATOM   7569  OG  SER C  19      28.762  66.800  35.038  1.00 56.76           O  \\nATOM   7570  N   ARG C  20      31.983  67.147  33.952  1.00 31.04           N  \\nATOM   7571  CA  ARG C  20      33.251  66.859  34.618  1.00 31.04           C  \\nATOM   7572  C   ARG C  20      34.190  68.082  34.622  1.00 31.04           C  \\nATOM   7573  O   ARG C  20      34.740  68.431  35.667  1.00 31.04           O  \\nATOM   7574  CB  ARG C  20      33.920  65.660  33.951  1.00 96.39           C  \\nATOM   7575  CG  ARG C  20      33.035  64.437  33.943  1.00 96.39           C  \\nATOM   7576  CD  ARG C  20      33.631  63.309  33.161  1.00 96.39           C  \\nATOM   7577  NE  ARG C  20      32.844  62.101  33.352  1.00 96.39           N  \\nATOM   7578  CZ  ARG C  20      33.136  60.929  32.803  1.00 96.39           C  \\nATOM   7579  NH1 ARG C  20      34.199  60.808  32.017  1.00 96.39           N  \\nATOM   7580  NH2 ARG C  20      32.386  59.869  33.067  1.00 96.39           N  \\nATOM   7581  N   ALA C  21      34.345  68.749  33.474  1.00 30.60           N  \\nATOM   7582  CA  ALA C  21      35.210  69.933  33.372  1.00 30.60           C  \\nATOM   7583  C   ALA C  21      34.711  71.144  34.161  1.00 30.60           C  \\nATOM   7584  O   ALA C  21      35.500  72.020  34.504  1.00 30.60           O  \\nATOM   7585  CB  ALA C  21      35.405  70.312  31.930  1.00 34.29           C  \\nATOM   7586  N   GLY C  22      33.396  71.195  34.398  1.00 32.80           N  \\nATOM   7587  CA  GLY C  22      32.760  72.278  35.137  1.00 32.80           C  \\nATOM   7588  C   GLY C  22      32.322  73.334  34.148  1.00 32.80           C  \\nATOM   7589  O   GLY C  22      32.238  74.523  34.471  1.00 32.80           O  \\nATOM   7590  N   LEU C  23      31.983  72.879  32.947  1.00 19.16           N  \\nATOM   7591  CA  LEU C  23      31.607  73.780  31.867  1.00 19.16           C  \\nATOM   7592  C   LEU C  23      30.188  73.712  31.293  1.00 19.16           C  \\nATOM   7593  O   LEU C  23      29.495  72.685  31.367  1.00 19.16           O  \\nATOM   7594  CB  LEU C  23      32.606  73.626  30.701  1.00 24.74           C  \\nATOM   7595  CG  LEU C  23      34.127  73.683  30.920  1.00 24.74           C  \\nATOM   7596  CD1 LEU C  23      34.841  73.463  29.592  1.00 24.74           C  \\nATOM   7597  CD2 LEU C  23      34.540  75.009  31.527  1.00 24.74           C  \\nATOM   7598  N   GLN C  24      29.795  74.829  30.680  1.00 26.26           N  \\nATOM   7599  CA  GLN C  24      28.504  74.963  30.032  1.00 26.26           C  \\nATOM   7600  C   GLN C  24      28.651  74.484  28.595  1.00 26.26           C  \\nATOM   7601  O   GLN C  24      27.807  73.742  28.118  1.00 26.26           O  \\nATOM   7602  CB  GLN C  24      28.015  76.419  30.047  1.00 20.89           C  \\nATOM   7603  CG  GLN C  24      27.845  77.066  31.445  1.00 20.89           C  \\nATOM   7604  CD  GLN C  24      26.904  76.296  32.341  1.00 20.89           C  \\nATOM   7605  OE1 GLN C  24      25.735  76.091  32.019  1.00 20.89           O  \\nATOM   7606  NE2 GLN C  24      27.423  75.840  33.465  1.00 20.89           N  \\nATOM   7607  N   PHE C  25      29.751  74.873  27.941  1.00 27.29           N  \\nATOM   7608  CA  PHE C  25      30.051  74.494  26.546  1.00 27.29           C  \\nATOM   7609  C   PHE C  25      30.239  72.972  26.357  1.00 27.29           C  \\nATOM   7610  O   PHE C  25      30.633  72.268  27.296  1.00 27.29           O  \\nATOM   7611  CB  PHE C  25      31.268  75.280  26.030  1.00 29.98           C  \\nATOM   7612  CG  PHE C  25      30.915  76.611  25.398  1.00 29.98           C  \\nATOM   7613  CD1 PHE C  25      29.913  77.423  25.944  1.00 29.98           C  \\nATOM   7614  CD2 PHE C  25      31.519  77.010  24.199  1.00 29.98           C  \\nATOM   7615  CE1 PHE C  25      29.508  78.611  25.301  1.00 29.98           C  \\nATOM   7616  CE2 PHE C  25      31.121  78.196  23.546  1.00 29.98           C  \\nATOM   7617  CZ  PHE C  25      30.108  78.993  24.100  1.00 29.98           C  \\nATOM   7618  N   PRO C  26      29.972  72.454  25.131  1.00 28.33           N  \\nATOM   7619  CA  PRO C  26      30.059  71.042  24.718  1.00 28.33           C  \\nATOM   7620  C   PRO C  26      31.433  70.441  24.493  1.00 28.33           C  \\nATOM   7621  O   PRO C  26      31.931  70.470  23.380  1.00 28.33           O  \\nATOM   7622  CB  PRO C  26      29.276  71.032  23.413  1.00 22.13           C  \\nATOM   7623  CG  PRO C  26      29.704  72.313  22.794  1.00 22.13           C  \\nATOM   7624  CD  PRO C  26      29.630  73.299  23.969  1.00 22.13           C  \\nATOM   7625  N   VAL C  27      32.008  69.825  25.523  1.00 19.54           N  \\nATOM   7626  CA  VAL C  27      33.321  69.207  25.404  1.00 19.54           C  \\nATOM   7627  C   VAL C  27      33.204  68.063  24.416  1.00 19.54           C  \\nATOM   7628  O   VAL C  27      34.077  67.872  23.564  1.00 19.54           O  \\nATOM   7629  CB  VAL C  27      33.780  68.676  26.741  1.00  9.81           C  \\nATOM   7630  CG1 VAL C  27      35.050  67.840  26.581  1.00  9.81           C  \\nATOM   7631  CG2 VAL C  27      33.996  69.835  27.689  1.00  9.81           C  \\nATOM   7632  N   GLY C  28      32.078  67.356  24.497  1.00 22.10           N  \\nATOM   7633  CA  GLY C  28      31.840  66.254  23.592  1.00 22.10           C  \\nATOM   7634  C   GLY C  28      31.932  66.750  22.162  1.00 22.10           C  \\nATOM   7635  O   GLY C  28      32.791  66.313  21.411  1.00 22.10           O  \\nATOM   7636  N   ARG C  29      31.092  67.722  21.813  1.00 26.79           N  \\nATOM   7637  CA  ARG C  29      31.053  68.295  20.458  1.00 26.79           C  \\nATOM   7638  C   ARG C  29      32.358  68.941  19.972  1.00 26.79           C  \\nATOM   7639  O   ARG C  29      32.737  68.807  18.816  1.00 26.79           O  \\nATOM   7640  CB  ARG C  29      29.892  69.299  20.352  1.00 40.02           C  \\nATOM   7641  CG  ARG C  29      30.024  70.288  19.216  1.00 40.02           C  \\nATOM   7642  CD  ARG C  29      28.866  70.225  18.281  1.00 40.02           C  \\nATOM   7643  NE  ARG C  29      27.783  71.144  18.615  1.00 40.02           N  \\nATOM   7644  CZ  ARG C  29      26.559  70.757  18.971  1.00 40.02           C  \\nATOM   7645  NH1 ARG C  29      26.252  69.465  19.063  1.00 40.02           N  \\nATOM   7646  NH2 ARG C  29      25.603  71.653  19.143  1.00 40.02           N  \\nATOM   7647  N   VAL C  30      33.011  69.693  20.843  1.00 26.10           N  \\nATOM   7648  CA  VAL C  30      34.259  70.344  20.506  1.00 26.10           C  \\nATOM   7649  C   VAL C  30      35.313  69.287  20.148  1.00 26.10           C  \\nATOM   7650  O   VAL C  30      35.898  69.359  19.076  1.00 26.10           O  \\nATOM   7651  CB  VAL C  30      34.720  71.263  21.670  1.00 12.73           C  \\nATOM   7652  CG1 VAL C  30      36.153  71.686  21.490  1.00 12.73           C  \\nATOM   7653  CG2 VAL C  30      33.828  72.494  21.755  1.00 12.73           C  \\nATOM   7654  N   HIS C  31      35.502  68.272  20.998  1.00 38.23           N  \\nATOM   7655  CA  HIS C  31      36.480  67.194  20.737  1.00 38.23           C  \\nATOM   7656  C   HIS C  31      36.212  66.595  19.369  1.00 38.23           C  \\nATOM   7657  O   HIS C  31      37.124  66.306  18.607  1.00 38.23           O  \\nATOM   7658  CB  HIS C  31      36.348  66.081  21.783  1.00 40.63           C  \\nATOM   7659  CG  HIS C  31      37.442  65.058  21.732  1.00 40.63           C  \\nATOM   7660  ND1 HIS C  31      38.716  65.344  21.290  1.00 40.63           N  \\nATOM   7661  CD2 HIS C  31      37.460  63.757  22.107  1.00 40.63           C  \\nATOM   7662  CE1 HIS C  31      39.473  64.267  21.399  1.00 40.63           C  \\nATOM   7663  NE2 HIS C  31      38.734  63.291  21.892  1.00 40.63           N  \\nATOM   7664  N   ARG C  32      34.935  66.400  19.086  1.00 53.53           N  \\nATOM   7665  CA  ARG C  32      34.487  65.851  17.824  1.00 53.53           C  \\nATOM   7666  C   ARG C  32      34.857  66.730  16.623  1.00 53.53           C  \\nATOM   7667  O   ARG C  32      35.311  66.222  15.593  1.00 53.53           O  \\nATOM   7668  CB  ARG C  32      32.977  65.653  17.887  1.00 39.79           C  \\nATOM   7669  CG  ARG C  32      32.419  64.860  16.745  1.00 39.79           C  \\nATOM   7670  CD  ARG C  32      30.921  64.815  16.821  1.00 39.79           C  \\nATOM   7671  NE  ARG C  32      30.301  65.818  15.961  1.00 39.79           N  \\nATOM   7672  CZ  ARG C  32      29.533  66.813  16.399  1.00 39.79           C  \\nATOM   7673  NH1 ARG C  32      29.293  66.975  17.694  1.00 39.79           N  \\nATOM   7674  NH2 ARG C  32      28.906  67.580  15.529  1.00 39.79           N  \\nATOM   7675  N   LEU C  33      34.624  68.039  16.736  1.00 52.46           N  \\nATOM   7676  CA  LEU C  33      34.943  68.980  15.658  1.00 52.46           C  \\nATOM   7677  C   LEU C  33      36.433  69.057  15.368  1.00 52.46           C  \\nATOM   7678  O   LEU C  33      36.833  69.390  14.250  1.00 52.46           O  \\nATOM   7679  CB  LEU C  33      34.416  70.374  15.973  1.00 21.73           C  \\nATOM   7680  CG  LEU C  33      32.901  70.513  16.055  1.00 21.73           C  \\nATOM   7681  CD1 LEU C  33      32.514  71.928  16.553  1.00 21.73           C  \\nATOM   7682  CD2 LEU C  33      32.283  70.206  14.699  1.00 21.73           C  \\nATOM   7683  N   LEU C  34      37.242  68.844  16.404  1.00 35.66           N  \\nATOM   7684  CA  LEU C  34      38.695  68.840  16.271  1.00 35.66           C  \\nATOM   7685  C   LEU C  34      39.181  67.689  15.370  1.00 35.66           C  \\nATOM   7686  O   LEU C  34      40.103  67.861  14.567  1.00 35.66           O  \\nATOM   7687  CB  LEU C  34      39.345  68.771  17.653  1.00  9.33           C  \\nATOM   7688  CG  LEU C  34      39.366  70.086  18.452  1.00  9.33           C  \\nATOM   7689  CD1 LEU C  34      40.000  69.908  19.832  1.00  9.33           C  \\nATOM   7690  CD2 LEU C  34      40.159  71.140  17.677  1.00  9.33           C  \\nATOM   7691  N   ARG C  35      38.576  66.515  15.522  1.00 52.98           N  \\nATOM   7692  CA  ARG C  35      38.928  65.370  14.698  1.00 52.98           C  \\nATOM   7693  C   ARG C  35      38.544  65.646  13.252  1.00 52.98           C  \\nATOM   7694  O   ARG C  35      39.406  65.663  12.368  1.00 52.98           O  \\nATOM   7695  CB  ARG C  35      38.191  64.117  15.160  1.00 48.67           C  \\nATOM   7696  CG  ARG C  35      38.459  63.726  16.581  1.00 48.67           C  \\nATOM   7697  CD  ARG C  35      37.649  62.513  16.958  1.00 48.67           C  \\nATOM   7698  NE  ARG C  35      37.898  62.116  18.339  1.00 48.67           N  \\nATOM   7699  CZ  ARG C  35      39.095  61.794  18.828  1.00 48.67           C  \\nATOM   7700  NH1 ARG C  35      40.180  61.818  18.049  1.00 48.67           N  \\nATOM   7701  NH2 ARG C  35      39.210  61.436  20.105  1.00 48.67           N  \\nATOM   7702  N   LYS C  36      37.267  65.953  13.027  1.00 33.81           N  \\nATOM   7703  CA  LYS C  36      36.766  66.191  11.668  1.00 33.81           C  \\nATOM   7704  C   LYS C  36      37.276  67.407  10.885  1.00 33.81           C  \\nATOM   7705  O   LYS C  36      36.921  67.588   9.713  1.00 33.81           O  \\nATOM   7706  CB  LYS C  36      35.237  66.109  11.653  1.00120.36           C  \\nATOM   7707  CG  LYS C  36      34.754  64.688  11.908  1.00120.36           C  \\nATOM   7708  CD  LYS C  36      33.267  64.600  12.176  1.00120.36           C  \\nATOM   7709  CE  LYS C  36      32.887  63.181  12.599  1.00120.36           C  \\nATOM   7710  NZ  LYS C  36      31.449  63.075  12.968  1.00120.36           N  \\nATOM   7711  N   GLY C  37      38.174  68.178  11.505  1.00 26.55           N  \\nATOM   7712  CA  GLY C  37      38.737  69.364  10.873  1.00 26.55           C  \\nATOM   7713  C   GLY C  37      40.157  69.162  10.389  1.00 26.55           C  \\nATOM   7714  O   GLY C  37      40.749  70.076   9.802  1.00 26.55           O  \\nATOM   7715  N   ASN C  38      40.703  67.975  10.659  1.00 50.66           N  \\nATOM   7716  CA  ASN C  38      42.049  67.596  10.244  1.00 50.66           C  \\nATOM   7717  C   ASN C  38      43.100  68.613  10.603  1.00 50.66           C  \\nATOM   7718  O   ASN C  38      43.598  69.370   9.754  1.00 50.66           O  \\nATOM   7719  CB  ASN C  38      42.087  67.309   8.753  1.00 95.21           C  \\nATOM   7720  CG  ASN C  38      41.230  66.137   8.372  1.00 95.21           C  \\nATOM   7721  OD1 ASN C  38      40.960  65.933   7.194  1.00 95.21           O  \\nATOM   7722  ND2 ASN C  38      40.744  65.385   9.366  1.00 95.21           N  \\nATOM   7723  N   TYR C  39      43.416  68.636  11.886  1.00 45.69           N  \\nATOM   7724  CA  TYR C  39      44.402  69.554  12.406  1.00 45.69           C  \\nATOM   7725  C   TYR C  39      45.686  68.815  12.705  1.00 45.69           C  \\nATOM   7726  O   TYR C  39      46.779  69.302  12.438  1.00 45.69           O  \\nATOM   7727  CB  TYR C  39      43.824  70.216  13.644  1.00 32.01           C  \\nATOM   7728  CG  TYR C  39      42.669  71.113  13.289  1.00 32.01           C  \\nATOM   7729  CD1 TYR C  39      42.866  72.220  12.459  1.00 32.01           C  \\nATOM   7730  CD2 TYR C  39      41.399  70.880  13.781  1.00 32.01           C  \\nATOM   7731  CE1 TYR C  39      41.832  73.081  12.134  1.00 32.01           C  \\nATOM   7732  CE2 TYR C  39      40.341  71.738  13.459  1.00 32.01           C  \\nATOM   7733  CZ  TYR C  39      40.561  72.850  12.633  1.00 32.01           C  \\nATOM   7734  OH  TYR C  39      39.533  73.746  12.327  1.00 32.01           O  \\nATOM   7735  N   ALA C  40      45.536  67.610  13.230  1.00 27.55           N  \\nATOM   7736  CA  ALA C  40      46.666  66.768  13.560  1.00 27.55           C  \\nATOM   7737  C   ALA C  40      46.163  65.346  13.447  1.00 27.55           C  \\nATOM   7738  O   ALA C  40      44.961  65.135  13.298  1.00 27.55           O  \\nATOM   7739  CB  ALA C  40      47.133  67.058  14.961  1.00  5.11           C  \\nATOM   7740  N   GLU C  41      47.063  64.368  13.481  1.00 43.32           N  \\nATOM   7741  CA  GLU C  41      46.628  62.974  13.389  1.00 43.32           C  \\nATOM   7742  C   GLU C  41      45.736  62.615  14.577  1.00 43.32           C  \\nATOM   7743  O   GLU C  41      44.556  62.304  14.418  1.00 43.32           O  \\nATOM   7744  CB  GLU C  41      47.832  62.029  13.317  1.00165.44           C  \\nATOM   7745  CG  GLU C  41      48.629  62.124  12.017  1.00165.44           C  \\nATOM   7746  CD  GLU C  41      47.781  61.896  10.765  1.00165.44           C  \\nATOM   7747  OE1 GLU C  41      46.791  61.131  10.823  1.00165.44           O  \\nATOM   7748  OE2 GLU C  41      48.109  62.484   9.712  1.00165.44           O  \\nATOM   7749  N   ARG C  42      46.278  62.783  15.771  1.00 23.94           N  \\nATOM   7750  CA  ARG C  42      45.561  62.472  16.985  1.00 23.94           C  \\nATOM   7751  C   ARG C  42      45.230  63.739  17.795  1.00 23.94           C  \\nATOM   7752  O   ARG C  42      45.903  64.762  17.656  1.00 23.94           O  \\nATOM   7753  CB  ARG C  42      46.411  61.531  17.844  1.00 66.90           C  \\nATOM   7754  CG  ARG C  42      46.914  60.283  17.143  1.00 66.90           C  \\nATOM   7755  CD  ARG C  42      48.165  59.733  17.837  1.00 66.90           C  \\nATOM   7756  NE  ARG C  42      48.024  58.339  18.264  1.00 66.90           N  \\nATOM   7757  CZ  ARG C  42      48.224  57.916  19.512  1.00 66.90           C  \\nATOM   7758  NH1 ARG C  42      48.573  58.786  20.461  1.00 66.90           N  \\nATOM   7759  NH2 ARG C  42      48.080  56.623  19.814  1.00 66.90           N  \\nATOM   7760  N   VAL C  43      44.220  63.631  18.669  1.00 28.22           N  \\nATOM   7761  CA  VAL C  43      43.771  64.713  19.554  1.00 28.22           C  \\nATOM   7762  C   VAL C  43      43.584  64.141  20.948  1.00 28.22           C  \\nATOM   7763  O   VAL C  43      42.728  63.287  21.157  1.00 28.22           O  \\nATOM   7764  CB  VAL C  43      42.412  65.337  19.093  1.00 15.12           C  \\nATOM   7765  CG1 VAL C  43      41.837  66.257  20.175  1.00 15.12           C  \\nATOM   7766  CG2 VAL C  43      42.612  66.141  17.845  1.00 15.12           C  \\nATOM   7767  N   GLY C  44      44.325  64.672  21.912  1.00 20.39           N  \\nATOM   7768  CA  GLY C  44      44.235  64.169  23.275  1.00 20.39           C  \\nATOM   7769  C   GLY C  44      42.967  64.605  23.962  1.00 20.39           C  \\nATOM   7770  O   GLY C  44      42.300  65.512  23.481  1.00 20.39           O  \\nATOM   7771  N   ALA C  45      42.653  64.000  25.101  1.00 32.90           N  \\nATOM   7772  CA  ALA C  45      41.437  64.336  25.857  1.00 32.90           C  \\nATOM   7773  C   ALA C  45      41.356  65.774  26.380  1.00 32.90           C  \\nATOM   7774  O   ALA C  45      40.292  66.394  26.386  1.00 32.90           O  \\nATOM   7775  CB  ALA C  45      41.259  63.365  27.013  1.00 33.28           C  \\nATOM   7776  N   GLY C  46      42.480  66.297  26.838  1.00 29.38           N  \\nATOM   7777  CA  GLY C  46      42.483  67.639  27.366  1.00 29.38           C  \\nATOM   7778  C   GLY C  46      42.273  68.682  26.296  1.00 29.38           C  \\nATOM   7779  O   GLY C  46      41.789  69.752  26.584  1.00 29.38           O  \\nATOM   7780  N   ALA C  47      42.588  68.372  25.049  1.00 21.17           N  \\nATOM   7781  CA  ALA C  47      42.430  69.362  23.998  1.00 21.17           C  \\nATOM   7782  C   ALA C  47      41.054  69.998  23.985  1.00 21.17           C  \\nATOM   7783  O   ALA C  47      40.927  71.196  24.202  1.00 21.17           O  \\nATOM   7784  CB  ALA C  47      42.771  68.771  22.621  1.00 50.96           C  \\nATOM   7785  N   PRO C  48      39.995  69.189  23.817  1.00 27.08           N  \\nATOM   7786  CA  PRO C  48      38.660  69.786  23.791  1.00 27.08           C  \\nATOM   7787  C   PRO C  48      38.285  70.509  25.079  1.00 27.08           C  \\nATOM   7788  O   PRO C  48      37.724  71.597  25.027  1.00 27.08           O  \\nATOM   7789  CB  PRO C  48      37.763  68.590  23.489  1.00 19.04           C  \\nATOM   7790  CG  PRO C  48      38.503  67.445  24.114  1.00 19.04           C  \\nATOM   7791  CD  PRO C  48      39.914  67.723  23.699  1.00 19.04           C  \\nATOM   7792  N   VAL C  49      38.636  69.935  26.226  1.00 17.06           N  \\nATOM   7793  CA  VAL C  49      38.335  70.561  27.515  1.00 17.06           C  \\nATOM   7794  C   VAL C  49      38.845  72.005  27.570  1.00 17.06           C  \\nATOM   7795  O   VAL C  49      38.124  72.933  27.944  1.00 17.06           O  \\nATOM   7796  CB  VAL C  49      38.970  69.776  28.676  1.00 18.11           C  \\nATOM   7797  CG1 VAL C  49      38.743  70.504  29.990  1.00 18.11           C  \\nATOM   7798  CG2 VAL C  49      38.406  68.381  28.734  1.00 18.11           C  \\nATOM   7799  N   TYR C  50      40.096  72.182  27.180  1.00 27.15           N  \\nATOM   7800  CA  TYR C  50      40.727  73.487  27.167  1.00 27.15           C  \\nATOM   7801  C   TYR C  50      40.063  74.436  26.195  1.00 27.15           C  \\nATOM   7802  O   TYR C  50      39.704  75.550  26.541  1.00 27.15           O  \\nATOM   7803  CB  TYR C  50      42.185  73.342  26.763  1.00 27.13           C  \\nATOM   7804  CG  TYR C  50      43.027  74.461  27.288  1.00 27.13           C  \\nATOM   7805  CD1 TYR C  50      42.875  75.756  26.808  1.00 27.13           C  \\nATOM   7806  CD2 TYR C  50      43.978  74.225  28.279  1.00 27.13           C  \\nATOM   7807  CE1 TYR C  50      43.648  76.782  27.299  1.00 27.13           C  \\nATOM   7808  CE2 TYR C  50      44.752  75.241  28.779  1.00 27.13           C  \\nATOM   7809  CZ  TYR C  50      44.589  76.516  28.283  1.00 27.13           C  \\nATOM   7810  OH  TYR C  50      45.400  77.518  28.750  1.00 27.13           O  \\nATOM   7811  N   LEU C  51      39.957  74.002  24.953  1.00 17.39           N  \\nATOM   7812  CA  LEU C  51      39.356  74.819  23.925  1.00 17.39           C  \\nATOM   7813  C   LEU C  51      37.964  75.241  24.348  1.00 17.39           C  \\nATOM   7814  O   LEU C  51      37.613  76.405  24.235  1.00 17.39           O  \\nATOM   7815  CB  LEU C  51      39.317  74.065  22.601  1.00 18.01           C  \\nATOM   7816  CG  LEU C  51      38.849  74.958  21.460  1.00 18.01           C  \\nATOM   7817  CD1 LEU C  51      39.588  76.282  21.479  1.00 18.01           C  \\nATOM   7818  CD2 LEU C  51      39.085  74.257  20.174  1.00 18.01           C  \\nATOM   7819  N   ALA C  52      37.194  74.306  24.888  1.00 24.24           N  \\nATOM   7820  CA  ALA C  52      35.849  74.601  25.349  1.00 24.24           C  \\nATOM   7821  C   ALA C  52      35.867  75.665  26.463  1.00 24.24           C  \\nATOM   7822  O   ALA C  52      35.050  76.583  26.473  1.00 24.24           O  \\nATOM   7823  CB  ALA C  52      35.188  73.340  25.827  1.00 16.03           C  \\nATOM   7824  N   ALA C  53      36.817  75.562  27.383  1.00 26.35           N  \\nATOM   7825  CA  ALA C  53      36.929  76.534  28.463  1.00 26.35           C  \\nATOM   7826  C   ALA C  53      37.212  77.921  27.904  1.00 26.35           C  \\nATOM   7827  O   ALA C  53      36.617  78.917  28.324  1.00 26.35           O  \\nATOM   7828  CB  ALA C  53      38.025  76.113  29.428  1.00 29.90           C  \\nATOM   7829  N   VAL C  54      38.123  77.978  26.942  1.00 11.25           N  \\nATOM   7830  CA  VAL C  54      38.487  79.234  26.317  1.00 11.25           C  \\nATOM   7831  C   VAL C  54      37.319  79.841  25.523  1.00 11.25           C  \\nATOM   7832  O   VAL C  54      36.988  81.003  25.683  1.00 11.25           O  \\nATOM   7833  CB  VAL C  54      39.741  79.024  25.444  1.00 21.58           C  \\nATOM   7834  CG1 VAL C  54      40.103  80.279  24.653  1.00 21.58           C  \\nATOM   7835  CG2 VAL C  54      40.895  78.631  26.331  1.00 21.58           C  \\nATOM   7836  N   LEU C  55      36.667  79.048  24.689  1.00 25.41           N  \\nATOM   7837  CA  LEU C  55      35.553  79.560  23.917  1.00 25.41           C  \\nATOM   7838  C   LEU C  55      34.459  80.056  24.857  1.00 25.41           C  \\nATOM   7839  O   LEU C  55      33.956  81.156  24.696  1.00 25.41           O  \\nATOM   7840  CB  LEU C  55      35.016  78.475  23.001  1.00 12.38           C  \\nATOM   7841  CG  LEU C  55      35.902  77.940  21.867  1.00 12.38           C  \\nATOM   7842  CD1 LEU C  55      35.607  76.483  21.727  1.00 12.38           C  \\nATOM   7843  CD2 LEU C  55      35.695  78.634  20.511  1.00 12.38           C  \\nATOM   7844  N   GLU C  56      34.105  79.265  25.861  1.00 18.75           N  \\nATOM   7845  CA  GLU C  56      33.082  79.685  26.802  1.00 18.75           C  \\nATOM   7846  C   GLU C  56      33.467  81.008  27.443  1.00 18.75           C  \\nATOM   7847  O   GLU C  56      32.663  81.946  27.495  1.00 18.75           O  \\nATOM   7848  CB  GLU C  56      32.916  78.641  27.897  1.00 21.43           C  \\nATOM   7849  CG  GLU C  56      31.962  79.033  29.020  1.00 21.43           C  \\nATOM   7850  CD  GLU C  56      31.594  77.854  29.920  1.00 21.43           C  \\nATOM   7851  OE1 GLU C  56      31.482  76.714  29.407  1.00 21.43           O  \\nATOM   7852  OE2 GLU C  56      31.375  78.060  31.132  1.00 21.43           O  \\nATOM   7853  N   TYR C  57      34.708  81.075  27.926  1.00 18.22           N  \\nATOM   7854  CA  TYR C  57      35.219  82.261  28.589  1.00 18.22           C  \\nATOM   7855  C   TYR C  57      35.061  83.475  27.724  1.00 18.22           C  \\nATOM   7856  O   TYR C  57      34.542  84.474  28.171  1.00 18.22           O  \\nATOM   7857  CB  TYR C  57      36.693  82.081  28.977  1.00 29.28           C  \\nATOM   7858  CG  TYR C  57      37.407  83.385  29.254  1.00 29.28           C  \\nATOM   7859  CD1 TYR C  57      37.000  84.216  30.292  1.00 29.28           C  \\nATOM   7860  CD2 TYR C  57      38.433  83.831  28.415  1.00 29.28           C  \\nATOM   7861  CE1 TYR C  57      37.580  85.469  30.483  1.00 29.28           C  \\nATOM   7862  CE2 TYR C  57      39.028  85.082  28.599  1.00 29.28           C  \\nATOM   7863  CZ  TYR C  57      38.587  85.897  29.633  1.00 29.28           C  \\nATOM   7864  OH  TYR C  57      39.119  87.160  29.788  1.00 29.28           O  \\nATOM   7865  N   LEU C  58      35.492  83.391  26.478  1.00 21.30           N  \\nATOM   7866  CA  LEU C  58      35.386  84.516  25.577  1.00 21.30           C  \\nATOM   7867  C   LEU C  58      33.938  84.936  25.336  1.00 21.30           C  \\nATOM   7868  O   LEU C  58      33.640  86.138  25.337  1.00 21.30           O  \\nATOM   7869  CB  LEU C  58      36.077  84.202  24.256  1.00  8.81           C  \\nATOM   7870  CG  LEU C  58      37.597  83.988  24.257  1.00  8.81           C  \\nATOM   7871  CD1 LEU C  58      38.035  83.370  22.954  1.00  8.81           C  \\nATOM   7872  CD2 LEU C  58      38.323  85.320  24.488  1.00  8.81           C  \\nATOM   7873  N   THR C  59      33.027  83.980  25.128  1.00 20.47           N  \\nATOM   7874  CA  THR C  59      31.637  84.369  24.907  1.00 20.47           C  \\nATOM   7875  C   THR C  59      31.085  85.076  26.166  1.00 20.47           C  \\nATOM   7876  O   THR C  59      30.340  86.040  26.057  1.00 20.47           O  \\nATOM   7877  CB  THR C  59      30.706  83.204  24.370  1.00 14.78           C  \\nATOM   7878  OG1 THR C  59      29.962  82.632  25.444  1.00 14.78           O  \\nATOM   7879  CG2 THR C  59      31.489  82.120  23.658  1.00 14.78           C  \\nATOM   7880  N   ALA C  60      31.486  84.651  27.364  1.00 18.29           N  \\nATOM   7881  CA  ALA C  60      31.029  85.357  28.580  1.00 18.29           C  \\nATOM   7882  C   ALA C  60      31.495  86.816  28.556  1.00 18.29           C  \\nATOM   7883  O   ALA C  60      30.767  87.705  28.931  1.00 18.29           O  \\nATOM   7884  CB  ALA C  60      31.546  84.683  29.817  1.00 14.20           C  \\nATOM   7885  N   GLU C  61      32.725  87.038  28.114  1.00 11.63           N  \\nATOM   7886  CA  GLU C  61      33.319  88.363  28.009  1.00 11.63           C  \\nATOM   7887  C   GLU C  61      32.521  89.254  27.052  1.00 11.63           C  \\nATOM   7888  O   GLU C  61      32.134  90.370  27.394  1.00 11.63           O  \\nATOM   7889  CB  GLU C  61      34.764  88.211  27.535  1.00 35.41           C  \\nATOM   7890  CG  GLU C  61      35.609  89.458  27.614  1.00 35.41           C  \\nATOM   7891  CD  GLU C  61      35.651  90.103  29.003  1.00 35.41           C  \\nATOM   7892  OE1 GLU C  61      35.499  89.385  30.031  1.00 35.41           O  \\nATOM   7893  OE2 GLU C  61      35.855  91.345  29.057  1.00 35.41           O  \\nATOM   7894  N   ILE C  62      32.252  88.768  25.849  1.00 18.09           N  \\nATOM   7895  CA  ILE C  62      31.488  89.563  24.895  1.00 18.09           C  \\nATOM   7896  C   ILE C  62      30.061  89.828  25.370  1.00 18.09           C  \\nATOM   7897  O   ILE C  62      29.558  90.931  25.164  1.00 18.09           O  \\nATOM   7898  CB  ILE C  62      31.443  88.910  23.500  1.00 38.01           C  \\nATOM   7899  CG1 ILE C  62      32.832  88.935  22.873  1.00 38.01           C  \\nATOM   7900  CG2 ILE C  62      30.458  89.634  22.601  1.00 38.01           C  \\nATOM   7901  CD1 ILE C  62      32.819  89.147  21.357  1.00 38.01           C  \\nATOM   7902  N   LEU C  63      29.415  88.816  25.974  1.00 12.07           N  \\nATOM   7903  CA  LEU C  63      28.028  88.913  26.489  1.00 12.07           C  \\nATOM   7904  C   LEU C  63      27.925  89.874  27.690  1.00 12.07           C  \\nATOM   7905  O   LEU C  63      27.004  90.683  27.773  1.00 12.07           O  \\nATOM   7906  CB  LEU C  63      27.448  87.522  26.816  1.00  7.20           C  \\nATOM   7907  CG  LEU C  63      27.134  86.500  25.683  1.00  7.20           C  \\nATOM   7908  CD1 LEU C  63      26.664  85.182  26.244  1.00  7.20           C  \\nATOM   7909  CD2 LEU C  63      26.072  87.000  24.729  1.00  7.20           C  \\nATOM   7910  N   GLU C  64      28.883  89.815  28.607  1.00 12.85           N  \\nATOM   7911  CA  GLU C  64      28.877  90.746  29.727  1.00 12.85           C  \\nATOM   7912  C   GLU C  64      28.979  92.118  29.109  1.00 12.85           C  \\nATOM   7913  O   GLU C  64      28.114  92.929  29.320  1.00 12.85           O  \\nATOM   7914  CB  GLU C  64      30.045  90.513  30.687  1.00 24.48           C  \\nATOM   7915  CG  GLU C  64      30.127  91.527  31.827  1.00 24.48           C  \\nATOM   7916  CD  GLU C  64      29.194  91.247  33.016  1.00 24.48           C  \\nATOM   7917  OE1 GLU C  64      29.252  90.133  33.580  1.00 24.48           O  \\nATOM   7918  OE2 GLU C  64      28.444  92.160  33.439  1.00 24.48           O  \\nATOM   7919  N   LEU C  65      29.959  92.338  28.240  1.00 19.43           N  \\nATOM   7920  CA  LEU C  65      30.111  93.661  27.612  1.00 19.43           C  \\nATOM   7921  C   LEU C  65      28.896  94.150  26.794  1.00 19.43           C  \\nATOM   7922  O   LEU C  65      28.468  95.301  26.956  1.00 19.43           O  \\nATOM   7923  CB  LEU C  65      31.398  93.727  26.776  1.00 22.04           C  \\nATOM   7924  CG  LEU C  65      32.733  93.794  27.537  1.00 22.04           C  \\nATOM   7925  CD1 LEU C  65      33.903  93.766  26.569  1.00 22.04           C  \\nATOM   7926  CD2 LEU C  65      32.768  95.062  28.390  1.00 22.04           C  \\nATOM   7927  N   ALA C  66      28.351  93.279  25.937  1.00 29.10           N  \\nATOM   7928  CA  ALA C  66      27.176  93.590  25.113  1.00 29.10           C  \\nATOM   7929  C   ALA C  66      25.910  93.842  25.945  1.00 29.10           C  \\nATOM   7930  O   ALA C  66      25.124  94.749  25.654  1.00 29.10           O  \\nATOM   7931  CB  ALA C  66      26.926  92.482  24.105  1.00 16.64           C  \\nATOM   7932  N   GLY C  67      25.700  93.035  26.975  1.00 11.25           N  \\nATOM   7933  CA  GLY C  67      24.553  93.245  27.820  1.00 11.25           C  \\nATOM   7934  C   GLY C  67      24.580  94.649  28.403  1.00 11.25           C  \\nATOM   7935  O   GLY C  67      23.530  95.251  28.615  1.00 11.25           O  \\nATOM   7936  N   ASN C  68      25.769  95.164  28.717  1.00 21.17           N  \\nATOM   7937  CA  ASN C  68      25.867  96.514  29.267  1.00 21.17           C  \\nATOM   7938  C   ASN C  68      25.404  97.499  28.217  1.00 21.17           C  \\nATOM   7939  O   ASN C  68      24.640  98.407  28.508  1.00 21.17           O  \\nATOM   7940  CB  ASN C  68      27.297  96.863  29.678  1.00 28.26           C  \\nATOM   7941  CG  ASN C  68      27.817  96.003  30.811  1.00 28.26           C  \\nATOM   7942  OD1 ASN C  68      27.065  95.403  31.566  1.00 28.26           O  \\nATOM   7943  ND2 ASN C  68      29.127  95.948  30.931  1.00 28.26           N  \\nATOM   7944  N   ALA C  69      25.882  97.335  26.991  1.00 20.87           N  \\nATOM   7945  CA  ALA C  69      25.467  98.232  25.943  1.00 20.87           C  \\nATOM   7946  C   ALA C  69      23.946  98.198  25.876  1.00 20.87           C  \\nATOM   7947  O   ALA C  69      23.307  99.222  25.678  1.00 20.87           O  \\nATOM   7948  CB  ALA C  69      26.090  97.838  24.633  1.00 11.60           C  \\nATOM   7949  N   ALA C  70      23.367  97.023  26.096  1.00 22.08           N  \\nATOM   7950  CA  ALA C  70      21.918  96.886  26.090  1.00 22.08           C  \\nATOM   7951  C   ALA C  70      21.327  97.799  27.155  1.00 22.08           C  \\nATOM   7952  O   ALA C  70      20.450  98.590  26.866  1.00 22.08           O  \\nATOM   7953  CB  ALA C  70      21.524  95.444  26.344  1.00 29.84           C  \\nATOM   7954  N   ARG C  71      21.789  97.663  28.391  1.00 27.17           N  \\nATOM   7955  CA  ARG C  71      21.335  98.499  29.510  1.00 27.17           C  \\nATOM   7956  C   ARG C  71      21.463  99.980  29.158  1.00 27.17           C  \\nATOM   7957  O   ARG C  71      20.511 100.735  29.302  1.00 27.17           O  \\nATOM   7958  CB  ARG C  71      22.169  98.215  30.760  1.00153.29           C  \\nATOM   7959  CG  ARG C  71      21.785  96.959  31.525  1.00153.29           C  \\nATOM   7960  CD  ARG C  71      20.926  97.294  32.738  1.00153.29           C  \\nATOM   7961  NE  ARG C  71      21.571  98.262  33.631  1.00153.29           N  \\nATOM   7962  CZ  ARG C  71      21.787  98.072  34.934  1.00153.29           C  \\nATOM   7963  NH1 ARG C  71      21.415  96.940  35.519  1.00153.29           N  \\nATOM   7964  NH2 ARG C  71      22.364  99.024  35.663  1.00153.29           N  \\nATOM   7965  N   ASP C  72      22.627 100.376  28.652  1.00 37.53           N  \\nATOM   7966  CA  ASP C  72      22.900 101.760  28.281  1.00 37.53           C  \\nATOM   7967  C   ASP C  72      21.861 102.385  27.380  1.00 37.53           C  \\nATOM   7968  O   ASP C  72      21.562 103.559  27.523  1.00 37.53           O  \\nATOM   7969  CB  ASP C  72      24.247 101.872  27.588  1.00 45.02           C  \\nATOM   7970  CG  ASP C  72      25.404 101.474  28.480  1.00 45.02           C  \\nATOM   7971  OD1 ASP C  72      25.241 101.484  29.721  1.00 45.02           O  \\nATOM   7972  OD2 ASP C  72      26.484 101.153  27.929  1.00 45.02           O  \\nATOM   7973  N   ASN C  73      21.381 101.636  26.395  1.00 29.61           N  \\nATOM   7974  CA  ASN C  73      20.377 102.156  25.474  1.00 29.61           C  \\nATOM   7975  C   ASN C  73      18.960 101.773  25.844  1.00 29.61           C  \\nATOM   7976  O   ASN C  73      18.044 101.799  25.012  1.00 29.61           O  \\nATOM   7977  CB  ASN C  73      20.720 101.741  24.058  1.00 61.07           C  \\nATOM   7978  CG  ASN C  73      22.105 102.181  23.676  1.00 61.07           C  \\nATOM   7979  OD1 ASN C  73      22.328 103.343  23.342  1.00 61.07           O  \\nATOM   7980  ND2 ASN C  73      23.069 101.291  23.844  1.00 61.07           N  \\nATOM   7981  N   LYS C  74      18.802 101.413  27.111  1.00 27.77           N  \\nATOM   7982  CA  LYS C  74      17.518 101.048  27.697  1.00 27.77           C  \\nATOM   7983  C   LYS C  74      16.763  99.888  27.029  1.00 27.77           C  \\nATOM   7984  O   LYS C  74      15.539  99.779  27.118  1.00 27.77           O  \\nATOM   7985  CB  LYS C  74      16.674 102.323  27.860  1.00112.03           C  \\nATOM   7986  CG  LYS C  74      17.381 103.344  28.780  1.00112.03           C  \\nATOM   7987  CD  LYS C  74      16.914 104.787  28.638  1.00112.03           C  \\nATOM   7988  CE  LYS C  74      17.830 105.699  29.457  1.00112.03           C  \\nATOM   7989  NZ  LYS C  74      17.433 107.130  29.413  1.00112.03           N  \\nATOM   7990  N   LYS C  75      17.533  98.965  26.458  1.00 33.45           N  \\nATOM   7991  CA  LYS C  75      16.990  97.792  25.796  1.00 33.45           C  \\nATOM   7992  C   LYS C  75      17.242  96.561  26.660  1.00 33.45           C  \\nATOM   7993  O   LYS C  75      18.103  96.562  27.546  1.00 33.45           O  \\nATOM   7994  CB  LYS C  75      17.673  97.620  24.463  1.00 30.01           C  \\nATOM   7995  CG  LYS C  75      17.610  98.853  23.625  1.00 30.01           C  \\nATOM   7996  CD  LYS C  75      16.407  98.861  22.703  1.00 30.01           C  \\nATOM   7997  CE  LYS C  75      16.438 100.097  21.796  1.00 30.01           C  \\nATOM   7998  NZ  LYS C  75      16.124 101.357  22.548  1.00 30.01           N  \\nATOM   7999  N   THR C  76      16.517  95.496  26.366  1.00 35.80           N  \\nATOM   8000  CA  THR C  76      16.633  94.262  27.115  1.00 35.80           C  \\nATOM   8001  C   THR C  76      17.103  93.128  26.231  1.00 35.80           C  \\nATOM   8002  O   THR C  76      17.628  92.123  26.715  1.00 35.80           O  \\nATOM   8003  CB  THR C  76      15.272  93.924  27.740  1.00 32.82           C  \\nATOM   8004  OG1 THR C  76      15.218  94.523  29.037  1.00 32.82           O  \\nATOM   8005  CG2 THR C  76      14.992  92.382  27.799  1.00 32.82           C  \\nATOM   8006  N   ARG C  77      16.853  93.258  24.934  1.00 25.08           N  \\nATOM   8007  CA  ARG C  77      17.268  92.241  24.010  1.00 25.08           C  \\nATOM   8008  C   ARG C  77      18.489  92.789  23.289  1.00 25.08           C  \\nATOM   8009  O   ARG C  77      18.436  93.843  22.647  1.00 25.08           O  \\nATOM   8010  CB  ARG C  77      16.153  91.929  23.019  1.00 41.83           C  \\nATOM   8011  CG  ARG C  77      16.282  90.557  22.391  1.00 41.83           C  \\nATOM   8012  CD  ARG C  77      15.158  90.262  21.423  1.00 41.83           C  \\nATOM   8013  NE  ARG C  77      13.847  90.244  22.074  1.00 41.83           N  \\nATOM   8014  CZ  ARG C  77      12.860  91.097  21.788  1.00 41.83           C  \\nATOM   8015  NH1 ARG C  77      13.035  92.027  20.859  1.00 41.83           N  \\nATOM   8016  NH2 ARG C  77      11.710  91.052  22.459  1.00 41.83           N  \\nATOM   8017  N   ILE C  78      19.608  92.107  23.477  1.00 20.39           N  \\nATOM   8018  CA  ILE C  78      20.857  92.463  22.825  1.00 20.39           C  \\nATOM   8019  C   ILE C  78      20.649  92.313  21.318  1.00 20.39           C  \\nATOM   8020  O   ILE C  78      20.033  91.343  20.859  1.00 20.39           O  \\nATOM   8021  CB  ILE C  78      21.996  91.463  23.190  1.00  7.96           C  \\nATOM   8022  CG1 ILE C  78      22.377  91.566  24.659  1.00  7.96           C  \\nATOM   8023  CG2 ILE C  78      23.204  91.666  22.296  1.00  7.96           C  \\nATOM   8024  CD1 ILE C  78      23.247  90.427  25.137  1.00  7.96           C  \\nATOM   8025  N   ILE C  79      21.149  93.283  20.562  1.00 26.88           N  \\nATOM   8026  CA  ILE C  79      21.080  93.223  19.120  1.00 26.88           C  \\nATOM   8027  C   ILE C  79      22.499  93.433  18.633  1.00 26.88           C  \\nATOM   8028  O   ILE C  79      23.382  93.757  19.416  1.00 26.88           O  \\nATOM   8029  CB  ILE C  79      20.139  94.288  18.528  1.00 16.98           C  \\nATOM   8030  CG1 ILE C  79      20.596  95.690  18.900  1.00 16.98           C  \\nATOM   8031  CG2 ILE C  79      18.704  94.015  18.958  1.00 16.98           C  \\nATOM   8032  CD1 ILE C  79      19.753  96.747  18.261  1.00 16.98           C  \\nATOM   8033  N   PRO C  80      22.750  93.217  17.338  1.00 31.46           N  \\nATOM   8034  CA  PRO C  80      24.102  93.401  16.799  1.00 31.46           C  \\nATOM   8035  C   PRO C  80      24.776  94.704  17.174  1.00 31.46           C  \\nATOM   8036  O   PRO C  80      25.958  94.693  17.488  1.00 31.46           O  \\nATOM   8037  CB  PRO C  80      23.883  93.294  15.305  1.00 19.69           C  \\nATOM   8038  CG  PRO C  80      22.794  92.236  15.236  1.00 19.69           C  \\nATOM   8039  CD  PRO C  80      21.836  92.678  16.315  1.00 19.69           C  \\nATOM   8040  N   ARG C  81      24.051  95.825  17.166  1.00 11.81           N  \\nATOM   8041  CA  ARG C  81      24.681  97.098  17.541  1.00 11.81           C  \\nATOM   8042  C   ARG C  81      25.337  97.014  18.926  1.00 11.81           C  \\nATOM   8043  O   ARG C  81      26.406  97.590  19.165  1.00 11.81           O  \\nATOM   8044  CB  ARG C  81      23.710  98.288  17.495  1.00 12.63           C  \\nATOM   8045  CG  ARG C  81      24.092  99.356  18.521  1.00 12.63           C  \\nATOM   8046  CD  ARG C  81      24.413 100.773  18.021  1.00 12.63           C  \\nATOM   8047  NE  ARG C  81      25.433 100.881  16.970  1.00 12.63           N  \\nATOM   8048  CZ  ARG C  81      26.179 101.973  16.739  1.00 12.63           C  \\nATOM   8049  NH1 ARG C  81      26.080 103.064  17.501  1.00 12.63           N  \\nATOM   8050  NH2 ARG C  81      26.938 102.023  15.646  1.00 12.63           N  \\nATOM   8051  N   HIS C  82      24.711  96.271  19.830  1.00 25.22           N  \\nATOM   8052  CA  HIS C  82      25.239  96.121  21.176  1.00 25.22           C  \\nATOM   8053  C   HIS C  82      26.554  95.354  21.122  1.00 25.22           C  \\nATOM   8054  O   HIS C  82      27.493  95.694  21.836  1.00 25.22           O  \\nATOM   8055  CB  HIS C  82      24.201  95.458  22.076  1.00 27.97           C  \\nATOM   8056  CG  HIS C  82      22.902  96.202  22.132  1.00 27.97           C  \\nATOM   8057  ND1 HIS C  82      21.732  95.632  22.573  1.00 27.97           N  \\nATOM   8058  CD2 HIS C  82      22.590  97.477  21.797  1.00 27.97           C  \\nATOM   8059  CE1 HIS C  82      20.754  96.518  22.509  1.00 27.97           C  \\nATOM   8060  NE2 HIS C  82      21.249  97.648  22.039  1.00 27.97           N  \\nATOM   8061  N   LEU C  83      26.638  94.365  20.227  1.00 11.71           N  \\nATOM   8062  CA  LEU C  83      27.869  93.591  20.027  1.00 11.71           C  \\nATOM   8063  C   LEU C  83      28.979  94.507  19.460  1.00 11.71           C  \\nATOM   8064  O   LEU C  83      30.100  94.506  19.984  1.00 11.71           O  \\nATOM   8065  CB  LEU C  83      27.618  92.407  19.085  1.00  6.54           C  \\nATOM   8066  CG  LEU C  83      26.644  91.357  19.628  1.00  6.54           C  \\nATOM   8067  CD1 LEU C  83      26.223  90.333  18.555  1.00  6.54           C  \\nATOM   8068  CD2 LEU C  83      27.273  90.667  20.862  1.00  6.54           C  \\nATOM   8069  N   GLN C  84      28.665  95.299  18.419  1.00 11.71           N  \\nATOM   8070  CA  GLN C  84      29.652  96.220  17.827  1.00 11.71           C  \\nATOM   8071  C   GLN C  84      30.199  97.147  18.883  1.00 11.71           C  \\nATOM   8072  O   GLN C  84      31.408  97.249  19.055  1.00 11.71           O  \\nATOM   8073  CB  GLN C  84      29.055  97.115  16.747  1.00 21.58           C  \\nATOM   8074  CG  GLN C  84      29.554  96.848  15.345  1.00 21.58           C  \\nATOM   8075  CD  GLN C  84      30.998  97.284  15.011  1.00 21.58           C  \\nATOM   8076  OE1 GLN C  84      31.262  98.465  14.793  1.00 21.58           O  \\nATOM   8077  NE2 GLN C  84      31.880  96.298  14.790  1.00 21.58           N  \\nATOM   8078  N   LEU C  85      29.292  97.847  19.559  1.00 12.34           N  \\nATOM   8079  CA  LEU C  85      29.666  98.774  20.602  1.00 12.34           C  \\nATOM   8080  C   LEU C  85      30.580  98.095  21.586  1.00 12.34           C  \\nATOM   8081  O   LEU C  85      31.678  98.573  21.787  1.00 12.34           O  \\nATOM   8082  CB  LEU C  85      28.436  99.326  21.302  1.00 21.97           C  \\nATOM   8083  CG  LEU C  85      27.540 100.159  20.388  1.00 21.97           C  \\nATOM   8084  CD1 LEU C  85      26.271 100.505  21.107  1.00 21.97           C  \\nATOM   8085  CD2 LEU C  85      28.261 101.410  19.928  1.00 21.97           C  \\nATOM   8086  N   ALA C  86      30.175  96.949  22.135  1.00 23.23           N  \\nATOM   8087  CA  ALA C  86      30.994  96.205  23.100  1.00 23.23           C  \\nATOM   8088  C   ALA C  86      32.427  95.902  22.638  1.00 23.23           C  \\nATOM   8089  O   ALA C  86      33.388  96.107  23.388  1.00 23.23           O  \\nATOM   8090  CB  ALA C  86      30.300  94.922  23.475  1.00 29.12           C  \\nATOM   8091  N   VAL C  87      32.547  95.370  21.424  1.00 17.48           N  \\nATOM   8092  CA  VAL C  87      33.822  95.040  20.814  1.00 17.48           C  \\nATOM   8093  C   VAL C  87      34.649  96.296  20.537  1.00 17.48           C  \\nATOM   8094  O   VAL C  87      35.695  96.504  21.130  1.00 17.48           O  \\nATOM   8095  CB  VAL C  87      33.573  94.255  19.518  1.00  7.89           C  \\nATOM   8096  CG1 VAL C  87      34.807  94.199  18.661  1.00  7.89           C  \\nATOM   8097  CG2 VAL C  87      33.079  92.854  19.858  1.00  7.89           C  \\nATOM   8098  N   ARG C  88      34.114  97.196  19.734  1.00 20.27           N  \\nATOM   8099  CA  ARG C  88      34.837  98.394  19.392  1.00 20.27           C  \\nATOM   8100  C   ARG C  88      35.243  99.250  20.584  1.00 20.27           C  \\nATOM   8101  O   ARG C  88      36.218 100.003  20.496  1.00 20.27           O  \\nATOM   8102  CB  ARG C  88      34.067  99.213  18.343  1.00  8.63           C  \\nATOM   8103  CG  ARG C  88      33.774  98.443  17.053  1.00  8.63           C  \\nATOM   8104  CD  ARG C  88      34.950  97.555  16.652  1.00  8.63           C  \\nATOM   8105  NE  ARG C  88      34.568  96.527  15.689  1.00  8.63           N  \\nATOM   8106  CZ  ARG C  88      35.345  95.510  15.308  1.00  8.63           C  \\nATOM   8107  NH1 ARG C  88      36.566  95.371  15.808  1.00  8.63           N  \\nATOM   8108  NH2 ARG C  88      34.921  94.641  14.393  1.00  8.63           N  \\nATOM   8109  N   ASN C  89      34.520  99.155  21.693  1.00 24.83           N  \\nATOM   8110  CA  ASN C  89      34.873  99.949  22.880  1.00 24.83           C  \\nATOM   8111  C   ASN C  89      35.901  99.313  23.801  1.00 24.83           C  \\nATOM   8112  O   ASN C  89      36.427  99.973  24.703  1.00 24.83           O  \\nATOM   8113  CB  ASN C  89      33.634 100.309  23.694  1.00 36.18           C  \\nATOM   8114  CG  ASN C  89      32.871 101.470  23.102  1.00 36.18           C  \\nATOM   8115  OD1 ASN C  89      33.448 102.522  22.799  1.00 36.18           O  \\nATOM   8116  ND2 ASN C  89      31.569 101.290  22.930  1.00 36.18           N  \\nATOM   8117  N   ASP C  90      36.185  98.037  23.552  1.00 30.38           N  \\nATOM   8118  CA  ASP C  90      37.122  97.256  24.332  1.00 30.38           C  \\nATOM   8119  C   ASP C  90      38.352  97.089  23.465  1.00 30.38           C  \\nATOM   8120  O   ASP C  90      38.278  96.500  22.387  1.00 30.38           O  \\nATOM   8121  CB  ASP C  90      36.503  95.899  24.612  1.00 26.41           C  \\nATOM   8122  CG  ASP C  90      37.317  95.079  25.546  1.00 26.41           C  \\nATOM   8123  OD1 ASP C  90      37.460  95.521  26.706  1.00 26.41           O  \\nATOM   8124  OD2 ASP C  90      37.805  94.001  25.124  1.00 26.41           O  \\nATOM   8125  N   GLU C  91      39.494  97.572  23.954  1.00 22.86           N  \\nATOM   8126  CA  GLU C  91      40.748  97.510  23.207  1.00 22.86           C  \\nATOM   8127  C   GLU C  91      41.107  96.129  22.735  1.00 22.86           C  \\nATOM   8128  O   GLU C  91      41.422  95.947  21.557  1.00 22.86           O  \\nATOM   8129  CB  GLU C  91      41.897  98.067  24.038  1.00 76.59           C  \\nATOM   8130  CG  GLU C  91      42.273  99.484  23.669  1.00 76.59           C  \\nATOM   8131  CD  GLU C  91      43.284 100.089  24.620  1.00 76.59           C  \\nATOM   8132  OE1 GLU C  91      44.191  99.357  25.094  1.00 76.59           O  \\nATOM   8133  OE2 GLU C  91      43.166 101.306  24.887  1.00 76.59           O  \\nATOM   8134  N   GLU C  92      40.994  95.151  23.641  1.00 24.82           N  \\nATOM   8135  CA  GLU C  92      41.355  93.766  23.332  1.00 24.82           C  \\nATOM   8136  C   GLU C  92      40.434  93.016  22.407  1.00 24.82           C  \\nATOM   8137  O   GLU C  92      40.899  92.376  21.457  1.00 24.82           O  \\nATOM   8138  CB  GLU C  92      41.704  92.992  24.591  1.00 34.30           C  \\nATOM   8139  CG  GLU C  92      43.183  93.193  24.895  1.00 34.30           C  \\nATOM   8140  CD  GLU C  92      43.593  92.837  26.302  1.00 34.30           C  \\nATOM   8141  OE1 GLU C  92      42.816  92.131  26.978  1.00 34.30           O  \\nATOM   8142  OE2 GLU C  92      44.700  93.270  26.728  1.00 34.30           O  \\nATOM   8143  N   LEU C  93      39.130  93.135  22.640  1.00 16.31           N  \\nATOM   8144  CA  LEU C  93      38.162  92.509  21.753  1.00 16.31           C  \\nATOM   8145  C   LEU C  93      38.296  93.176  20.388  1.00 16.31           C  \\nATOM   8146  O   LEU C  93      38.238  92.521  19.357  1.00 16.31           O  \\nATOM   8147  CB  LEU C  93      36.757  92.686  22.304  1.00 17.29           C  \\nATOM   8148  CG  LEU C  93      36.308  91.665  23.352  1.00 17.29           C  \\nATOM   8149  CD1 LEU C  93      34.948  92.038  23.858  1.00 17.29           C  \\nATOM   8150  CD2 LEU C  93      36.229  90.269  22.736  1.00 17.29           C  \\nATOM   8151  N   ASN C  94      38.521  94.486  20.390  1.00 17.48           N  \\nATOM   8152  CA  ASN C  94      38.687  95.216  19.144  1.00 17.48           C  \\nATOM   8153  C   ASN C  94      39.882  94.703  18.360  1.00 17.48           C  \\nATOM   8154  O   ASN C  94      39.844  94.658  17.134  1.00 17.48           O  \\nATOM   8155  CB  ASN C  94      38.859  96.704  19.395  1.00 28.92           C  \\nATOM   8156  CG  ASN C  94      38.837  97.498  18.116  1.00 28.92           C  \\nATOM   8157  OD1 ASN C  94      37.963  97.298  17.280  1.00 28.92           O  \\nATOM   8158  ND2 ASN C  94      39.819  98.361  17.929  1.00 28.92           N  \\nATOM   8159  N   LYS C  95      40.969  94.400  19.066  1.00 19.82           N  \\nATOM   8160  CA  LYS C  95      42.157  93.865  18.420  1.00 19.82           C  \\nATOM   8161  C   LYS C  95      41.821  92.496  17.838  1.00 19.82           C  \\nATOM   8162  O   LYS C  95      41.855  92.299  16.634  1.00 19.82           O  \\nATOM   8163  CB  LYS C  95      43.321  93.762  19.405  1.00 70.14           C  \\nATOM   8164  CG  LYS C  95      44.651  93.501  18.723  1.00 70.14           C  \\nATOM   8165  CD  LYS C  95      45.822  93.802  19.637  1.00 70.14           C  \\nATOM   8166  CE  LYS C  95      47.149  93.605  18.904  1.00 70.14           C  \\nATOM   8167  NZ  LYS C  95      48.349  93.952  19.740  1.00 70.14           N  \\nATOM   8168  N   LEU C  96      41.347  91.602  18.693  1.00 14.03           N  \\nATOM   8169  CA  LEU C  96      40.992  90.243  18.303  1.00 14.03           C  \\nATOM   8170  C   LEU C  96      40.069  90.139  17.122  1.00 14.03           C  \\nATOM   8171  O   LEU C  96      40.101  89.127  16.436  1.00 14.03           O  \\nATOM   8172  CB  LEU C  96      40.355  89.515  19.493  1.00 15.02           C  \\nATOM   8173  CG  LEU C  96      39.842  88.078  19.367  1.00 15.02           C  \\nATOM   8174  CD1 LEU C  96      40.912  87.157  18.788  1.00 15.02           C  \\nATOM   8175  CD2 LEU C  96      39.444  87.586  20.750  1.00 15.02           C  \\nATOM   8176  N   LEU C  97      39.168  91.118  16.971  1.00 24.89           N  \\nATOM   8177  CA  LEU C  97      38.178  91.136  15.889  1.00 24.89           C  \\nATOM   8178  C   LEU C  97      38.385  92.335  14.985  1.00 24.89           C  \\nATOM   8179  O   LEU C  97      37.433  92.904  14.425  1.00 24.89           O  \\nATOM   8180  CB  LEU C  97      36.769  91.149  16.487  1.00 16.23           C  \\nATOM   8181  CG  LEU C  97      36.468  89.981  17.441  1.00 16.23           C  \\nATOM   8182  CD1 LEU C  97      35.139  90.169  18.118  1.00 16.23           C  \\nATOM   8183  CD2 LEU C  97      36.494  88.641  16.713  1.00 16.23           C  \\nATOM   8184  N   GLY C  98      39.653  92.696  14.836  1.00 17.33           N  \\nATOM   8185  CA  GLY C  98      40.020  93.834  14.019  1.00 17.33           C  \\nATOM   8186  C   GLY C  98      39.928  93.676  12.513  1.00 17.33           C  \\nATOM   8187  O   GLY C  98      40.153  94.646  11.785  1.00 17.33           O  \\nATOM   8188  N   ARG C  99      39.675  92.455  12.044  1.00 25.00           N  \\nATOM   8189  CA  ARG C  99      39.540  92.173  10.617  1.00 25.00           C  \\nATOM   8190  C   ARG C  99      38.182  91.492  10.435  1.00 25.00           C  \\nATOM   8191  O   ARG C  99      37.936  90.770   9.461  1.00 25.00           O  \\nATOM   8192  CB  ARG C  99      40.682  91.270  10.149  1.00 72.76           C  \\nATOM   8193  CG  ARG C  99      42.018  91.974  10.015  1.00 72.76           C  \\nATOM   8194  CD  ARG C  99      42.156  92.636   8.652  1.00 72.76           C  \\nATOM   8195  NE  ARG C  99      43.375  93.444   8.532  1.00 72.76           N  \\nATOM   8196  CZ  ARG C  99      44.470  93.099   7.847  1.00 72.76           C  \\nATOM   8197  NH1 ARG C  99      44.528  91.938   7.198  1.00 72.76           N  \\nATOM   8198  NH2 ARG C  99      45.514  93.928   7.803  1.00 72.76           N  \\nATOM   8199  N   VAL C 100      37.303  91.735  11.401  1.00 16.39           N  \\nATOM   8200  CA  VAL C 100      35.970  91.158  11.394  1.00 16.39           C  \\nATOM   8201  C   VAL C 100      34.887  92.209  11.310  1.00 16.39           C  \\nATOM   8202  O   VAL C 100      34.971  93.262  11.952  1.00 16.39           O  \\nATOM   8203  CB  VAL C 100      35.714  90.317  12.651  1.00  9.64           C  \\nATOM   8204  CG1 VAL C 100      34.258  89.989  12.776  1.00  9.64           C  \\nATOM   8205  CG2 VAL C 100      36.497  89.032  12.572  1.00  9.64           C  \\nATOM   8206  N   THR C 101      33.912  91.964  10.445  1.00 10.48           N  \\nATOM   8207  CA  THR C 101      32.807  92.887  10.342  1.00 10.48           C  \\nATOM   8208  C   THR C 101      31.513  92.195  10.797  1.00 10.48           C  \\nATOM   8209  O   THR C 101      31.190  91.120  10.344  1.00 10.48           O  \\nATOM   8210  CB  THR C 101      32.726  93.633   8.936  1.00 24.76           C  \\nATOM   8211  OG1 THR C 101      31.475  93.357   8.297  1.00 24.76           O  \\nATOM   8212  CG2 THR C 101      33.882  93.258   8.013  1.00 24.76           C  \\nATOM   8213  N   ILE C 102      30.952  92.731  11.877  1.00  8.73           N  \\nATOM   8214  CA  ILE C 102      29.707  92.298  12.509  1.00  8.73           C  \\nATOM   8215  C   ILE C 102      28.590  92.983  11.715  1.00  8.73           C  \\nATOM   8216  O   ILE C 102      28.420  94.212  11.793  1.00  8.73           O  \\nATOM   8217  CB  ILE C 102      29.622  92.858  13.958  1.00  5.00           C  \\nATOM   8218  CG1 ILE C 102      30.689  92.232  14.856  1.00  5.00           C  \\nATOM   8219  CG2 ILE C 102      28.230  92.721  14.519  1.00  5.00           C  \\nATOM   8220  CD1 ILE C 102      30.674  92.776  16.287  1.00  5.00           C  \\nATOM   8221  N   ALA C 103      27.856  92.208  10.924  1.00 17.87           N  \\nATOM   8222  CA  ALA C 103      26.773  92.756  10.132  1.00 17.87           C  \\nATOM   8223  C   ALA C 103      25.775  93.502  11.052  1.00 17.87           C  \\nATOM   8224  O   ALA C 103      25.642  93.151  12.228  1.00 17.87           O  \\nATOM   8225  CB  ALA C 103      26.099  91.640   9.364  1.00  5.00           C  \\nATOM   8226  N   GLN C 104      25.157  94.567  10.517  1.00 20.70           N  \\nATOM   8227  CA  GLN C 104      24.193  95.448  11.191  1.00 20.70           C  \\nATOM   8228  C   GLN C 104      24.686  96.076  12.491  1.00 20.70           C  \\nATOM   8229  O   GLN C 104      23.886  96.406  13.390  1.00 20.70           O  \\nATOM   8230  CB  GLN C 104      22.836  94.766  11.398  1.00 26.73           C  \\nATOM   8231  CG  GLN C 104      21.873  94.811  10.182  1.00 26.73           C  \\nATOM   8232  CD  GLN C 104      21.459  96.247   9.720  1.00 26.73           C  \\nATOM   8233  OE1 GLN C 104      20.778  97.006  10.452  1.00 26.73           O  \\nATOM   8234  NE2 GLN C 104      21.835  96.593   8.480  1.00 26.73           N  \\nATOM   8235  N   GLY C 105      26.000  96.268  12.594  1.00 13.32           N  \\nATOM   8236  CA  GLY C 105      26.545  96.866  13.804  1.00 13.32           C  \\nATOM   8237  C   GLY C 105      26.840  98.363  13.734  1.00 13.32           C  \\nATOM   8238  O   GLY C 105      26.944  99.029  14.780  1.00 13.32           O  \\nATOM   8239  N   GLY C 106      26.961  98.895  12.509  1.00 17.90           N  \\nATOM   8240  CA  GLY C 106      27.253 100.303  12.332  1.00 17.90           C  \\nATOM   8241  C   GLY C 106      28.652 100.646  12.807  1.00 17.90           C  \\nATOM   8242  O   GLY C 106      29.540  99.780  12.904  1.00 17.90           O  \\nATOM   8243  N   VAL C 107      28.851 101.910  13.160  1.00 19.93           N  \\nATOM   8244  CA  VAL C 107      30.166 102.373  13.587  1.00 19.93           C  \\nATOM   8245  C   VAL C 107      30.037 103.142  14.878  1.00 19.93           C  \\nATOM   8246  O   VAL C 107      28.933 103.503  15.263  1.00 19.93           O  \\nATOM   8247  CB  VAL C 107      30.799 103.308  12.510  1.00  5.00           C  \\nATOM   8248  CG1 VAL C 107      30.940 102.574  11.175  1.00  5.00           C  \\nATOM   8249  CG2 VAL C 107      29.977 104.614  12.344  1.00  5.00           C  \\nATOM   8250  N   LEU C 108      31.158 103.357  15.565  1.00 31.65           N  \\nATOM   8251  CA  LEU C 108      31.146 104.127  16.811  1.00 31.65           C  \\nATOM   8252  C   LEU C 108      31.038 105.591  16.440  1.00 31.65           C  \\nATOM   8253  O   LEU C 108      31.678 106.038  15.482  1.00 31.65           O  \\nATOM   8254  CB  LEU C 108      32.438 103.937  17.599  1.00 10.35           C  \\nATOM   8255  CG  LEU C 108      32.712 102.607  18.290  1.00 10.35           C  \\nATOM   8256  CD1 LEU C 108      33.811 102.846  19.272  1.00 10.35           C  \\nATOM   8257  CD2 LEU C 108      31.475 102.100  19.014  1.00 10.35           C  \\nATOM   8258  N   PRO C 109      30.164 106.342  17.129  1.00 24.79           N  \\nATOM   8259  CA  PRO C 109      30.061 107.759  16.773  1.00 24.79           C  \\nATOM   8260  C   PRO C 109      31.335 108.474  17.148  1.00 24.79           C  \\nATOM   8261  O   PRO C 109      31.754 108.425  18.304  1.00 24.79           O  \\nATOM   8262  CB  PRO C 109      28.848 108.245  17.574  1.00 20.28           C  \\nATOM   8263  CG  PRO C 109      28.656 107.216  18.642  1.00 20.28           C  \\nATOM   8264  CD  PRO C 109      29.041 105.928  17.986  1.00 20.28           C  \\nATOM   8265  N   ASN C 110      31.983 109.070  16.145  1.00 20.40           N  \\nATOM   8266  CA  ASN C 110      33.238 109.784  16.350  1.00 20.40           C  \\nATOM   8267  C   ASN C 110      33.520 110.800  15.262  1.00 20.40           C  \\nATOM   8268  O   ASN C 110      33.844 110.426  14.125  1.00 20.40           O  \\nATOM   8269  CB  ASN C 110      34.403 108.777  16.418  1.00 57.71           C  \\nATOM   8270  CG  ASN C 110      35.756 109.435  16.671  1.00 57.71           C  \\nATOM   8271  OD1 ASN C 110      35.852 110.480  17.322  1.00 57.71           O  \\nATOM   8272  ND2 ASN C 110      36.813 108.805  16.175  1.00 57.71           N  \\nATOM   8273  N   ILE C 111      33.434 112.078  15.632  1.00 28.97           N  \\nATOM   8274  CA  ILE C 111      33.713 113.187  14.717  1.00 28.97           C  \\nATOM   8275  C   ILE C 111      35.065 113.837  15.022  1.00 28.97           C  \\nATOM   8276  O   ILE C 111      35.289 114.295  16.144  1.00 28.97           O  \\nATOM   8277  CB  ILE C 111      32.682 114.309  14.843  1.00 24.04           C  \\nATOM   8278  CG1 ILE C 111      31.320 113.850  14.351  1.00 24.04           C  \\nATOM   8279  CG2 ILE C 111      33.126 115.510  14.037  1.00 24.04           C  \\nATOM   8280  CD1 ILE C 111      30.246 114.908  14.492  1.00 24.04           C  \\nATOM   8281  N   GLN C 112      35.917 113.959  14.000  1.00 18.78           N  \\nATOM   8282  CA  GLN C 112      37.238 114.568  14.140  1.00 18.78           C  \\nATOM   8283  C   GLN C 112      37.048 115.984  14.622  1.00 18.78           C  \\nATOM   8284  O   GLN C 112      36.198 116.698  14.099  1.00 18.78           O  \\nATOM   8285  CB  GLN C 112      37.954 114.554  12.805  1.00 27.63           C  \\nATOM   8286  CG  GLN C 112      38.144 113.158  12.270  1.00 27.63           C  \\nATOM   8287  CD  GLN C 112      38.991 112.316  13.190  1.00 27.63           C  \\nATOM   8288  OE1 GLN C 112      40.142 112.651  13.451  1.00 27.63           O  \\nATOM   8289  NE2 GLN C 112      38.425 111.233  13.707  1.00 27.63           N  \\nATOM   8290  N   SER C 113      37.833 116.363  15.630  1.00 41.64           N  \\nATOM   8291  CA  SER C 113      37.784 117.683  16.267  1.00 41.64           C  \\nATOM   8292  C   SER C 113      37.725 118.890  15.335  1.00 41.64           C  \\nATOM   8293  O   SER C 113      36.907 119.782  15.505  1.00 34.99           O  \\nATOM   8294  CB  SER C 113      38.993 117.850  17.177  1.00 65.70           C  \\nATOM   8295  OG  SER C 113      39.349 116.610  17.747  1.00 65.70           O  \\nATOM   8296  N   VAL C 114      38.575 118.899  14.325  1.00 30.24           N  \\nATOM   8297  CA  VAL C 114      38.637 120.010  13.396  1.00 30.24           C  \\nATOM   8298  C   VAL C 114      37.422 120.158  12.501  1.00 30.24           C  \\nATOM   8299  O   VAL C 114      37.408 121.016  11.614  1.00 30.24           O  \\nATOM   8300  CB  VAL C 114      39.876 119.901  12.513  1.00 37.79           C  \\nATOM   8301  CG1 VAL C 114      41.140 119.889  13.384  1.00 37.79           C  \\nATOM   8302  CG2 VAL C 114      39.797 118.651  11.675  1.00 37.79           C  \\nATOM   8303  N   LEU C 115      36.420 119.305  12.700  1.00 26.44           N  \\nATOM   8304  CA  LEU C 115      35.198 119.358  11.896  1.00 26.44           C  \\nATOM   8305  C   LEU C 115      34.086 120.089  12.638  1.00 26.44           C  \\nATOM   8306  O   LEU C 115      33.114 120.517  12.028  1.00 26.44           O  \\nATOM   8307  CB  LEU C 115      34.744 117.941  11.505  1.00 19.01           C  \\nATOM   8308  CG  LEU C 115      35.695 117.108  10.629  1.00 19.01           C  \\nATOM   8309  CD1 LEU C 115      35.099 115.757  10.323  1.00 19.01           C  \\nATOM   8310  CD2 LEU C 115      35.999 117.850   9.354  1.00 19.01           C  \\nATOM   8311  N   LEU C 116      34.254 120.240  13.950  1.00 24.39           N  \\nATOM   8312  CA  LEU C 116      33.288 120.935  14.781  1.00 24.39           C  \\nATOM   8313  C   LEU C 116      33.389 122.438  14.486  1.00 24.39           C  \\nATOM   8314  O   LEU C 116      34.418 122.918  14.008  1.00 24.39           O  \\nATOM   8315  CB  LEU C 116      33.576 120.676  16.257  1.00 19.78           C  \\nATOM   8316  CG  LEU C 116      33.634 119.222  16.732  1.00 19.78           C  \\nATOM   8317  CD1 LEU C 116      34.027 119.221  18.204  1.00 19.78           C  \\nATOM   8318  CD2 LEU C 116      32.319 118.495  16.518  1.00 19.78           C  \\nATOM   8319  N   PRO C 117      32.317 123.200  14.778  1.00 72.63           N  \\nATOM   8320  CA  PRO C 117      32.241 124.651  14.555  1.00 72.63           C  \\nATOM   8321  C   PRO C 117      33.195 125.511  15.397  1.00 72.63           C  \\nATOM   8322  O   PRO C 117      33.977 124.988  16.196  1.00 72.63           O  \\nATOM   8323  CB  PRO C 117      30.778 124.969  14.893  1.00 55.90           C  \\nATOM   8324  CG  PRO C 117      30.062 123.671  14.686  1.00 55.90           C  \\nATOM   8325  CD  PRO C 117      31.027 122.690  15.277  1.00 55.90           C  \\nATOM   8326  N   LYS C 118      33.077 126.833  15.223  1.00120.09           N  \\nATOM   8327  CA  LYS C 118      33.885 127.843  15.915  1.00120.09           C  \\nATOM   8328  C   LYS C 118      33.918 127.734  17.444  1.00120.09           C  \\nATOM   8329  O   LYS C 118      35.044 127.711  18.001  1.00 56.68           O  \\nATOM   8330  CB  LYS C 118      33.413 129.252  15.531  1.00 92.79           C  \\nATOM   8331  CG  LYS C 118      34.122 130.332  16.322  1.00 92.79           C  \\nATOM   8332  CD  LYS C 118      33.680 131.733  15.989  1.00 92.79           C  \\nATOM   8333  CE  LYS C 118      34.625 132.714  16.681  1.00 92.79           C  \\nATOM   8334  NZ  LYS C 118      34.372 134.147  16.366  1.00 92.79           N  \\nTER    8335      LYS C 118                                                      \\nATOM   8336  N   LYS D  24       5.819  58.872  -0.632  1.00107.71           N  \\nATOM   8337  CA  LYS D  24       6.907  59.854  -0.352  1.00107.71           C  \\nATOM   8338  C   LYS D  24       7.776  59.411   0.821  1.00107.71           C  \\nATOM   8339  O   LYS D  24       7.797  58.230   1.168  1.00107.71           O  \\nATOM   8340  CB  LYS D  24       6.309  61.230  -0.077  1.00 69.93           C  \\nATOM   8341  CG  LYS D  24       5.572  61.807  -1.262  1.00 69.93           C  \\nATOM   8342  CD  LYS D  24       5.160  63.230  -0.981  1.00 69.93           C  \\nATOM   8343  CE  LYS D  24       5.233  64.043  -2.253  1.00 69.93           C  \\nATOM   8344  NZ  LYS D  24       5.212  65.493  -1.951  1.00 69.93           N  \\nATOM   8345  N   LYS D  25       8.490  60.351   1.438  1.00109.97           N  \\nATOM   8346  CA  LYS D  25       9.371  60.013   2.558  1.00109.97           C  \\nATOM   8347  C   LYS D  25       9.397  61.080   3.674  1.00109.97           C  \\nATOM   8348  O   LYS D  25       8.715  62.107   3.589  1.00109.97           O  \\nATOM   8349  CB  LYS D  25      10.806  59.793   2.040  1.00121.69           C  \\nATOM   8350  CG  LYS D  25      10.956  58.924   0.777  1.00121.69           C  \\nATOM   8351  CD  LYS D  25      12.420  58.822   0.350  1.00121.69           C  \\nATOM   8352  CE  LYS D  25      12.595  58.021  -0.930  1.00121.69           C  \\nATOM   8353  NZ  LYS D  25      14.040  57.874  -1.275  1.00121.69           N  \\nATOM   8354  N   ARG D  26      10.188  60.811   4.716  1.00150.56           N  \\nATOM   8355  CA  ARG D  26      10.368  61.713   5.863  1.00150.56           C  \\nATOM   8356  C   ARG D  26      11.776  62.319   5.742  1.00150.56           C  \\nATOM   8357  O   ARG D  26      12.758  61.760   6.243  1.00150.56           O  \\nATOM   8358  CB  ARG D  26      10.249  60.922   7.172  1.00133.59           C  \\nATOM   8359  CG  ARG D  26      10.328  61.749   8.457  1.00133.59           C  \\nATOM   8360  CD  ARG D  26      11.064  60.981   9.557  1.00133.59           C  \\nATOM   8361  NE  ARG D  26      10.726  59.558   9.544  1.00133.59           N  \\nATOM   8362  CZ  ARG D  26      11.589  58.576   9.281  1.00133.59           C  \\nATOM   8363  NH1 ARG D  26      12.861  58.848   9.014  1.00133.59           N  \\nATOM   8364  NH2 ARG D  26      11.166  57.320   9.233  1.00133.59           N  \\nATOM   8365  N   ARG D  27      11.863  63.472   5.088  1.00148.32           N  \\nATOM   8366  CA  ARG D  27      13.145  64.124   4.859  1.00148.32           C  \\nATOM   8367  C   ARG D  27      13.502  65.273   5.818  1.00148.32           C  \\nATOM   8368  O   ARG D  27      13.055  66.411   5.642  1.00148.32           O  \\nATOM   8369  CB  ARG D  27      13.220  64.563   3.388  1.00 75.01           C  \\nATOM   8370  CG  ARG D  27      13.053  63.391   2.380  1.00 75.01           C  \\nATOM   8371  CD  ARG D  27      13.156  63.843   0.904  1.00 75.01           C  \\nATOM   8372  NE  ARG D  27      13.082  62.737  -0.062  1.00 75.01           N  \\nATOM   8373  CZ  ARG D  27      13.436  62.815  -1.349  1.00 75.01           C  \\nATOM   8374  NH1 ARG D  27      13.903  63.943  -1.871  1.00 75.01           N  \\nATOM   8375  NH2 ARG D  27      13.277  61.765  -2.142  1.00 75.01           N  \\nATOM   8376  N   LYS D  28      14.316  64.952   6.827  1.00125.26           N  \\nATOM   8377  CA  LYS D  28      14.772  65.922   7.830  1.00125.26           C  \\nATOM   8378  C   LYS D  28      15.876  66.819   7.259  1.00125.26           C  \\nATOM   8379  O   LYS D  28      15.934  67.031   6.046  1.00125.26           O  \\nATOM   8380  CB  LYS D  28      15.309  65.198   9.069  1.00118.41           C  \\nATOM   8381  CG  LYS D  28      14.266  64.609  10.008  1.00118.41           C  \\nATOM   8382  CD  LYS D  28      14.953  64.097  11.279  1.00118.41           C  \\nATOM   8383  CE  LYS D  28      13.966  63.640  12.344  1.00118.41           C  \\nATOM   8384  NZ  LYS D  28      14.668  63.324  13.621  1.00118.41           N  \\nATOM   8385  N   THR D  29      16.754  67.331   8.128  1.00116.78           N  \\nATOM   8386  CA  THR D  29      17.858  68.203   7.694  1.00116.78           C  \\nATOM   8387  C   THR D  29      19.102  68.275   8.634  1.00116.78           C  \\nATOM   8388  O   THR D  29      20.208  67.883   8.241  1.00116.78           O  \\nATOM   8389  CB  THR D  29      17.334  69.636   7.374  1.00 97.47           C  \\nATOM   8390  OG1 THR D  29      15.918  69.710   7.615  1.00 97.47           O  \\nATOM   8391  CG2 THR D  29      17.608  69.992   5.910  1.00 97.47           C  \\nATOM   8392  N   ARG D  30      18.893  68.786   9.853  1.00108.78           N  \\nATOM   8393  CA  ARG D  30      19.904  68.959  10.929  1.00108.78           C  \\nATOM   8394  C   ARG D  30      21.193  69.763  10.717  1.00108.78           C  \\nATOM   8395  O   ARG D  30      22.101  69.337   9.999  1.00108.78           O  \\nATOM   8396  CB  ARG D  30      20.248  67.639  11.640  1.00 83.99           C  \\nATOM   8397  CG  ARG D  30      21.104  67.873  12.888  1.00 83.99           C  \\nATOM   8398  CD  ARG D  30      21.110  66.722  13.870  1.00 83.99           C  \\nATOM   8399  NE  ARG D  30      21.546  67.190  15.188  1.00 83.99           N  \\nATOM   8400  CZ  ARG D  30      22.201  66.453  16.085  1.00 83.99           C  \\nATOM   8401  NH1 ARG D  30      22.514  65.194  15.822  1.00 83.99           N  \\nATOM   8402  NH2 ARG D  30      22.559  66.977  17.250  1.00 83.99           N  \\nATOM   8403  N   LYS D  31      21.289  70.865  11.470  1.00 56.71           N  \\nATOM   8404  CA  LYS D  31      22.423  71.800  11.452  1.00 56.71           C  \\nATOM   8405  C   LYS D  31      22.735  72.304  12.879  1.00 56.71           C  \\nATOM   8406  O   LYS D  31      22.031  73.164  13.419  1.00 56.71           O  \\nATOM   8407  CB  LYS D  31      22.118  73.015  10.551  1.00108.63           C  \\nATOM   8408  CG  LYS D  31      21.608  72.691   9.139  1.00108.63           C  \\nATOM   8409  CD  LYS D  31      20.213  73.275   8.922  1.00108.63           C  \\nATOM   8410  CE  LYS D  31      19.354  72.379   8.047  1.00108.63           C  \\nATOM   8411  NZ  LYS D  31      17.919  72.583   8.384  1.00108.63           N  \\nATOM   8412  N   GLU D  32      23.804  71.778  13.472  1.00 33.93           N  \\nATOM   8413  CA  GLU D  32      24.233  72.146  14.825  1.00 33.93           C  \\nATOM   8414  C   GLU D  32      24.597  73.634  14.993  1.00 33.93           C  \\nATOM   8415  O   GLU D  32      24.992  74.301  14.035  1.00 33.93           O  \\nATOM   8416  CB  GLU D  32      25.426  71.296  15.192  1.00 90.36           C  \\nATOM   8417  CG  GLU D  32      26.514  71.419  14.152  1.00 90.36           C  \\nATOM   8418  CD  GLU D  32      27.561  70.366  14.292  1.00 90.36           C  \\nATOM   8419  OE1 GLU D  32      27.729  69.878  15.422  1.00 90.36           O  \\nATOM   8420  OE2 GLU D  32      28.208  70.026  13.276  1.00 90.36           O  \\nATOM   8421  N   SER D  33      24.530  74.118  16.232  1.00 25.89           N  \\nATOM   8422  CA  SER D  33      24.809  75.519  16.568  1.00 25.89           C  \\nATOM   8423  C   SER D  33      25.396  75.545  17.972  1.00 25.89           C  \\nATOM   8424  O   SER D  33      25.616  74.496  18.541  1.00 25.89           O  \\nATOM   8425  CB  SER D  33      23.478  76.297  16.537  1.00 32.72           C  \\nATOM   8426  OG  SER D  33      23.579  77.620  17.030  1.00 32.72           O  \\nATOM   8427  N   TYR D  34      25.782  76.719  18.466  1.00 24.46           N  \\nATOM   8428  CA  TYR D  34      26.300  76.862  19.836  1.00 24.46           C  \\nATOM   8429  C   TYR D  34      25.260  77.659  20.608  1.00 24.46           C  \\nATOM   8430  O   TYR D  34      25.465  77.996  21.769  1.00 24.46           O  \\nATOM   8431  CB  TYR D  34      27.619  77.638  19.888  1.00 23.16           C  \\nATOM   8432  CG  TYR D  34      28.822  76.869  19.420  1.00 23.16           C  \\nATOM   8433  CD1 TYR D  34      29.570  76.084  20.308  1.00 23.16           C  \\nATOM   8434  CD2 TYR D  34      29.243  76.942  18.098  1.00 23.16           C  \\nATOM   8435  CE1 TYR D  34      30.721  75.394  19.878  1.00 23.16           C  \\nATOM   8436  CE2 TYR D  34      30.370  76.260  17.667  1.00 23.16           C  \\nATOM   8437  CZ  TYR D  34      31.104  75.493  18.556  1.00 23.16           C  \\nATOM   8438  OH  TYR D  34      32.223  74.834  18.093  1.00 23.16           O  \\nATOM   8439  N   ALA D  35      24.164  77.982  19.922  1.00 30.67           N  \\nATOM   8440  CA  ALA D  35      23.054  78.753  20.468  1.00 30.67           C  \\nATOM   8441  C   ALA D  35      22.639  78.462  21.918  1.00 30.67           C  \\nATOM   8442  O   ALA D  35      22.687  79.352  22.768  1.00 30.67           O  \\nATOM   8443  CB  ALA D  35      21.846  78.659  19.530  1.00 60.44           C  \\nATOM   8444  N   ILE D  36      22.244  77.229  22.214  1.00 28.93           N  \\nATOM   8445  CA  ILE D  36      21.831  76.905  23.573  1.00 28.93           C  \\nATOM   8446  C   ILE D  36      22.963  77.189  24.560  1.00 28.93           C  \\nATOM   8447  O   ILE D  36      22.733  77.686  25.665  1.00 28.93           O  \\nATOM   8448  CB  ILE D  36      21.353  75.429  23.708  1.00 23.57           C  \\nATOM   8449  CG1 ILE D  36      22.504  74.460  23.482  1.00 23.57           C  \\nATOM   8450  CG2 ILE D  36      20.252  75.133  22.708  1.00 23.57           C  \\nATOM   8451  CD1 ILE D  36      22.086  73.023  23.654  1.00 23.57           C  \\nATOM   8452  N   TYR D  37      24.195  76.952  24.134  1.00 24.80           N  \\nATOM   8453  CA  TYR D  37      25.322  77.192  25.022  1.00 24.80           C  \\nATOM   8454  C   TYR D  37      25.586  78.685  25.199  1.00 24.80           C  \\nATOM   8455  O   TYR D  37      25.862  79.136  26.314  1.00 24.80           O  \\nATOM   8456  CB  TYR D  37      26.549  76.440  24.526  1.00 30.83           C  \\nATOM   8457  CG  TYR D  37      26.257  74.986  24.304  1.00 30.83           C  \\nATOM   8458  CD1 TYR D  37      26.058  74.135  25.380  1.00 30.83           C  \\nATOM   8459  CD2 TYR D  37      26.112  74.473  23.012  1.00 30.83           C  \\nATOM   8460  CE1 TYR D  37      25.717  72.804  25.195  1.00 30.83           C  \\nATOM   8461  CE2 TYR D  37      25.773  73.124  22.800  1.00 30.83           C  \\nATOM   8462  CZ  TYR D  37      25.572  72.293  23.904  1.00 30.83           C  \\nATOM   8463  OH  TYR D  37      25.224  70.957  23.729  1.00 30.83           O  \\nATOM   8464  N   VAL D  38      25.497  79.457  24.112  1.00  9.62           N  \\nATOM   8465  CA  VAL D  38      25.683  80.901  24.203  1.00  9.62           C  \\nATOM   8466  C   VAL D  38      24.623  81.334  25.178  1.00  9.62           C  \\nATOM   8467  O   VAL D  38      24.942  81.930  26.199  1.00  9.62           O  \\nATOM   8468  CB  VAL D  38      25.475  81.630  22.864  1.00  8.16           C  \\nATOM   8469  CG1 VAL D  38      25.486  83.116  23.078  1.00  8.16           C  \\nATOM   8470  CG2 VAL D  38      26.580  81.283  21.927  1.00  8.16           C  \\nATOM   8471  N   TYR D  39      23.383  80.893  24.943  1.00 18.17           N  \\nATOM   8472  CA  TYR D  39      22.272  81.223  25.828  1.00 18.17           C  \\nATOM   8473  C   TYR D  39      22.525  80.898  27.333  1.00 18.17           C  \\nATOM   8474  O   TYR D  39      22.367  81.778  28.181  1.00 18.17           O  \\nATOM   8475  CB  TYR D  39      20.981  80.603  25.317  1.00 56.31           C  \\nATOM   8476  CG  TYR D  39      19.769  81.355  25.789  1.00 56.31           C  \\nATOM   8477  CD1 TYR D  39      19.265  82.442  25.067  1.00 56.31           C  \\nATOM   8478  CD2 TYR D  39      19.137  81.009  26.986  1.00 56.31           C  \\nATOM   8479  CE1 TYR D  39      18.142  83.180  25.538  1.00 56.31           C  \\nATOM   8480  CE2 TYR D  39      18.019  81.729  27.473  1.00 56.31           C  \\nATOM   8481  CZ  TYR D  39      17.519  82.814  26.750  1.00 56.31           C  \\nATOM   8482  OH  TYR D  39      16.401  83.492  27.240  1.00 56.31           O  \\nATOM   8483  N   LYS D  40      22.969  79.685  27.674  1.00 22.61           N  \\nATOM   8484  CA  LYS D  40      23.228  79.357  29.085  1.00 22.61           C  \\nATOM   8485  C   LYS D  40      24.124  80.398  29.723  1.00 22.61           C  \\nATOM   8486  O   LYS D  40      23.785  80.985  30.761  1.00 22.61           O  \\nATOM   8487  CB  LYS D  40      23.882  77.990  29.251  1.00 50.79           C  \\nATOM   8488  CG  LYS D  40      22.976  76.824  28.989  1.00 50.79           C  \\nATOM   8489  CD  LYS D  40      23.675  75.517  29.328  1.00 50.79           C  \\nATOM   8490  CE  LYS D  40      22.853  74.295  28.920  1.00 50.79           C  \\nATOM   8491  NZ  LYS D  40      23.535  73.039  29.358  1.00 50.79           N  \\nATOM   8492  N   VAL D  41      25.248  80.658  29.062  1.00 47.68           N  \\nATOM   8493  CA  VAL D  41      26.220  81.627  29.547  1.00 47.68           C  \\nATOM   8494  C   VAL D  41      25.563  82.996  29.633  1.00 47.68           C  \\nATOM   8495  O   VAL D  41      25.744  83.721  30.615  1.00 47.68           O  \\nATOM   8496  CB  VAL D  41      27.470  81.676  28.638  1.00 38.76           C  \\nATOM   8497  CG1 VAL D  41      28.437  82.749  29.128  1.00 38.76           C  \\nATOM   8498  CG2 VAL D  41      28.162  80.322  28.629  1.00 38.76           C  \\nATOM   8499  N   LEU D  42      24.787  83.334  28.607  1.00 21.97           N  \\nATOM   8500  CA  LEU D  42      24.075  84.604  28.582  1.00 21.97           C  \\nATOM   8501  C   LEU D  42      23.317  84.808  29.886  1.00 21.97           C  \\nATOM   8502  O   LEU D  42      23.402  85.876  30.514  1.00 21.97           O  \\nATOM   8503  CB  LEU D  42      23.073  84.649  27.437  1.00 10.75           C  \\nATOM   8504  CG  LEU D  42      22.168  85.894  27.507  1.00 10.75           C  \\nATOM   8505  CD1 LEU D  42      23.028  87.179  27.604  1.00 10.75           C  \\nATOM   8506  CD2 LEU D  42      21.189  85.951  26.319  1.00 10.75           C  \\nATOM   8507  N   LYS D  43      22.592  83.768  30.291  1.00 26.05           N  \\nATOM   8508  CA  LYS D  43      21.803  83.825  31.509  1.00 26.05           C  \\nATOM   8509  C   LYS D  43      22.641  83.939  32.741  1.00 26.05           C  \\nATOM   8510  O   LYS D  43      22.184  84.467  33.749  1.00 26.05           O  \\nATOM   8511  CB  LYS D  43      20.814  82.662  31.590  1.00 44.66           C  \\nATOM   8512  CG  LYS D  43      19.661  82.839  30.618  1.00 44.66           C  \\nATOM   8513  CD  LYS D  43      19.242  84.294  30.640  1.00 44.66           C  \\nATOM   8514  CE  LYS D  43      17.961  84.547  29.909  1.00 44.66           C  \\nATOM   8515  NZ  LYS D  43      17.517  85.935  30.183  1.00 44.66           N  \\nATOM   8516  N   GLN D  44      23.874  83.457  32.655  1.00 20.19           N  \\nATOM   8517  CA  GLN D  44      24.794  83.549  33.785  1.00 20.19           C  \\nATOM   8518  C   GLN D  44      25.287  84.984  34.066  1.00 20.19           C  \\nATOM   8519  O   GLN D  44      25.281  85.426  35.220  1.00 20.19           O  \\nATOM   8520  CB  GLN D  44      25.998  82.615  33.585  1.00 34.11           C  \\nATOM   8521  CG  GLN D  44      25.738  81.134  33.860  1.00 34.11           C  \\nATOM   8522  CD  GLN D  44      26.978  80.267  33.649  1.00 34.11           C  \\nATOM   8523  OE1 GLN D  44      27.752  80.492  32.713  1.00 34.11           O  \\nATOM   8524  NE2 GLN D  44      27.169  79.273  34.512  1.00 34.11           N  \\nATOM   8525  N   VAL D  45      25.699  85.714  33.021  1.00 36.55           N  \\nATOM   8526  CA  VAL D  45      26.236  87.075  33.198  1.00 36.55           C  \\nATOM   8527  C   VAL D  45      25.214  88.167  33.490  1.00 36.55           C  \\nATOM   8528  O   VAL D  45      25.383  88.971  34.431  1.00 36.55           O  \\nATOM   8529  CB  VAL D  45      27.167  87.487  32.013  1.00 24.97           C  \\nATOM   8530  CG1 VAL D  45      28.339  86.495  31.912  1.00 24.97           C  \\nATOM   8531  CG2 VAL D  45      26.396  87.549  30.696  1.00 24.97           C  \\nATOM   8532  N   HIS D  46      24.139  88.132  32.700  1.00 21.80           N  \\nATOM   8533  CA  HIS D  46      23.004  89.054  32.774  1.00 21.80           C  \\nATOM   8534  C   HIS D  46      21.723  88.206  32.734  1.00 21.80           C  \\nATOM   8535  O   HIS D  46      21.102  88.022  31.684  1.00 21.80           O  \\nATOM   8536  CB  HIS D  46      23.032  89.992  31.578  1.00 14.96           C  \\nATOM   8537  CG  HIS D  46      24.176  90.946  31.591  1.00 14.96           C  \\nATOM   8538  ND1 HIS D  46      25.077  91.032  30.554  1.00 14.96           N  \\nATOM   8539  CD2 HIS D  46      24.541  91.887  32.493  1.00 14.96           C  \\nATOM   8540  CE1 HIS D  46      25.948  91.987  30.814  1.00 14.96           C  \\nATOM   8541  NE2 HIS D  46      25.645  92.523  31.982  1.00 14.96           N  \\nATOM   8542  N   PRO D  47      21.247  87.787  33.908  1.00 26.89           N  \\nATOM   8543  CA  PRO D  47      20.055  86.951  34.114  1.00 26.89           C  \\nATOM   8544  C   PRO D  47      18.745  87.380  33.444  1.00 26.89           C  \\nATOM   8545  O   PRO D  47      17.975  86.533  32.980  1.00 26.89           O  \\nATOM   8546  CB  PRO D  47      19.922  86.929  35.643  1.00 25.83           C  \\nATOM   8547  CG  PRO D  47      21.305  87.310  36.145  1.00 25.83           C  \\nATOM   8548  CD  PRO D  47      21.693  88.366  35.186  1.00 25.83           C  \\nATOM   8549  N   ASP D  48      18.528  88.687  33.340  1.00 28.06           N  \\nATOM   8550  CA  ASP D  48      17.286  89.192  32.760  1.00 28.06           C  \\nATOM   8551  C   ASP D  48      17.400  89.817  31.362  1.00 28.06           C  \\nATOM   8552  O   ASP D  48      16.536  90.591  30.957  1.00 28.06           O  \\nATOM   8553  CB  ASP D  48      16.612  90.174  33.749  1.00 40.32           C  \\nATOM   8554  CG  ASP D  48      16.301  89.532  35.128  1.00 40.32           C  \\nATOM   8555  OD1 ASP D  48      16.074  88.299  35.212  1.00 40.32           O  \\nATOM   8556  OD2 ASP D  48      16.278  90.269  36.139  1.00 40.32           O  \\nATOM   8557  N   THR D  49      18.416  89.426  30.598  1.00  7.13           N  \\nATOM   8558  CA  THR D  49      18.614  89.976  29.256  1.00  7.13           C  \\nATOM   8559  C   THR D  49      18.401  88.904  28.172  1.00  7.13           C  \\nATOM   8560  O   THR D  49      18.631  87.726  28.405  1.00  7.13           O  \\nATOM   8561  CB  THR D  49      20.046  90.597  29.160  1.00 14.55           C  \\nATOM   8562  OG1 THR D  49      20.242  91.504  30.257  1.00 14.55           O  \\nATOM   8563  CG2 THR D  49      20.252  91.344  27.851  1.00 14.55           C  \\nATOM   8564  N   GLY D  50      17.927  89.314  27.007  1.00 25.20           N  \\nATOM   8565  CA  GLY D  50      17.718  88.366  25.932  1.00 25.20           C  \\nATOM   8566  C   GLY D  50      18.661  88.644  24.767  1.00 25.20           C  \\nATOM   8567  O   GLY D  50      19.582  89.440  24.897  1.00 25.20           O  \\nATOM   8568  N   ILE D  51      18.390  88.049  23.606  1.00 36.28           N  \\nATOM   8569  CA  ILE D  51      19.235  88.245  22.430  1.00 36.28           C  \\nATOM   8570  C   ILE D  51      18.460  87.912  21.149  1.00 36.28           C  \\nATOM   8571  O   ILE D  51      17.854  86.843  21.042  1.00 36.28           O  \\nATOM   8572  CB  ILE D  51      20.548  87.396  22.548  1.00 20.49           C  \\nATOM   8573  CG1 ILE D  51      21.473  87.631  21.343  1.00 20.49           C  \\nATOM   8574  CG2 ILE D  51      20.241  85.904  22.704  1.00 20.49           C  \\nATOM   8575  CD1 ILE D  51      22.901  87.033  21.505  1.00 20.49           C  \\nATOM   8576  N   SER D  52      18.454  88.841  20.191  1.00 23.83           N  \\nATOM   8577  CA  SER D  52      17.738  88.627  18.938  1.00 23.83           C  \\nATOM   8578  C   SER D  52      18.368  87.470  18.181  1.00 23.83           C  \\nATOM   8579  O   SER D  52      19.488  87.082  18.477  1.00 23.83           O  \\nATOM   8580  CB  SER D  52      17.728  89.894  18.079  1.00 34.42           C  \\nATOM   8581  OG  SER D  52      19.011  90.232  17.594  1.00 34.42           O  \\nATOM   8582  N   SER D  53      17.667  86.902  17.207  1.00 24.91           N  \\nATOM   8583  CA  SER D  53      18.238  85.779  16.475  1.00 24.91           C  \\nATOM   8584  C   SER D  53      19.428  86.241  15.647  1.00 24.91           C  \\nATOM   8585  O   SER D  53      20.385  85.488  15.464  1.00 24.91           O  \\nATOM   8586  CB  SER D  53      17.193  85.116  15.581  1.00 29.05           C  \\nATOM   8587  OG  SER D  53      16.867  85.959  14.498  1.00 29.05           O  \\nATOM   8588  N   LYS D  54      19.373  87.485  15.171  1.00 26.31           N  \\nATOM   8589  CA  LYS D  54      20.461  88.035  14.376  1.00 26.31           C  \\nATOM   8590  C   LYS D  54      21.708  88.102  15.239  1.00 26.31           C  \\nATOM   8591  O   LYS D  54      22.766  87.649  14.830  1.00 26.31           O  \\nATOM   8592  CB  LYS D  54      20.118  89.416  13.825  1.00 57.06           C  \\nATOM   8593  CG  LYS D  54      19.174  89.400  12.643  1.00 57.06           C  \\nATOM   8594  CD  LYS D  54      19.054  90.791  11.991  1.00 57.06           C  \\nATOM   8595  CE  LYS D  54      18.050  90.808  10.813  1.00 57.06           C  \\nATOM   8596  NZ  LYS D  54      17.962  92.144  10.139  1.00 57.06           N  \\nATOM   8597  N   ALA D  55      21.592  88.636  16.449  1.00 20.14           N  \\nATOM   8598  CA  ALA D  55      22.738  88.696  17.343  1.00 20.14           C  \\nATOM   8599  C   ALA D  55      23.264  87.292  17.673  1.00 20.14           C  \\nATOM   8600  O   ALA D  55      24.474  87.072  17.715  1.00 20.14           O  \\nATOM   8601  CB  ALA D  55      22.386  89.431  18.604  1.00 16.06           C  \\nATOM   8602  N   MET D  56      22.374  86.335  17.914  1.00 23.36           N  \\nATOM   8603  CA  MET D  56      22.827  84.981  18.203  1.00 23.36           C  \\nATOM   8604  C   MET D  56      23.594  84.450  17.011  1.00 23.36           C  \\nATOM   8605  O   MET D  56      24.665  83.894  17.163  1.00 23.36           O  \\nATOM   8606  CB  MET D  56      21.673  84.053  18.562  1.00 15.09           C  \\nATOM   8607  CG  MET D  56      22.115  82.631  18.841  1.00 15.09           C  \\nATOM   8608  SD  MET D  56      23.278  82.500  20.205  1.00 15.09           S  \\nATOM   8609  CE  MET D  56      22.171  82.731  21.660  1.00 15.09           C  \\nATOM   8610  N   SER D  57      23.071  84.661  15.816  1.00 25.65           N  \\nATOM   8611  CA  SER D  57      23.768  84.221  14.618  1.00 25.65           C  \\nATOM   8612  C   SER D  57      25.206  84.706  14.672  1.00 25.65           C  \\nATOM   8613  O   SER D  57      26.147  83.959  14.421  1.00 25.65           O  \\nATOM   8614  CB  SER D  57      23.110  84.803  13.386  1.00 19.09           C  \\nATOM   8615  OG  SER D  57      23.849  84.416  12.254  1.00 19.09           O  \\nATOM   8616  N   ILE D  58      25.360  85.978  14.996  1.00 13.01           N  \\nATOM   8617  CA  ILE D  58      26.677  86.580  15.128  1.00 13.01           C  \\nATOM   8618  C   ILE D  58      27.531  85.891  16.197  1.00 13.01           C  \\nATOM   8619  O   ILE D  58      28.684  85.523  15.936  1.00 13.01           O  \\nATOM   8620  CB  ILE D  58      26.548  88.107  15.372  1.00 13.30           C  \\nATOM   8621  CG1 ILE D  58      26.305  88.789  14.022  1.00 13.30           C  \\nATOM   8622  CG2 ILE D  58      27.785  88.664  16.048  1.00 13.30           C  \\nATOM   8623  CD1 ILE D  58      26.047  90.216  14.135  1.00 13.30           C  \\nATOM   8624  N   MET D  59      26.956  85.678  17.382  1.00 12.73           N  \\nATOM   8625  CA  MET D  59      27.679  85.010  18.466  1.00 12.73           C  \\nATOM   8626  C   MET D  59      28.149  83.647  18.021  1.00 12.73           C  \\nATOM   8627  O   MET D  59      29.241  83.189  18.380  1.00 12.73           O  \\nATOM   8628  CB  MET D  59      26.810  84.900  19.697  1.00 19.19           C  \\nATOM   8629  CG  MET D  59      26.740  86.199  20.444  1.00 19.19           C  \\nATOM   8630  SD  MET D  59      28.416  86.827  20.808  1.00 19.19           S  \\nATOM   8631  CE  MET D  59      28.871  85.879  22.278  1.00 19.19           C  \\nATOM   8632  N   ASN D  60      27.339  83.032  17.169  1.00 14.11           N  \\nATOM   8633  CA  ASN D  60      27.679  81.734  16.642  1.00 14.11           C  \\nATOM   8634  C   ASN D  60      28.855  81.837  15.687  1.00 14.11           C  \\nATOM   8635  O   ASN D  60      29.766  81.011  15.757  1.00 14.11           O  \\nATOM   8636  CB  ASN D  60      26.482  81.066  15.985  1.00 20.73           C  \\nATOM   8637  CG  ASN D  60      26.555  79.579  16.103  1.00 20.73           C  \\nATOM   8638  OD1 ASN D  60      26.659  79.058  17.203  1.00 20.73           O  \\nATOM   8639  ND2 ASN D  60      26.585  78.882  14.977  1.00 20.73           N  \\nATOM   8640  N   SER D  61      28.834  82.843  14.804  1.00 25.59           N  \\nATOM   8641  CA  SER D  61      29.932  83.078  13.859  1.00 25.59           C  \\nATOM   8642  C   SER D  61      31.228  83.275  14.627  1.00 25.59           C  \\nATOM   8643  O   SER D  61      32.228  82.614  14.349  1.00 25.59           O  \\nATOM   8644  CB  SER D  61      29.685  84.320  13.001  1.00 34.21           C  \\nATOM   8645  OG  SER D  61      28.742  84.068  11.976  1.00 34.21           O  \\nATOM   8646  N   PHE D  62      31.181  84.160  15.621  1.00 20.95           N  \\nATOM   8647  CA  PHE D  62      32.324  84.469  16.462  1.00 20.95           C  \\nATOM   8648  C   PHE D  62      32.965  83.204  17.021  1.00 20.95           C  \\nATOM   8649  O   PHE D  62      34.139  82.946  16.793  1.00 20.95           O  \\nATOM   8650  CB  PHE D  62      31.866  85.353  17.594  1.00 17.36           C  \\nATOM   8651  CG  PHE D  62      32.857  85.482  18.692  1.00 17.36           C  \\nATOM   8652  CD1 PHE D  62      34.055  86.152  18.494  1.00 17.36           C  \\nATOM   8653  CD2 PHE D  62      32.587  84.968  19.946  1.00 17.36           C  \\nATOM   8654  CE1 PHE D  62      34.973  86.310  19.538  1.00 17.36           C  \\nATOM   8655  CE2 PHE D  62      33.499  85.124  20.996  1.00 17.36           C  \\nATOM   8656  CZ  PHE D  62      34.686  85.795  20.788  1.00 17.36           C  \\nATOM   8657  N   VAL D  63      32.176  82.410  17.735  1.00 21.26           N  \\nATOM   8658  CA  VAL D  63      32.651  81.166  18.333  1.00 21.26           C  \\nATOM   8659  C   VAL D  63      33.382  80.257  17.348  1.00 21.26           C  \\nATOM   8660  O   VAL D  63      34.485  79.791  17.621  1.00 21.26           O  \\nATOM   8661  CB  VAL D  63      31.481  80.385  18.950  1.00 17.21           C  \\nATOM   8662  CG1 VAL D  63      31.958  79.044  19.416  1.00 17.21           C  \\nATOM   8663  CG2 VAL D  63      30.865  81.168  20.108  1.00 17.21           C  \\nATOM   8664  N   ASN D  64      32.762  79.998  16.203  1.00 14.46           N  \\nATOM   8665  CA  ASN D  64      33.379  79.144  15.199  1.00 14.46           C  \\nATOM   8666  C   ASN D  64      34.662  79.768  14.707  1.00 14.46           C  \\nATOM   8667  O   ASN D  64      35.683  79.108  14.645  1.00 14.46           O  \\nATOM   8668  CB  ASN D  64      32.411  78.868  14.054  1.00 46.77           C  \\nATOM   8669  CG  ASN D  64      31.271  77.956  14.482  1.00 46.77           C  \\nATOM   8670  OD1 ASN D  64      31.501  76.872  15.038  1.00 46.77           O  \\nATOM   8671  ND2 ASN D  64      30.036  78.390  14.237  1.00 46.77           N  \\nATOM   8672  N   ASP D  65      34.619  81.067  14.438  1.00 24.22           N  \\nATOM   8673  CA  ASP D  65      35.781  81.804  13.974  1.00 24.22           C  \\nATOM   8674  C   ASP D  65      36.954  81.581  14.902  1.00 24.22           C  \\nATOM   8675  O   ASP D  65      37.967  81.043  14.508  1.00 24.22           O  \\nATOM   8676  CB  ASP D  65      35.479  83.292  13.933  1.00 33.89           C  \\nATOM   8677  CG  ASP D  65      36.591  84.079  13.304  1.00 33.89           C  \\nATOM   8678  OD1 ASP D  65      37.102  83.621  12.262  1.00 33.89           O  \\nATOM   8679  OD2 ASP D  65      36.954  85.142  13.841  1.00 33.89           O  \\nATOM   8680  N   VAL D  66      36.790  81.970  16.153  1.00 24.26           N  \\nATOM   8681  CA  VAL D  66      37.839  81.810  17.135  1.00 24.26           C  \\nATOM   8682  C   VAL D  66      38.272  80.342  17.206  1.00 24.26           C  \\nATOM   8683  O   VAL D  66      39.462  80.033  17.305  1.00 24.26           O  \\nATOM   8684  CB  VAL D  66      37.372  82.292  18.505  1.00  5.83           C  \\nATOM   8685  CG1 VAL D  66      38.465  82.058  19.517  1.00  5.83           C  \\nATOM   8686  CG2 VAL D  66      36.941  83.767  18.451  1.00  5.83           C  \\nATOM   8687  N   PHE D  67      37.308  79.434  17.140  1.00 21.67           N  \\nATOM   8688  CA  PHE D  67      37.617  78.013  17.162  1.00 21.67           C  \\nATOM   8689  C   PHE D  67      38.602  77.615  16.040  1.00 21.67           C  \\nATOM   8690  O   PHE D  67      39.621  76.979  16.291  1.00 21.67           O  \\nATOM   8691  CB  PHE D  67      36.318  77.217  17.046  1.00 33.21           C  \\nATOM   8692  CG  PHE D  67      36.520  75.745  16.876  1.00 33.21           C  \\nATOM   8693  CD1 PHE D  67      36.638  74.919  17.978  1.00 33.21           C  \\nATOM   8694  CD2 PHE D  67      36.597  75.184  15.607  1.00 33.21           C  \\nATOM   8695  CE1 PHE D  67      36.836  73.553  17.818  1.00 33.21           C  \\nATOM   8696  CE2 PHE D  67      36.796  73.823  15.442  1.00 33.21           C  \\nATOM   8697  CZ  PHE D  67      36.915  73.009  16.556  1.00 33.21           C  \\nATOM   8698  N   GLU D  68      38.297  77.977  14.799  1.00 26.19           N  \\nATOM   8699  CA  GLU D  68      39.176  77.643  13.680  1.00 26.19           C  \\nATOM   8700  C   GLU D  68      40.534  78.328  13.785  1.00 26.19           C  \\nATOM   8701  O   GLU D  68      41.531  77.834  13.261  1.00 26.19           O  \\nATOM   8702  CB  GLU D  68      38.510  78.002  12.361  1.00 72.74           C  \\nATOM   8703  CG  GLU D  68      37.322  77.132  12.052  1.00 72.74           C  \\nATOM   8704  CD  GLU D  68      36.238  77.853  11.282  1.00 72.74           C  \\nATOM   8705  OE1 GLU D  68      36.548  78.791  10.510  1.00 72.74           O  \\nATOM   8706  OE2 GLU D  68      35.061  77.474  11.458  1.00 72.74           O  \\nATOM   8707  N   ARG D  69      40.559  79.492  14.427  1.00 20.80           N  \\nATOM   8708  CA  ARG D  69      41.790  80.247  14.602  1.00 20.80           C  \\nATOM   8709  C   ARG D  69      42.703  79.564  15.573  1.00 20.80           C  \\nATOM   8710  O   ARG D  69      43.886  79.353  15.293  1.00 20.80           O  \\nATOM   8711  CB  ARG D  69      41.466  81.645  15.064  1.00 22.98           C  \\nATOM   8712  CG  ARG D  69      40.762  82.418  13.972  1.00 22.98           C  \\nATOM   8713  CD  ARG D  69      41.182  83.858  13.977  1.00 22.98           C  \\nATOM   8714  NE  ARG D  69      40.091  84.757  14.297  1.00 22.98           N  \\nATOM   8715  CZ  ARG D  69      40.259  85.894  14.945  1.00 22.98           C  \\nATOM   8716  NH1 ARG D  69      41.458  86.249  15.355  1.00 22.98           N  \\nATOM   8717  NH2 ARG D  69      39.250  86.725  15.104  1.00 22.98           N  \\nATOM   8718  N   ILE D  70      42.121  79.159  16.695  1.00 23.63           N  \\nATOM   8719  CA  ILE D  70      42.857  78.454  17.723  1.00 23.63           C  \\nATOM   8720  C   ILE D  70      43.272  77.065  17.262  1.00 23.63           C  \\nATOM   8721  O   ILE D  70      44.420  76.675  17.472  1.00 23.63           O  \\nATOM   8722  CB  ILE D  70      42.047  78.356  18.997  1.00 13.50           C  \\nATOM   8723  CG1 ILE D  70      42.069  79.707  19.711  1.00 13.50           C  \\nATOM   8724  CG2 ILE D  70      42.615  77.272  19.880  1.00 13.50           C  \\nATOM   8725  CD1 ILE D  70      41.261  79.766  20.966  1.00 13.50           C  \\nATOM   8726  N   ALA D  71      42.347  76.336  16.618  1.00 17.31           N  \\nATOM   8727  CA  ALA D  71      42.608  74.982  16.102  1.00 17.31           C  \\nATOM   8728  C   ALA D  71      43.660  75.055  15.010  1.00 17.31           C  \\nATOM   8729  O   ALA D  71      44.533  74.204  14.916  1.00 17.31           O  \\nATOM   8730  CB  ALA D  71      41.328  74.354  15.569  1.00 12.33           C  \\nATOM   8731  N   GLY D  72      43.598  76.125  14.236  1.00 20.95           N  \\nATOM   8732  CA  GLY D  72      44.562  76.320  13.178  1.00 20.95           C  \\nATOM   8733  C   GLY D  72      45.949  76.545  13.764  1.00 20.95           C  \\nATOM   8734  O   GLY D  72      46.923  75.926  13.320  1.00 20.95           O  \\nATOM   8735  N   GLU D  73      46.055  77.460  14.729  1.00 32.31           N  \\nATOM   8736  CA  GLU D  73      47.336  77.717  15.372  1.00 32.31           C  \\nATOM   8737  C   GLU D  73      47.876  76.381  15.841  1.00 32.31           C  \\nATOM   8738  O   GLU D  73      48.936  75.950  15.404  1.00 32.31           O  \\nATOM   8739  CB  GLU D  73      47.187  78.655  16.580  1.00 47.12           C  \\nATOM   8740  CG  GLU D  73      47.173  80.139  16.261  1.00 47.12           C  \\nATOM   8741  CD  GLU D  73      48.357  80.593  15.414  1.00 47.12           C  \\nATOM   8742  OE1 GLU D  73      49.463  80.000  15.514  1.00 47.12           O  \\nATOM   8743  OE2 GLU D  73      48.173  81.554  14.637  1.00 47.12           O  \\nATOM   8744  N   ALA D  74      47.092  75.705  16.678  1.00 20.51           N  \\nATOM   8745  CA  ALA D  74      47.449  74.398  17.221  1.00 20.51           C  \\nATOM   8746  C   ALA D  74      47.963  73.471  16.131  1.00 20.51           C  \\nATOM   8747  O   ALA D  74      49.016  72.878  16.278  1.00 20.51           O  \\nATOM   8748  CB  ALA D  74      46.252  73.778  17.910  1.00 27.58           C  \\nATOM   8749  N   SER D  75      47.220  73.352  15.041  1.00 20.45           N  \\nATOM   8750  CA  SER D  75      47.650  72.510  13.941  1.00 20.45           C  \\nATOM   8751  C   SER D  75      49.093  72.806  13.543  1.00 20.45           C  \\nATOM   8752  O   SER D  75      49.942  71.926  13.615  1.00 20.45           O  \\nATOM   8753  CB  SER D  75      46.739  72.696  12.725  1.00 28.27           C  \\nATOM   8754  OG  SER D  75      47.163  71.851  11.672  1.00 28.27           O  \\nATOM   8755  N   ARG D  76      49.367  74.058  13.182  1.00 20.62           N  \\nATOM   8756  CA  ARG D  76      50.695  74.489  12.759  1.00 20.62           C  \\nATOM   8757  C   ARG D  76      51.742  74.303  13.822  1.00 20.62           C  \\nATOM   8758  O   ARG D  76      52.846  73.855  13.533  1.00 20.62           O  \\nATOM   8759  CB  ARG D  76      50.672  75.942  12.305  1.00 46.88           C  \\nATOM   8760  CG  ARG D  76      50.341  76.101  10.839  1.00 46.88           C  \\nATOM   8761  CD  ARG D  76      49.977  77.533  10.502  1.00 46.88           C  \\nATOM   8762  NE  ARG D  76      48.524  77.729  10.501  1.00 46.88           N  \\nATOM   8763  CZ  ARG D  76      47.869  78.573  11.300  1.00 46.88           C  \\nATOM   8764  NH1 ARG D  76      48.523  79.323  12.191  1.00 46.88           N  \\nATOM   8765  NH2 ARG D  76      46.554  78.682  11.198  1.00 46.88           N  \\nATOM   8766  N   LEU D  77      51.412  74.652  15.054  1.00 27.75           N  \\nATOM   8767  CA  LEU D  77      52.338  74.476  16.167  1.00 27.75           C  \\nATOM   8768  C   LEU D  77      52.827  73.009  16.209  1.00 27.75           C  \\nATOM   8769  O   LEU D  77      54.023  72.752  16.267  1.00 27.75           O  \\nATOM   8770  CB  LEU D  77      51.625  74.841  17.459  1.00 18.60           C  \\nATOM   8771  CG  LEU D  77      52.427  75.098  18.724  1.00 18.60           C  \\nATOM   8772  CD1 LEU D  77      53.676  75.946  18.432  1.00 18.60           C  \\nATOM   8773  CD2 LEU D  77      51.506  75.799  19.717  1.00 18.60           C  \\nATOM   8774  N   ALA D  78      51.895  72.056  16.140  1.00 34.33           N  \\nATOM   8775  CA  ALA D  78      52.210  70.631  16.147  1.00 34.33           C  \\nATOM   8776  C   ALA D  78      53.165  70.204  15.019  1.00 34.33           C  \\nATOM   8777  O   ALA D  78      54.082  69.425  15.244  1.00 34.33           O  \\nATOM   8778  CB  ALA D  78      50.930  69.826  16.074  1.00 22.89           C  \\nATOM   8779  N   HIS D  79      52.917  70.634  13.788  1.00 19.86           N  \\nATOM   8780  CA  HIS D  79      53.826  70.254  12.713  1.00 19.86           C  \\nATOM   8781  C   HIS D  79      55.198  70.893  12.940  1.00 19.86           C  \\nATOM   8782  O   HIS D  79      56.200  70.209  12.891  1.00 19.86           O  \\nATOM   8783  CB  HIS D  79      53.231  70.554  11.336  1.00 98.39           C  \\nATOM   8784  CG  HIS D  79      52.038  69.704  11.006  1.00 98.39           C  \\nATOM   8785  ND1 HIS D  79      51.526  69.596   9.730  1.00 98.39           N  \\nATOM   8786  CD2 HIS D  79      51.256  68.923  11.792  1.00 98.39           C  \\nATOM   8787  CE1 HIS D  79      50.480  68.789   9.744  1.00 98.39           C  \\nATOM   8788  NE2 HIS D  79      50.295  68.368  10.983  1.00 98.39           N  \\nATOM   8789  N   TYR D  80      55.231  72.156  13.350  1.00 39.77           N  \\nATOM   8790  CA  TYR D  80      56.498  72.845  13.630  1.00 39.77           C  \\nATOM   8791  C   TYR D  80      57.394  72.041  14.557  1.00 39.77           C  \\nATOM   8792  O   TYR D  80      58.614  72.241  14.582  1.00 39.77           O  \\nATOM   8793  CB  TYR D  80      56.241  74.204  14.277  1.00 56.56           C  \\nATOM   8794  CG  TYR D  80      55.509  75.162  13.384  1.00 56.56           C  \\nATOM   8795  CD1 TYR D  80      55.369  74.899  12.020  1.00 56.56           C  \\nATOM   8796  CD2 TYR D  80      54.972  76.342  13.888  1.00 56.56           C  \\nATOM   8797  CE1 TYR D  80      54.715  75.787  11.175  1.00 56.56           C  \\nATOM   8798  CE2 TYR D  80      54.317  77.243  13.055  1.00 56.56           C  \\nATOM   8799  CZ  TYR D  80      54.190  76.962  11.693  1.00 56.56           C  \\nATOM   8800  OH  TYR D  80      53.546  77.853  10.846  1.00 56.56           O  \\nATOM   8801  N   ASN D  81      56.776  71.146  15.326  1.00 29.42           N  \\nATOM   8802  CA  ASN D  81      57.502  70.318  16.277  1.00 29.42           C  \\nATOM   8803  C   ASN D  81      57.458  68.836  16.000  1.00 29.42           C  \\nATOM   8804  O   ASN D  81      57.788  68.043  16.874  1.00 29.42           O  \\nATOM   8805  CB  ASN D  81      57.006  70.574  17.698  1.00 33.90           C  \\nATOM   8806  CG  ASN D  81      57.319  71.968  18.175  1.00 33.90           C  \\nATOM   8807  OD1 ASN D  81      58.338  72.202  18.823  1.00 33.90           O  \\nATOM   8808  ND2 ASN D  81      56.462  72.916  17.830  1.00 33.90           N  \\nATOM   8809  N   LYS D  82      57.081  68.460  14.786  1.00 42.10           N  \\nATOM   8810  CA  LYS D  82      56.987  67.050  14.401  1.00 42.10           C  \\nATOM   8811  C   LYS D  82      56.143  66.239  15.392  1.00 42.10           C  \\nATOM   8812  O   LYS D  82      56.473  65.098  15.725  1.00 42.10           O  \\nATOM   8813  CB  LYS D  82      58.389  66.461  14.210  1.00 46.61           C  \\nATOM   8814  CG  LYS D  82      59.225  67.291  13.249  1.00 46.61           C  \\nATOM   8815  CD  LYS D  82      60.662  66.857  13.200  1.00 46.61           C  \\nATOM   8816  CE  LYS D  82      61.506  67.864  12.406  1.00 46.61           C  \\nATOM   8817  NZ  LYS D  82      62.978  67.519  12.402  1.00 46.61           N  \\nATOM   8818  N   ARG D  83      55.095  66.895  15.901  1.00 54.16           N  \\nATOM   8819  CA  ARG D  83      54.129  66.321  16.832  1.00 54.16           C  \\nATOM   8820  C   ARG D  83      52.919  65.906  16.010  1.00 54.16           C  \\nATOM   8821  O   ARG D  83      52.498  66.629  15.095  1.00 54.16           O  \\nATOM   8822  CB  ARG D  83      53.651  67.347  17.864  1.00118.10           C  \\nATOM   8823  CG  ARG D  83      54.353  67.291  19.193  1.00118.10           C  \\nATOM   8824  CD  ARG D  83      55.617  68.094  19.146  1.00118.10           C  \\nATOM   8825  NE  ARG D  83      56.781  67.335  19.586  1.00118.10           N  \\nATOM   8826  CZ  ARG D  83      57.036  67.029  20.854  1.00118.10           C  \\nATOM   8827  NH1 ARG D  83      56.204  67.418  21.817  1.00118.10           N  \\nATOM   8828  NH2 ARG D  83      58.132  66.353  21.165  1.00118.10           N  \\nATOM   8829  N   SER D  84      52.349  64.751  16.336  1.00 32.97           N  \\nATOM   8830  CA  SER D  84      51.188  64.277  15.606  1.00 32.97           C  \\nATOM   8831  C   SER D  84      49.900  64.369  16.419  1.00 32.97           C  \\nATOM   8832  O   SER D  84      48.820  64.105  15.890  1.00 32.97           O  \\nATOM   8833  CB  SER D  84      51.422  62.865  15.077  1.00 24.81           C  \\nATOM   8834  OG  SER D  84      51.965  62.066  16.098  1.00 24.81           O  \\nATOM   8835  N   THR D  85      50.008  64.693  17.711  1.00 34.98           N  \\nATOM   8836  CA  THR D  85      48.807  64.851  18.537  1.00 34.98           C  \\nATOM   8837  C   THR D  85      48.704  66.289  19.042  1.00 34.98           C  \\nATOM   8838  O   THR D  85      49.724  66.948  19.293  1.00 34.98           O  \\nATOM   8839  CB  THR D  85      48.765  63.905  19.776  1.00 57.56           C  \\nATOM   8840  OG1 THR D  85      49.644  64.396  20.784  1.00 57.56           O  \\nATOM   8841  CG2 THR D  85      49.203  62.514  19.423  1.00 57.56           C  \\nATOM   8842  N   ILE D  86      47.475  66.793  19.077  1.00 36.02           N  \\nATOM   8843  CA  ILE D  86      47.218  68.129  19.598  1.00 36.02           C  \\nATOM   8844  C   ILE D  86      46.669  67.971  21.019  1.00 36.02           C  \\nATOM   8845  O   ILE D  86      45.558  67.467  21.225  1.00 36.02           O  \\nATOM   8846  CB  ILE D  86      46.196  68.939  18.749  1.00 23.29           C  \\nATOM   8847  CG1 ILE D  86      46.785  69.287  17.386  1.00 23.29           C  \\nATOM   8848  CG2 ILE D  86      45.837  70.247  19.463  1.00 23.29           C  \\nATOM   8849  CD1 ILE D  86      45.804  69.988  16.473  1.00 23.29           C  \\nATOM   8850  N   THR D  87      47.470  68.367  21.998  1.00 21.80           N  \\nATOM   8851  CA  THR D  87      47.057  68.254  23.372  1.00 21.80           C  \\nATOM   8852  C   THR D  87      46.704  69.611  23.971  1.00 21.80           C  \\nATOM   8853  O   THR D  87      46.809  70.655  23.317  1.00 21.80           O  \\nATOM   8854  CB  THR D  87      48.168  67.614  24.192  1.00 24.46           C  \\nATOM   8855  OG1 THR D  87      49.342  68.432  24.106  1.00 24.46           O  \\nATOM   8856  CG2 THR D  87      48.490  66.255  23.646  1.00 24.46           C  \\nATOM   8857  N   SER D  88      46.300  69.596  25.232  1.00 36.60           N  \\nATOM   8858  CA  SER D  88      45.958  70.827  25.911  1.00 36.60           C  \\nATOM   8859  C   SER D  88      47.102  71.841  25.801  1.00 36.60           C  \\nATOM   8860  O   SER D  88      46.862  73.043  25.672  1.00 36.60           O  \\nATOM   8861  CB  SER D  88      45.623  70.543  27.383  1.00 24.19           C  \\nATOM   8862  OG  SER D  88      46.755  70.102  28.110  1.00 24.19           O  \\nATOM   8863  N   ARG D  89      48.336  71.344  25.720  1.00 27.44           N  \\nATOM   8864  CA  ARG D  89      49.518  72.214  25.629  1.00 27.44           C  \\nATOM   8865  C   ARG D  89      49.592  73.025  24.319  1.00 27.44           C  \\nATOM   8866  O   ARG D  89      50.023  74.184  24.298  1.00 27.44           O  \\nATOM   8867  CB  ARG D  89      50.781  71.382  25.790  1.00 46.42           C  \\nATOM   8868  CG  ARG D  89      52.008  72.224  25.955  1.00 46.42           C  \\nATOM   8869  CD  ARG D  89      53.247  71.393  26.279  1.00 46.42           C  \\nATOM   8870  NE  ARG D  89      54.371  72.274  26.605  1.00 46.42           N  \\nATOM   8871  CZ  ARG D  89      55.326  72.621  25.755  1.00 46.42           C  \\nATOM   8872  NH1 ARG D  89      55.321  72.151  24.519  1.00 46.42           N  \\nATOM   8873  NH2 ARG D  89      56.242  73.499  26.131  1.00 46.42           N  \\nATOM   8874  N   GLU D  90      49.184  72.405  23.219  1.00 33.49           N  \\nATOM   8875  CA  GLU D  90      49.195  73.105  21.951  1.00 33.49           C  \\nATOM   8876  C   GLU D  90      48.141  74.200  22.076  1.00 33.49           C  \\nATOM   8877  O   GLU D  90      48.432  75.370  21.853  1.00 33.49           O  \\nATOM   8878  CB  GLU D  90      48.867  72.176  20.773  1.00 29.09           C  \\nATOM   8879  CG  GLU D  90      49.285  70.694  20.886  1.00 29.09           C  \\nATOM   8880  CD  GLU D  90      50.711  70.457  21.372  1.00 29.09           C  \\nATOM   8881  OE1 GLU D  90      51.676  70.953  20.754  1.00 29.09           O  \\nATOM   8882  OE2 GLU D  90      50.859  69.741  22.382  1.00 29.09           O  \\nATOM   8883  N   ILE D  91      46.947  73.819  22.532  1.00 21.46           N  \\nATOM   8884  CA  ILE D  91      45.841  74.770  22.711  1.00 21.46           C  \\nATOM   8885  C   ILE D  91      46.304  75.947  23.543  1.00 21.46           C  \\nATOM   8886  O   ILE D  91      46.072  77.093  23.166  1.00 21.46           O  \\nATOM   8887  CB  ILE D  91      44.589  74.135  23.427  1.00 13.51           C  \\nATOM   8888  CG1 ILE D  91      44.138  72.865  22.691  1.00 13.51           C  \\nATOM   8889  CG2 ILE D  91      43.418  75.149  23.518  1.00 13.51           C  \\nATOM   8890  CD1 ILE D  91      43.865  73.082  21.249  1.00 13.51           C  \\nATOM   8891  N   GLN D  92      47.003  75.674  24.641  1.00 25.30           N  \\nATOM   8892  CA  GLN D  92      47.474  76.761  25.489  1.00 25.30           C  \\nATOM   8893  C   GLN D  92      48.357  77.781  24.773  1.00 25.30           C  \\nATOM   8894  O   GLN D  92      48.107  78.979  24.891  1.00 25.30           O  \\nATOM   8895  CB  GLN D  92      48.137  76.272  26.781  1.00 53.72           C  \\nATOM   8896  CG  GLN D  92      48.383  77.432  27.747  1.00 53.72           C  \\nATOM   8897  CD  GLN D  92      48.830  77.027  29.148  1.00 53.72           C  \\nATOM   8898  OE1 GLN D  92      50.019  77.026  29.447  1.00 53.72           O  \\nATOM   8899  NE2 GLN D  92      47.871  76.786  30.033  1.00 53.72           N  \\nATOM   8900  N   THR D  93      49.376  77.344  24.030  1.00 20.58           N  \\nATOM   8901  CA  THR D  93      50.196  78.333  23.323  1.00 20.58           C  \\nATOM   8902  C   THR D  93      49.448  78.943  22.121  1.00 20.58           C  \\nATOM   8903  O   THR D  93      49.654  80.091  21.777  1.00 20.58           O  \\nATOM   8904  CB  THR D  93      51.621  77.812  22.968  1.00 32.75           C  \\nATOM   8905  OG1 THR D  93      51.524  76.501  22.420  1.00 32.75           O  \\nATOM   8906  CG2 THR D  93      52.495  77.749  24.232  1.00 32.75           C  \\nATOM   8907  N   ALA D  94      48.536  78.197  21.514  1.00 13.14           N  \\nATOM   8908  CA  ALA D  94      47.746  78.741  20.411  1.00 13.14           C  \\nATOM   8909  C   ALA D  94      47.022  79.959  20.969  1.00 13.14           C  \\nATOM   8910  O   ALA D  94      47.028  81.031  20.372  1.00 13.14           O  \\nATOM   8911  CB  ALA D  94      46.735  77.720  19.949  1.00 17.14           C  \\nATOM   8912  N   VAL D  95      46.415  79.770  22.143  1.00 15.28           N  \\nATOM   8913  CA  VAL D  95      45.690  80.821  22.843  1.00 15.28           C  \\nATOM   8914  C   VAL D  95      46.595  82.014  23.093  1.00 15.28           C  \\nATOM   8915  O   VAL D  95      46.185  83.138  22.895  1.00 15.28           O  \\nATOM   8916  CB  VAL D  95      45.159  80.323  24.204  1.00 14.13           C  \\nATOM   8917  CG1 VAL D  95      44.667  81.489  25.030  1.00 14.13           C  \\nATOM   8918  CG2 VAL D  95      44.051  79.289  23.995  1.00 14.13           C  \\nATOM   8919  N   ARG D  96      47.808  81.761  23.575  1.00 31.61           N  \\nATOM   8920  CA  ARG D  96      48.773  82.828  23.854  1.00 31.61           C  \\nATOM   8921  C   ARG D  96      49.188  83.584  22.590  1.00 31.61           C  \\nATOM   8922  O   ARG D  96      49.354  84.810  22.609  1.00 31.61           O  \\nATOM   8923  CB  ARG D  96      50.000  82.254  24.547  1.00 42.27           C  \\nATOM   8924  CG  ARG D  96      49.712  81.635  25.898  1.00 42.27           C  \\nATOM   8925  CD  ARG D  96      50.064  82.587  27.034  1.00 42.27           C  \\nATOM   8926  NE  ARG D  96      50.044  81.933  28.347  1.00 42.27           N  \\nATOM   8927  CZ  ARG D  96      50.856  80.942  28.727  1.00 42.27           C  \\nATOM   8928  NH1 ARG D  96      51.782  80.464  27.901  1.00 42.27           N  \\nATOM   8929  NH2 ARG D  96      50.729  80.406  29.937  1.00 42.27           N  \\nATOM   8930  N   LEU D  97      49.357  82.853  21.494  1.00 29.71           N  \\nATOM   8931  CA  LEU D  97      49.735  83.456  20.230  1.00 29.71           C  \\nATOM   8932  C   LEU D  97      48.621  84.276  19.618  1.00 29.71           C  \\nATOM   8933  O   LEU D  97      48.885  85.280  18.967  1.00 29.71           O  \\nATOM   8934  CB  LEU D  97      50.152  82.391  19.227  1.00 13.82           C  \\nATOM   8935  CG  LEU D  97      51.515  81.735  19.428  1.00 13.82           C  \\nATOM   8936  CD1 LEU D  97      51.564  80.425  18.618  1.00 13.82           C  \\nATOM   8937  CD2 LEU D  97      52.637  82.718  19.039  1.00 13.82           C  \\nATOM   8938  N   LEU D  98      47.382  83.851  19.831  1.00 17.35           N  \\nATOM   8939  CA  LEU D  98      46.242  84.537  19.259  1.00 17.35           C  \\nATOM   8940  C   LEU D  98      45.528  85.612  20.098  1.00 17.35           C  \\nATOM   8941  O   LEU D  98      45.123  86.659  19.590  1.00 17.35           O  \\nATOM   8942  CB  LEU D  98      45.262  83.482  18.761  1.00 25.48           C  \\nATOM   8943  CG  LEU D  98      44.077  83.980  17.955  1.00 25.48           C  \\nATOM   8944  CD1 LEU D  98      44.475  84.213  16.535  1.00 25.48           C  \\nATOM   8945  CD2 LEU D  98      42.993  82.950  18.025  1.00 25.48           C  \\nATOM   8946  N   LEU D  99      45.358  85.379  21.377  1.00 23.96           N  \\nATOM   8947  CA  LEU D  99      44.661  86.364  22.183  1.00 23.96           C  \\nATOM   8948  C   LEU D  99      45.547  87.465  22.732  1.00 23.96           C  \\nATOM   8949  O   LEU D  99      46.675  87.217  23.180  1.00 23.96           O  \\nATOM   8950  CB  LEU D  99      43.954  85.686  23.351  1.00 19.68           C  \\nATOM   8951  CG  LEU D  99      43.076  84.504  22.978  1.00 19.68           C  \\nATOM   8952  CD1 LEU D  99      42.344  84.027  24.216  1.00 19.68           C  \\nATOM   8953  CD2 LEU D  99      42.104  84.925  21.907  1.00 19.68           C  \\nATOM   8954  N   PRO D 100      45.060  88.712  22.674  1.00 33.99           N  \\nATOM   8955  CA  PRO D 100      45.813  89.859  23.183  1.00 33.99           C  \\nATOM   8956  C   PRO D 100      45.918  89.853  24.702  1.00 33.99           C  \\nATOM   8957  O   PRO D 100      45.174  89.165  25.374  1.00 33.99           O  \\nATOM   8958  CB  PRO D 100      45.009  91.057  22.669  1.00 45.52           C  \\nATOM   8959  CG  PRO D 100      43.640  90.502  22.444  1.00 45.52           C  \\nATOM   8960  CD  PRO D 100      43.942  89.168  21.833  1.00 45.52           C  \\nATOM   8961  N   GLY D 101      46.928  90.562  25.202  1.00 15.80           N  \\nATOM   8962  CA  GLY D 101      47.218  90.716  26.622  1.00 15.80           C  \\nATOM   8963  C   GLY D 101      46.368  90.127  27.712  1.00 15.80           C  \\nATOM   8964  O   GLY D 101      46.422  88.938  27.939  1.00 15.80           O  \\nATOM   8965  N   GLU D 102      45.591  90.965  28.393  1.00 24.73           N  \\nATOM   8966  CA  GLU D 102      44.750  90.520  29.509  1.00 24.73           C  \\nATOM   8967  C   GLU D 102      43.765  89.374  29.233  1.00 24.73           C  \\nATOM   8968  O   GLU D 102      43.536  88.528  30.092  1.00 24.73           O  \\nATOM   8969  CB  GLU D 102      44.025  91.710  30.135  1.00 59.05           C  \\nATOM   8970  CG  GLU D 102      43.653  91.517  31.608  1.00 59.05           C  \\nATOM   8971  CD  GLU D 102      44.862  91.361  32.541  1.00 59.05           C  \\nATOM   8972  OE1 GLU D 102      46.003  91.687  32.134  1.00 59.05           O  \\nATOM   8973  OE2 GLU D 102      44.665  90.911  33.696  1.00 59.05           O  \\nATOM   8974  N   LEU D 103      43.247  89.306  28.014  1.00 35.08           N  \\nATOM   8975  CA  LEU D 103      42.293  88.276  27.607  1.00 35.08           C  \\nATOM   8976  C   LEU D 103      42.981  86.917  27.537  1.00 35.08           C  \\nATOM   8977  O   LEU D 103      42.426  85.916  27.970  1.00 35.08           O  \\nATOM   8978  CB  LEU D 103      41.722  88.655  26.246  1.00 17.41           C  \\nATOM   8979  CG  LEU D 103      40.280  88.394  25.851  1.00 17.41           C  \\nATOM   8980  CD1 LEU D 103      39.310  88.707  26.990  1.00 17.41           C  \\nATOM   8981  CD2 LEU D 103      39.996  89.253  24.619  1.00 17.41           C  \\nATOM   8982  N   ALA D 104      44.189  86.884  26.979  1.00 28.75           N  \\nATOM   8983  CA  ALA D 104      44.972  85.655  26.884  1.00 28.75           C  \\nATOM   8984  C   ALA D 104      45.257  85.161  28.300  1.00 28.75           C  \\nATOM   8985  O   ALA D 104      45.120  83.971  28.596  1.00 28.75           O  \\nATOM   8986  CB  ALA D 104      46.267  85.915  26.153  1.00  5.90           C  \\nATOM   8987  N   LYS D 105      45.616  86.094  29.179  1.00 25.77           N  \\nATOM   8988  CA  LYS D 105      45.893  85.784  30.571  1.00 25.77           C  \\nATOM   8989  C   LYS D 105      44.703  85.077  31.203  1.00 25.77           C  \\nATOM   8990  O   LYS D 105      44.856  84.005  31.795  1.00 25.77           O  \\nATOM   8991  CB  LYS D 105      46.226  87.062  31.333  1.00 66.01           C  \\nATOM   8992  CG  LYS D 105      46.521  86.870  32.806  1.00 66.01           C  \\nATOM   8993  CD  LYS D 105      47.262  88.078  33.380  1.00 66.01           C  \\nATOM   8994  CE  LYS D 105      48.638  88.254  32.724  1.00 66.01           C  \\nATOM   8995  NZ  LYS D 105      49.384  89.446  33.228  1.00 66.01           N  \\nATOM   8996  N   HIS D 106      43.509  85.640  31.033  1.00 27.76           N  \\nATOM   8997  CA  HIS D 106      42.314  85.027  31.611  1.00 27.76           C  \\nATOM   8998  C   HIS D 106      41.886  83.690  30.985  1.00 27.76           C  \\nATOM   8999  O   HIS D 106      41.505  82.766  31.725  1.00 27.76           O  \\nATOM   9000  CB  HIS D 106      41.143  86.022  31.701  1.00 33.04           C  \\nATOM   9001  CG  HIS D 106      41.311  87.081  32.758  1.00 33.04           C  \\nATOM   9002  ND1 HIS D 106      40.923  88.391  32.566  1.00 33.04           N  \\nATOM   9003  CD2 HIS D 106      41.818  87.022  34.014  1.00 33.04           C  \\nATOM   9004  CE1 HIS D 106      41.188  89.095  33.653  1.00 33.04           C  \\nATOM   9005  NE2 HIS D 106      41.731  88.288  34.546  1.00 33.04           N  \\nATOM   9006  N   ALA D 107      41.946  83.574  29.649  1.00 28.67           N  \\nATOM   9007  CA  ALA D 107      41.601  82.308  28.960  1.00 28.67           C  \\nATOM   9008  C   ALA D 107      42.451  81.154  29.495  1.00 28.67           C  \\nATOM   9009  O   ALA D 107      41.934  80.076  29.766  1.00 28.67           O  \\nATOM   9010  CB  ALA D 107      41.800  82.430  27.470  1.00  7.98           C  \\nATOM   9011  N   VAL D 108      43.751  81.401  29.667  1.00 24.38           N  \\nATOM   9012  CA  VAL D 108      44.674  80.399  30.204  1.00 24.38           C  \\nATOM   9013  C   VAL D 108      44.278  79.904  31.580  1.00 24.38           C  \\nATOM   9014  O   VAL D 108      44.321  78.700  31.822  1.00 24.38           O  \\nATOM   9015  CB  VAL D 108      46.122  80.905  30.238  1.00 23.34           C  \\nATOM   9016  CG1 VAL D 108      47.048  79.828  30.824  1.00 23.34           C  \\nATOM   9017  CG2 VAL D 108      46.561  81.260  28.816  1.00 23.34           C  \\nATOM   9018  N   SER D 109      43.939  80.820  32.492  1.00 32.26           N  \\nATOM   9019  CA  SER D 109      43.487  80.411  33.825  1.00 32.26           C  \\nATOM   9020  C   SER D 109      42.287  79.484  33.662  1.00 32.26           C  \\nATOM   9021  O   SER D 109      42.301  78.357  34.129  1.00 32.26           O  \\nATOM   9022  CB  SER D 109      43.076  81.606  34.671  1.00 46.18           C  \\nATOM   9023  OG  SER D 109      44.211  82.345  35.058  1.00 46.18           O  \\nATOM   9024  N   GLU D 110      41.279  79.943  32.937  1.00 29.42           N  \\nATOM   9025  CA  GLU D 110      40.092  79.144  32.709  1.00 29.42           C  \\nATOM   9026  C   GLU D 110      40.434  77.786  32.096  1.00 29.42           C  \\nATOM   9027  O   GLU D 110      39.981  76.754  32.582  1.00 29.42           O  \\nATOM   9028  CB  GLU D 110      39.108  79.903  31.817  1.00 82.75           C  \\nATOM   9029  CG  GLU D 110      38.442  81.101  32.492  1.00 82.75           C  \\nATOM   9030  CD  GLU D 110      37.007  80.832  32.924  1.00 82.75           C  \\nATOM   9031  OE1 GLU D 110      36.419  79.806  32.510  1.00 82.75           O  \\nATOM   9032  OE2 GLU D 110      36.456  81.672  33.664  1.00 82.75           O  \\nATOM   9033  N   GLY D 111      41.247  77.780  31.045  1.00 23.14           N  \\nATOM   9034  CA  GLY D 111      41.626  76.531  30.407  1.00 23.14           C  \\nATOM   9035  C   GLY D 111      42.271  75.566  31.378  1.00 23.14           C  \\nATOM   9036  O   GLY D 111      41.766  74.479  31.602  1.00 23.14           O  \\nATOM   9037  N   THR D 112      43.370  75.976  31.995  1.00 33.21           N  \\nATOM   9038  CA  THR D 112      44.052  75.129  32.957  1.00 33.21           C  \\nATOM   9039  C   THR D 112      43.048  74.659  34.006  1.00 33.21           C  \\nATOM   9040  O   THR D 112      42.929  73.474  34.246  1.00 33.21           O  \\nATOM   9041  CB  THR D 112      45.165  75.891  33.648  1.00 27.40           C  \\nATOM   9042  OG1 THR D 112      45.944  76.578  32.663  1.00 27.40           O  \\nATOM   9043  CG2 THR D 112      46.048  74.937  34.419  1.00 27.40           C  \\nATOM   9044  N   LYS D 113      42.283  75.593  34.566  1.00 22.13           N  \\nATOM   9045  CA  LYS D 113      41.271  75.308  35.571  1.00 22.13           C  \\nATOM   9046  C   LYS D 113      40.417  74.117  35.118  1.00 22.13           C  \\nATOM   9047  O   LYS D 113      40.376  73.085  35.774  1.00 22.13           O  \\nATOM   9048  CB  LYS D 113      40.388  76.543  35.743  1.00 73.02           C  \\nATOM   9049  CG  LYS D 113      39.643  76.659  37.057  1.00 73.02           C  \\nATOM   9050  CD  LYS D 113      38.628  77.802  36.974  1.00 73.02           C  \\nATOM   9051  CE  LYS D 113      38.199  78.318  38.346  1.00 73.02           C  \\nATOM   9052  NZ  LYS D 113      37.499  77.321  39.201  1.00 73.02           N  \\nATOM   9053  N   ALA D 114      39.788  74.238  33.958  1.00 25.11           N  \\nATOM   9054  CA  ALA D 114      38.947  73.185  33.433  1.00 25.11           C  \\nATOM   9055  C   ALA D 114      39.680  71.867  33.272  1.00 25.11           C  \\nATOM   9056  O   ALA D 114      39.196  70.820  33.690  1.00 25.11           O  \\nATOM   9057  CB  ALA D 114      38.356  73.607  32.127  1.00 14.18           C  \\nATOM   9058  N   VAL D 115      40.852  71.898  32.671  1.00 29.90           N  \\nATOM   9059  CA  VAL D 115      41.594  70.655  32.490  1.00 29.90           C  \\nATOM   9060  C   VAL D 115      41.901  69.957  33.815  1.00 29.90           C  \\nATOM   9061  O   VAL D 115      41.571  68.790  33.984  1.00 29.90           O  \\nATOM   9062  CB  VAL D 115      42.867  70.884  31.669  1.00 24.44           C  \\nATOM   9063  CG1 VAL D 115      43.741  69.661  31.707  1.00 24.44           C  \\nATOM   9064  CG2 VAL D 115      42.477  71.233  30.213  1.00 24.44           C  \\nATOM   9065  N   THR D 116      42.474  70.697  34.760  1.00 25.58           N  \\nATOM   9066  CA  THR D 116      42.796  70.189  36.087  1.00 25.58           C  \\nATOM   9067  C   THR D 116      41.564  69.512  36.699  1.00 25.58           C  \\nATOM   9068  O   THR D 116      41.654  68.376  37.178  1.00 25.58           O  \\nATOM   9069  CB  THR D 116      43.237  71.330  37.018  1.00 25.88           C  \\nATOM   9070  OG1 THR D 116      44.379  71.976  36.460  1.00 25.88           O  \\nATOM   9071  CG2 THR D 116      43.615  70.806  38.385  1.00 25.88           C  \\nATOM   9072  N   LYS D 117      40.418  70.202  36.670  1.00 49.18           N  \\nATOM   9073  CA  LYS D 117      39.182  69.650  37.209  1.00 49.18           C  \\nATOM   9074  C   LYS D 117      38.730  68.405  36.461  1.00 49.18           C  \\nATOM   9075  O   LYS D 117      38.230  67.463  37.073  1.00 49.18           O  \\nATOM   9076  CB  LYS D 117      38.036  70.669  37.215  1.00 32.95           C  \\nATOM   9077  CG  LYS D 117      36.824  70.116  38.000  1.00 32.95           C  \\nATOM   9078  CD  LYS D 117      35.528  70.936  37.983  1.00 32.95           C  \\nATOM   9079  CE  LYS D 117      34.565  70.433  39.092  1.00 32.95           C  \\nATOM   9080  NZ  LYS D 117      33.096  70.720  38.935  1.00 32.95           N  \\nATOM   9081  N   TYR D 118      38.841  68.418  35.139  1.00 28.93           N  \\nATOM   9082  CA  TYR D 118      38.445  67.260  34.348  1.00 28.93           C  \\nATOM   9083  C   TYR D 118      39.219  65.998  34.731  1.00 28.93           C  \\nATOM   9084  O   TYR D 118      38.612  64.959  34.980  1.00 28.93           O  \\nATOM   9085  CB  TYR D 118      38.662  67.538  32.872  1.00 49.98           C  \\nATOM   9086  CG  TYR D 118      38.395  66.354  31.969  1.00 49.98           C  \\nATOM   9087  CD1 TYR D 118      37.100  66.035  31.581  1.00 49.98           C  \\nATOM   9088  CD2 TYR D 118      39.446  65.606  31.432  1.00 49.98           C  \\nATOM   9089  CE1 TYR D 118      36.850  65.011  30.668  1.00 49.98           C  \\nATOM   9090  CE2 TYR D 118      39.208  64.579  30.517  1.00 49.98           C  \\nATOM   9091  CZ  TYR D 118      37.905  64.291  30.133  1.00 49.98           C  \\nATOM   9092  OH  TYR D 118      37.650  63.321  29.178  1.00 49.98           O  \\nATOM   9093  N   THR D 119      40.550  66.099  34.774  1.00 54.75           N  \\nATOM   9094  CA  THR D 119      41.418  64.968  35.118  1.00 54.75           C  \\nATOM   9095  C   THR D 119      41.244  64.467  36.542  1.00 54.75           C  \\nATOM   9096  O   THR D 119      41.786  63.411  36.884  1.00 54.75           O  \\nATOM   9097  CB  THR D 119      42.904  65.303  34.942  1.00 49.95           C  \\nATOM   9098  OG1 THR D 119      43.284  66.316  35.884  1.00 49.95           O  \\nATOM   9099  CG2 THR D 119      43.172  65.779  33.544  1.00 49.95           C  \\nATOM   9100  N   SER D 120      40.566  65.267  37.374  1.00 52.09           N  \\nATOM   9101  CA  SER D 120      40.282  64.934  38.776  1.00 52.09           C  \\nATOM   9102  C   SER D 120      39.217  63.853  38.905  1.00 52.09           C  \\nATOM   9103  O   SER D 120      38.916  63.402  40.017  1.00 52.09           O  \\nATOM   9104  CB  SER D 120      39.832  66.169  39.555  1.00 46.30           C  \\nATOM   9105  OG  SER D 120      40.881  67.114  39.649  1.00 46.30           O  \\nATOM   9106  N   ALA D 121      38.625  63.476  37.772  1.00101.37           N  \\nATOM   9107  CA  ALA D 121      37.607  62.434  37.721  1.00101.37           C  \\nATOM   9108  C   ALA D 121      38.284  61.068  37.609  1.00101.37           C  \\nATOM   9109  O   ALA D 121      39.012  60.801  36.648  1.00101.37           O  \\nATOM   9110  CB  ALA D 121      36.672  62.664  36.533  1.00115.63           C  \\nATOM   9111  N   LYS D 122      38.061  60.227  38.615  1.00131.28           N  \\nATOM   9112  CA  LYS D 122      38.633  58.886  38.656  1.00131.28           C  \\nATOM   9113  C   LYS D 122      37.745  57.878  37.919  1.00131.28           C  \\nATOM   9114  O   LYS D 122      38.186  57.416  36.843  1.00 93.89           O  \\nATOM   9115  CB  LYS D 122      38.857  58.455  40.111  1.00 93.89           C  \\nATOM   9116  CG  LYS D 122      39.295  57.013  40.294  1.00 93.89           C  \\nATOM   9117  CD  LYS D 122      39.533  56.715  41.756  1.00 93.89           C  \\nATOM   9118  CE  LYS D 122      39.931  55.274  41.968  1.00 93.89           C  \\nATOM   9119  NZ  LYS D 122      40.659  55.134  43.257  1.00 93.89           N  \\nATOM   9120  OXT LYS D 122      36.628  57.571  38.406  1.00 93.89           O  \\nTER    9121      LYS D 122                                                      \\nATOM   9122  N   LEU E  20     -14.486 153.224  11.692  1.00106.36           N  \\nATOM   9123  CA  LEU E  20     -13.348 153.712  12.530  1.00106.36           C  \\nATOM   9124  C   LEU E  20     -12.884 155.127  12.154  1.00106.36           C  \\nATOM   9125  O   LEU E  20     -12.574 155.407  10.993  1.00106.36           O  \\nATOM   9126  CB  LEU E  20     -12.167 152.724  12.473  1.00128.73           C  \\nATOM   9127  CG  LEU E  20     -12.309 151.374  13.195  1.00128.73           C  \\nATOM   9128  CD1 LEU E  20     -11.098 150.489  12.913  1.00128.73           C  \\nATOM   9129  CD2 LEU E  20     -12.467 151.596  14.695  1.00128.73           C  \\nATOM   9130  N   ALA E  21     -12.841 156.002  13.160  1.00 91.92           N  \\nATOM   9131  CA  ALA E  21     -12.430 157.408  13.027  1.00 91.92           C  \\nATOM   9132  C   ALA E  21     -11.630 157.784  14.285  1.00 91.92           C  \\nATOM   9133  O   ALA E  21     -10.769 158.675  14.261  1.00 91.92           O  \\nATOM   9134  CB  ALA E  21     -13.670 158.307  12.908  1.00 42.87           C  \\nATOM   9135  N   THR E  22     -11.903 157.024  15.350  1.00177.26           N  \\nATOM   9136  CA  THR E  22     -11.321 157.144  16.692  1.00177.26           C  \\nATOM   9137  C   THR E  22      -9.813 157.436  16.784  1.00177.26           C  \\nATOM   9138  O   THR E  22      -9.084 157.398  15.790  1.00177.26           O  \\nATOM   9139  CB  THR E  22     -11.649 155.861  17.536  1.00118.64           C  \\nATOM   9140  OG1 THR E  22     -12.936 155.358  17.155  1.00118.64           O  \\nATOM   9141  CG2 THR E  22     -11.681 156.167  19.040  1.00118.64           C  \\nATOM   9142  N   LYS E  23      -9.378 157.713  18.010  1.00182.95           N  \\nATOM   9143  CA  LYS E  23      -8.000 158.041  18.372  1.00182.95           C  \\nATOM   9144  C   LYS E  23      -6.827 157.251  17.755  1.00182.95           C  \\nATOM   9145  O   LYS E  23      -6.235 157.688  16.763  1.00182.95           O  \\nATOM   9146  CB  LYS E  23      -7.877 158.014  19.899  1.00143.82           C  \\nATOM   9147  CG  LYS E  23      -8.862 158.909  20.649  1.00143.82           C  \\nATOM   9148  CD  LYS E  23      -9.068 158.376  22.056  1.00143.82           C  \\nATOM   9149  CE  LYS E  23      -7.732 158.123  22.734  1.00143.82           C  \\nATOM   9150  NZ  LYS E  23      -7.855 157.189  23.880  1.00143.82           N  \\nATOM   9151  N   ALA E  24      -6.488 156.101  18.346  1.00156.15           N  \\nATOM   9152  CA  ALA E  24      -5.347 155.302  17.883  1.00156.15           C  \\nATOM   9153  C   ALA E  24      -5.606 154.052  17.041  1.00156.15           C  \\nATOM   9154  O   ALA E  24      -6.271 153.109  17.483  1.00156.15           O  \\nATOM   9155  CB  ALA E  24      -4.444 154.952  19.070  1.00 77.70           C  \\nATOM   9156  N   ALA E  25      -5.004 154.059  15.849  1.00167.90           N  \\nATOM   9157  CA  ALA E  25      -5.061 152.982  14.851  1.00167.90           C  \\nATOM   9158  C   ALA E  25      -4.699 153.506  13.451  1.00167.90           C  \\nATOM   9159  O   ALA E  25      -4.265 152.730  12.598  1.00167.90           O  \\nATOM   9160  CB  ALA E  25      -6.439 152.300  14.821  1.00 58.63           C  \\nATOM   9161  N   ARG E  26      -4.842 154.822  13.246  1.00136.36           N  \\nATOM   9162  CA  ARG E  26      -4.561 155.506  11.965  1.00136.36           C  \\nATOM   9163  C   ARG E  26      -3.413 154.958  11.104  1.00136.36           C  \\nATOM   9164  O   ARG E  26      -2.239 155.181  11.414  1.00136.36           O  \\nATOM   9165  CB  ARG E  26      -4.328 157.002  12.203  1.00164.62           C  \\nATOM   9166  CG  ARG E  26      -5.590 157.832  12.334  1.00164.62           C  \\nATOM   9167  CD  ARG E  26      -5.251 159.314  12.392  1.00164.62           C  \\nATOM   9168  NE  ARG E  26      -6.415 160.158  12.123  1.00164.62           N  \\nATOM   9169  CZ  ARG E  26      -6.350 161.406  11.663  1.00164.62           C  \\nATOM   9170  NH1 ARG E  26      -5.174 161.972  11.424  1.00164.62           N  \\nATOM   9171  NH2 ARG E  26      -7.465 162.080  11.416  1.00164.62           N  \\nATOM   9172  N   LYS E  27      -3.777 154.311   9.991  1.00179.64           N  \\nATOM   9173  CA  LYS E  27      -2.842 153.687   9.036  1.00179.64           C  \\nATOM   9174  C   LYS E  27      -1.484 153.276   9.602  1.00179.64           C  \\nATOM   9175  O   LYS E  27      -0.425 153.628   9.071  1.00179.64           O  \\nATOM   9176  CB  LYS E  27      -2.694 154.516   7.751  1.00106.28           C  \\nATOM   9177  CG  LYS E  27      -3.870 154.340   6.785  1.00106.28           C  \\nATOM   9178  CD  LYS E  27      -3.557 154.874   5.388  1.00106.28           C  \\nATOM   9179  CE  LYS E  27      -4.720 154.641   4.413  1.00106.28           C  \\nATOM   9180  NZ  LYS E  27      -4.458 155.175   3.036  1.00106.28           N  \\nATOM   9181  N   SER E  28      -1.553 152.539  10.708  1.00177.31           N  \\nATOM   9182  CA  SER E  28      -0.388 152.027  11.416  1.00177.31           C  \\nATOM   9183  C   SER E  28      -0.064 150.610  10.918  1.00177.31           C  \\nATOM   9184  O   SER E  28      -0.172 149.637  11.674  1.00177.31           O  \\nATOM   9185  CB  SER E  28      -0.680 152.027  12.928  1.00 87.20           C  \\nATOM   9186  OG  SER E  28       0.426 151.581  13.693  1.00 87.20           O  \\nATOM   9187  N   ALA E  29       0.294 150.502   9.634  1.00182.81           N  \\nATOM   9188  CA  ALA E  29       0.650 149.216   9.015  1.00182.81           C  \\nATOM   9189  C   ALA E  29       1.956 148.633   9.586  1.00182.81           C  \\nATOM   9190  O   ALA E  29       2.071 147.411   9.734  1.00182.81           O  \\nATOM   9191  CB  ALA E  29       0.724 149.339   7.467  1.00 79.14           C  \\nATOM   9192  N   PRO E  30       2.970 149.491   9.866  1.00200.00           N  \\nATOM   9193  CA  PRO E  30       4.246 149.012  10.424  1.00200.00           C  \\nATOM   9194  C   PRO E  30       4.284 148.906  11.969  1.00200.00           C  \\nATOM   9195  O   PRO E  30       5.026 149.640  12.633  1.00200.00           O  \\nATOM   9196  CB  PRO E  30       5.246 150.048   9.905  1.00151.78           C  \\nATOM   9197  CG  PRO E  30       4.445 151.315   9.930  1.00151.78           C  \\nATOM   9198  CD  PRO E  30       3.128 150.865   9.335  1.00151.78           C  \\nATOM   9199  N   ALA E  31       3.491 147.988  12.528  1.00163.95           N  \\nATOM   9200  CA  ALA E  31       3.437 147.777  13.980  1.00163.95           C  \\nATOM   9201  C   ALA E  31       4.314 146.592  14.406  1.00163.95           C  \\nATOM   9202  O   ALA E  31       5.190 146.742  15.263  1.00163.95           O  \\nATOM   9203  CB  ALA E  31       1.986 147.579  14.444  1.00 46.45           C  \\nATOM   9204  N   THR E  32       4.069 145.419  13.819  1.00146.03           N  \\nATOM   9205  CA  THR E  32       4.865 144.230  14.128  1.00146.03           C  \\nATOM   9206  C   THR E  32       6.031 144.112  13.141  1.00146.03           C  \\nATOM   9207  O   THR E  32       5.943 143.414  12.125  1.00146.03           O  \\nATOM   9208  CB  THR E  32       4.021 142.909  14.137  1.00121.24           C  \\nATOM   9209  OG1 THR E  32       3.385 142.710  12.867  1.00121.24           O  \\nATOM   9210  CG2 THR E  32       2.968 142.946  15.245  1.00121.24           C  \\nATOM   9211  N   GLY E  33       7.103 144.845  13.436  1.00131.57           N  \\nATOM   9212  CA  GLY E  33       8.288 144.828  12.597  1.00131.57           C  \\nATOM   9213  C   GLY E  33       9.298 143.781  13.033  1.00131.57           C  \\nATOM   9214  O   GLY E  33      10.299 143.560  12.348  1.00131.57           O  \\nATOM   9215  N   GLY E  34       9.033 143.137  14.170  1.00141.43           N  \\nATOM   9216  CA  GLY E  34       9.925 142.111  14.689  1.00141.43           C  \\nATOM   9217  C   GLY E  34       9.829 140.769  13.977  1.00141.43           C  \\nATOM   9218  O   GLY E  34      10.669 139.887  14.184  1.00141.43           O  \\nATOM   9219  N   VAL E  35       8.792 140.605  13.156  1.00191.87           N  \\nATOM   9220  CA  VAL E  35       8.579 139.371  12.397  1.00191.87           C  \\nATOM   9221  C   VAL E  35       9.507 139.402  11.157  1.00191.87           C  \\nATOM   9222  O   VAL E  35       9.272 140.173  10.219  1.00191.87           O  \\nATOM   9223  CB  VAL E  35       7.059 139.229  11.975  1.00 99.07           C  \\nATOM   9224  CG1 VAL E  35       6.739 137.798  11.514  1.00 99.07           C  \\nATOM   9225  CG2 VAL E  35       6.133 139.629  13.133  1.00 99.07           C  \\nATOM   9226  N   LYS E  36      10.592 138.616  11.186  1.00162.54           N  \\nATOM   9227  CA  LYS E  36      11.547 138.565  10.068  1.00162.54           C  \\nATOM   9228  C   LYS E  36      11.201 137.559   8.963  1.00162.54           C  \\nATOM   9229  O   LYS E  36      10.363 136.676   9.154  1.00162.54           O  \\nATOM   9230  CB  LYS E  36      12.988 138.395  10.567  1.00109.10           C  \\nATOM   9231  CG  LYS E  36      13.495 139.613  11.350  1.00109.10           C  \\nATOM   9232  CD  LYS E  36      13.226 140.906  10.583  1.00109.10           C  \\nATOM   9233  CE  LYS E  36      13.305 142.132  11.477  1.00109.10           C  \\nATOM   9234  NZ  LYS E  36      14.690 142.624  11.732  1.00109.10           N  \\nATOM   9235  N   LYS E  37      11.910 137.647   7.840  1.00132.82           N  \\nATOM   9236  CA  LYS E  37      11.606 136.821   6.676  1.00132.82           C  \\nATOM   9237  C   LYS E  37      11.835 135.284   6.653  1.00132.82           C  \\nATOM   9238  O   LYS E  37      10.943 134.547   7.094  1.00132.82           O  \\nATOM   9239  CB  LYS E  37      12.063 137.546   5.398  1.00 78.08           C  \\nATOM   9240  CG  LYS E  37      11.485 138.972   5.244  1.00 78.08           C  \\nATOM   9241  CD  LYS E  37      12.185 139.979   6.172  1.00 78.08           C  \\nATOM   9242  CE  LYS E  37      11.262 141.104   6.644  1.00 78.08           C  \\nATOM   9243  NZ  LYS E  37      11.921 141.926   7.705  1.00 78.08           N  \\nATOM   9244  N   PRO E  38      12.991 134.769   6.152  1.00156.93           N  \\nATOM   9245  CA  PRO E  38      13.100 133.299   6.170  1.00156.93           C  \\nATOM   9246  C   PRO E  38      14.101 132.704   7.177  1.00156.93           C  \\nATOM   9247  O   PRO E  38      14.402 133.326   8.199  1.00156.93           O  \\nATOM   9248  CB  PRO E  38      13.490 132.969   4.718  1.00 47.90           C  \\nATOM   9249  CG  PRO E  38      13.997 134.359   4.124  1.00 47.90           C  \\nATOM   9250  CD  PRO E  38      14.060 135.316   5.302  1.00 47.90           C  \\nATOM   9251  N   HIS E  39      14.617 131.508   6.879  1.00 96.77           N  \\nATOM   9252  CA  HIS E  39      15.568 130.821   7.767  1.00 96.77           C  \\nATOM   9253  C   HIS E  39      16.545 129.873   7.057  1.00 96.77           C  \\nATOM   9254  O   HIS E  39      16.141 129.100   6.185  1.00 96.77           O  \\nATOM   9255  CB  HIS E  39      14.802 130.034   8.830  1.00 75.75           C  \\nATOM   9256  CG  HIS E  39      15.680 129.241   9.746  1.00 75.75           C  \\nATOM   9257  ND1 HIS E  39      16.055 127.941   9.478  1.00 75.75           N  \\nATOM   9258  CD2 HIS E  39      16.246 129.558  10.936  1.00 75.75           C  \\nATOM   9259  CE1 HIS E  39      16.811 127.491  10.464  1.00 75.75           C  \\nATOM   9260  NE2 HIS E  39      16.941 128.453  11.361  1.00 75.75           N  \\nATOM   9261  N   ARG E  40      17.802 129.868   7.514  1.00 46.30           N  \\nATOM   9262  CA  ARG E  40      18.849 129.025   6.922  1.00 46.30           C  \\nATOM   9263  C   ARG E  40      19.920 128.482   7.833  1.00 46.30           C  \\nATOM   9264  O   ARG E  40      20.493 129.214   8.636  1.00 46.30           O  \\nATOM   9265  CB  ARG E  40      19.606 129.783   5.840  1.00 24.00           C  \\nATOM   9266  CG  ARG E  40      19.071 129.548   4.506  1.00 24.00           C  \\nATOM   9267  CD  ARG E  40      20.118 129.518   3.473  1.00 24.00           C  \\nATOM   9268  NE  ARG E  40      19.441 129.151   2.251  1.00 24.00           N  \\nATOM   9269  CZ  ARG E  40      19.842 128.213   1.406  1.00 24.00           C  \\nATOM   9270  NH1 ARG E  40      20.964 127.514   1.612  1.00 24.00           N  \\nATOM   9271  NH2 ARG E  40      19.059 127.909   0.378  1.00 24.00           N  \\nATOM   9272  N   TYR E  41      20.245 127.206   7.661  1.00 26.00           N  \\nATOM   9273  CA  TYR E  41      21.337 126.629   8.432  1.00 26.00           C  \\nATOM   9274  C   TYR E  41      22.635 126.889   7.645  1.00 26.00           C  \\nATOM   9275  O   TYR E  41      22.680 126.754   6.404  1.00 26.00           O  \\nATOM   9276  CB  TYR E  41      21.101 125.139   8.689  1.00 26.16           C  \\nATOM   9277  CG  TYR E  41      20.116 124.878   9.811  1.00 26.16           C  \\nATOM   9278  CD1 TYR E  41      20.417 125.248  11.118  1.00 26.16           C  \\nATOM   9279  CD2 TYR E  41      18.881 124.275   9.569  1.00 26.16           C  \\nATOM   9280  CE1 TYR E  41      19.519 125.030  12.161  1.00 26.16           C  \\nATOM   9281  CE2 TYR E  41      17.973 124.045  10.607  1.00 26.16           C  \\nATOM   9282  CZ  TYR E  41      18.300 124.427  11.902  1.00 26.16           C  \\nATOM   9283  OH  TYR E  41      17.421 124.218  12.953  1.00 26.16           O  \\nATOM   9284  N   ARG E  42      23.673 127.314   8.356  1.00 24.35           N  \\nATOM   9285  CA  ARG E  42      24.941 127.629   7.723  1.00 24.35           C  \\nATOM   9286  C   ARG E  42      25.577 126.382   7.122  1.00 24.35           C  \\nATOM   9287  O   ARG E  42      25.493 125.294   7.686  1.00 24.35           O  \\nATOM   9288  CB  ARG E  42      25.861 128.315   8.721  1.00 53.92           C  \\nATOM   9289  CG  ARG E  42      25.363 129.681   9.091  1.00 53.92           C  \\nATOM   9290  CD  ARG E  42      26.187 130.277  10.191  1.00 53.92           C  \\nATOM   9291  NE  ARG E  42      27.582 130.504   9.804  1.00 53.92           N  \\nATOM   9292  CZ  ARG E  42      28.556 130.841  10.656  1.00 53.92           C  \\nATOM   9293  NH1 ARG E  42      28.298 130.981  11.953  1.00 53.92           N  \\nATOM   9294  NH2 ARG E  42      29.791 131.067  10.214  1.00 53.92           N  \\nATOM   9295  N   PRO E  43      26.244 126.523   5.968  1.00 15.33           N  \\nATOM   9296  CA  PRO E  43      26.848 125.337   5.381  1.00 15.33           C  \\nATOM   9297  C   PRO E  43      27.699 124.537   6.346  1.00 15.33           C  \\nATOM   9298  O   PRO E  43      28.593 125.085   7.004  1.00 15.33           O  \\nATOM   9299  CB  PRO E  43      27.659 125.913   4.211  1.00 16.96           C  \\nATOM   9300  CG  PRO E  43      27.946 127.283   4.618  1.00 16.96           C  \\nATOM   9301  CD  PRO E  43      26.657 127.726   5.220  1.00 16.96           C  \\nATOM   9302  N   GLY E  44      27.326 123.267   6.502  1.00 12.88           N  \\nATOM   9303  CA  GLY E  44      28.077 122.369   7.358  1.00 12.88           C  \\nATOM   9304  C   GLY E  44      27.347 121.918   8.598  1.00 12.88           C  \\nATOM   9305  O   GLY E  44      27.667 120.879   9.183  1.00 12.88           O  \\nATOM   9306  N   THR E  45      26.359 122.699   9.010  1.00 20.22           N  \\nATOM   9307  CA  THR E  45      25.582 122.379  10.196  1.00 20.22           C  \\nATOM   9308  C   THR E  45      24.775 121.108   9.968  1.00 20.22           C  \\nATOM   9309  O   THR E  45      24.794 120.177  10.778  1.00 20.22           O  \\nATOM   9310  CB  THR E  45      24.645 123.535  10.520  1.00 43.22           C  \\nATOM   9311  OG1 THR E  45      25.414 124.736  10.579  1.00 43.22           O  \\nATOM   9312  CG2 THR E  45      23.966 123.328  11.842  1.00 43.22           C  \\nATOM   9313  N   VAL E  46      24.106 121.055   8.825  1.00 22.85           N  \\nATOM   9314  CA  VAL E  46      23.287 119.908   8.466  1.00 22.85           C  \\nATOM   9315  C   VAL E  46      24.194 118.690   8.257  1.00 22.85           C  \\nATOM   9316  O   VAL E  46      23.897 117.606   8.738  1.00 22.85           O  \\nATOM   9317  CB  VAL E  46      22.481 120.198   7.177  1.00 15.66           C  \\nATOM   9318  CG1 VAL E  46      21.552 119.031   6.856  1.00 15.66           C  \\nATOM   9319  CG2 VAL E  46      21.704 121.515   7.315  1.00 15.66           C  \\nATOM   9320  N   ALA E  47      25.332 118.899   7.592  1.00 28.37           N  \\nATOM   9321  CA  ALA E  47      26.303 117.832   7.330  1.00 28.37           C  \\nATOM   9322  C   ALA E  47      26.733 117.116   8.610  1.00 28.37           C  \\nATOM   9323  O   ALA E  47      26.997 115.917   8.584  1.00 28.37           O  \\nATOM   9324  CB  ALA E  47      27.502 118.391   6.617  1.00  6.71           C  \\nATOM   9325  N   LEU E  48      26.838 117.873   9.708  1.00 25.70           N  \\nATOM   9326  CA  LEU E  48      27.203 117.356  11.035  1.00 25.70           C  \\nATOM   9327  C   LEU E  48      26.026 116.644  11.648  1.00 25.70           C  \\nATOM   9328  O   LEU E  48      26.197 115.640  12.316  1.00 25.70           O  \\nATOM   9329  CB  LEU E  48      27.614 118.493  11.954  1.00 31.39           C  \\nATOM   9330  CG  LEU E  48      29.019 119.019  11.710  1.00 31.39           C  \\nATOM   9331  CD1 LEU E  48      29.148 120.419  12.234  1.00 31.39           C  \\nATOM   9332  CD2 LEU E  48      30.025 118.099  12.383  1.00 31.39           C  \\nATOM   9333  N   ARG E  49      24.839 117.221  11.471  1.00 18.12           N  \\nATOM   9334  CA  ARG E  49      23.591 116.647  11.955  1.00 18.12           C  \\nATOM   9335  C   ARG E  49      23.468 115.221  11.368  1.00 18.12           C  \\nATOM   9336  O   ARG E  49      23.176 114.253  12.073  1.00 18.12           O  \\nATOM   9337  CB  ARG E  49      22.438 117.515  11.452  1.00 48.87           C  \\nATOM   9338  CG  ARG E  49      21.296 117.679  12.429  1.00 48.87           C  \\nATOM   9339  CD  ARG E  49      19.913 117.786  11.737  1.00 48.87           C  \\nATOM   9340  NE  ARG E  49      19.699 118.995  10.935  1.00 48.87           N  \\nATOM   9341  CZ  ARG E  49      19.751 120.236  11.405  1.00 48.87           C  \\nATOM   9342  NH1 ARG E  49      20.022 120.470  12.684  1.00 48.87           N  \\nATOM   9343  NH2 ARG E  49      19.524 121.249  10.590  1.00 48.87           N  \\nATOM   9344  N   GLU E  50      23.726 115.116  10.065  1.00 27.71           N  \\nATOM   9345  CA  GLU E  50      23.674 113.859   9.334  1.00 27.71           C  \\nATOM   9346  C   GLU E  50      24.722 112.852   9.832  1.00 27.71           C  \\nATOM   9347  O   GLU E  50      24.441 111.664   9.938  1.00 27.71           O  \\nATOM   9348  CB  GLU E  50      23.844 114.118   7.822  1.00 31.99           C  \\nATOM   9349  CG  GLU E  50      22.671 114.809   7.121  1.00 31.99           C  \\nATOM   9350  CD  GLU E  50      22.956 115.132   5.643  1.00 31.99           C  \\nATOM   9351  OE1 GLU E  50      23.017 114.195   4.813  1.00 31.99           O  \\nATOM   9352  OE2 GLU E  50      23.133 116.327   5.295  1.00 31.99           O  \\nATOM   9353  N   ILE E  51      25.939 113.316  10.095  1.00 21.68           N  \\nATOM   9354  CA  ILE E  51      26.993 112.435  10.592  1.00 21.68           C  \\nATOM   9355  C   ILE E  51      26.514 111.834  11.894  1.00 21.68           C  \\nATOM   9356  O   ILE E  51      26.457 110.612  12.044  1.00 21.68           O  \\nATOM   9357  CB  ILE E  51      28.301 113.200  10.837  1.00  6.79           C  \\nATOM   9358  CG1 ILE E  51      28.864 113.682   9.503  1.00  6.79           C  \\nATOM   9359  CG2 ILE E  51      29.317 112.308  11.490  1.00  6.79           C  \\nATOM   9360  CD1 ILE E  51      30.059 114.582   9.619  1.00  6.79           C  \\nATOM   9361  N   ARG E  52      26.080 112.705  12.797  1.00 19.79           N  \\nATOM   9362  CA  ARG E  52      25.577 112.282  14.090  1.00 19.79           C  \\nATOM   9363  C   ARG E  52      24.455 111.289  13.894  1.00 19.79           C  \\nATOM   9364  O   ARG E  52      24.391 110.274  14.583  1.00 19.79           O  \\nATOM   9365  CB  ARG E  52      25.093 113.484  14.907  1.00 33.55           C  \\nATOM   9366  CG  ARG E  52      26.202 114.447  15.303  1.00 33.55           C  \\nATOM   9367  CD  ARG E  52      25.704 115.540  16.216  1.00 33.55           C  \\nATOM   9368  NE  ARG E  52      26.312 116.845  15.920  1.00 33.55           N  \\nATOM   9369  CZ  ARG E  52      27.490 117.260  16.390  1.00 33.55           C  \\nATOM   9370  NH1 ARG E  52      28.217 116.459  17.187  1.00 33.55           N  \\nATOM   9371  NH2 ARG E  52      27.915 118.500  16.113  1.00 33.55           N  \\nATOM   9372  N   ARG E  53      23.593 111.577  12.929  1.00 21.63           N  \\nATOM   9373  CA  ARG E  53      22.459 110.728  12.629  1.00 21.63           C  \\nATOM   9374  C   ARG E  53      22.826 109.319  12.187  1.00 21.63           C  \\nATOM   9375  O   ARG E  53      22.384 108.337  12.798  1.00 21.63           O  \\nATOM   9376  CB  ARG E  53      21.567 111.373  11.570  1.00 33.63           C  \\nATOM   9377  CG  ARG E  53      20.443 110.456  11.150  1.00 33.63           C  \\nATOM   9378  CD  ARG E  53      19.641 110.948   9.960  1.00 33.63           C  \\nATOM   9379  NE  ARG E  53      18.865 109.840   9.397  1.00 33.63           N  \\nATOM   9380  CZ  ARG E  53      17.931 109.968   8.457  1.00 33.63           C  \\nATOM   9381  NH1 ARG E  53      17.636 111.166   7.953  1.00 33.63           N  \\nATOM   9382  NH2 ARG E  53      17.311 108.879   8.000  1.00 33.63           N  \\nATOM   9383  N   TYR E  54      23.648 109.212  11.142  1.00 19.14           N  \\nATOM   9384  CA  TYR E  54      24.041 107.913  10.601  1.00 19.14           C  \\nATOM   9385  C   TYR E  54      24.989 107.123  11.448  1.00 19.14           C  \\nATOM   9386  O   TYR E  54      25.008 105.900  11.362  1.00 19.14           O  \\nATOM   9387  CB  TYR E  54      24.533 108.055   9.168  1.00 18.72           C  \\nATOM   9388  CG  TYR E  54      23.394 108.446   8.243  1.00 18.72           C  \\nATOM   9389  CD1 TYR E  54      22.329 107.567   8.012  1.00 18.72           C  \\nATOM   9390  CD2 TYR E  54      23.334 109.719   7.659  1.00 18.72           C  \\nATOM   9391  CE1 TYR E  54      21.230 107.942   7.235  1.00 18.72           C  \\nATOM   9392  CE2 TYR E  54      22.243 110.104   6.873  1.00 18.72           C  \\nATOM   9393  CZ  TYR E  54      21.201 109.212   6.669  1.00 18.72           C  \\nATOM   9394  OH  TYR E  54      20.133 109.576   5.894  1.00 18.72           O  \\nATOM   9395  N   GLN E  55      25.793 107.811  12.251  1.00 27.55           N  \\nATOM   9396  CA  GLN E  55      26.697 107.115  13.151  1.00 27.55           C  \\nATOM   9397  C   GLN E  55      25.901 106.402  14.267  1.00 27.55           C  \\nATOM   9398  O   GLN E  55      26.375 105.401  14.818  1.00 27.55           O  \\nATOM   9399  CB  GLN E  55      27.756 108.065  13.715  1.00 31.00           C  \\nATOM   9400  CG  GLN E  55      28.823 108.479  12.681  1.00 31.00           C  \\nATOM   9401  CD  GLN E  55      30.050 109.160  13.302  1.00 31.00           C  \\nATOM   9402  OE1 GLN E  55      29.961 109.762  14.373  1.00 31.00           O  \\nATOM   9403  NE2 GLN E  55      31.191 109.064  12.629  1.00 31.00           N  \\nATOM   9404  N   LYS E  56      24.689 106.899  14.564  1.00 23.85           N  \\nATOM   9405  CA  LYS E  56      23.800 106.317  15.575  1.00 23.85           C  \\nATOM   9406  C   LYS E  56      23.073 105.094  15.014  1.00 23.85           C  \\nATOM   9407  O   LYS E  56      22.744 104.163  15.757  1.00 23.85           O  \\nATOM   9408  CB  LYS E  56      22.715 107.307  16.029  1.00 43.45           C  \\nATOM   9409  CG  LYS E  56      23.110 108.442  16.978  1.00 43.45           C  \\nATOM   9410  CD  LYS E  56      21.836 108.989  17.713  1.00 43.45           C  \\nATOM   9411  CE  LYS E  56      21.703 110.552  17.764  1.00 43.45           C  \\nATOM   9412  NZ  LYS E  56      21.091 111.216  16.539  1.00 43.45           N  \\nATOM   9413  N   SER E  57      22.721 105.125  13.731  1.00 28.47           N  \\nATOM   9414  CA  SER E  57      22.022 103.978  13.158  1.00 28.47           C  \\nATOM   9415  C   SER E  57      22.897 102.867  12.563  1.00 28.47           C  \\nATOM   9416  O   SER E  57      24.145 102.964  12.537  1.00 28.47           O  \\nATOM   9417  CB  SER E  57      20.968 104.435  12.145  1.00 30.41           C  \\nATOM   9418  OG  SER E  57      21.499 105.321  11.185  1.00 30.41           O  \\nATOM   9419  N   THR E  58      22.225 101.813  12.088  1.00 15.13           N  \\nATOM   9420  CA  THR E  58      22.899 100.665  11.489  1.00 15.13           C  \\nATOM   9421  C   THR E  58      22.237 100.185  10.202  1.00 15.13           C  \\nATOM   9422  O   THR E  58      22.698  99.226   9.600  1.00 15.13           O  \\nATOM   9423  CB  THR E  58      22.925  99.478  12.429  1.00 21.48           C  \\nATOM   9424  OG1 THR E  58      21.604  98.960  12.552  1.00 21.48           O  \\nATOM   9425  CG2 THR E  58      23.415  99.883  13.790  1.00 21.48           C  \\nATOM   9426  N   GLU E  59      21.103 100.791   9.858  1.00 16.27           N  \\nATOM   9427  CA  GLU E  59      20.326 100.524   8.631  1.00 16.27           C  \\nATOM   9428  C   GLU E  59      21.299 100.625   7.469  1.00 16.27           C  \\nATOM   9429  O   GLU E  59      22.294 101.358   7.567  1.00 16.27           O  \\nATOM   9430  CB  GLU E  59      19.364 101.691   8.444  1.00 37.49           C  \\nATOM   9431  CG  GLU E  59      20.104 103.008   8.770  1.00 37.49           C  \\nATOM   9432  CD  GLU E  59      19.409 104.266   8.344  1.00 37.49           C  \\nATOM   9433  OE1 GLU E  59      18.875 104.296   7.213  1.00 37.49           O  \\nATOM   9434  OE2 GLU E  59      19.457 105.255   9.123  1.00 37.49           O  \\nATOM   9435  N   LEU E  60      21.035  99.944   6.359  1.00 27.54           N  \\nATOM   9436  CA  LEU E  60      21.958 100.090   5.231  1.00 27.54           C  \\nATOM   9437  C   LEU E  60      21.630 101.405   4.540  1.00 27.54           C  \\nATOM   9438  O   LEU E  60      20.536 101.960   4.715  1.00 27.54           O  \\nATOM   9439  CB  LEU E  60      21.893  98.922   4.250  1.00 12.49           C  \\nATOM   9440  CG  LEU E  60      22.311  97.570   4.814  1.00 12.49           C  \\nATOM   9441  CD1 LEU E  60      22.075  96.496   3.799  1.00 12.49           C  \\nATOM   9442  CD2 LEU E  60      23.767  97.611   5.242  1.00 12.49           C  \\nATOM   9443  N   LEU E  61      22.577 101.894   3.750  1.00 19.03           N  \\nATOM   9444  CA  LEU E  61      22.409 103.162   3.089  1.00 19.03           C  \\nATOM   9445  C   LEU E  61      22.301 103.163   1.565  1.00 19.03           C  \\nATOM   9446  O   LEU E  61      22.061 104.207   0.982  1.00 19.03           O  \\nATOM   9447  CB  LEU E  61      23.494 104.114   3.594  1.00 10.35           C  \\nATOM   9448  CG  LEU E  61      23.630 104.288   5.129  1.00 10.35           C  \\nATOM   9449  CD1 LEU E  61      24.925 105.020   5.467  1.00 10.35           C  \\nATOM   9450  CD2 LEU E  61      22.441 105.033   5.722  1.00 10.35           C  \\nATOM   9451  N   ILE E  62      22.464 102.015   0.913  1.00 24.84           N  \\nATOM   9452  CA  ILE E  62      22.319 101.950  -0.549  1.00 24.84           C  \\nATOM   9453  C   ILE E  62      20.952 101.314  -0.790  1.00 24.84           C  \\nATOM   9454  O   ILE E  62      20.598 100.365  -0.098  1.00 24.84           O  \\nATOM   9455  CB  ILE E  62      23.433 101.074  -1.199  1.00 13.17           C  \\nATOM   9456  CG1 ILE E  62      24.760 101.808  -1.153  1.00 13.17           C  \\nATOM   9457  CG2 ILE E  62      23.116 100.749  -2.647  1.00 13.17           C  \\nATOM   9458  CD1 ILE E  62      25.939 100.887  -1.131  1.00 13.17           C  \\nATOM   9459  N   ARG E  63      20.168 101.859  -1.724  1.00 17.80           N  \\nATOM   9460  CA  ARG E  63      18.849 101.301  -1.999  1.00 17.80           C  \\nATOM   9461  C   ARG E  63      18.991  99.842  -2.381  1.00 17.80           C  \\nATOM   9462  O   ARG E  63      19.732  99.494  -3.290  1.00 17.80           O  \\nATOM   9463  CB  ARG E  63      18.139 102.105  -3.067  1.00 73.98           C  \\nATOM   9464  CG  ARG E  63      17.263 103.208  -2.506  1.00 73.98           C  \\nATOM   9465  CD  ARG E  63      17.147 104.346  -3.506  1.00 73.98           C  \\nATOM   9466  NE  ARG E  63      17.210 103.892  -4.903  1.00 73.98           N  \\nATOM   9467  CZ  ARG E  63      17.794 104.572  -5.893  1.00 73.98           C  \\nATOM   9468  NH1 ARG E  63      18.365 105.735  -5.635  1.00 73.98           N  \\nATOM   9469  NH2 ARG E  63      17.813 104.102  -7.142  1.00 73.98           N  \\nATOM   9470  N   LYS E  64      18.290  98.984  -1.655  1.00 18.59           N  \\nATOM   9471  CA  LYS E  64      18.368  97.543  -1.866  1.00 18.59           C  \\nATOM   9472  C   LYS E  64      18.200  97.019  -3.288  1.00 18.59           C  \\nATOM   9473  O   LYS E  64      19.011  96.227  -3.755  1.00 18.59           O  \\nATOM   9474  CB  LYS E  64      17.462  96.806  -0.869  1.00 59.69           C  \\nATOM   9475  CG  LYS E  64      18.099  96.682   0.517  1.00 59.69           C  \\nATOM   9476  CD  LYS E  64      17.071  96.659   1.631  1.00 59.69           C  \\nATOM   9477  CE  LYS E  64      17.710  96.891   3.009  1.00 59.69           C  \\nATOM   9478  NZ  LYS E  64      18.462  95.706   3.510  1.00 59.69           N  \\nATOM   9479  N   LEU E  65      17.167  97.440  -3.989  1.00 31.10           N  \\nATOM   9480  CA  LEU E  65      17.019  96.948  -5.334  1.00 31.10           C  \\nATOM   9481  C   LEU E  65      18.183  97.362  -6.235  1.00 31.10           C  \\nATOM   9482  O   LEU E  65      18.877  96.503  -6.770  1.00 31.10           O  \\nATOM   9483  CB  LEU E  65      15.665  97.352  -5.928  1.00 23.29           C  \\nATOM   9484  CG  LEU E  65      15.315  97.002  -7.388  1.00 23.29           C  \\nATOM   9485  CD1 LEU E  65      15.633  95.552  -7.722  1.00 23.29           C  \\nATOM   9486  CD2 LEU E  65      13.842  97.273  -7.594  1.00 23.29           C  \\nATOM   9487  N   PRO E  66      18.489  98.662  -6.340  1.00 20.16           N  \\nATOM   9488  CA  PRO E  66      19.605  99.046  -7.219  1.00 20.16           C  \\nATOM   9489  C   PRO E  66      20.874  98.235  -6.976  1.00 20.16           C  \\nATOM   9490  O   PRO E  66      21.545  97.829  -7.938  1.00 20.16           O  \\nATOM   9491  CB  PRO E  66      19.814 100.514  -6.898  1.00 15.14           C  \\nATOM   9492  CG  PRO E  66      18.478 100.950  -6.500  1.00 15.14           C  \\nATOM   9493  CD  PRO E  66      17.946  99.833  -5.648  1.00 15.14           C  \\nATOM   9494  N   PHE E  67      21.191  97.995  -5.693  1.00 17.28           N  \\nATOM   9495  CA  PHE E  67      22.367  97.207  -5.316  1.00 17.28           C  \\nATOM   9496  C   PHE E  67      22.231  95.780  -5.830  1.00 17.28           C  \\nATOM   9497  O   PHE E  67      23.146  95.274  -6.492  1.00 17.28           O  \\nATOM   9498  CB  PHE E  67      22.572  97.196  -3.815  1.00 16.74           C  \\nATOM   9499  CG  PHE E  67      23.798  96.459  -3.392  1.00 16.74           C  \\nATOM   9500  CD1 PHE E  67      25.018  97.114  -3.311  1.00 16.74           C  \\nATOM   9501  CD2 PHE E  67      23.747  95.091  -3.113  1.00 16.74           C  \\nATOM   9502  CE1 PHE E  67      26.177  96.425  -2.960  1.00 16.74           C  \\nATOM   9503  CE2 PHE E  67      24.901  94.383  -2.761  1.00 16.74           C  \\nATOM   9504  CZ  PHE E  67      26.121  95.063  -2.686  1.00 16.74           C  \\nATOM   9505  N   GLN E  68      21.093  95.133  -5.551  1.00 10.24           N  \\nATOM   9506  CA  GLN E  68      20.868  93.775  -6.049  1.00 10.24           C  \\nATOM   9507  C   GLN E  68      21.133  93.671  -7.574  1.00 10.24           C  \\nATOM   9508  O   GLN E  68      21.760  92.727  -8.042  1.00 10.24           O  \\nATOM   9509  CB  GLN E  68      19.473  93.293  -5.720  1.00 43.59           C  \\nATOM   9510  CG  GLN E  68      19.260  91.883  -6.177  1.00 43.59           C  \\nATOM   9511  CD  GLN E  68      18.000  91.274  -5.624  1.00 43.59           C  \\nATOM   9512  OE1 GLN E  68      16.950  91.284  -6.282  1.00 43.59           O  \\nATOM   9513  NE2 GLN E  68      18.086  90.741  -4.400  1.00 43.59           N  \\nATOM   9514  N   ARG E  69      20.723  94.690  -8.324  1.00 13.32           N  \\nATOM   9515  CA  ARG E  69      20.926  94.750  -9.771  1.00 13.32           C  \\nATOM   9516  C   ARG E  69      22.400  94.868 -10.166  1.00 13.32           C  \\nATOM   9517  O   ARG E  69      22.839  94.239 -11.115  1.00 13.32           O  \\nATOM   9518  CB  ARG E  69      20.163  95.932 -10.340  1.00 28.76           C  \\nATOM   9519  CG  ARG E  69      18.960  95.563 -11.141  1.00 28.76           C  \\nATOM   9520  CD  ARG E  69      18.414  96.809 -11.849  1.00 28.76           C  \\nATOM   9521  NE  ARG E  69      17.330  97.447 -11.105  1.00 28.76           N  \\nATOM   9522  CZ  ARG E  69      17.342  98.704 -10.683  1.00 28.76           C  \\nATOM   9523  NH1 ARG E  69      18.395  99.492 -10.922  1.00 28.76           N  \\nATOM   9524  NH2 ARG E  69      16.284  99.168 -10.033  1.00 28.76           N  \\nATOM   9525  N   LEU E  70      23.145  95.733  -9.490  1.00 17.42           N  \\nATOM   9526  CA  LEU E  70      24.562  95.888  -9.782  1.00 17.42           C  \\nATOM   9527  C   LEU E  70      25.245  94.550  -9.569  1.00 17.42           C  \\nATOM   9528  O   LEU E  70      26.055  94.124 -10.406  1.00 17.42           O  \\nATOM   9529  CB  LEU E  70      25.200  96.919  -8.848  1.00 15.96           C  \\nATOM   9530  CG  LEU E  70      26.717  97.159  -8.997  1.00 15.96           C  \\nATOM   9531  CD1 LEU E  70      27.052  97.750 -10.380  1.00 15.96           C  \\nATOM   9532  CD2 LEU E  70      27.215  98.047  -7.851  1.00 15.96           C  \\nATOM   9533  N   VAL E  71      24.943  93.901  -8.436  1.00 12.32           N  \\nATOM   9534  CA  VAL E  71      25.525  92.595  -8.132  1.00 12.32           C  \\nATOM   9535  C   VAL E  71      25.220  91.643  -9.284  1.00 12.32           C  \\nATOM   9536  O   VAL E  71      26.137  91.100  -9.880  1.00 12.32           O  \\nATOM   9537  CB  VAL E  71      25.002  91.995  -6.788  1.00 12.93           C  \\nATOM   9538  CG1 VAL E  71      25.348  90.506  -6.692  1.00 12.93           C  \\nATOM   9539  CG2 VAL E  71      25.598  92.741  -5.579  1.00 12.93           C  \\nATOM   9540  N   ARG E  72      23.944  91.489  -9.638  1.00 15.49           N  \\nATOM   9541  CA  ARG E  72      23.566  90.599 -10.732  1.00 15.49           C  \\nATOM   9542  C   ARG E  72      24.282  90.931 -12.035  1.00 15.49           C  \\nATOM   9543  O   ARG E  72      24.701  90.032 -12.752  1.00 15.49           O  \\nATOM   9544  CB  ARG E  72      22.053  90.578 -10.942  1.00 23.81           C  \\nATOM   9545  CG  ARG E  72      21.318  89.885  -9.825  1.00 23.81           C  \\nATOM   9546  CD  ARG E  72      19.827  89.849 -10.053  1.00 23.81           C  \\nATOM   9547  NE  ARG E  72      19.137  89.401  -8.843  1.00 23.81           N  \\nATOM   9548  CZ  ARG E  72      19.013  88.126  -8.466  1.00 23.81           C  \\nATOM   9549  NH1 ARG E  72      19.525  87.147  -9.211  1.00 23.81           N  \\nATOM   9550  NH2 ARG E  72      18.405  87.833  -7.320  1.00 23.81           N  \\nATOM   9551  N   GLU E  73      24.443  92.215 -12.332  1.00 17.63           N  \\nATOM   9552  CA  GLU E  73      25.119  92.616 -13.552  1.00 17.63           C  \\nATOM   9553  C   GLU E  73      26.558  92.113 -13.559  1.00 17.63           C  \\nATOM   9554  O   GLU E  73      26.974  91.424 -14.475  1.00 17.63           O  \\nATOM   9555  CB  GLU E  73      25.085  94.138 -13.702  1.00 21.24           C  \\nATOM   9556  CG  GLU E  73      25.950  94.656 -14.848  1.00 21.24           C  \\nATOM   9557  CD  GLU E  73      25.892  96.168 -15.020  1.00 21.24           C  \\nATOM   9558  OE1 GLU E  73      24.790  96.748 -14.915  1.00 21.24           O  \\nATOM   9559  OE2 GLU E  73      26.951  96.775 -15.282  1.00 21.24           O  \\nATOM   9560  N   ILE E  74      27.303  92.436 -12.515  1.00 19.79           N  \\nATOM   9561  CA  ILE E  74      28.683  92.003 -12.416  1.00 19.79           C  \\nATOM   9562  C   ILE E  74      28.798  90.483 -12.511  1.00 19.79           C  \\nATOM   9563  O   ILE E  74      29.532  89.967 -13.356  1.00 19.79           O  \\nATOM   9564  CB  ILE E  74      29.316  92.477 -11.077  1.00 12.86           C  \\nATOM   9565  CG1 ILE E  74      29.413  94.000 -11.071  1.00 12.86           C  \\nATOM   9566  CG2 ILE E  74      30.707  91.857 -10.880  1.00 12.86           C  \\nATOM   9567  CD1 ILE E  74      29.735  94.563  -9.740  1.00 12.86           C  \\nATOM   9568  N   ALA E  75      28.062  89.781 -11.648  1.00 17.30           N  \\nATOM   9569  CA  ALA E  75      28.080  88.330 -11.586  1.00 17.30           C  \\nATOM   9570  C   ALA E  75      27.835  87.725 -12.953  1.00 17.30           C  \\nATOM   9571  O   ALA E  75      28.592  86.882 -13.418  1.00 17.30           O  \\nATOM   9572  CB  ALA E  75      27.044  87.858 -10.623  1.00 23.14           C  \\nATOM   9573  N   GLN E  76      26.783  88.186 -13.606  1.00 38.14           N  \\nATOM   9574  CA  GLN E  76      26.411  87.715 -14.922  1.00 38.14           C  \\nATOM   9575  C   GLN E  76      27.529  87.924 -15.923  1.00 38.14           C  \\nATOM   9576  O   GLN E  76      27.619  87.198 -16.909  1.00 38.14           O  \\nATOM   9577  CB  GLN E  76      25.186  88.470 -15.365  1.00 36.55           C  \\nATOM   9578  CG  GLN E  76      24.694  88.144 -16.722  1.00 36.55           C  \\nATOM   9579  CD  GLN E  76      23.663  89.140 -17.150  1.00 36.55           C  \\nATOM   9580  OE1 GLN E  76      23.871  90.353 -17.037  1.00 36.55           O  \\nATOM   9581  NE2 GLN E  76      22.530  88.647 -17.615  1.00 36.55           N  \\nATOM   9582  N   ASP E  77      28.326  88.970 -15.731  1.00 30.23           N  \\nATOM   9583  CA  ASP E  77      29.455  89.204 -16.633  1.00 30.23           C  \\nATOM   9584  C   ASP E  77      30.725  88.320 -16.332  1.00 30.23           C  \\nATOM   9585  O   ASP E  77      31.700  88.338 -17.094  1.00 30.23           O  \\nATOM   9586  CB  ASP E  77      29.732  90.734 -16.829  1.00 58.30           C  \\nATOM   9587  CG  ASP E  77      28.752  91.417 -17.881  1.00 58.30           C  \\nATOM   9588  OD1 ASP E  77      28.366  90.785 -18.904  1.00 58.30           O  \\nATOM   9589  OD2 ASP E  77      28.371  92.598 -17.704  1.00 58.30           O  \\nATOM   9590  N   PHE E  78      30.671  87.497 -15.272  1.00 29.60           N  \\nATOM   9591  CA  PHE E  78      31.752  86.567 -14.911  1.00 29.60           C  \\nATOM   9592  C   PHE E  78      31.237  85.164 -15.284  1.00 29.60           C  \\nATOM   9593  O   PHE E  78      31.973  84.322 -15.819  1.00 29.60           O  \\nATOM   9594  CB  PHE E  78      32.103  86.641 -13.414  1.00 50.46           C  \\nATOM   9595  CG  PHE E  78      33.131  85.599 -12.965  1.00 50.46           C  \\nATOM   9596  CD1 PHE E  78      34.276  85.332 -13.723  1.00 50.46           C  \\nATOM   9597  CD2 PHE E  78      32.949  84.869 -11.783  1.00 50.46           C  \\nATOM   9598  CE1 PHE E  78      35.213  84.355 -13.307  1.00 50.46           C  \\nATOM   9599  CE2 PHE E  78      33.890  83.890 -11.366  1.00 50.46           C  \\nATOM   9600  CZ  PHE E  78      35.011  83.642 -12.130  1.00 50.46           C  \\nATOM   9601  N   LYS E  79      29.959  84.927 -15.020  1.00 28.89           N  \\nATOM   9602  CA  LYS E  79      29.337  83.657 -15.354  1.00 28.89           C  \\nATOM   9603  C   LYS E  79      27.819  83.875 -15.543  1.00 28.89           C  \\nATOM   9604  O   LYS E  79      27.138  84.486 -14.697  1.00 28.89           O  \\nATOM   9605  CB  LYS E  79      29.651  82.626 -14.260  1.00 39.61           C  \\nATOM   9606  CG  LYS E  79      29.960  81.204 -14.756  1.00 39.61           C  \\nATOM   9607  CD  LYS E  79      28.678  80.405 -14.983  1.00 39.61           C  \\nATOM   9608  CE  LYS E  79      28.891  79.161 -15.838  1.00 39.61           C  \\nATOM   9609  NZ  LYS E  79      27.582  78.755 -16.473  1.00 39.61           N  \\nATOM   9610  N   THR E  80      27.310  83.440 -16.695  1.00 24.38           N  \\nATOM   9611  CA  THR E  80      25.892  83.589 -17.024  1.00 24.38           C  \\nATOM   9612  C   THR E  80      25.012  82.531 -16.387  1.00 24.38           C  \\nATOM   9613  O   THR E  80      25.502  81.585 -15.778  1.00 24.38           O  \\nATOM   9614  CB  THR E  80      25.678  83.525 -18.522  1.00 42.15           C  \\nATOM   9615  OG1 THR E  80      26.596  82.576 -19.074  1.00 42.15           O  \\nATOM   9616  CG2 THR E  80      25.891  84.892 -19.157  1.00 42.15           C  \\nATOM   9617  N   ASP E  81      23.705  82.694 -16.545  1.00 44.69           N  \\nATOM   9618  CA  ASP E  81      22.745  81.754 -15.978  1.00 44.69           C  \\nATOM   9619  C   ASP E  81      23.085  81.452 -14.519  1.00 44.69           C  \\nATOM   9620  O   ASP E  81      23.499  80.342 -14.194  1.00 44.69           O  \\nATOM   9621  CB  ASP E  81      22.730  80.451 -16.785  1.00 94.42           C  \\nATOM   9622  CG  ASP E  81      22.517  80.683 -18.263  1.00 94.42           C  \\nATOM   9623  OD1 ASP E  81      21.384  81.031 -18.659  1.00 94.42           O  \\nATOM   9624  OD2 ASP E  81      23.491  80.520 -19.027  1.00 94.42           O  \\nATOM   9625  N   LEU E  82      22.953  82.455 -13.657  1.00 50.42           N  \\nATOM   9626  CA  LEU E  82      23.253  82.296 -12.237  1.00 50.42           C  \\nATOM   9627  C   LEU E  82      22.106  82.717 -11.331  1.00 50.42           C  \\nATOM   9628  O   LEU E  82      21.355  83.624 -11.665  1.00 50.42           O  \\nATOM   9629  CB  LEU E  82      24.466  83.145 -11.860  1.00 31.71           C  \\nATOM   9630  CG  LEU E  82      25.908  82.653 -11.986  1.00 31.71           C  \\nATOM   9631  CD1 LEU E  82      26.836  83.802 -11.676  1.00 31.71           C  \\nATOM   9632  CD2 LEU E  82      26.168  81.523 -11.027  1.00 31.71           C  \\nATOM   9633  N   ARG E  83      21.961  82.044 -10.195  1.00 24.42           N  \\nATOM   9634  CA  ARG E  83      20.939  82.395  -9.215  1.00 24.42           C  \\nATOM   9635  C   ARG E  83      21.603  82.922  -7.933  1.00 24.42           C  \\nATOM   9636  O   ARG E  83      22.789  82.684  -7.697  1.00 24.42           O  \\nATOM   9637  CB  ARG E  83      20.043  81.192  -8.907  1.00 48.97           C  \\nATOM   9638  CG  ARG E  83      19.163  80.810 -10.064  1.00 48.97           C  \\nATOM   9639  CD  ARG E  83      18.117  79.776  -9.711  1.00 48.97           C  \\nATOM   9640  NE  ARG E  83      17.108  79.779 -10.766  1.00 48.97           N  \\nATOM   9641  CZ  ARG E  83      15.789  79.798 -10.569  1.00 48.97           C  \\nATOM   9642  NH1 ARG E  83      15.284  79.790  -9.334  1.00 48.97           N  \\nATOM   9643  NH2 ARG E  83      14.976  79.918 -11.614  1.00 48.97           N  \\nATOM   9644  N   PHE E  84      20.814  83.572  -7.080  1.00 33.16           N  \\nATOM   9645  CA  PHE E  84      21.318  84.151  -5.835  1.00 33.16           C  \\nATOM   9646  C   PHE E  84      20.349  84.062  -4.637  1.00 33.16           C  \\nATOM   9647  O   PHE E  84      19.204  84.522  -4.727  1.00 33.16           O  \\nATOM   9648  CB  PHE E  84      21.590  85.645  -6.035  1.00 32.55           C  \\nATOM   9649  CG  PHE E  84      22.920  85.986  -6.668  1.00 32.55           C  \\nATOM   9650  CD1 PHE E  84      23.098  85.918  -8.052  1.00 32.55           C  \\nATOM   9651  CD2 PHE E  84      23.944  86.537  -5.893  1.00 32.55           C  \\nATOM   9652  CE1 PHE E  84      24.274  86.410  -8.648  1.00 32.55           C  \\nATOM   9653  CE2 PHE E  84      25.108  87.026  -6.474  1.00 32.55           C  \\nATOM   9654  CZ  PHE E  84      25.274  86.966  -7.849  1.00 32.55           C  \\nATOM   9655  N   GLN E  85      20.824  83.534  -3.505  1.00  7.64           N  \\nATOM   9656  CA  GLN E  85      20.025  83.483  -2.280  1.00  7.64           C  \\nATOM   9657  C   GLN E  85      19.757  84.937  -1.906  1.00  7.64           C  \\nATOM   9658  O   GLN E  85      20.577  85.818  -2.184  1.00  7.64           O  \\nATOM   9659  CB  GLN E  85      20.802  82.799  -1.144  1.00 18.63           C  \\nATOM   9660  CG  GLN E  85      21.240  81.352  -1.459  1.00 18.63           C  \\nATOM   9661  CD  GLN E  85      21.635  80.531  -0.214  1.00 18.63           C  \\nATOM   9662  OE1 GLN E  85      22.367  80.997   0.666  1.00 18.63           O  \\nATOM   9663  NE2 GLN E  85      21.190  79.277  -0.177  1.00 18.63           N  \\nATOM   9664  N   SER E  86      18.609  85.222  -1.305  1.00 29.43           N  \\nATOM   9665  CA  SER E  86      18.325  86.614  -0.954  1.00 29.43           C  \\nATOM   9666  C   SER E  86      19.445  87.070  -0.040  1.00 29.43           C  \\nATOM   9667  O   SER E  86      20.002  88.144  -0.213  1.00 29.43           O  \\nATOM   9668  CB  SER E  86      16.977  86.757  -0.246  1.00 44.20           C  \\nATOM   9669  OG  SER E  86      17.067  86.363   1.107  1.00 44.20           O  \\nATOM   9670  N   SER E  87      19.874  86.155   0.821  1.00 19.77           N  \\nATOM   9671  CA  SER E  87      20.921  86.439   1.779  1.00 19.77           C  \\nATOM   9672  C   SER E  87      22.318  86.540   1.191  1.00 19.77           C  \\nATOM   9673  O   SER E  87      23.181  87.173   1.779  1.00 19.77           O  \\nATOM   9674  CB  SER E  87      20.898  85.426   2.915  1.00 23.89           C  \\nATOM   9675  OG  SER E  87      21.324  84.177   2.441  1.00 23.89           O  \\nATOM   9676  N   ALA E  88      22.575  85.898   0.064  1.00 19.03           N  \\nATOM   9677  CA  ALA E  88      23.892  86.031  -0.526  1.00 19.03           C  \\nATOM   9678  C   ALA E  88      24.032  87.510  -0.863  1.00 19.03           C  \\nATOM   9679  O   ALA E  88      25.045  88.135  -0.565  1.00 19.03           O  \\nATOM   9680  CB  ALA E  88      23.979  85.224  -1.752  1.00  7.54           C  \\nATOM   9681  N   VAL E  89      22.968  88.097  -1.402  1.00 13.75           N  \\nATOM   9682  CA  VAL E  89      22.987  89.519  -1.768  1.00 13.75           C  \\nATOM   9683  C   VAL E  89      23.110  90.427  -0.555  1.00 13.75           C  \\nATOM   9684  O   VAL E  89      23.815  91.417  -0.608  1.00 13.75           O  \\nATOM   9685  CB  VAL E  89      21.729  89.925  -2.572  1.00 11.12           C  \\nATOM   9686  CG1 VAL E  89      21.902  91.318  -3.172  1.00 11.12           C  \\nATOM   9687  CG2 VAL E  89      21.442  88.897  -3.648  1.00 11.12           C  \\nATOM   9688  N   MET E  90      22.367  90.131   0.507  1.00 14.56           N  \\nATOM   9689  CA  MET E  90      22.442  90.915   1.729  1.00 14.56           C  \\nATOM   9690  C   MET E  90      23.884  90.846   2.244  1.00 14.56           C  \\nATOM   9691  O   MET E  90      24.478  91.883   2.586  1.00 14.56           O  \\nATOM   9692  CB  MET E  90      21.492  90.385   2.802  1.00 52.83           C  \\nATOM   9693  CG  MET E  90      20.018  90.728   2.625  1.00 52.83           C  \\nATOM   9694  SD  MET E  90      19.013  90.146   4.068  1.00 52.83           S  \\nATOM   9695  CE  MET E  90      18.702  88.350   3.708  1.00 52.83           C  \\nATOM   9696  N   ALA E  91      24.467  89.642   2.266  1.00 17.16           N  \\nATOM   9697  CA  ALA E  91      25.845  89.455   2.722  1.00 17.16           C  \\nATOM   9698  C   ALA E  91      26.775  90.380   1.954  1.00 17.16           C  \\nATOM   9699  O   ALA E  91      27.597  91.066   2.548  1.00 17.16           O  \\nATOM   9700  CB  ALA E  91      26.264  88.027   2.541  1.00 26.01           C  \\nATOM   9701  N   LEU E  92      26.638  90.415   0.635  1.00 16.85           N  \\nATOM   9702  CA  LEU E  92      27.457  91.318  -0.167  1.00 16.85           C  \\nATOM   9703  C   LEU E  92      27.201  92.770   0.212  1.00 16.85           C  \\nATOM   9704  O   LEU E  92      28.145  93.538   0.348  1.00 16.85           O  \\nATOM   9705  CB  LEU E  92      27.190  91.140  -1.661  1.00 12.63           C  \\nATOM   9706  CG  LEU E  92      27.647  89.797  -2.231  1.00 12.63           C  \\nATOM   9707  CD1 LEU E  92      26.854  89.389  -3.438  1.00 12.63           C  \\nATOM   9708  CD2 LEU E  92      29.095  89.920  -2.562  1.00 12.63           C  \\nATOM   9709  N   GLN E  93      25.945  93.165   0.405  1.00 17.17           N  \\nATOM   9710  CA  GLN E  93      25.692  94.563   0.760  1.00 17.17           C  \\nATOM   9711  C   GLN E  93      26.342  94.952   2.060  1.00 17.17           C  \\nATOM   9712  O   GLN E  93      27.003  95.979   2.149  1.00 17.17           O  \\nATOM   9713  CB  GLN E  93      24.211  94.882   0.817  1.00 18.53           C  \\nATOM   9714  CG  GLN E  93      23.937  96.286   0.346  1.00 18.53           C  \\nATOM   9715  CD  GLN E  93      22.475  96.556   0.175  1.00 18.53           C  \\nATOM   9716  OE1 GLN E  93      21.710  95.700  -0.304  1.00 18.53           O  \\nATOM   9717  NE2 GLN E  93      22.063  97.757   0.562  1.00 18.53           N  \\nATOM   9718  N   GLU E  94      26.163  94.107   3.060  1.00 14.49           N  \\nATOM   9719  CA  GLU E  94      26.752  94.314   4.370  1.00 14.49           C  \\nATOM   9720  C   GLU E  94      28.246  94.536   4.272  1.00 14.49           C  \\nATOM   9721  O   GLU E  94      28.759  95.510   4.793  1.00 14.49           O  \\nATOM   9722  CB  GLU E  94      26.473  93.105   5.239  1.00 35.41           C  \\nATOM   9723  CG  GLU E  94      25.030  93.015   5.678  1.00 35.41           C  \\nATOM   9724  CD  GLU E  94      24.653  94.093   6.688  1.00 35.41           C  \\nATOM   9725  OE1 GLU E  94      25.548  94.614   7.402  1.00 35.41           O  \\nATOM   9726  OE2 GLU E  94      23.451  94.421   6.786  1.00 35.41           O  \\nATOM   9727  N   ALA E  95      28.934  93.640   3.575  1.00 10.08           N  \\nATOM   9728  CA  ALA E  95      30.369  93.736   3.387  1.00 10.08           C  \\nATOM   9729  C   ALA E  95      30.733  94.957   2.578  1.00 10.08           C  \\nATOM   9730  O   ALA E  95      31.730  95.611   2.851  1.00 10.08           O  \\nATOM   9731  CB  ALA E  95      30.882  92.496   2.685  1.00  5.00           C  \\nATOM   9732  N   SER E  96      29.928  95.260   1.570  1.00 13.59           N  \\nATOM   9733  CA  SER E  96      30.186  96.393   0.690  1.00 13.59           C  \\nATOM   9734  C   SER E  96      30.199  97.743   1.380  1.00 13.59           C  \\nATOM   9735  O   SER E  96      31.151  98.509   1.245  1.00 13.59           O  \\nATOM   9736  CB  SER E  96      29.189  96.393  -0.469  1.00 29.71           C  \\nATOM   9737  OG  SER E  96      29.379  95.267  -1.321  1.00 29.71           O  \\nATOM   9738  N   GLU E  97      29.155  98.031   2.143  1.00  9.47           N  \\nATOM   9739  CA  GLU E  97      29.083  99.301   2.855  1.00  9.47           C  \\nATOM   9740  C   GLU E  97      30.071  99.356   4.024  1.00  9.47           C  \\nATOM   9741  O   GLU E  97      30.661 100.396   4.263  1.00  9.47           O  \\nATOM   9742  CB  GLU E  97      27.665  99.554   3.354  1.00 21.93           C  \\nATOM   9743  CG  GLU E  97      26.618  99.337   2.287  1.00 21.93           C  \\nATOM   9744  CD  GLU E  97      25.297 100.045   2.570  1.00 21.93           C  \\nATOM   9745  OE1 GLU E  97      25.160 100.705   3.623  1.00 21.93           O  \\nATOM   9746  OE2 GLU E  97      24.375  99.941   1.735  1.00 21.93           O  \\nATOM   9747  N   ALA E  98      30.254  98.247   4.746  1.00  5.00           N  \\nATOM   9748  CA  ALA E  98      31.167  98.234   5.881  1.00  5.00           C  \\nATOM   9749  C   ALA E  98      32.527  98.665   5.392  1.00  5.00           C  \\nATOM   9750  O   ALA E  98      33.195  99.490   6.035  1.00  5.00           O  \\nATOM   9751  CB  ALA E  98      31.244  96.891   6.486  1.00  5.00           C  \\nATOM   9752  N   TYR E  99      32.887  98.164   4.208  1.00 18.26           N  \\nATOM   9753  CA  TYR E  99      34.141  98.494   3.541  1.00 18.26           C  \\nATOM   9754  C   TYR E  99      34.200  99.970   3.132  1.00 18.26           C  \\nATOM   9755  O   TYR E  99      35.174 100.663   3.414  1.00 18.26           O  \\nATOM   9756  CB  TYR E  99      34.320  97.591   2.320  1.00  9.24           C  \\nATOM   9757  CG  TYR E  99      35.395  98.036   1.364  1.00  9.24           C  \\nATOM   9758  CD1 TYR E  99      36.734  97.706   1.573  1.00  9.24           C  \\nATOM   9759  CD2 TYR E  99      35.077  98.850   0.268  1.00  9.24           C  \\nATOM   9760  CE1 TYR E  99      37.747  98.201   0.704  1.00  9.24           C  \\nATOM   9761  CE2 TYR E  99      36.057  99.339  -0.590  1.00  9.24           C  \\nATOM   9762  CZ  TYR E  99      37.386  99.021  -0.375  1.00  9.24           C  \\nATOM   9763  OH  TYR E  99      38.331  99.527  -1.261  1.00  9.24           O  \\nATOM   9764  N   LEU E 100      33.169 100.430   2.433  1.00 17.47           N  \\nATOM   9765  CA  LEU E 100      33.093 101.810   1.976  1.00 17.47           C  \\nATOM   9766  C   LEU E 100      33.101 102.828   3.099  1.00 17.47           C  \\nATOM   9767  O   LEU E 100      33.734 103.871   3.002  1.00 17.47           O  \\nATOM   9768  CB  LEU E 100      31.862 101.996   1.099  1.00 13.86           C  \\nATOM   9769  CG  LEU E 100      32.116 101.518  -0.331  1.00 13.86           C  \\nATOM   9770  CD1 LEU E 100      30.854 101.659  -1.144  1.00 13.86           C  \\nATOM   9771  CD2 LEU E 100      33.238 102.360  -0.961  1.00 13.86           C  \\nATOM   9772  N   VAL E 101      32.405 102.519   4.177  1.00 15.75           N  \\nATOM   9773  CA  VAL E 101      32.357 103.409   5.309  1.00 15.75           C  \\nATOM   9774  C   VAL E 101      33.765 103.570   5.888  1.00 15.75           C  \\nATOM   9775  O   VAL E 101      34.222 104.693   6.078  1.00 15.75           O  \\nATOM   9776  CB  VAL E 101      31.337 102.902   6.364  1.00 10.48           C  \\nATOM   9777  CG1 VAL E 101      31.449 103.702   7.660  1.00 10.48           C  \\nATOM   9778  CG2 VAL E 101      29.925 103.022   5.805  1.00 10.48           C  \\nATOM   9779  N   ALA E 102      34.470 102.460   6.118  1.00 30.71           N  \\nATOM   9780  CA  ALA E 102      35.835 102.514   6.652  1.00 30.71           C  \\nATOM   9781  C   ALA E 102      36.757 103.244   5.674  1.00 30.71           C  \\nATOM   9782  O   ALA E 102      37.620 104.011   6.088  1.00 30.71           O  \\nATOM   9783  CB  ALA E 102      36.357 101.125   6.926  1.00 10.84           C  \\nATOM   9784  N   LEU E 103      36.602 102.989   4.378  1.00 16.86           N  \\nATOM   9785  CA  LEU E 103      37.405 103.691   3.375  1.00 16.86           C  \\nATOM   9786  C   LEU E 103      37.272 105.201   3.590  1.00 16.86           C  \\nATOM   9787  O   LEU E 103      38.254 105.922   3.563  1.00 16.86           O  \\nATOM   9788  CB  LEU E 103      36.929 103.352   1.966  1.00  5.00           C  \\nATOM   9789  CG  LEU E 103      37.936 103.728   0.893  1.00  5.00           C  \\nATOM   9790  CD1 LEU E 103      39.249 103.046   1.185  1.00  5.00           C  \\nATOM   9791  CD2 LEU E 103      37.436 103.301  -0.453  1.00  5.00           C  \\nATOM   9792  N   PHE E 104      36.045 105.675   3.804  1.00 21.69           N  \\nATOM   9793  CA  PHE E 104      35.805 107.095   4.035  1.00 21.69           C  \\nATOM   9794  C   PHE E 104      36.475 107.634   5.301  1.00 21.69           C  \\nATOM   9795  O   PHE E 104      36.975 108.749   5.295  1.00 21.69           O  \\nATOM   9796  CB  PHE E 104      34.307 107.408   4.003  1.00  6.31           C  \\nATOM   9797  CG  PHE E 104      33.700 107.361   2.618  1.00  6.31           C  \\nATOM   9798  CD1 PHE E 104      34.199 108.168   1.600  1.00  6.31           C  \\nATOM   9799  CD2 PHE E 104      32.635 106.512   2.341  1.00  6.31           C  \\nATOM   9800  CE1 PHE E 104      33.654 108.137   0.319  1.00  6.31           C  \\nATOM   9801  CE2 PHE E 104      32.078 106.462   1.077  1.00  6.31           C  \\nATOM   9802  CZ  PHE E 104      32.584 107.277   0.050  1.00  6.31           C  \\nATOM   9803  N   GLU E 105      36.481 106.860   6.381  1.00 16.41           N  \\nATOM   9804  CA  GLU E 105      37.156 107.299   7.589  1.00 16.41           C  \\nATOM   9805  C   GLU E 105      38.610 107.610   7.230  1.00 16.41           C  \\nATOM   9806  O   GLU E 105      39.107 108.679   7.561  1.00 16.41           O  \\nATOM   9807  CB  GLU E 105      37.130 106.224   8.668  1.00 35.72           C  \\nATOM   9808  CG  GLU E 105      35.794 105.545   8.855  1.00 35.72           C  \\nATOM   9809  CD  GLU E 105      35.713 104.717  10.126  1.00 35.72           C  \\nATOM   9810  OE1 GLU E 105      36.782 104.430  10.710  1.00 35.72           O  \\nATOM   9811  OE2 GLU E 105      34.579 104.376  10.561  1.00 35.72           O  \\nATOM   9812  N   ASP E 106      39.284 106.706   6.510  1.00 20.74           N  \\nATOM   9813  CA  ASP E 106      40.691 106.909   6.118  1.00 20.74           C  \\nATOM   9814  C   ASP E 106      40.843 108.108   5.213  1.00 20.74           C  \\nATOM   9815  O   ASP E 106      41.689 108.960   5.456  1.00 20.74           O  \\nATOM   9816  CB  ASP E 106      41.264 105.668   5.434  1.00 14.24           C  \\nATOM   9817  CG  ASP E 106      41.362 104.477   6.373  1.00 14.24           C  \\nATOM   9818  OD1 ASP E 106      41.285 104.659   7.610  1.00 14.24           O  \\nATOM   9819  OD2 ASP E 106      41.510 103.335   5.874  1.00 14.24           O  \\nATOM   9820  N   THR E 107      40.026 108.148   4.159  1.00  9.09           N  \\nATOM   9821  CA  THR E 107      39.988 109.239   3.178  1.00  9.09           C  \\nATOM   9822  C   THR E 107      39.905 110.555   3.915  1.00  9.09           C  \\nATOM   9823  O   THR E 107      40.681 111.453   3.662  1.00  9.09           O  \\nATOM   9824  CB  THR E 107      38.749 109.114   2.287  1.00 11.61           C  \\nATOM   9825  OG1 THR E 107      38.901 107.991   1.416  1.00 11.61           O  \\nATOM   9826  CG2 THR E 107      38.549 110.326   1.450  1.00 11.61           C  \\nATOM   9827  N   ASN E 108      38.988 110.637   4.872  1.00 12.16           N  \\nATOM   9828  CA  ASN E 108      38.782 111.823   5.690  1.00 12.16           C  \\nATOM   9829  C   ASN E 108      40.106 112.236   6.301  1.00 12.16           C  \\nATOM   9830  O   ASN E 108      40.504 113.403   6.200  1.00 12.16           O  \\nATOM   9831  CB  ASN E 108      37.789 111.484   6.803  1.00 25.35           C  \\nATOM   9832  CG  ASN E 108      37.092 112.700   7.369  1.00 25.35           C  \\nATOM   9833  OD1 ASN E 108      36.873 113.691   6.662  1.00 25.35           O  \\nATOM   9834  ND2 ASN E 108      36.688 112.614   8.637  1.00 25.35           N  \\nATOM   9835  N   LEU E 109      40.768 111.276   6.966  1.00 13.14           N  \\nATOM   9836  CA  LEU E 109      42.066 111.509   7.595  1.00 13.14           C  \\nATOM   9837  C   LEU E 109      43.088 112.053   6.594  1.00 13.14           C  \\nATOM   9838  O   LEU E 109      43.820 112.978   6.901  1.00 13.14           O  \\nATOM   9839  CB  LEU E 109      42.572 110.250   8.251  1.00  5.00           C  \\nATOM   9840  CG  LEU E 109      41.842 109.734   9.487  1.00  5.00           C  \\nATOM   9841  CD1 LEU E 109      42.650 108.620  10.105  1.00  5.00           C  \\nATOM   9842  CD2 LEU E 109      41.717 110.813  10.511  1.00  5.00           C  \\nATOM   9843  N   CYS E 110      43.148 111.503   5.394  1.00 14.04           N  \\nATOM   9844  CA  CYS E 110      44.069 112.069   4.426  1.00 14.04           C  \\nATOM   9845  C   CYS E 110      43.762 113.547   4.150  1.00 14.04           C  \\nATOM   9846  O   CYS E 110      44.644 114.394   4.285  1.00 14.04           O  \\nATOM   9847  CB  CYS E 110      44.069 111.268   3.132  1.00 16.17           C  \\nATOM   9848  SG  CYS E 110      44.754 109.641   3.421  1.00 16.17           S  \\nATOM   9849  N   ALA E 111      42.503 113.866   3.825  1.00 16.19           N  \\nATOM   9850  CA  ALA E 111      42.102 115.246   3.543  1.00 16.19           C  \\nATOM   9851  C   ALA E 111      42.547 116.141   4.670  1.00 16.19           C  \\nATOM   9852  O   ALA E 111      43.186 117.155   4.445  1.00 16.19           O  \\nATOM   9853  CB  ALA E 111      40.608 115.350   3.359  1.00  7.47           C  \\nATOM   9854  N   ILE E 112      42.247 115.736   5.892  1.00 22.10           N  \\nATOM   9855  CA  ILE E 112      42.626 116.524   7.051  1.00 22.10           C  \\nATOM   9856  C   ILE E 112      44.125 116.722   7.120  1.00 22.10           C  \\nATOM   9857  O   ILE E 112      44.581 117.750   7.574  1.00 22.10           O  \\nATOM   9858  CB  ILE E 112      42.110 115.886   8.345  1.00 18.41           C  \\nATOM   9859  CG1 ILE E 112      40.595 116.008   8.408  1.00 18.41           C  \\nATOM   9860  CG2 ILE E 112      42.725 116.536   9.549  1.00 18.41           C  \\nATOM   9861  CD1 ILE E 112      39.989 115.283   9.610  1.00 18.41           C  \\nATOM   9862  N   HIS E 113      44.881 115.724   6.684  1.00 18.03           N  \\nATOM   9863  CA  HIS E 113      46.339 115.785   6.669  1.00 18.03           C  \\nATOM   9864  C   HIS E 113      46.838 116.900   5.759  1.00 18.03           C  \\nATOM   9865  O   HIS E 113      47.892 117.476   6.005  1.00 18.03           O  \\nATOM   9866  CB  HIS E 113      46.904 114.460   6.170  1.00 25.32           C  \\nATOM   9867  CG  HIS E 113      48.364 114.302   6.429  1.00 25.32           C  \\nATOM   9868  ND1 HIS E 113      49.309 114.391   5.428  1.00 25.32           N  \\nATOM   9869  CD2 HIS E 113      49.047 114.114   7.585  1.00 25.32           C  \\nATOM   9870  CE1 HIS E 113      50.513 114.272   5.957  1.00 25.32           C  \\nATOM   9871  NE2 HIS E 113      50.382 114.102   7.264  1.00 25.32           N  \\nATOM   9872  N   ALA E 114      46.131 117.096   4.648  1.00 19.45           N  \\nATOM   9873  CA  ALA E 114      46.423 118.152   3.676  1.00 19.45           C  \\nATOM   9874  C   ALA E 114      45.856 119.484   4.169  1.00 19.45           C  \\nATOM   9875  O   ALA E 114      45.801 120.468   3.423  1.00 19.45           O  \\nATOM   9876  CB  ALA E 114      45.803 117.807   2.324  1.00  8.08           C  \\nATOM   9877  N   LYS E 115      45.392 119.489   5.416  1.00 32.88           N  \\nATOM   9878  CA  LYS E 115      44.816 120.665   6.030  1.00 32.88           C  \\nATOM   9879  C   LYS E 115      43.560 121.122   5.291  1.00 32.88           C  \\nATOM   9880  O   LYS E 115      43.289 122.318   5.215  1.00 32.88           O  \\nATOM   9881  CB  LYS E 115      45.857 121.771   6.106  1.00 49.66           C  \\nATOM   9882  CG  LYS E 115      47.104 121.320   6.842  1.00 49.66           C  \\nATOM   9883  CD  LYS E 115      48.192 122.361   6.845  1.00 49.66           C  \\nATOM   9884  CE  LYS E 115      48.902 122.346   8.188  1.00 49.66           C  \\nATOM   9885  NZ  LYS E 115      49.845 123.497   8.368  1.00 49.66           N  \\nATOM   9886  N   ARG E 116      42.826 120.161   4.713  1.00 29.09           N  \\nATOM   9887  CA  ARG E 116      41.558 120.410   4.016  1.00 29.09           C  \\nATOM   9888  C   ARG E 116      40.439 119.796   4.854  1.00 29.09           C  \\nATOM   9889  O   ARG E 116      40.709 119.202   5.902  1.00 29.09           O  \\nATOM   9890  CB  ARG E 116      41.543 119.789   2.617  1.00 23.96           C  \\nATOM   9891  CG  ARG E 116      42.475 120.470   1.628  1.00 23.96           C  \\nATOM   9892  CD  ARG E 116      42.342 119.908   0.205  1.00 23.96           C  \\nATOM   9893  NE  ARG E 116      43.222 118.771  -0.074  1.00 23.96           N  \\nATOM   9894  CZ  ARG E 116      42.895 117.492   0.111  1.00 23.96           C  \\nATOM   9895  NH1 ARG E 116      41.694 117.142   0.577  1.00 23.96           N  \\nATOM   9896  NH2 ARG E 116      43.798 116.558  -0.142  1.00 23.96           N  \\nATOM   9897  N   VAL E 117      39.190 119.949   4.393  1.00 21.02           N  \\nATOM   9898  CA  VAL E 117      37.970 119.443   5.067  1.00 21.02           C  \\nATOM   9899  C   VAL E 117      37.138 118.670   4.027  1.00 21.02           C  \\nATOM   9900  O   VAL E 117      36.291 117.843   4.358  1.00 21.02           O  \\nATOM   9901  CB  VAL E 117      37.116 120.633   5.624  1.00 26.46           C  \\nATOM   9902  CG1 VAL E 117      35.859 120.143   6.281  1.00 26.46           C  \\nATOM   9903  CG2 VAL E 117      37.901 121.412   6.635  1.00 26.46           C  \\nATOM   9904  N   THR E 118      37.377 118.985   2.762  1.00 20.40           N  \\nATOM   9905  CA  THR E 118      36.699 118.346   1.651  1.00 20.40           C  \\nATOM   9906  C   THR E 118      37.449 117.125   1.143  1.00 20.40           C  \\nATOM   9907  O   THR E 118      38.523 117.260   0.561  1.00 20.40           O  \\nATOM   9908  CB  THR E 118      36.596 119.311   0.472  1.00 19.98           C  \\nATOM   9909  OG1 THR E 118      36.050 120.551   0.921  1.00 19.98           O  \\nATOM   9910  CG2 THR E 118      35.701 118.735  -0.602  1.00 19.98           C  \\nATOM   9911  N   ILE E 119      36.882 115.938   1.301  1.00 13.88           N  \\nATOM   9912  CA  ILE E 119      37.586 114.767   0.794  1.00 13.88           C  \\nATOM   9913  C   ILE E 119      37.598 114.850  -0.739  1.00 13.88           C  \\nATOM   9914  O   ILE E 119      36.663 115.380  -1.323  1.00 13.88           O  \\nATOM   9915  CB  ILE E 119      36.944 113.437   1.271  1.00 12.22           C  \\nATOM   9916  CG1 ILE E 119      35.576 113.222   0.608  1.00 12.22           C  \\nATOM   9917  CG2 ILE E 119      36.859 113.410   2.799  1.00 12.22           C  \\nATOM   9918  CD1 ILE E 119      34.862 111.938   1.049  1.00 12.22           C  \\nATOM   9919  N   MET E 120      38.704 114.441  -1.358  1.00 26.11           N  \\nATOM   9920  CA  MET E 120      38.862 114.445  -2.812  1.00 26.11           C  \\nATOM   9921  C   MET E 120      39.393 113.074  -3.229  1.00 26.11           C  \\nATOM   9922  O   MET E 120      39.913 112.339  -2.396  1.00 26.11           O  \\nATOM   9923  CB  MET E 120      39.887 115.488  -3.256  1.00 26.39           C  \\nATOM   9924  CG  MET E 120      39.857 116.818  -2.530  1.00 26.39           C  \\nATOM   9925  SD  MET E 120      40.863 118.061  -3.385  1.00 26.39           S  \\nATOM   9926  CE  MET E 120      39.969 119.541  -2.845  1.00 26.39           C  \\nATOM   9927  N   PRO E 121      39.279 112.717  -4.529  1.00 23.87           N  \\nATOM   9928  CA  PRO E 121      39.751 111.434  -5.072  1.00 23.87           C  \\nATOM   9929  C   PRO E 121      41.207 111.173  -4.652  1.00 23.87           C  \\nATOM   9930  O   PRO E 121      41.588 110.073  -4.276  1.00 23.87           O  \\nATOM   9931  CB  PRO E 121      39.619 111.658  -6.576  1.00 15.50           C  \\nATOM   9932  CG  PRO E 121      38.365 112.475  -6.669  1.00 15.50           C  \\nATOM   9933  CD  PRO E 121      38.629 113.509  -5.591  1.00 15.50           C  \\nATOM   9934  N   LYS E 122      41.996 112.231  -4.735  1.00 18.52           N  \\nATOM   9935  CA  LYS E 122      43.400 112.283  -4.342  1.00 18.52           C  \\nATOM   9936  C   LYS E 122      43.535 111.602  -2.946  1.00 18.52           C  \\nATOM   9937  O   LYS E 122      44.406 110.776  -2.732  1.00 18.52           O  \\nATOM   9938  CB  LYS E 122      43.745 113.783  -4.267  1.00 44.76           C  \\nATOM   9939  CG  LYS E 122      45.179 114.205  -4.299  1.00 44.76           C  \\nATOM   9940  CD  LYS E 122      45.289 115.703  -3.975  1.00 44.76           C  \\nATOM   9941  CE  LYS E 122      44.524 116.575  -4.981  1.00 44.76           C  \\nATOM   9942  NZ  LYS E 122      44.589 118.056  -4.699  1.00 44.76           N  \\nATOM   9943  N   ASP E 123      42.639 111.917  -2.016  1.00 24.10           N  \\nATOM   9944  CA  ASP E 123      42.669 111.317  -0.678  1.00 24.10           C  \\nATOM   9945  C   ASP E 123      42.318 109.836  -0.742  1.00 24.10           C  \\nATOM   9946  O   ASP E 123      43.013 109.007  -0.172  1.00 24.10           O  \\nATOM   9947  CB  ASP E 123      41.680 112.016   0.245  1.00 32.41           C  \\nATOM   9948  CG  ASP E 123      41.933 113.490   0.346  1.00 32.41           C  \\nATOM   9949  OD1 ASP E 123      42.889 113.874   1.031  1.00 32.41           O  \\nATOM   9950  OD2 ASP E 123      41.188 114.267  -0.262  1.00 32.41           O  \\nATOM   9951  N   ILE E 124      41.214 109.519  -1.416  1.00 31.41           N  \\nATOM   9952  CA  ILE E 124      40.776 108.136  -1.586  1.00 31.41           C  \\nATOM   9953  C   ILE E 124      41.927 107.287  -2.112  1.00 31.41           C  \\nATOM   9954  O   ILE E 124      42.209 106.233  -1.570  1.00 31.41           O  \\nATOM   9955  CB  ILE E 124      39.621 108.027  -2.602  1.00 36.45           C  \\nATOM   9956  CG1 ILE E 124      38.346 108.657  -2.030  1.00 36.45           C  \\nATOM   9957  CG2 ILE E 124      39.417 106.571  -3.031  1.00 36.45           C  \\nATOM   9958  CD1 ILE E 124      37.101 108.355  -2.844  1.00 36.45           C  \\nATOM   9959  N   GLN E 125      42.598 107.766  -3.158  1.00 23.28           N  \\nATOM   9960  CA  GLN E 125      43.718 107.056  -3.767  1.00 23.28           C  \\nATOM   9961  C   GLN E 125      44.929 106.894  -2.852  1.00 23.28           C  \\nATOM   9962  O   GLN E 125      45.614 105.880  -2.914  1.00 23.28           O  \\nATOM   9963  CB  GLN E 125      44.101 107.723  -5.076  1.00 31.66           C  \\nATOM   9964  CG  GLN E 125      42.997 107.627  -6.115  1.00 31.66           C  \\nATOM   9965  CD  GLN E 125      43.102 108.692  -7.202  1.00 31.66           C  \\nATOM   9966  OE1 GLN E 125      44.125 109.362  -7.336  1.00 31.66           O  \\nATOM   9967  NE2 GLN E 125      42.026 108.868  -7.972  1.00 31.66           N  \\nATOM   9968  N   LEU E 126      45.188 107.879  -1.997  1.00 16.70           N  \\nATOM   9969  CA  LEU E 126      46.315 107.793  -1.077  1.00 16.70           C  \\nATOM   9970  C   LEU E 126      45.981 106.756  -0.013  1.00 16.70           C  \\nATOM   9971  O   LEU E 126      46.833 105.967   0.398  1.00 16.70           O  \\nATOM   9972  CB  LEU E 126      46.634 109.165  -0.432  1.00  8.01           C  \\nATOM   9973  CG  LEU E 126      47.706 109.082   0.661  1.00  8.01           C  \\nATOM   9974  CD1 LEU E 126      49.007 108.742   0.010  1.00  8.01           C  \\nATOM   9975  CD2 LEU E 126      47.836 110.345   1.484  1.00  8.01           C  \\nATOM   9976  N   ALA E 127      44.733 106.763   0.444  1.00 15.14           N  \\nATOM   9977  CA  ALA E 127      44.294 105.815   1.458  1.00 15.14           C  \\nATOM   9978  C   ALA E 127      44.559 104.399   0.977  1.00 15.14           C  \\nATOM   9979  O   ALA E 127      45.236 103.643   1.647  1.00 15.14           O  \\nATOM   9980  CB  ALA E 127      42.814 106.012   1.769  1.00 32.30           C  \\nATOM   9981  N   ARG E 128      44.064 104.072  -0.216  1.00 22.16           N  \\nATOM   9982  CA  ARG E 128      44.234 102.750  -0.818  1.00 22.16           C  \\nATOM   9983  C   ARG E 128      45.689 102.432  -1.109  1.00 22.16           C  \\nATOM   9984  O   ARG E 128      46.106 101.305  -0.911  1.00 22.16           O  \\nATOM   9985  CB  ARG E 128      43.400 102.615  -2.090  1.00 27.57           C  \\nATOM   9986  CG  ARG E 128      41.974 103.110  -1.935  1.00 27.57           C  \\nATOM   9987  CD  ARG E 128      40.992 102.209  -2.633  1.00 27.57           C  \\nATOM   9988  NE  ARG E 128      41.306 102.021  -4.046  1.00 27.57           N  \\nATOM   9989  CZ  ARG E 128      41.062 100.898  -4.712  1.00 27.57           C  \\nATOM   9990  NH1 ARG E 128      40.497  99.864  -4.100  1.00 27.57           N  \\nATOM   9991  NH2 ARG E 128      41.419 100.790  -5.980  1.00 27.57           N  \\nATOM   9992  N   ARG E 129      46.455 103.401  -1.611  1.00 20.42           N  \\nATOM   9993  CA  ARG E 129      47.880 103.184  -1.877  1.00 20.42           C  \\nATOM   9994  C   ARG E 129      48.544 102.668  -0.594  1.00 20.42           C  \\nATOM   9995  O   ARG E 129      49.173 101.615  -0.598  1.00 20.42           O  \\nATOM   9996  CB  ARG E 129      48.549 104.488  -2.340  1.00 84.01           C  \\nATOM   9997  CG  ARG E 129      50.083 104.450  -2.498  1.00 84.01           C  \\nATOM   9998  CD  ARG E 129      50.568 104.424  -3.966  1.00 84.01           C  \\nATOM   9999  NE  ARG E 129      49.581 104.903  -4.946  1.00 84.01           N  \\nATOM  10000  CZ  ARG E 129      49.363 106.182  -5.263  1.00 84.01           C  \\nATOM  10001  NH1 ARG E 129      50.064 107.148  -4.682  1.00 84.01           N  \\nATOM  10002  NH2 ARG E 129      48.423 106.498  -6.148  1.00 84.01           N  \\nATOM  10003  N   ILE E 130      48.345 103.369   0.518  1.00 28.10           N  \\nATOM  10004  CA  ILE E 130      48.943 102.956   1.775  1.00 28.10           C  \\nATOM  10005  C   ILE E 130      48.405 101.609   2.244  1.00 28.10           C  \\nATOM  10006  O   ILE E 130      49.183 100.755   2.672  1.00 28.10           O  \\nATOM  10007  CB  ILE E 130      48.776 104.050   2.846  1.00 25.00           C  \\nATOM  10008  CG1 ILE E 130      49.569 105.294   2.417  1.00 25.00           C  \\nATOM  10009  CG2 ILE E 130      49.227 103.561   4.221  1.00 25.00           C  \\nATOM  10010  CD1 ILE E 130      49.143 106.557   3.150  1.00 25.00           C  \\nATOM  10011  N   ARG E 131      47.090 101.421   2.145  1.00 39.55           N  \\nATOM  10012  CA  ARG E 131      46.413 100.181   2.541  1.00 39.55           C  \\nATOM  10013  C   ARG E 131      46.888  98.946   1.782  1.00 39.55           C  \\nATOM  10014  O   ARG E 131      46.661  97.825   2.221  1.00 39.55           O  \\nATOM  10015  CB  ARG E 131      44.917 100.298   2.289  1.00 16.53           C  \\nATOM  10016  CG  ARG E 131      44.105 101.089   3.284  1.00 16.53           C  \\nATOM  10017  CD  ARG E 131      42.710 101.273   2.684  1.00 16.53           C  \\nATOM  10018  NE  ARG E 131      41.660 101.437   3.677  1.00 16.53           N  \\nATOM  10019  CZ  ARG E 131      40.490 100.825   3.585  1.00 16.53           C  \\nATOM  10020  NH1 ARG E 131      40.262 100.022   2.548  1.00 16.53           N  \\nATOM  10021  NH2 ARG E 131      39.544 101.029   4.501  1.00 16.53           N  \\nATOM  10022  N   GLY E 132      47.412  99.146   0.581  1.00 32.31           N  \\nATOM  10023  CA  GLY E 132      47.893  98.026  -0.205  1.00 32.31           C  \\nATOM  10024  C   GLY E 132      46.838  97.445  -1.132  1.00 32.31           C  \\nATOM  10025  O   GLY E 132      46.650  96.227  -1.169  1.00 32.31           O  \\nATOM  10026  N   GLU E 133      46.124  98.314  -1.850  1.00 47.32           N  \\nATOM  10027  CA  GLU E 133      45.075  97.903  -2.791  1.00 47.32           C  \\nATOM  10028  C   GLU E 133      45.418  98.377  -4.201  1.00 47.32           C  \\nATOM  10029  O   GLU E 133      44.846  97.922  -5.192  1.00 47.32           O  \\nATOM  10030  CB  GLU E 133      43.703  98.458  -2.340  1.00 16.09           C  \\nATOM  10031  CG  GLU E 133      43.218  97.879  -0.986  1.00 16.09           C  \\nATOM  10032  CD  GLU E 133      41.939  98.523  -0.420  1.00 16.09           C  \\nATOM  10033  OE1 GLU E 133      41.174  99.168  -1.186  1.00 16.09           O  \\nATOM  10034  OE2 GLU E 133      41.706  98.373   0.810  1.00 16.09           O  \\nATOM  10035  N   ARG E 134      46.398  99.266  -4.282  1.00123.79           N  \\nATOM  10036  CA  ARG E 134      46.845  99.829  -5.547  1.00123.79           C  \\nATOM  10037  C   ARG E 134      48.100 100.635  -5.195  1.00123.79           C  \\nATOM  10038  O   ARG E 134      48.283 101.766  -5.657  1.00123.79           O  \\nATOM  10039  CB  ARG E 134      45.742 100.741  -6.092  1.00182.72           C  \\nATOM  10040  CG  ARG E 134      45.895 101.136  -7.537  1.00182.72           C  \\nATOM  10041  CD  ARG E 134      44.722 101.990  -7.979  1.00182.72           C  \\nATOM  10042  NE  ARG E 134      44.882 102.441  -9.358  1.00182.72           N  \\nATOM  10043  CZ  ARG E 134      43.982 103.154 -10.031  1.00182.72           C  \\nATOM  10044  NH1 ARG E 134      42.835 103.508  -9.458  1.00182.72           N  \\nATOM  10045  NH2 ARG E 134      44.239 103.521 -11.281  1.00182.72           N  \\nATOM  10046  N   ALA E 135      48.956 100.021  -4.373  1.00181.34           N  \\nATOM  10047  CA  ALA E 135      50.203 100.609  -3.857  1.00181.34           C  \\nATOM  10048  C   ALA E 135      51.401 100.780  -4.822  1.00181.34           C  \\nATOM  10049  O   ALA E 135      52.556 100.481  -4.397  1.00 49.58           O  \\nATOM  10050  CB  ALA E 135      50.634  99.837  -2.588  1.00 49.58           C  \\nATOM  10051  OXT ALA E 135      51.183 101.276  -5.962  1.00 49.58           O  \\nTER   10052      ALA E 135                                                      \\nATOM  10053  N   LYS F  16       8.938  85.187 -27.137  1.00192.20           N  \\nATOM  10054  CA  LYS F  16      10.295  85.240 -26.507  1.00192.20           C  \\nATOM  10055  C   LYS F  16      10.236  84.666 -25.086  1.00192.20           C  \\nATOM  10056  O   LYS F  16       9.232  84.821 -24.386  1.00192.20           O  \\nATOM  10057  CB  LYS F  16      10.803  86.685 -26.457  1.00 64.20           C  \\nATOM  10058  CG  LYS F  16      12.318  86.845 -26.499  1.00 64.20           C  \\nATOM  10059  CD  LYS F  16      12.709  88.281 -26.205  1.00 64.20           C  \\nATOM  10060  CE  LYS F  16      13.946  88.675 -26.969  1.00 64.20           C  \\nATOM  10061  NZ  LYS F  16      14.242  90.087 -26.732  1.00 64.20           N  \\nATOM  10062  N   ARG F  17      11.319  84.011 -24.669  1.00147.11           N  \\nATOM  10063  CA  ARG F  17      11.402  83.405 -23.345  1.00147.11           C  \\nATOM  10064  C   ARG F  17      11.407  84.459 -22.252  1.00147.11           C  \\nATOM  10065  O   ARG F  17      10.349  84.889 -21.793  1.00147.11           O  \\nATOM  10066  CB  ARG F  17      12.654  82.526 -23.241  1.00124.37           C  \\nATOM  10067  CG  ARG F  17      12.781  81.749 -21.941  1.00124.37           C  \\nATOM  10068  CD  ARG F  17      13.802  80.647 -22.076  1.00124.37           C  \\nATOM  10069  NE  ARG F  17      13.458  79.772 -23.194  1.00124.37           N  \\nATOM  10070  CZ  ARG F  17      14.285  79.452 -24.188  1.00124.37           C  \\nATOM  10071  NH1 ARG F  17      15.527  79.925 -24.216  1.00124.37           N  \\nATOM  10072  NH2 ARG F  17      13.851  78.694 -25.186  1.00124.37           N  \\nATOM  10073  N   HIS F  18      12.596  84.913 -21.878  1.00 88.38           N  \\nATOM  10074  CA  HIS F  18      12.732  85.899 -20.817  1.00 88.38           C  \\nATOM  10075  C   HIS F  18      13.943  86.792 -21.084  1.00 88.38           C  \\nATOM  10076  O   HIS F  18      14.383  86.959 -22.226  1.00 88.38           O  \\nATOM  10077  CB  HIS F  18      12.974  85.185 -19.464  1.00179.56           C  \\nATOM  10078  CG  HIS F  18      11.799  84.421 -18.925  1.00179.56           C  \\nATOM  10079  ND1 HIS F  18      11.467  83.154 -19.356  1.00179.56           N  \\nATOM  10080  CD2 HIS F  18      10.929  84.713 -17.927  1.00179.56           C  \\nATOM  10081  CE1 HIS F  18      10.449  82.697 -18.649  1.00179.56           C  \\nATOM  10082  NE2 HIS F  18      10.104  83.624 -17.774  1.00179.56           N  \\nATOM  10083  N   ARG F  19      14.447  87.358 -19.986  1.00143.68           N  \\nATOM  10084  CA  ARG F  19      15.629  88.205 -19.924  1.00143.68           C  \\nATOM  10085  C   ARG F  19      15.569  89.650 -20.394  1.00143.68           C  \\nATOM  10086  O   ARG F  19      15.128  89.950 -21.507  1.00143.68           O  \\nATOM  10087  CB  ARG F  19      16.820  87.501 -20.577  1.00166.80           C  \\nATOM  10088  CG  ARG F  19      18.168  87.948 -20.041  1.00166.80           C  \\nATOM  10089  CD  ARG F  19      19.066  88.449 -21.158  1.00166.80           C  \\nATOM  10090  NE  ARG F  19      20.465  88.532 -20.741  1.00166.80           N  \\nATOM  10091  CZ  ARG F  19      21.396  87.631 -21.054  1.00166.80           C  \\nATOM  10092  NH1 ARG F  19      21.079  86.572 -21.790  1.00166.80           N  \\nATOM  10093  NH2 ARG F  19      22.648  87.786 -20.635  1.00166.80           N  \\nATOM  10094  N   LYS F  20      16.011  90.532 -19.498  1.00 42.55           N  \\nATOM  10095  CA  LYS F  20      16.121  91.971 -19.748  1.00 42.55           C  \\nATOM  10096  C   LYS F  20      17.638  92.213 -19.648  1.00 42.55           C  \\nATOM  10097  O   LYS F  20      18.330  91.530 -18.876  1.00 42.55           O  \\nATOM  10098  CB  LYS F  20      15.387  92.784 -18.665  1.00 52.35           C  \\nATOM  10099  CG  LYS F  20      14.811  94.141 -19.145  1.00 52.35           C  \\nATOM  10100  CD  LYS F  20      15.869  95.140 -19.650  1.00 52.35           C  \\nATOM  10101  CE  LYS F  20      15.245  96.412 -20.251  1.00 52.35           C  \\nATOM  10102  NZ  LYS F  20      15.884  97.662 -19.745  1.00 52.35           N  \\nATOM  10103  N   VAL F  21      18.174  93.121 -20.461  1.00 29.96           N  \\nATOM  10104  CA  VAL F  21      19.609  93.380 -20.407  1.00 29.96           C  \\nATOM  10105  C   VAL F  21      19.939  94.271 -19.245  1.00 29.96           C  \\nATOM  10106  O   VAL F  21      19.278  95.290 -19.006  1.00 29.96           O  \\nATOM  10107  CB  VAL F  21      20.187  93.989 -21.704  1.00 26.17           C  \\nATOM  10108  CG1 VAL F  21      19.914  93.078 -22.839  1.00 26.17           C  \\nATOM  10109  CG2 VAL F  21      19.596  95.373 -21.982  1.00 26.17           C  \\nATOM  10110  N   LEU F  22      20.951  93.849 -18.504  1.00 30.71           N  \\nATOM  10111  CA  LEU F  22      21.403  94.592 -17.350  1.00 30.71           C  \\nATOM  10112  C   LEU F  22      22.598  95.402 -17.767  1.00 30.71           C  \\nATOM  10113  O   LEU F  22      23.573  94.844 -18.264  1.00 30.71           O  \\nATOM  10114  CB  LEU F  22      21.800  93.629 -16.245  1.00 19.20           C  \\nATOM  10115  CG  LEU F  22      20.620  92.847 -15.686  1.00 19.20           C  \\nATOM  10116  CD1 LEU F  22      21.092  91.500 -15.181  1.00 19.20           C  \\nATOM  10117  CD2 LEU F  22      19.954  93.647 -14.588  1.00 19.20           C  \\nATOM  10118  N   ARG F  23      22.491  96.720 -17.636  1.00 29.57           N  \\nATOM  10119  CA  ARG F  23      23.598  97.596 -17.984  1.00 29.57           C  \\nATOM  10120  C   ARG F  23      23.549  98.913 -17.259  1.00 29.57           C  \\nATOM  10121  O   ARG F  23      22.479  99.403 -16.915  1.00 29.57           O  \\nATOM  10122  CB  ARG F  23      23.699  97.823 -19.492  1.00 15.25           C  \\nATOM  10123  CG  ARG F  23      22.531  98.487 -20.130  1.00 15.25           C  \\nATOM  10124  CD  ARG F  23      22.723  98.396 -21.612  1.00 15.25           C  \\nATOM  10125  NE  ARG F  23      22.447  99.656 -22.304  1.00 15.25           N  \\nATOM  10126  CZ  ARG F  23      21.224 100.136 -22.544  1.00 15.25           C  \\nATOM  10127  NH1 ARG F  23      20.126  99.480 -22.145  1.00 15.25           N  \\nATOM  10128  NH2 ARG F  23      21.099 101.257 -23.231  1.00 15.25           N  \\nATOM  10129  N   ASP F  24      24.738  99.428 -16.954  1.00 17.59           N  \\nATOM  10130  CA  ASP F  24      24.906 100.702 -16.259  1.00 17.59           C  \\nATOM  10131  C   ASP F  24      24.298 100.748 -14.875  1.00 17.59           C  \\nATOM  10132  O   ASP F  24      24.037 101.818 -14.361  1.00 17.59           O  \\nATOM  10133  CB  ASP F  24      24.331 101.828 -17.106  1.00 44.09           C  \\nATOM  10134  CG  ASP F  24      25.037 103.123 -16.881  1.00 44.09           C  \\nATOM  10135  OD1 ASP F  24      26.277 103.141 -17.034  1.00 44.09           O  \\nATOM  10136  OD2 ASP F  24      24.360 104.119 -16.552  1.00 44.09           O  \\nATOM  10137  N   ASN F  25      24.087  99.598 -14.252  1.00 19.05           N  \\nATOM  10138  CA  ASN F  25      23.514  99.584 -12.922  1.00 19.05           C  \\nATOM  10139  C   ASN F  25      24.426 100.194 -11.876  1.00 19.05           C  \\nATOM  10140  O   ASN F  25      24.012 100.413 -10.741  1.00 19.05           O  \\nATOM  10141  CB  ASN F  25      23.085  98.183 -12.531  1.00 20.91           C  \\nATOM  10142  CG  ASN F  25      21.805  97.767 -13.230  1.00 20.91           C  \\nATOM  10143  OD1 ASN F  25      20.694  98.173 -12.845  1.00 20.91           O  \\nATOM  10144  ND2 ASN F  25      21.954  97.002 -14.300  1.00 20.91           N  \\nATOM  10145  N   ILE F  26      25.655 100.506 -12.266  1.00 33.36           N  \\nATOM  10146  CA  ILE F  26      26.603 101.125 -11.358  1.00 33.36           C  \\nATOM  10147  C   ILE F  26      26.011 102.472 -10.938  1.00 33.36           C  \\nATOM  10148  O   ILE F  26      26.311 102.961  -9.860  1.00 33.36           O  \\nATOM  10149  CB  ILE F  26      27.984 101.342 -12.053  1.00 13.03           C  \\nATOM  10150  CG1 ILE F  26      29.161 100.888 -11.159  1.00 13.03           C  \\nATOM  10151  CG2 ILE F  26      28.138 102.788 -12.525  1.00 13.03           C  \\nATOM  10152  CD1 ILE F  26      29.403 101.657  -9.887  1.00 13.03           C  \\nATOM  10153  N   GLN F  27      25.131 103.053 -11.753  1.00 28.86           N  \\nATOM  10154  CA  GLN F  27      24.549 104.351 -11.411  1.00 28.86           C  \\nATOM  10155  C   GLN F  27      23.457 104.271 -10.347  1.00 28.86           C  \\nATOM  10156  O   GLN F  27      22.930 105.305  -9.919  1.00 28.86           O  \\nATOM  10157  CB  GLN F  27      24.037 105.070 -12.653  1.00 32.34           C  \\nATOM  10158  CG  GLN F  27      25.091 105.316 -13.736  1.00 32.34           C  \\nATOM  10159  CD  GLN F  27      26.225 106.240 -13.303  1.00 32.34           C  \\nATOM  10160  OE1 GLN F  27      25.995 107.280 -12.680  1.00 32.34           O  \\nATOM  10161  NE2 GLN F  27      27.458 105.873 -13.656  1.00 32.34           N  \\nATOM  10162  N   GLY F  28      23.143 103.045  -9.908  1.00 26.28           N  \\nATOM  10163  CA  GLY F  28      22.154 102.821  -8.859  1.00 26.28           C  \\nATOM  10164  C   GLY F  28      22.779 103.227  -7.533  1.00 26.28           C  \\nATOM  10165  O   GLY F  28      22.143 103.228  -6.463  1.00 26.28           O  \\nATOM  10166  N   ILE F  29      24.082 103.478  -7.599  1.00 22.58           N  \\nATOM  10167  CA  ILE F  29      24.832 103.924  -6.455  1.00 22.58           C  \\nATOM  10168  C   ILE F  29      24.662 105.408  -6.624  1.00 22.58           C  \\nATOM  10169  O   ILE F  29      25.413 106.073  -7.337  1.00 22.58           O  \\nATOM  10170  CB  ILE F  29      26.313 103.526  -6.555  1.00 30.31           C  \\nATOM  10171  CG1 ILE F  29      26.434 102.018  -6.845  1.00 30.31           C  \\nATOM  10172  CG2 ILE F  29      27.042 103.912  -5.275  1.00 30.31           C  \\nATOM  10173  CD1 ILE F  29      25.647 101.129  -5.908  1.00 30.31           C  \\nATOM  10174  N   THR F  30      23.566 105.885  -6.057  1.00 21.16           N  \\nATOM  10175  CA  THR F  30      23.193 107.276  -6.124  1.00 21.16           C  \\nATOM  10176  C   THR F  30      24.086 108.232  -5.342  1.00 21.16           C  \\nATOM  10177  O   THR F  30      24.708 107.856  -4.339  1.00 21.16           O  \\nATOM  10178  CB  THR F  30      21.716 107.433  -5.689  1.00 29.66           C  \\nATOM  10179  OG1 THR F  30      21.512 106.908  -4.365  1.00 29.66           O  \\nATOM  10180  CG2 THR F  30      20.845 106.673  -6.649  1.00 29.66           C  \\nATOM  10181  N   LYS F  31      24.147 109.472  -5.829  1.00 26.39           N  \\nATOM  10182  CA  LYS F  31      24.905 110.536  -5.182  1.00 26.39           C  \\nATOM  10183  C   LYS F  31      24.515 110.551  -3.680  1.00 26.39           C  \\nATOM  10184  O   LYS F  31      25.391 110.462  -2.816  1.00 26.39           O  \\nATOM  10185  CB  LYS F  31      24.604 111.863  -5.882  1.00 24.79           C  \\nATOM  10186  CG  LYS F  31      25.421 113.035  -5.415  1.00 24.79           C  \\nATOM  10187  CD  LYS F  31      24.990 114.293  -6.125  1.00 24.79           C  \\nATOM  10188  CE  LYS F  31      25.504 115.531  -5.397  1.00 24.79           C  \\nATOM  10189  NZ  LYS F  31      24.964 116.787  -6.019  1.00 24.79           N  \\nATOM  10190  N   PRO F  32      23.194 110.623  -3.351  1.00 26.78           N  \\nATOM  10191  CA  PRO F  32      22.777 110.621  -1.944  1.00 26.78           C  \\nATOM  10192  C   PRO F  32      23.159 109.351  -1.178  1.00 26.78           C  \\nATOM  10193  O   PRO F  32      23.494 109.426  -0.011  1.00 26.78           O  \\nATOM  10194  CB  PRO F  32      21.258 110.789  -2.037  1.00 24.44           C  \\nATOM  10195  CG  PRO F  32      20.914 110.372  -3.420  1.00 24.44           C  \\nATOM  10196  CD  PRO F  32      22.034 110.972  -4.193  1.00 24.44           C  \\nATOM  10197  N   ALA F  33      23.110 108.185  -1.808  1.00 17.28           N  \\nATOM  10198  CA  ALA F  33      23.504 106.983  -1.089  1.00 17.28           C  \\nATOM  10199  C   ALA F  33      24.979 107.052  -0.693  1.00 17.28           C  \\nATOM  10200  O   ALA F  33      25.338 106.752   0.446  1.00 17.28           O  \\nATOM  10201  CB  ALA F  33      23.220 105.764  -1.907  1.00  5.00           C  \\nATOM  10202  N   ILE F  34      25.834 107.472  -1.621  1.00  6.09           N  \\nATOM  10203  CA  ILE F  34      27.271 107.616  -1.326  1.00  6.09           C  \\nATOM  10204  C   ILE F  34      27.508 108.706  -0.267  1.00  6.09           C  \\nATOM  10205  O   ILE F  34      28.433 108.605   0.549  1.00  6.09           O  \\nATOM  10206  CB  ILE F  34      28.054 108.069  -2.569  1.00  8.45           C  \\nATOM  10207  CG1 ILE F  34      28.041 106.979  -3.647  1.00  8.45           C  \\nATOM  10208  CG2 ILE F  34      29.450 108.574  -2.169  1.00  8.45           C  \\nATOM  10209  CD1 ILE F  34      28.477 107.478  -4.992  1.00  8.45           C  \\nATOM  10210  N   ARG F  35      26.740 109.799  -0.345  1.00 17.00           N  \\nATOM  10211  CA  ARG F  35      26.884 110.890   0.627  1.00 17.00           C  \\nATOM  10212  C   ARG F  35      26.536 110.379   2.030  1.00 17.00           C  \\nATOM  10213  O   ARG F  35      27.162 110.752   3.014  1.00 17.00           O  \\nATOM  10214  CB  ARG F  35      26.045 112.112   0.220  1.00 62.74           C  \\nATOM  10215  CG  ARG F  35      26.516 113.417   0.867  1.00 62.74           C  \\nATOM  10216  CD  ARG F  35      25.937 114.664   0.219  1.00 62.74           C  \\nATOM  10217  NE  ARG F  35      24.487 114.649   0.316  1.00 62.74           N  \\nATOM  10218  CZ  ARG F  35      23.671 114.785  -0.724  1.00 62.74           C  \\nATOM  10219  NH1 ARG F  35      24.162 114.965  -1.945  1.00 62.74           N  \\nATOM  10220  NH2 ARG F  35      22.363 114.656  -0.555  1.00 62.74           N  \\nATOM  10221  N   ARG F  36      25.571 109.471   2.108  1.00 12.74           N  \\nATOM  10222  CA  ARG F  36      25.188 108.885   3.382  1.00 12.74           C  \\nATOM  10223  C   ARG F  36      26.345 108.071   3.926  1.00 12.74           C  \\nATOM  10224  O   ARG F  36      26.689 108.186   5.099  1.00 12.74           O  \\nATOM  10225  CB  ARG F  36      23.968 107.969   3.220  1.00 20.32           C  \\nATOM  10226  CG  ARG F  36      22.630 108.678   3.176  1.00 20.32           C  \\nATOM  10227  CD  ARG F  36      21.492 107.688   3.281  1.00 20.32           C  \\nATOM  10228  NE  ARG F  36      21.263 106.880   2.079  1.00 20.32           N  \\nATOM  10229  CZ  ARG F  36      20.668 107.308   0.959  1.00 20.32           C  \\nATOM  10230  NH1 ARG F  36      20.245 108.561   0.839  1.00 20.32           N  \\nATOM  10231  NH2 ARG F  36      20.446 106.447  -0.034  1.00 20.32           N  \\nATOM  10232  N   LEU F  37      26.915 107.214   3.078  1.00 18.40           N  \\nATOM  10233  CA  LEU F  37      28.053 106.378   3.467  1.00 18.40           C  \\nATOM  10234  C   LEU F  37      29.188 107.218   4.073  1.00 18.40           C  \\nATOM  10235  O   LEU F  37      29.695 106.897   5.152  1.00 18.40           O  \\nATOM  10236  CB  LEU F  37      28.544 105.580   2.258  1.00  5.00           C  \\nATOM  10237  CG  LEU F  37      27.663 104.375   1.937  1.00  5.00           C  \\nATOM  10238  CD1 LEU F  37      27.677 103.991   0.476  1.00  5.00           C  \\nATOM  10239  CD2 LEU F  37      28.134 103.262   2.806  1.00  5.00           C  \\nATOM  10240  N   ALA F  38      29.536 108.321   3.399  1.00 17.35           N  \\nATOM  10241  CA  ALA F  38      30.571 109.260   3.858  1.00 17.35           C  \\nATOM  10242  C   ALA F  38      30.269 109.797   5.263  1.00 17.35           C  \\nATOM  10243  O   ALA F  38      31.163 109.915   6.108  1.00 17.35           O  \\nATOM  10244  CB  ALA F  38      30.700 110.412   2.873  1.00  5.00           C  \\nATOM  10245  N   ARG F  39      29.015 110.174   5.476  1.00 14.06           N  \\nATOM  10246  CA  ARG F  39      28.547 110.679   6.760  1.00 14.06           C  \\nATOM  10247  C   ARG F  39      28.796 109.703   7.889  1.00 14.06           C  \\nATOM  10248  O   ARG F  39      29.216 110.108   8.970  1.00 14.06           O  \\nATOM  10249  CB  ARG F  39      27.054 110.955   6.693  1.00 11.94           C  \\nATOM  10250  CG  ARG F  39      26.694 112.033   5.730  1.00 11.94           C  \\nATOM  10251  CD  ARG F  39      27.337 113.331   6.113  1.00 11.94           C  \\nATOM  10252  NE  ARG F  39      26.728 114.409   5.371  1.00 11.94           N  \\nATOM  10253  CZ  ARG F  39      27.388 115.259   4.607  1.00 11.94           C  \\nATOM  10254  NH1 ARG F  39      28.696 115.166   4.476  1.00 11.94           N  \\nATOM  10255  NH2 ARG F  39      26.731 116.238   4.007  1.00 11.94           N  \\nATOM  10256  N   ARG F  40      28.425 108.442   7.687  1.00 14.83           N  \\nATOM  10257  CA  ARG F  40      28.655 107.433   8.715  1.00 14.83           C  \\nATOM  10258  C   ARG F  40      30.163 107.347   8.875  1.00 14.83           C  \\nATOM  10259  O   ARG F  40      30.676 107.161   9.984  1.00 14.83           O  \\nATOM  10260  CB  ARG F  40      28.054 106.083   8.307  1.00 13.76           C  \\nATOM  10261  CG  ARG F  40      28.108 105.022   9.397  1.00 13.76           C  \\nATOM  10262  CD  ARG F  40      27.288 103.820   9.005  1.00 13.76           C  \\nATOM  10263  NE  ARG F  40      25.898 103.918   9.441  1.00 13.76           N  \\nATOM  10264  CZ  ARG F  40      24.872 103.312   8.839  1.00 13.76           C  \\nATOM  10265  NH1 ARG F  40      25.055 102.568   7.756  1.00 13.76           N  \\nATOM  10266  NH2 ARG F  40      23.645 103.434   9.314  1.00 13.76           N  \\nATOM  10267  N   GLY F  41      30.855 107.521   7.748  1.00  7.01           N  \\nATOM  10268  CA  GLY F  41      32.298 107.545   7.731  1.00  7.01           C  \\nATOM  10269  C   GLY F  41      32.832 108.824   8.361  1.00  7.01           C  \\nATOM  10270  O   GLY F  41      34.038 109.050   8.388  1.00  7.01           O  \\nATOM  10271  N   GLY F  42      31.946 109.672   8.872  1.00 23.78           N  \\nATOM  10272  CA  GLY F  42      32.367 110.892   9.546  1.00 23.78           C  \\nATOM  10273  C   GLY F  42      32.914 112.007   8.686  1.00 23.78           C  \\nATOM  10274  O   GLY F  42      33.626 112.879   9.188  1.00 23.78           O  \\nATOM  10275  N   VAL F  43      32.597 111.962   7.396  1.00  9.78           N  \\nATOM  10276  CA  VAL F  43      33.038 112.956   6.439  1.00  9.78           C  \\nATOM  10277  C   VAL F  43      32.069 114.131   6.384  1.00  9.78           C  \\nATOM  10278  O   VAL F  43      30.918 113.966   6.012  1.00  9.78           O  \\nATOM  10279  CB  VAL F  43      33.133 112.341   5.052  1.00  5.96           C  \\nATOM  10280  CG1 VAL F  43      33.586 113.366   4.051  1.00  5.96           C  \\nATOM  10281  CG2 VAL F  43      34.060 111.180   5.073  1.00  5.96           C  \\nATOM  10282  N   LYS F  44      32.582 115.331   6.647  1.00 19.53           N  \\nATOM  10283  CA  LYS F  44      31.785 116.558   6.654  1.00 19.53           C  \\nATOM  10284  C   LYS F  44      31.575 117.260   5.293  1.00 19.53           C  \\nATOM  10285  O   LYS F  44      30.504 117.824   5.027  1.00 19.53           O  \\nATOM  10286  CB  LYS F  44      32.406 117.533   7.641  1.00 25.19           C  \\nATOM  10287  CG  LYS F  44      31.707 118.849   7.711  1.00 25.19           C  \\nATOM  10288  CD  LYS F  44      32.438 119.818   8.586  1.00 25.19           C  \\nATOM  10289  CE  LYS F  44      31.564 121.005   8.818  1.00 25.19           C  \\nATOM  10290  NZ  LYS F  44      32.210 121.925   9.759  1.00 25.19           N  \\nATOM  10291  N   ARG F  45      32.598 117.264   4.444  1.00 19.67           N  \\nATOM  10292  CA  ARG F  45      32.486 117.902   3.141  1.00 19.67           C  \\nATOM  10293  C   ARG F  45      33.031 116.981   2.039  1.00 19.67           C  \\nATOM  10294  O   ARG F  45      34.018 116.260   2.250  1.00 19.67           O  \\nATOM  10295  CB  ARG F  45      33.221 119.233   3.165  1.00 20.29           C  \\nATOM  10296  CG  ARG F  45      32.677 120.257   2.221  1.00 20.29           C  \\nATOM  10297  CD  ARG F  45      33.425 121.547   2.382  1.00 20.29           C  \\nATOM  10298  NE  ARG F  45      32.822 122.577   1.556  1.00 20.29           N  \\nATOM  10299  CZ  ARG F  45      33.331 123.040   0.413  1.00 20.29           C  \\nATOM  10300  NH1 ARG F  45      34.480 122.582  -0.061  1.00 20.29           N  \\nATOM  10301  NH2 ARG F  45      32.624 123.907  -0.312  1.00 20.29           N  \\nATOM  10302  N   ILE F  46      32.424 117.067   0.849  1.00 31.51           N  \\nATOM  10303  CA  ILE F  46      32.767 116.215  -0.291  1.00 31.51           C  \\nATOM  10304  C   ILE F  46      32.960 116.882  -1.661  1.00 31.51           C  \\nATOM  10305  O   ILE F  46      32.056 117.574  -2.144  1.00 31.51           O  \\nATOM  10306  CB  ILE F  46      31.625 115.212  -0.499  1.00 10.31           C  \\nATOM  10307  CG1 ILE F  46      31.251 114.533   0.808  1.00 10.31           C  \\nATOM  10308  CG2 ILE F  46      31.991 114.182  -1.514  1.00 10.31           C  \\nATOM  10309  CD1 ILE F  46      30.068 113.649   0.686  1.00 10.31           C  \\nATOM  10310  N   SER F  47      34.087 116.594  -2.328  1.00 28.14           N  \\nATOM  10311  CA  SER F  47      34.370 117.113  -3.680  1.00 28.14           C  \\nATOM  10312  C   SER F  47      33.459 116.469  -4.749  1.00 28.14           C  \\nATOM  10313  O   SER F  47      33.251 115.258  -4.750  1.00 28.14           O  \\nATOM  10314  CB  SER F  47      35.826 116.828  -4.052  1.00 13.08           C  \\nATOM  10315  OG  SER F  47      35.989 116.693  -5.469  1.00 13.08           O  \\nATOM  10316  N   GLY F  48      33.023 117.247  -5.732  1.00 17.12           N  \\nATOM  10317  CA  GLY F  48      32.154 116.695  -6.757  1.00 17.12           C  \\nATOM  10318  C   GLY F  48      32.665 115.480  -7.525  1.00 17.12           C  \\nATOM  10319  O   GLY F  48      31.878 114.750  -8.166  1.00 17.12           O  \\nATOM  10320  N   LEU F  49      33.974 115.231  -7.439  1.00 19.24           N  \\nATOM  10321  CA  LEU F  49      34.600 114.109  -8.138  1.00 19.24           C  \\nATOM  10322  C   LEU F  49      34.626 112.781  -7.362  1.00 19.24           C  \\nATOM  10323  O   LEU F  49      35.056 111.736  -7.869  1.00 19.24           O  \\nATOM  10324  CB  LEU F  49      36.010 114.516  -8.521  1.00 19.82           C  \\nATOM  10325  CG  LEU F  49      36.051 115.550  -9.633  1.00 19.82           C  \\nATOM  10326  CD1 LEU F  49      37.473 115.903  -9.906  1.00 19.82           C  \\nATOM  10327  CD2 LEU F  49      35.417 114.964 -10.888  1.00 19.82           C  \\nATOM  10328  N   ILE F  50      34.150 112.841  -6.130  1.00 18.75           N  \\nATOM  10329  CA  ILE F  50      34.114 111.700  -5.259  1.00 18.75           C  \\nATOM  10330  C   ILE F  50      33.115 110.643  -5.698  1.00 18.75           C  \\nATOM  10331  O   ILE F  50      33.383 109.450  -5.575  1.00 18.75           O  \\nATOM  10332  CB  ILE F  50      33.758 112.150  -3.841  1.00 16.04           C  \\nATOM  10333  CG1 ILE F  50      34.962 112.831  -3.173  1.00 16.04           C  \\nATOM  10334  CG2 ILE F  50      33.275 110.987  -3.015  1.00 16.04           C  \\nATOM  10335  CD1 ILE F  50      36.081 111.915  -2.753  1.00 16.04           C  \\nATOM  10336  N   TYR F  51      31.988 111.060  -6.263  1.00 11.41           N  \\nATOM  10337  CA  TYR F  51      30.965 110.087  -6.626  1.00 11.41           C  \\nATOM  10338  C   TYR F  51      31.409 109.103  -7.657  1.00 11.41           C  \\nATOM  10339  O   TYR F  51      31.166 107.907  -7.507  1.00 11.41           O  \\nATOM  10340  CB  TYR F  51      29.643 110.763  -6.985  1.00 12.99           C  \\nATOM  10341  CG  TYR F  51      29.258 111.819  -5.971  1.00 12.99           C  \\nATOM  10342  CD1 TYR F  51      28.882 111.480  -4.670  1.00 12.99           C  \\nATOM  10343  CD2 TYR F  51      29.364 113.173  -6.297  1.00 12.99           C  \\nATOM  10344  CE1 TYR F  51      28.631 112.486  -3.713  1.00 12.99           C  \\nATOM  10345  CE2 TYR F  51      29.118 114.178  -5.368  1.00 12.99           C  \\nATOM  10346  CZ  TYR F  51      28.757 113.844  -4.080  1.00 12.99           C  \\nATOM  10347  OH  TYR F  51      28.547 114.885  -3.186  1.00 12.99           O  \\nATOM  10348  N   GLU F  52      32.125 109.581  -8.670  1.00 19.85           N  \\nATOM  10349  CA  GLU F  52      32.604 108.652  -9.681  1.00 19.85           C  \\nATOM  10350  C   GLU F  52      33.736 107.771  -9.166  1.00 19.85           C  \\nATOM  10351  O   GLU F  52      33.735 106.576  -9.447  1.00 19.85           O  \\nATOM  10352  CB  GLU F  52      32.943 109.340 -11.002  1.00 66.51           C  \\nATOM  10353  CG  GLU F  52      31.711 109.523 -11.923  1.00 66.51           C  \\nATOM  10354  CD  GLU F  52      30.912 108.228 -12.197  1.00 66.51           C  \\nATOM  10355  OE1 GLU F  52      31.514 107.129 -12.261  1.00 66.51           O  \\nATOM  10356  OE2 GLU F  52      29.674 108.311 -12.368  1.00 66.51           O  \\nATOM  10357  N   GLU F  53      34.648 108.335  -8.365  1.00 14.28           N  \\nATOM  10358  CA  GLU F  53      35.742 107.559  -7.775  1.00 14.28           C  \\nATOM  10359  C   GLU F  53      35.179 106.403  -6.973  1.00 14.28           C  \\nATOM  10360  O   GLU F  53      35.589 105.245  -7.150  1.00 14.28           O  \\nATOM  10361  CB  GLU F  53      36.584 108.391  -6.815  1.00 34.19           C  \\nATOM  10362  CG  GLU F  53      37.735 109.135  -7.453  1.00 34.19           C  \\nATOM  10363  CD  GLU F  53      38.864 108.248  -7.967  1.00 34.19           C  \\nATOM  10364  OE1 GLU F  53      39.244 107.266  -7.283  1.00 34.19           O  \\nATOM  10365  OE2 GLU F  53      39.391 108.560  -9.059  1.00 34.19           O  \\nATOM  10366  N   THR F  54      34.256 106.731  -6.070  1.00 12.11           N  \\nATOM  10367  CA  THR F  54      33.626 105.747  -5.216  1.00 12.11           C  \\nATOM  10368  C   THR F  54      32.982 104.652  -6.048  1.00 12.11           C  \\nATOM  10369  O   THR F  54      33.121 103.470  -5.737  1.00 12.11           O  \\nATOM  10370  CB  THR F  54      32.576 106.379  -4.315  1.00 10.89           C  \\nATOM  10371  OG1 THR F  54      33.048 107.651  -3.860  1.00 10.89           O  \\nATOM  10372  CG2 THR F  54      32.321 105.498  -3.103  1.00 10.89           C  \\nATOM  10373  N   ARG F  55      32.285 105.018  -7.113  1.00 15.61           N  \\nATOM  10374  CA  ARG F  55      31.683 103.990  -7.936  1.00 15.61           C  \\nATOM  10375  C   ARG F  55      32.784 103.032  -8.414  1.00 15.61           C  \\nATOM  10376  O   ARG F  55      32.719 101.830  -8.176  1.00 15.61           O  \\nATOM  10377  CB  ARG F  55      30.882 104.614  -9.094  1.00 17.08           C  \\nATOM  10378  CG  ARG F  55      29.606 105.292  -8.603  1.00 17.08           C  \\nATOM  10379  CD  ARG F  55      28.696 105.737  -9.726  1.00 17.08           C  \\nATOM  10380  NE  ARG F  55      27.645 106.602  -9.182  1.00 17.08           N  \\nATOM  10381  CZ  ARG F  55      27.609 107.927  -9.315  1.00 17.08           C  \\nATOM  10382  NH1 ARG F  55      28.557 108.568  -9.989  1.00 17.08           N  \\nATOM  10383  NH2 ARG F  55      26.661 108.611  -8.702  1.00 17.08           N  \\nATOM  10384  N   GLY F  56      33.835 103.575  -9.002  1.00 16.80           N  \\nATOM  10385  CA  GLY F  56      34.915 102.727  -9.461  1.00 16.80           C  \\nATOM  10386  C   GLY F  56      35.466 101.806  -8.384  1.00 16.80           C  \\nATOM  10387  O   GLY F  56      35.603 100.607  -8.605  1.00 16.80           O  \\nATOM  10388  N   VAL F  57      35.766 102.362  -7.216  1.00 14.74           N  \\nATOM  10389  CA  VAL F  57      36.301 101.603  -6.104  1.00 14.74           C  \\nATOM  10390  C   VAL F  57      35.385 100.441  -5.725  1.00 14.74           C  \\nATOM  10391  O   VAL F  57      35.830  99.315  -5.500  1.00 14.74           O  \\nATOM  10392  CB  VAL F  57      36.509 102.515  -4.909  1.00  7.90           C  \\nATOM  10393  CG1 VAL F  57      36.617 101.687  -3.626  1.00  7.90           C  \\nATOM  10394  CG2 VAL F  57      37.747 103.342  -5.119  1.00  7.90           C  \\nATOM  10395  N   LEU F  58      34.098 100.720  -5.649  1.00 15.55           N  \\nATOM  10396  CA  LEU F  58      33.129  99.698  -5.337  1.00 15.55           C  \\nATOM  10397  C   LEU F  58      33.045  98.638  -6.439  1.00 15.55           C  \\nATOM  10398  O   LEU F  58      33.009  97.451  -6.143  1.00 15.55           O  \\nATOM  10399  CB  LEU F  58      31.767 100.342  -5.137  1.00 11.46           C  \\nATOM  10400  CG  LEU F  58      30.646  99.372  -4.809  1.00 11.46           C  \\nATOM  10401  CD1 LEU F  58      30.972  98.671  -3.495  1.00 11.46           C  \\nATOM  10402  CD2 LEU F  58      29.315 100.102  -4.749  1.00 11.46           C  \\nATOM  10403  N   LYS F  59      33.008  99.038  -7.706  1.00 16.41           N  \\nATOM  10404  CA  LYS F  59      32.926  98.033  -8.772  1.00 16.41           C  \\nATOM  10405  C   LYS F  59      33.981  96.960  -8.583  1.00 16.41           C  \\nATOM  10406  O   LYS F  59      33.679  95.769  -8.581  1.00 16.41           O  \\nATOM  10407  CB  LYS F  59      33.067  98.629 -10.162  1.00 33.67           C  \\nATOM  10408  CG  LYS F  59      32.253  97.825 -11.150  1.00 33.67           C  \\nATOM  10409  CD  LYS F  59      32.350  98.307 -12.580  1.00 33.67           C  \\nATOM  10410  CE  LYS F  59      33.504  97.629 -13.297  1.00 33.67           C  \\nATOM  10411  NZ  LYS F  59      33.556  97.985 -14.747  1.00 33.67           N  \\nATOM  10412  N   VAL F  60      35.202  97.404  -8.316  1.00 12.00           N  \\nATOM  10413  CA  VAL F  60      36.321  96.513  -8.097  1.00 12.00           C  \\nATOM  10414  C   VAL F  60      36.153  95.674  -6.841  1.00 12.00           C  \\nATOM  10415  O   VAL F  60      36.506  94.496  -6.819  1.00 12.00           O  \\nATOM  10416  CB  VAL F  60      37.599  97.294  -7.942  1.00 14.82           C  \\nATOM  10417  CG1 VAL F  60      38.712  96.354  -7.607  1.00 14.82           C  \\nATOM  10418  CG2 VAL F  60      37.912  98.037  -9.217  1.00 14.82           C  \\nATOM  10419  N   PHE F  61      35.679  96.291  -5.770  1.00  6.74           N  \\nATOM  10420  CA  PHE F  61      35.506  95.543  -4.556  1.00  6.74           C  \\nATOM  10421  C   PHE F  61      34.592  94.386  -4.847  1.00  6.74           C  \\nATOM  10422  O   PHE F  61      34.901  93.248  -4.533  1.00  6.74           O  \\nATOM  10423  CB  PHE F  61      34.897  96.399  -3.457  1.00  8.94           C  \\nATOM  10424  CG  PHE F  61      34.672  95.638  -2.160  1.00  8.94           C  \\nATOM  10425  CD1 PHE F  61      35.725  95.470  -1.234  1.00  8.94           C  \\nATOM  10426  CD2 PHE F  61      33.428  95.075  -1.870  1.00  8.94           C  \\nATOM  10427  CE1 PHE F  61      35.523  94.749  -0.046  1.00  8.94           C  \\nATOM  10428  CE2 PHE F  61      33.229  94.365  -0.704  1.00  8.94           C  \\nATOM  10429  CZ  PHE F  61      34.266  94.197   0.216  1.00  8.94           C  \\nATOM  10430  N   LEU F  62      33.480  94.690  -5.496  1.00 10.92           N  \\nATOM  10431  CA  LEU F  62      32.486  93.699  -5.836  1.00 10.92           C  \\nATOM  10432  C   LEU F  62      32.956  92.624  -6.796  1.00 10.92           C  \\nATOM  10433  O   LEU F  62      32.675  91.460  -6.591  1.00 10.92           O  \\nATOM  10434  CB  LEU F  62      31.238  94.391  -6.386  1.00 14.47           C  \\nATOM  10435  CG  LEU F  62      30.276  94.927  -5.323  1.00 14.47           C  \\nATOM  10436  CD1 LEU F  62      29.194  95.726  -5.989  1.00 14.47           C  \\nATOM  10437  CD2 LEU F  62      29.654  93.778  -4.529  1.00 14.47           C  \\nATOM  10438  N   GLU F  63      33.618  93.005  -7.876  1.00 16.06           N  \\nATOM  10439  CA  GLU F  63      34.106  92.006  -8.820  1.00 16.06           C  \\nATOM  10440  C   GLU F  63      34.983  90.979  -8.098  1.00 16.06           C  \\nATOM  10441  O   GLU F  63      34.899  89.775  -8.340  1.00 16.06           O  \\nATOM  10442  CB  GLU F  63      34.975  92.644  -9.883  1.00 50.87           C  \\nATOM  10443  CG  GLU F  63      34.388  93.817 -10.585  1.00 50.87           C  \\nATOM  10444  CD  GLU F  63      35.439  94.532 -11.412  1.00 50.87           C  \\nATOM  10445  OE1 GLU F  63      36.645  94.404 -11.085  1.00 50.87           O  \\nATOM  10446  OE2 GLU F  63      35.067  95.215 -12.389  1.00 50.87           O  \\nATOM  10447  N   ASN F  64      35.843  91.466  -7.216  1.00 15.51           N  \\nATOM  10448  CA  ASN F  64      36.726  90.574  -6.508  1.00 15.51           C  \\nATOM  10449  C   ASN F  64      35.964  89.585  -5.630  1.00 15.51           C  \\nATOM  10450  O   ASN F  64      36.136  88.373  -5.791  1.00 15.51           O  \\nATOM  10451  CB  ASN F  64      37.794  91.376  -5.753  1.00 20.15           C  \\nATOM  10452  CG  ASN F  64      38.692  92.233  -6.698  1.00 20.15           C  \\nATOM  10453  OD1 ASN F  64      38.579  92.195  -7.936  1.00 20.15           O  \\nATOM  10454  ND2 ASN F  64      39.567  93.022  -6.096  1.00 20.15           N  \\nATOM  10455  N   VAL F  65      35.057  90.072  -4.780  1.00 25.05           N  \\nATOM  10456  CA  VAL F  65      34.286  89.165  -3.927  1.00 25.05           C  \\nATOM  10457  C   VAL F  65      33.416  88.266  -4.782  1.00 25.05           C  \\nATOM  10458  O   VAL F  65      33.416  87.069  -4.598  1.00 25.05           O  \\nATOM  10459  CB  VAL F  65      33.383  89.883  -2.883  1.00 16.86           C  \\nATOM  10460  CG1 VAL F  65      33.152  88.971  -1.687  1.00 16.86           C  \\nATOM  10461  CG2 VAL F  65      34.015  91.134  -2.401  1.00 16.86           C  \\nATOM  10462  N   ILE F  66      32.698  88.829  -5.743  1.00 18.02           N  \\nATOM  10463  CA  ILE F  66      31.850  88.013  -6.600  1.00 18.02           C  \\nATOM  10464  C   ILE F  66      32.668  86.959  -7.334  1.00 18.02           C  \\nATOM  10465  O   ILE F  66      32.261  85.827  -7.358  1.00 18.02           O  \\nATOM  10466  CB  ILE F  66      31.010  88.858  -7.606  1.00 15.13           C  \\nATOM  10467  CG1 ILE F  66      29.954  89.678  -6.856  1.00 15.13           C  \\nATOM  10468  CG2 ILE F  66      30.309  87.948  -8.603  1.00 15.13           C  \\nATOM  10469  CD1 ILE F  66      29.204  90.662  -7.721  1.00 15.13           C  \\nATOM  10470  N   ARG F  67      33.820  87.306  -7.905  1.00 21.75           N  \\nATOM  10471  CA  ARG F  67      34.646  86.318  -8.592  1.00 21.75           C  \\nATOM  10472  C   ARG F  67      34.938  85.120  -7.696  1.00 21.75           C  \\nATOM  10473  O   ARG F  67      34.674  83.973  -8.053  1.00 21.75           O  \\nATOM  10474  CB  ARG F  67      35.983  86.894  -9.039  1.00 59.86           C  \\nATOM  10475  CG  ARG F  67      36.930  85.787  -9.512  1.00 59.86           C  \\nATOM  10476  CD  ARG F  67      38.190  86.310 -10.128  1.00 59.86           C  \\nATOM  10477  NE  ARG F  67      37.873  87.272 -11.175  1.00 59.86           N  \\nATOM  10478  CZ  ARG F  67      38.083  88.581 -11.060  1.00 59.86           C  \\nATOM  10479  NH1 ARG F  67      38.623  89.071  -9.942  1.00 59.86           N  \\nATOM  10480  NH2 ARG F  67      37.712  89.405 -12.036  1.00 59.86           N  \\nATOM  10481  N   ASP F  68      35.520  85.375  -6.542  1.00 20.87           N  \\nATOM  10482  CA  ASP F  68      35.806  84.272  -5.657  1.00 20.87           C  \\nATOM  10483  C   ASP F  68      34.538  83.508  -5.310  1.00 20.87           C  \\nATOM  10484  O   ASP F  68      34.480  82.300  -5.491  1.00 20.87           O  \\nATOM  10485  CB  ASP F  68      36.488  84.761  -4.383  1.00 38.39           C  \\nATOM  10486  CG  ASP F  68      37.870  85.310  -4.642  1.00 38.39           C  \\nATOM  10487  OD1 ASP F  68      38.397  85.136  -5.772  1.00 38.39           O  \\nATOM  10488  OD2 ASP F  68      38.419  85.923  -3.705  1.00 38.39           O  \\nATOM  10489  N   ALA F  69      33.507  84.220  -4.868  1.00 21.97           N  \\nATOM  10490  CA  ALA F  69      32.251  83.589  -4.483  1.00 21.97           C  \\nATOM  10491  C   ALA F  69      31.738  82.668  -5.587  1.00 21.97           C  \\nATOM  10492  O   ALA F  69      31.536  81.474  -5.365  1.00 21.97           O  \\nATOM  10493  CB  ALA F  69      31.226  84.645  -4.114  1.00  8.49           C  \\nATOM  10494  N   VAL F  70      31.635  83.198  -6.799  1.00 21.13           N  \\nATOM  10495  CA  VAL F  70      31.189  82.419  -7.942  1.00 21.13           C  \\nATOM  10496  C   VAL F  70      32.165  81.275  -8.235  1.00 21.13           C  \\nATOM  10497  O   VAL F  70      31.753  80.216  -8.675  1.00 21.13           O  \\nATOM  10498  CB  VAL F  70      30.973  83.302  -9.185  1.00  7.36           C  \\nATOM  10499  CG1 VAL F  70      30.952  82.437 -10.455  1.00  7.36           C  \\nATOM  10500  CG2 VAL F  70      29.656  84.095  -9.041  1.00  7.36           C  \\nATOM  10501  N   THR F  71      33.454  81.472  -7.984  1.00 22.82           N  \\nATOM  10502  CA  THR F  71      34.395  80.376  -8.177  1.00 22.82           C  \\nATOM  10503  C   THR F  71      34.030  79.252  -7.191  1.00 22.82           C  \\nATOM  10504  O   THR F  71      33.956  78.085  -7.565  1.00 22.82           O  \\nATOM  10505  CB  THR F  71      35.867  80.825  -8.001  1.00  9.91           C  \\nATOM  10506  OG1 THR F  71      36.155  81.885  -8.930  1.00  9.91           O  \\nATOM  10507  CG2 THR F  71      36.813  79.653  -8.283  1.00  9.91           C  \\nATOM  10508  N   TYR F  72      33.726  79.625  -5.954  1.00 29.23           N  \\nATOM  10509  CA  TYR F  72      33.321  78.661  -4.939  1.00 29.23           C  \\nATOM  10510  C   TYR F  72      32.083  77.894  -5.370  1.00 29.23           C  \\nATOM  10511  O   TYR F  72      31.938  76.710  -5.052  1.00 29.23           O  \\nATOM  10512  CB  TYR F  72      33.069  79.356  -3.607  1.00 23.24           C  \\nATOM  10513  CG  TYR F  72      34.317  79.440  -2.768  1.00 23.24           C  \\nATOM  10514  CD1 TYR F  72      34.936  78.284  -2.275  1.00 23.24           C  \\nATOM  10515  CD2 TYR F  72      34.893  80.673  -2.451  1.00 23.24           C  \\nATOM  10516  CE1 TYR F  72      36.095  78.362  -1.482  1.00 23.24           C  \\nATOM  10517  CE2 TYR F  72      36.062  80.751  -1.653  1.00 23.24           C  \\nATOM  10518  CZ  TYR F  72      36.641  79.601  -1.178  1.00 23.24           C  \\nATOM  10519  OH  TYR F  72      37.733  79.698  -0.366  1.00 23.24           O  \\nATOM  10520  N   THR F  73      31.189  78.596  -6.068  1.00 20.62           N  \\nATOM  10521  CA  THR F  73      29.952  78.030  -6.596  1.00 20.62           C  \\nATOM  10522  C   THR F  73      30.203  76.986  -7.672  1.00 20.62           C  \\nATOM  10523  O   THR F  73      29.734  75.859  -7.574  1.00 20.62           O  \\nATOM  10524  CB  THR F  73      29.123  79.114  -7.241  1.00 16.30           C  \\nATOM  10525  OG1 THR F  73      28.995  80.184  -6.320  1.00 16.30           O  \\nATOM  10526  CG2 THR F  73      27.747  78.603  -7.582  1.00 16.30           C  \\nATOM  10527  N   GLU F  74      30.869  77.409  -8.745  1.00 31.33           N  \\nATOM  10528  CA  GLU F  74      31.185  76.526  -9.855  1.00 31.33           C  \\nATOM  10529  C   GLU F  74      31.865  75.274  -9.321  1.00 31.33           C  \\nATOM  10530  O   GLU F  74      31.587  74.170  -9.776  1.00 31.33           O  \\nATOM  10531  CB  GLU F  74      32.066  77.240 -10.902  1.00 86.20           C  \\nATOM  10532  CG  GLU F  74      31.373  78.443 -11.579  1.00 86.20           C  \\nATOM  10533  CD  GLU F  74      32.071  78.973 -12.841  1.00 86.20           C  \\nATOM  10534  OE1 GLU F  74      32.941  79.874 -12.733  1.00 86.20           O  \\nATOM  10535  OE2 GLU F  74      31.705  78.523 -13.953  1.00 86.20           O  \\nATOM  10536  N   HIS F  75      32.716  75.425  -8.317  1.00 30.33           N  \\nATOM  10537  CA  HIS F  75      33.376  74.259  -7.780  1.00 30.33           C  \\nATOM  10538  C   HIS F  75      32.425  73.237  -7.150  1.00 30.33           C  \\nATOM  10539  O   HIS F  75      32.651  72.020  -7.193  1.00 30.33           O  \\nATOM  10540  CB  HIS F  75      34.434  74.641  -6.772  1.00 25.29           C  \\nATOM  10541  CG  HIS F  75      35.260  73.473  -6.359  1.00 25.29           C  \\nATOM  10542  ND1 HIS F  75      34.936  72.684  -5.277  1.00 25.29           N  \\nATOM  10543  CD2 HIS F  75      36.315  72.873  -6.957  1.00 25.29           C  \\nATOM  10544  CE1 HIS F  75      35.753  71.646  -5.225  1.00 25.29           C  \\nATOM  10545  NE2 HIS F  75      36.599  71.738  -6.235  1.00 25.29           N  \\nATOM  10546  N   ALA F  76      31.365  73.741  -6.546  1.00 28.06           N  \\nATOM  10547  CA  ALA F  76      30.389  72.892  -5.897  1.00 28.06           C  \\nATOM  10548  C   ALA F  76      29.377  72.338  -6.899  1.00 28.06           C  \\nATOM  10549  O   ALA F  76      28.419  71.661  -6.518  1.00 28.06           O  \\nATOM  10550  CB  ALA F  76      29.691  73.681  -4.811  1.00 22.80           C  \\nATOM  10551  N   LYS F  77      29.608  72.615  -8.180  1.00 34.56           N  \\nATOM  10552  CA  LYS F  77      28.724  72.164  -9.250  1.00 34.56           C  \\nATOM  10553  C   LYS F  77      27.300  72.707  -9.078  1.00 34.56           C  \\nATOM  10554  O   LYS F  77      26.308  72.037  -9.406  1.00 34.56           O  \\nATOM  10555  CB  LYS F  77      28.739  70.631  -9.360  1.00 49.98           C  \\nATOM  10556  CG  LYS F  77      29.948  70.081 -10.102  1.00 49.98           C  \\nATOM  10557  CD  LYS F  77      29.953  68.564 -10.114  1.00 49.98           C  \\nATOM  10558  CE  LYS F  77      31.141  68.014 -10.897  1.00 49.98           C  \\nATOM  10559  NZ  LYS F  77      31.320  66.540 -10.693  1.00 49.98           N  \\nATOM  10560  N   ARG F  78      27.219  73.934  -8.565  1.00 17.81           N  \\nATOM  10561  CA  ARG F  78      25.941  74.614  -8.347  1.00 17.81           C  \\nATOM  10562  C   ARG F  78      25.702  75.772  -9.312  1.00 17.81           C  \\nATOM  10563  O   ARG F  78      26.627  76.234  -9.993  1.00 17.81           O  \\nATOM  10564  CB  ARG F  78      25.852  75.147  -6.922  1.00 22.05           C  \\nATOM  10565  CG  ARG F  78      25.536  74.104  -5.893  1.00 22.05           C  \\nATOM  10566  CD  ARG F  78      25.201  74.750  -4.563  1.00 22.05           C  \\nATOM  10567  NE  ARG F  78      26.374  74.929  -3.707  1.00 22.05           N  \\nATOM  10568  CZ  ARG F  78      26.977  76.092  -3.473  1.00 22.05           C  \\nATOM  10569  NH1 ARG F  78      26.531  77.217  -4.035  1.00 22.05           N  \\nATOM  10570  NH2 ARG F  78      28.013  76.121  -2.648  1.00 22.05           N  \\nATOM  10571  N   LYS F  79      24.449  76.222  -9.370  1.00 31.69           N  \\nATOM  10572  CA  LYS F  79      24.035  77.335 -10.220  1.00 31.69           C  \\nATOM  10573  C   LYS F  79      23.505  78.411  -9.315  1.00 31.69           C  \\nATOM  10574  O   LYS F  79      23.065  79.445  -9.773  1.00 31.69           O  \\nATOM  10575  CB  LYS F  79      22.919  76.928 -11.186  1.00 81.44           C  \\nATOM  10576  CG  LYS F  79      23.325  75.963 -12.279  1.00 81.44           C  \\nATOM  10577  CD  LYS F  79      22.236  75.869 -13.332  1.00 81.44           C  \\nATOM  10578  CE  LYS F  79      22.587  74.882 -14.434  1.00 81.44           C  \\nATOM  10579  NZ  LYS F  79      21.545  74.884 -15.504  1.00 81.44           N  \\nATOM  10580  N   THR F  80      23.550  78.165  -8.018  1.00 28.05           N  \\nATOM  10581  CA  THR F  80      23.051  79.123  -7.055  1.00 28.05           C  \\nATOM  10582  C   THR F  80      24.127  79.575  -6.068  1.00 28.05           C  \\nATOM  10583  O   THR F  80      24.715  78.755  -5.343  1.00 28.05           O  \\nATOM  10584  CB  THR F  80      21.876  78.530  -6.298  1.00 26.98           C  \\nATOM  10585  OG1 THR F  80      20.908  78.072  -7.246  1.00 26.98           O  \\nATOM  10586  CG2 THR F  80      21.242  79.571  -5.407  1.00 26.98           C  \\nATOM  10587  N   VAL F  81      24.383  80.884  -6.053  1.00 14.37           N  \\nATOM  10588  CA  VAL F  81      25.380  81.472  -5.168  1.00 14.37           C  \\nATOM  10589  C   VAL F  81      24.719  81.582  -3.792  1.00 14.37           C  \\nATOM  10590  O   VAL F  81      23.635  82.179  -3.660  1.00 14.37           O  \\nATOM  10591  CB  VAL F  81      25.811  82.887  -5.659  1.00 10.18           C  \\nATOM  10592  CG1 VAL F  81      27.047  83.351  -4.914  1.00 10.18           C  \\nATOM  10593  CG2 VAL F  81      26.044  82.906  -7.172  1.00 10.18           C  \\nATOM  10594  N   THR F  82      25.333  80.929  -2.798  1.00 20.85           N  \\nATOM  10595  CA  THR F  82      24.840  80.925  -1.419  1.00 20.85           C  \\nATOM  10596  C   THR F  82      25.514  81.991  -0.552  1.00 20.85           C  \\nATOM  10597  O   THR F  82      26.508  82.607  -0.936  1.00 20.85           O  \\nATOM  10598  CB  THR F  82      25.055  79.529  -0.723  1.00 36.11           C  \\nATOM  10599  OG1 THR F  82      26.443  79.302  -0.479  1.00 36.11           O  \\nATOM  10600  CG2 THR F  82      24.539  78.392  -1.585  1.00 36.11           C  \\nATOM  10601  N   ALA F  83      24.969  82.219   0.629  1.00 29.25           N  \\nATOM  10602  CA  ALA F  83      25.594  83.163   1.525  1.00 29.25           C  \\nATOM  10603  C   ALA F  83      26.947  82.559   1.864  1.00 29.25           C  \\nATOM  10604  O   ALA F  83      27.937  83.274   1.951  1.00 29.25           O  \\nATOM  10605  CB  ALA F  83      24.789  83.309   2.758  1.00 28.82           C  \\nATOM  10606  N   MET F  84      26.999  81.230   2.013  1.00 17.92           N  \\nATOM  10607  CA  MET F  84      28.256  80.552   2.333  1.00 17.92           C  \\nATOM  10608  C   MET F  84      29.314  80.901   1.320  1.00 17.92           C  \\nATOM  10609  O   MET F  84      30.454  81.148   1.666  1.00 17.92           O  \\nATOM  10610  CB  MET F  84      28.091  79.039   2.404  1.00 34.94           C  \\nATOM  10611  CG  MET F  84      27.548  78.576   3.735  1.00 34.94           C  \\nATOM  10612  SD  MET F  84      27.998  79.750   5.058  1.00 34.94           S  \\nATOM  10613  CE  MET F  84      29.520  79.033   5.711  1.00 34.94           C  \\nATOM  10614  N   ASP F  85      28.931  80.936   0.060  1.00 12.46           N  \\nATOM  10615  CA  ASP F  85      29.880  81.296  -0.969  1.00 12.46           C  \\nATOM  10616  C   ASP F  85      30.466  82.656  -0.674  1.00 12.46           C  \\nATOM  10617  O   ASP F  85      31.678  82.798  -0.553  1.00 12.46           O  \\nATOM  10618  CB  ASP F  85      29.206  81.323  -2.337  1.00 35.98           C  \\nATOM  10619  CG  ASP F  85      28.776  79.954  -2.791  1.00 35.98           C  \\nATOM  10620  OD1 ASP F  85      29.359  78.957  -2.321  1.00 35.98           O  \\nATOM  10621  OD2 ASP F  85      27.840  79.860  -3.604  1.00 35.98           O  \\nATOM  10622  N   VAL F  86      29.585  83.642  -0.515  1.00 14.24           N  \\nATOM  10623  CA  VAL F  86      29.994  85.008  -0.242  1.00 14.24           C  \\nATOM  10624  C   VAL F  86      30.855  85.098   0.992  1.00 14.24           C  \\nATOM  10625  O   VAL F  86      31.909  85.719   0.972  1.00 14.24           O  \\nATOM  10626  CB  VAL F  86      28.788  85.910  -0.115  1.00  5.00           C  \\nATOM  10627  CG1 VAL F  86      29.223  87.334   0.150  1.00  5.00           C  \\nATOM  10628  CG2 VAL F  86      27.992  85.818  -1.414  1.00  5.00           C  \\nATOM  10629  N   VAL F  87      30.428  84.418   2.048  1.00 13.35           N  \\nATOM  10630  CA  VAL F  87      31.153  84.388   3.309  1.00 13.35           C  \\nATOM  10631  C   VAL F  87      32.570  83.835   3.160  1.00 13.35           C  \\nATOM  10632  O   VAL F  87      33.500  84.369   3.760  1.00 13.35           O  \\nATOM  10633  CB  VAL F  87      30.352  83.609   4.351  1.00  6.92           C  \\nATOM  10634  CG1 VAL F  87      31.215  83.265   5.582  1.00  6.92           C  \\nATOM  10635  CG2 VAL F  87      29.155  84.433   4.746  1.00  6.92           C  \\nATOM  10636  N   TYR F  88      32.727  82.767   2.381  1.00 17.93           N  \\nATOM  10637  CA  TYR F  88      34.041  82.187   2.129  1.00 17.93           C  \\nATOM  10638  C   TYR F  88      34.837  83.110   1.248  1.00 17.93           C  \\nATOM  10639  O   TYR F  88      36.016  83.278   1.477  1.00 17.93           O  \\nATOM  10640  CB  TYR F  88      33.959  80.849   1.424  1.00 32.87           C  \\nATOM  10641  CG  TYR F  88      33.232  79.803   2.190  1.00 32.87           C  \\nATOM  10642  CD1 TYR F  88      33.338  79.728   3.560  1.00 32.87           C  \\nATOM  10643  CD2 TYR F  88      32.461  78.861   1.532  1.00 32.87           C  \\nATOM  10644  CE1 TYR F  88      32.699  78.731   4.263  1.00 32.87           C  \\nATOM  10645  CE2 TYR F  88      31.815  77.859   2.215  1.00 32.87           C  \\nATOM  10646  CZ  TYR F  88      31.941  77.789   3.582  1.00 32.87           C  \\nATOM  10647  OH  TYR F  88      31.355  76.735   4.257  1.00 32.87           O  \\nATOM  10648  N   ALA F  89      34.222  83.667   0.210  1.00 19.95           N  \\nATOM  10649  CA  ALA F  89      34.940  84.578  -0.671  1.00 19.95           C  \\nATOM  10650  C   ALA F  89      35.503  85.754   0.153  1.00 19.95           C  \\nATOM  10651  O   ALA F  89      36.664  86.164  -0.027  1.00 19.95           O  \\nATOM  10652  CB  ALA F  89      34.048  85.056  -1.794  1.00  5.00           C  \\nATOM  10653  N   LEU F  90      34.704  86.261   1.089  1.00 20.33           N  \\nATOM  10654  CA  LEU F  90      35.149  87.340   1.964  1.00 20.33           C  \\nATOM  10655  C   LEU F  90      36.272  86.949   2.944  1.00 20.33           C  \\nATOM  10656  O   LEU F  90      37.111  87.766   3.263  1.00 20.33           O  \\nATOM  10657  CB  LEU F  90      33.971  87.953   2.720  1.00  7.70           C  \\nATOM  10658  CG  LEU F  90      32.977  88.731   1.856  1.00  7.70           C  \\nATOM  10659  CD1 LEU F  90      31.718  88.930   2.687  1.00  7.70           C  \\nATOM  10660  CD2 LEU F  90      33.545  90.094   1.348  1.00  7.70           C  \\nATOM  10661  N   LYS F  91      36.258  85.744   3.497  1.00 25.51           N  \\nATOM  10662  CA  LYS F  91      37.345  85.348   4.398  1.00 25.51           C  \\nATOM  10663  C   LYS F  91      38.688  85.324   3.624  1.00 25.51           C  \\nATOM  10664  O   LYS F  91      39.724  85.687   4.184  1.00 25.51           O  \\nATOM  10665  CB  LYS F  91      37.035  84.003   5.071  1.00 38.17           C  \\nATOM  10666  CG  LYS F  91      37.857  83.745   6.297  1.00 38.17           C  \\nATOM  10667  CD  LYS F  91      37.574  82.387   6.847  1.00 38.17           C  \\nATOM  10668  CE  LYS F  91      36.389  82.424   7.793  1.00 38.17           C  \\nATOM  10669  NZ  LYS F  91      35.946  81.033   8.205  1.00 38.17           N  \\nATOM  10670  N   ARG F  92      38.655  84.894   2.354  1.00 25.71           N  \\nATOM  10671  CA  ARG F  92      39.823  84.871   1.459  1.00 25.71           C  \\nATOM  10672  C   ARG F  92      40.434  86.259   1.358  1.00 25.71           C  \\nATOM  10673  O   ARG F  92      41.637  86.400   1.507  1.00 25.71           O  \\nATOM  10674  CB  ARG F  92      39.425  84.517   0.046  1.00 35.24           C  \\nATOM  10675  CG  ARG F  92      38.868  83.161  -0.142  1.00 35.24           C  \\nATOM  10676  CD  ARG F  92      39.275  82.666  -1.514  1.00 35.24           C  \\nATOM  10677  NE  ARG F  92      40.707  82.415  -1.527  1.00 35.24           N  \\nATOM  10678  CZ  ARG F  92      41.610  83.169  -2.141  1.00 35.24           C  \\nATOM  10679  NH1 ARG F  92      41.258  84.252  -2.828  1.00 35.24           N  \\nATOM  10680  NH2 ARG F  92      42.884  82.841  -2.020  1.00 35.24           N  \\nATOM  10681  N   GLN F  93      39.616  87.239   0.948  1.00 14.71           N  \\nATOM  10682  CA  GLN F  93      39.996  88.656   0.851  1.00 14.71           C  \\nATOM  10683  C   GLN F  93      40.392  89.308   2.200  1.00 14.71           C  \\nATOM  10684  O   GLN F  93      40.841  90.453   2.230  1.00 14.71           O  \\nATOM  10685  CB  GLN F  93      38.831  89.463   0.296  1.00 88.86           C  \\nATOM  10686  CG  GLN F  93      38.506  89.244  -1.152  1.00 88.86           C  \\nATOM  10687  CD  GLN F  93      37.791  90.454  -1.731  1.00 88.86           C  \\nATOM  10688  OE1 GLN F  93      37.823  91.551  -1.149  1.00 88.86           O  \\nATOM  10689  NE2 GLN F  93      37.159  90.273  -2.884  1.00 88.86           N  \\nATOM  10690  N   GLY F  94      40.219  88.592   3.304  1.00 22.16           N  \\nATOM  10691  CA  GLY F  94      40.545  89.136   4.607  1.00 22.16           C  \\nATOM  10692  C   GLY F  94      39.457  90.085   5.110  1.00 22.16           C  \\nATOM  10693  O   GLY F  94      39.735  91.020   5.850  1.00 22.16           O  \\nATOM  10694  N   ARG F  95      38.209  89.840   4.736  1.00 50.81           N  \\nATOM  10695  CA  ARG F  95      37.117  90.706   5.139  1.00 50.81           C  \\nATOM  10696  C   ARG F  95      36.016  90.009   5.957  1.00 50.81           C  \\nATOM  10697  O   ARG F  95      34.869  90.459   5.970  1.00 50.81           O  \\nATOM  10698  CB  ARG F  95      36.539  91.370   3.896  1.00 47.90           C  \\nATOM  10699  CG  ARG F  95      36.556  92.862   3.938  1.00 47.90           C  \\nATOM  10700  CD  ARG F  95      37.154  93.385   2.695  1.00 47.90           C  \\nATOM  10701  NE  ARG F  95      38.312  94.188   3.032  1.00 47.90           N  \\nATOM  10702  CZ  ARG F  95      39.368  94.359   2.240  1.00 47.90           C  \\nATOM  10703  NH1 ARG F  95      39.418  93.781   1.038  1.00 47.90           N  \\nATOM  10704  NH2 ARG F  95      40.406  95.080   2.665  1.00 47.90           N  \\nATOM  10705  N   THR F  96      36.402  88.950   6.675  1.00 17.64           N  \\nATOM  10706  CA  THR F  96      35.532  88.140   7.541  1.00 17.64           C  \\nATOM  10707  C   THR F  96      34.236  88.792   7.977  1.00 17.64           C  \\nATOM  10708  O   THR F  96      34.232  89.808   8.658  1.00 17.64           O  \\nATOM  10709  CB  THR F  96      36.266  87.735   8.809  1.00 18.61           C  \\nATOM  10710  OG1 THR F  96      37.531  87.189   8.450  1.00 18.61           O  \\nATOM  10711  CG2 THR F  96      35.483  86.702   9.579  1.00 18.61           C  \\nATOM  10712  N   LEU F  97      33.130  88.153   7.621  1.00 15.87           N  \\nATOM  10713  CA  LEU F  97      31.829  88.664   7.959  1.00 15.87           C  \\nATOM  10714  C   LEU F  97      31.092  87.769   8.926  1.00 15.87           C  \\nATOM  10715  O   LEU F  97      31.007  86.566   8.726  1.00 15.87           O  \\nATOM  10716  CB  LEU F  97      31.011  88.815   6.688  1.00 15.04           C  \\nATOM  10717  CG  LEU F  97      29.565  89.279   6.853  1.00 15.04           C  \\nATOM  10718  CD1 LEU F  97      29.495  90.679   7.455  1.00 15.04           C  \\nATOM  10719  CD2 LEU F  97      28.886  89.206   5.495  1.00 15.04           C  \\nATOM  10720  N   TYR F  98      30.569  88.368   9.988  1.00 15.85           N  \\nATOM  10721  CA  TYR F  98      29.774  87.650  10.977  1.00 15.85           C  \\nATOM  10722  C   TYR F  98      28.304  87.952  10.699  1.00 15.85           C  \\nATOM  10723  O   TYR F  98      27.949  89.056  10.274  1.00 15.85           O  \\nATOM  10724  CB  TYR F  98      30.063  88.137  12.390  1.00 14.74           C  \\nATOM  10725  CG  TYR F  98      31.330  87.659  13.041  1.00 14.74           C  \\nATOM  10726  CD1 TYR F  98      32.201  86.786  12.408  1.00 14.74           C  \\nATOM  10727  CD2 TYR F  98      31.656  88.105  14.313  1.00 14.74           C  \\nATOM  10728  CE1 TYR F  98      33.367  86.377  13.040  1.00 14.74           C  \\nATOM  10729  CE2 TYR F  98      32.801  87.711  14.950  1.00 14.74           C  \\nATOM  10730  CZ  TYR F  98      33.657  86.849  14.325  1.00 14.74           C  \\nATOM  10731  OH  TYR F  98      34.790  86.458  15.014  1.00 14.74           O  \\nATOM  10732  N   GLY F  99      27.453  86.972  10.961  1.00 23.29           N  \\nATOM  10733  CA  GLY F  99      26.036  87.174  10.764  1.00 23.29           C  \\nATOM  10734  C   GLY F  99      25.327  86.389   9.682  1.00 23.29           C  \\nATOM  10735  O   GLY F  99      24.111  86.452   9.629  1.00 23.29           O  \\nATOM  10736  N   PHE F 100      26.047  85.664   8.828  1.00 20.24           N  \\nATOM  10737  CA  PHE F 100      25.402  84.903   7.756  1.00 20.24           C  \\nATOM  10738  C   PHE F 100      25.776  83.428   7.694  1.00 20.24           C  \\nATOM  10739  O   PHE F 100      25.895  82.840   6.612  1.00 20.24           O  \\nATOM  10740  CB  PHE F 100      25.673  85.572   6.420  1.00 19.66           C  \\nATOM  10741  CG  PHE F 100      24.962  86.876   6.249  1.00 19.66           C  \\nATOM  10742  CD1 PHE F 100      25.384  88.013   6.931  1.00 19.66           C  \\nATOM  10743  CD2 PHE F 100      23.870  86.983   5.391  1.00 19.66           C  \\nATOM  10744  CE1 PHE F 100      24.731  89.241   6.758  1.00 19.66           C  \\nATOM  10745  CE2 PHE F 100      23.210  88.208   5.210  1.00 19.66           C  \\nATOM  10746  CZ  PHE F 100      23.645  89.333   5.899  1.00 19.66           C  \\nATOM  10747  N   GLY F 101      25.861  82.812   8.862  1.00 43.20           N  \\nATOM  10748  CA  GLY F 101      26.226  81.416   8.928  1.00 43.20           C  \\nATOM  10749  C   GLY F 101      27.724  81.225   8.788  1.00 43.20           C  \\nATOM  10750  O   GLY F 101      28.178  80.529   7.880  1.00 43.20           O  \\nATOM  10751  N   GLY F 102      28.497  81.861   9.669  1.00101.87           N  \\nATOM  10752  CA  GLY F 102      29.943  81.719   9.627  1.00101.87           C  \\nATOM  10753  C   GLY F 102      30.393  80.398  10.228  1.00101.87           C  \\nATOM  10754  O   GLY F 102      30.789  79.492   9.462  1.00110.04           O  \\nATOM  10755  OXT GLY F 102      30.338  80.254  11.468  1.00110.04           O  \\nTER   10756      GLY F 102                                                      \\nATOM  10757  N   ALA G  12      59.110  44.806 -13.305  1.00155.15           N  \\nATOM  10758  CA  ALA G  12      59.180  45.823 -14.401  1.00155.15           C  \\nATOM  10759  C   ALA G  12      60.110  46.972 -14.003  1.00155.15           C  \\nATOM  10760  O   ALA G  12      60.036  47.459 -12.872  1.00155.15           O  \\nATOM  10761  CB  ALA G  12      57.773  46.362 -14.714  1.00 37.06           C  \\nATOM  10762  N   LYS G  13      60.988  47.394 -14.919  1.00178.91           N  \\nATOM  10763  CA  LYS G  13      61.920  48.495 -14.640  1.00178.91           C  \\nATOM  10764  C   LYS G  13      61.202  49.812 -14.378  1.00178.91           C  \\nATOM  10765  O   LYS G  13      60.710  50.474 -15.298  1.00178.91           O  \\nATOM  10766  CB  LYS G  13      62.971  48.658 -15.748  1.00102.98           C  \\nATOM  10767  CG  LYS G  13      64.284  47.935 -15.444  1.00102.98           C  \\nATOM  10768  CD  LYS G  13      64.857  48.395 -14.104  1.00102.98           C  \\nATOM  10769  CE  LYS G  13      65.900  47.429 -13.570  1.00102.98           C  \\nATOM  10770  NZ  LYS G  13      66.288  47.786 -12.178  1.00102.98           N  \\nATOM  10771  N   ALA G  14      61.171  50.177 -13.100  1.00156.14           N  \\nATOM  10772  CA  ALA G  14      60.506  51.380 -12.630  1.00156.14           C  \\nATOM  10773  C   ALA G  14      61.080  52.691 -13.108  1.00156.14           C  \\nATOM  10774  O   ALA G  14      62.293  52.852 -13.251  1.00156.14           O  \\nATOM  10775  CB  ALA G  14      60.462  51.387 -11.122  1.00 51.77           C  \\nATOM  10776  N   LYS G  15      60.172  53.625 -13.349  1.00151.22           N  \\nATOM  10777  CA  LYS G  15      60.520  54.971 -13.753  1.00151.22           C  \\nATOM  10778  C   LYS G  15      59.468  55.870 -13.145  1.00151.22           C  \\nATOM  10779  O   LYS G  15      58.300  55.845 -13.536  1.00151.22           O  \\nATOM  10780  CB  LYS G  15      60.621  55.123 -15.274  1.00110.09           C  \\nATOM  10781  CG  LYS G  15      62.073  55.048 -15.752  1.00110.09           C  \\nATOM  10782  CD  LYS G  15      62.212  55.012 -17.260  1.00110.09           C  \\nATOM  10783  CE  LYS G  15      63.585  54.477 -17.643  1.00110.09           C  \\nATOM  10784  NZ  LYS G  15      63.731  54.267 -19.107  1.00110.09           N  \\nATOM  10785  N   THR G  16      59.899  56.537 -12.078  1.00 91.26           N  \\nATOM  10786  CA  THR G  16      59.108  57.469 -11.285  1.00 91.26           C  \\nATOM  10787  C   THR G  16      57.915  58.128 -11.959  1.00 91.26           C  \\nATOM  10788  O   THR G  16      57.852  58.268 -13.186  1.00 91.26           O  \\nATOM  10789  CB  THR G  16      59.985  58.617 -10.775  1.00 39.60           C  \\nATOM  10790  OG1 THR G  16      60.606  59.252 -11.897  1.00 39.60           O  \\nATOM  10791  CG2 THR G  16      61.055  58.114  -9.813  1.00 39.60           C  \\nATOM  10792  N   ARG G  17      57.032  58.649 -11.111  1.00 46.55           N  \\nATOM  10793  CA  ARG G  17      55.832  59.334 -11.550  1.00 46.55           C  \\nATOM  10794  C   ARG G  17      56.196  60.606 -12.308  1.00 46.55           C  \\nATOM  10795  O   ARG G  17      55.643  60.881 -13.375  1.00 46.55           O  \\nATOM  10796  CB  ARG G  17      54.996  59.664 -10.337  1.00 36.08           C  \\nATOM  10797  CG  ARG G  17      54.737  58.466  -9.445  1.00 36.08           C  \\nATOM  10798  CD  ARG G  17      53.461  58.670  -8.648  1.00 36.08           C  \\nATOM  10799  NE  ARG G  17      53.685  58.646  -7.211  1.00 36.08           N  \\nATOM  10800  CZ  ARG G  17      52.787  59.046  -6.326  1.00 36.08           C  \\nATOM  10801  NH1 ARG G  17      51.602  59.502  -6.755  1.00 36.08           N  \\nATOM  10802  NH2 ARG G  17      53.059  58.933  -5.026  1.00 36.08           N  \\nATOM  10803  N   SER G  18      57.156  61.361 -11.770  1.00 27.07           N  \\nATOM  10804  CA  SER G  18      57.629  62.601 -12.402  1.00 27.07           C  \\nATOM  10805  C   SER G  18      57.907  62.355 -13.879  1.00 27.07           C  \\nATOM  10806  O   SER G  18      57.440  63.090 -14.733  1.00 27.07           O  \\nATOM  10807  CB  SER G  18      58.891  63.115 -11.706  1.00 24.03           C  \\nATOM  10808  OG  SER G  18      58.660  63.370 -10.325  1.00 24.03           O  \\nATOM  10809  N   SER G  19      58.640  61.286 -14.155  1.00 40.89           N  \\nATOM  10810  CA  SER G  19      58.983  60.870 -15.505  1.00 40.89           C  \\nATOM  10811  C   SER G  19      57.726  60.788 -16.406  1.00 40.89           C  \\nATOM  10812  O   SER G  19      57.716  61.317 -17.534  1.00 40.89           O  \\nATOM  10813  CB  SER G  19      59.680  59.502 -15.422  1.00107.02           C  \\nATOM  10814  OG  SER G  19      60.075  59.011 -16.689  1.00107.02           O  \\nATOM  10815  N   ARG G  20      56.682  60.123 -15.901  1.00 57.92           N  \\nATOM  10816  CA  ARG G  20      55.421  59.947 -16.633  1.00 57.92           C  \\nATOM  10817  C   ARG G  20      54.663  61.238 -16.881  1.00 57.92           C  \\nATOM  10818  O   ARG G  20      54.100  61.431 -17.963  1.00 57.92           O  \\nATOM  10819  CB  ARG G  20      54.506  58.951 -15.914  1.00 97.69           C  \\nATOM  10820  CG  ARG G  20      55.094  57.573 -15.821  1.00 97.69           C  \\nATOM  10821  CD  ARG G  20      54.123  56.538 -15.310  1.00 97.69           C  \\nATOM  10822  NE  ARG G  20      54.828  55.266 -15.202  1.00 97.69           N  \\nATOM  10823  CZ  ARG G  20      54.970  54.569 -14.078  1.00 97.69           C  \\nATOM  10824  NH1 ARG G  20      54.437  55.001 -12.940  1.00 97.69           N  \\nATOM  10825  NH2 ARG G  20      55.702  53.461 -14.081  1.00 97.69           N  \\nATOM  10826  N   ALA G  21      54.605  62.085 -15.852  1.00 32.31           N  \\nATOM  10827  CA  ALA G  21      53.928  63.380 -15.933  1.00 32.31           C  \\nATOM  10828  C   ALA G  21      54.804  64.353 -16.717  1.00 32.31           C  \\nATOM  10829  O   ALA G  21      54.401  65.468 -17.055  1.00 32.31           O  \\nATOM  10830  CB  ALA G  21      53.652  63.900 -14.552  1.00 17.02           C  \\nATOM  10831  N   GLY G  22      56.031  63.916 -16.958  1.00 42.95           N  \\nATOM  10832  CA  GLY G  22      56.961  64.688 -17.741  1.00 42.95           C  \\nATOM  10833  C   GLY G  22      57.470  65.930 -17.083  1.00 42.95           C  \\nATOM  10834  O   GLY G  22      57.655  66.944 -17.757  1.00 42.95           O  \\nATOM  10835  N   LEU G  23      57.722  65.865 -15.782  1.00 25.18           N  \\nATOM  10836  CA  LEU G  23      58.237  67.035 -15.103  1.00 25.18           C  \\nATOM  10837  C   LEU G  23      59.405  66.740 -14.212  1.00 25.18           C  \\nATOM  10838  O   LEU G  23      59.636  65.594 -13.855  1.00 25.18           O  \\nATOM  10839  CB  LEU G  23      57.140  67.788 -14.346  1.00 29.77           C  \\nATOM  10840  CG  LEU G  23      55.839  67.099 -13.956  1.00 29.77           C  \\nATOM  10841  CD1 LEU G  23      55.703  67.008 -12.446  1.00 29.77           C  \\nATOM  10842  CD2 LEU G  23      54.724  67.921 -14.544  1.00 29.77           C  \\nATOM  10843  N   GLN G  24      60.152  67.792 -13.886  1.00 46.00           N  \\nATOM  10844  CA  GLN G  24      61.337  67.718 -13.042  1.00 46.00           C  \\nATOM  10845  C   GLN G  24      61.018  67.609 -11.562  1.00 46.00           C  \\nATOM  10846  O   GLN G  24      61.731  66.939 -10.818  1.00 46.00           O  \\nATOM  10847  CB  GLN G  24      62.226  68.945 -13.270  1.00 58.58           C  \\nATOM  10848  CG  GLN G  24      62.524  69.251 -14.736  1.00 58.58           C  \\nATOM  10849  CD  GLN G  24      63.025  68.038 -15.491  1.00 58.58           C  \\nATOM  10850  OE1 GLN G  24      63.996  67.402 -15.078  1.00 58.58           O  \\nATOM  10851  NE2 GLN G  24      62.348  67.691 -16.588  1.00 58.58           N  \\nATOM  10852  N   PHE G  25      59.980  68.304 -11.123  1.00 37.41           N  \\nATOM  10853  CA  PHE G  25      59.602  68.267  -9.724  1.00 37.41           C  \\nATOM  10854  C   PHE G  25      59.137  66.890  -9.260  1.00 37.41           C  \\nATOM  10855  O   PHE G  25      58.513  66.150 -10.013  1.00 37.41           O  \\nATOM  10856  CB  PHE G  25      58.597  69.372  -9.412  1.00 21.77           C  \\nATOM  10857  CG  PHE G  25      59.250  70.664  -9.027  1.00 21.77           C  \\nATOM  10858  CD1 PHE G  25      60.177  71.265  -9.872  1.00 21.77           C  \\nATOM  10859  CD2 PHE G  25      58.969  71.265  -7.797  1.00 21.77           C  \\nATOM  10860  CE1 PHE G  25      60.824  72.448  -9.503  1.00 21.77           C  \\nATOM  10861  CE2 PHE G  25      59.604  72.447  -7.411  1.00 21.77           C  \\nATOM  10862  CZ  PHE G  25      60.539  73.042  -8.271  1.00 21.77           C  \\nATOM  10863  N   PRO G  26      59.468  66.522  -8.011  1.00 41.25           N  \\nATOM  10864  CA  PRO G  26      59.150  65.253  -7.348  1.00 41.25           C  \\nATOM  10865  C   PRO G  26      57.696  65.000  -6.935  1.00 41.25           C  \\nATOM  10866  O   PRO G  26      57.274  65.328  -5.828  1.00 41.25           O  \\nATOM  10867  CB  PRO G  26      60.064  65.287  -6.138  1.00 33.78           C  \\nATOM  10868  CG  PRO G  26      59.981  66.720  -5.758  1.00 33.78           C  \\nATOM  10869  CD  PRO G  26      60.176  67.415  -7.077  1.00 33.78           C  \\nATOM  10870  N   VAL G  27      56.982  64.297  -7.802  1.00 31.86           N  \\nATOM  10871  CA  VAL G  27      55.593  63.934  -7.586  1.00 31.86           C  \\nATOM  10872  C   VAL G  27      55.411  63.048  -6.353  1.00 31.86           C  \\nATOM  10873  O   VAL G  27      54.514  63.286  -5.529  1.00 31.86           O  \\nATOM  10874  CB  VAL G  27      55.095  63.196  -8.798  1.00 17.80           C  \\nATOM  10875  CG1 VAL G  27      53.627  62.876  -8.671  1.00 17.80           C  \\nATOM  10876  CG2 VAL G  27      55.370  64.033 -10.022  1.00 17.80           C  \\nATOM  10877  N   GLY G  28      56.275  62.040  -6.219  1.00 38.83           N  \\nATOM  10878  CA  GLY G  28      56.205  61.137  -5.080  1.00 38.83           C  \\nATOM  10879  C   GLY G  28      56.327  61.894  -3.774  1.00 38.83           C  \\nATOM  10880  O   GLY G  28      55.737  61.511  -2.758  1.00 38.83           O  \\nATOM  10881  N   ARG G  29      57.052  63.007  -3.817  1.00 30.79           N  \\nATOM  10882  CA  ARG G  29      57.244  63.842  -2.633  1.00 30.79           C  \\nATOM  10883  C   ARG G  29      56.055  64.745  -2.354  1.00 30.79           C  \\nATOM  10884  O   ARG G  29      55.603  64.836  -1.213  1.00 30.79           O  \\nATOM  10885  CB  ARG G  29      58.504  64.694  -2.752  1.00 35.73           C  \\nATOM  10886  CG  ARG G  29      58.792  65.495  -1.512  1.00 35.73           C  \\nATOM  10887  CD  ARG G  29      60.009  66.350  -1.700  1.00 35.73           C  \\nATOM  10888  NE  ARG G  29      61.247  65.596  -1.556  1.00 35.73           N  \\nATOM  10889  CZ  ARG G  29      62.436  66.150  -1.318  1.00 35.73           C  \\nATOM  10890  NH1 ARG G  29      62.562  67.471  -1.215  1.00 35.73           N  \\nATOM  10891  NH2 ARG G  29      63.486  65.379  -1.069  1.00 35.73           N  \\nATOM  10892  N   VAL G  30      55.576  65.451  -3.374  1.00 19.38           N  \\nATOM  10893  CA  VAL G  30      54.426  66.327  -3.188  1.00 19.38           C  \\nATOM  10894  C   VAL G  30      53.281  65.488  -2.620  1.00 19.38           C  \\nATOM  10895  O   VAL G  30      52.552  65.936  -1.723  1.00 19.38           O  \\nATOM  10896  CB  VAL G  30      54.020  67.015  -4.492  1.00 15.55           C  \\nATOM  10897  CG1 VAL G  30      52.766  67.811  -4.300  1.00 15.55           C  \\nATOM  10898  CG2 VAL G  30      55.117  67.939  -4.944  1.00 15.55           C  \\nATOM  10899  N   HIS G  31      53.182  64.236  -3.068  1.00 26.40           N  \\nATOM  10900  CA  HIS G  31      52.156  63.330  -2.559  1.00 26.40           C  \\nATOM  10901  C   HIS G  31      52.353  63.041  -1.055  1.00 26.40           C  \\nATOM  10902  O   HIS G  31      51.427  63.189  -0.251  1.00 26.40           O  \\nATOM  10903  CB  HIS G  31      52.178  62.014  -3.346  1.00 50.15           C  \\nATOM  10904  CG  HIS G  31      50.874  61.274  -3.326  1.00 50.15           C  \\nATOM  10905  ND1 HIS G  31      49.989  61.344  -2.271  1.00 50.15           N  \\nATOM  10906  CD2 HIS G  31      50.294  60.469  -4.247  1.00 50.15           C  \\nATOM  10907  CE1 HIS G  31      48.921  60.616  -2.544  1.00 50.15           C  \\nATOM  10908  NE2 HIS G  31      49.082  60.075  -3.736  1.00 50.15           N  \\nATOM  10909  N   ARG G  32      53.560  62.609  -0.691  1.00 35.25           N  \\nATOM  10910  CA  ARG G  32      53.888  62.299   0.693  1.00 35.25           C  \\nATOM  10911  C   ARG G  32      53.646  63.501   1.603  1.00 35.25           C  \\nATOM  10912  O   ARG G  32      53.193  63.353   2.743  1.00 35.25           O  \\nATOM  10913  CB  ARG G  32      55.344  61.852   0.785  1.00 44.13           C  \\nATOM  10914  CG  ARG G  32      55.626  60.906   1.930  1.00 44.13           C  \\nATOM  10915  CD  ARG G  32      57.106  60.899   2.245  1.00 44.13           C  \\nATOM  10916  NE  ARG G  32      57.512  62.196   2.775  1.00 44.13           N  \\nATOM  10917  CZ  ARG G  32      58.486  62.959   2.274  1.00 44.13           C  \\nATOM  10918  NH1 ARG G  32      59.188  62.564   1.218  1.00 44.13           N  \\nATOM  10919  NH2 ARG G  32      58.726  64.153   2.808  1.00 44.13           N  \\nATOM  10920  N   LEU G  33      53.947  64.692   1.084  1.00 40.03           N  \\nATOM  10921  CA  LEU G  33      53.761  65.940   1.819  1.00 40.03           C  \\nATOM  10922  C   LEU G  33      52.297  66.240   2.045  1.00 40.03           C  \\nATOM  10923  O   LEU G  33      51.905  66.524   3.164  1.00 40.03           O  \\nATOM  10924  CB  LEU G  33      54.453  67.103   1.105  1.00 22.88           C  \\nATOM  10925  CG  LEU G  33      55.986  67.125   1.263  1.00 22.88           C  \\nATOM  10926  CD1 LEU G  33      56.584  68.314   0.499  1.00 22.88           C  \\nATOM  10927  CD2 LEU G  33      56.384  67.194   2.746  1.00 22.88           C  \\nATOM  10928  N   LEU G  34      51.490  66.159   0.993  1.00 33.22           N  \\nATOM  10929  CA  LEU G  34      50.053  66.404   1.122  1.00 33.22           C  \\nATOM  10930  C   LEU G  34      49.341  65.491   2.130  1.00 33.22           C  \\nATOM  10931  O   LEU G  34      48.488  65.961   2.892  1.00 33.22           O  \\nATOM  10932  CB  LEU G  34      49.359  66.317  -0.238  1.00 27.27           C  \\nATOM  10933  CG  LEU G  34      49.628  67.482  -1.195  1.00 27.27           C  \\nATOM  10934  CD1 LEU G  34      49.160  67.131  -2.621  1.00 27.27           C  \\nATOM  10935  CD2 LEU G  34      48.952  68.760  -0.644  1.00 27.27           C  \\nATOM  10936  N   ARG G  35      49.659  64.192   2.116  1.00 51.87           N  \\nATOM  10937  CA  ARG G  35      49.056  63.239   3.060  1.00 51.87           C  \\nATOM  10938  C   ARG G  35      49.376  63.708   4.476  1.00 51.87           C  \\nATOM  10939  O   ARG G  35      48.495  64.124   5.240  1.00 51.87           O  \\nATOM  10940  CB  ARG G  35      49.675  61.853   2.909  1.00 65.61           C  \\nATOM  10941  CG  ARG G  35      49.854  61.353   1.514  1.00 65.61           C  \\nATOM  10942  CD  ARG G  35      50.641  60.047   1.569  1.00 65.61           C  \\nATOM  10943  NE  ARG G  35      50.316  59.132   0.475  1.00 65.61           N  \\nATOM  10944  CZ  ARG G  35      49.078  58.764   0.135  1.00 65.61           C  \\nATOM  10945  NH1 ARG G  35      48.015  59.228   0.795  1.00 65.61           N  \\nATOM  10946  NH2 ARG G  35      48.897  57.914  -0.867  1.00 65.61           N  \\nATOM  10947  N   LYS G  36      50.676  63.746   4.754  1.00 44.11           N  \\nATOM  10948  CA  LYS G  36      51.211  64.134   6.051  1.00 44.11           C  \\nATOM  10949  C   LYS G  36      51.054  65.614   6.366  1.00 44.11           C  \\nATOM  10950  O   LYS G  36      51.586  66.101   7.366  1.00 44.11           O  \\nATOM  10951  CB  LYS G  36      52.683  63.701   6.152  1.00102.46           C  \\nATOM  10952  CG  LYS G  36      52.859  62.202   5.944  1.00102.46           C  \\nATOM  10953  CD  LYS G  36      54.279  61.706   6.135  1.00102.46           C  \\nATOM  10954  CE  LYS G  36      54.304  60.178   6.056  1.00102.46           C  \\nATOM  10955  NZ  LYS G  36      55.653  59.590   6.260  1.00102.46           N  \\nATOM  10956  N   GLY G  37      50.296  66.315   5.526  1.00 52.26           N  \\nATOM  10957  CA  GLY G  37      50.075  67.728   5.736  1.00 52.26           C  \\nATOM  10958  C   GLY G  37      48.845  67.991   6.567  1.00 52.26           C  \\nATOM  10959  O   GLY G  37      48.709  69.076   7.126  1.00 52.26           O  \\nATOM  10960  N   ASN G  38      47.979  66.987   6.695  1.00 50.23           N  \\nATOM  10961  CA  ASN G  38      46.735  67.123   7.449  1.00 50.23           C  \\nATOM  10962  C   ASN G  38      45.854  68.135   6.758  1.00 50.23           C  \\nATOM  10963  O   ASN G  38      45.409  69.115   7.367  1.00 50.23           O  \\nATOM  10964  CB  ASN G  38      46.979  67.572   8.893  1.00 49.13           C  \\nATOM  10965  CG  ASN G  38      47.389  66.442   9.794  1.00 49.13           C  \\nATOM  10966  OD1 ASN G  38      47.977  66.673  10.843  1.00 49.13           O  \\nATOM  10967  ND2 ASN G  38      47.092  65.208   9.390  1.00 49.13           N  \\nATOM  10968  N   TYR G  39      45.706  67.952   5.453  1.00 33.53           N  \\nATOM  10969  CA  TYR G  39      44.876  68.829   4.637  1.00 33.53           C  \\nATOM  10970  C   TYR G  39      43.532  68.149   4.404  1.00 33.53           C  \\nATOM  10971  O   TYR G  39      42.481  68.816   4.295  1.00 33.53           O  \\nATOM  10972  CB  TYR G  39      45.567  69.110   3.305  1.00 30.05           C  \\nATOM  10973  CG  TYR G  39      46.884  69.817   3.468  1.00 30.05           C  \\nATOM  10974  CD1 TYR G  39      46.937  71.139   3.890  1.00 30.05           C  \\nATOM  10975  CD2 TYR G  39      48.077  69.165   3.200  1.00 30.05           C  \\nATOM  10976  CE1 TYR G  39      48.147  71.795   4.035  1.00 30.05           C  \\nATOM  10977  CE2 TYR G  39      49.293  69.809   3.341  1.00 30.05           C  \\nATOM  10978  CZ  TYR G  39      49.327  71.127   3.754  1.00 30.05           C  \\nATOM  10979  OH  TYR G  39      50.544  71.782   3.840  1.00 30.05           O  \\nATOM  10980  N   ALA G  40      43.590  66.813   4.376  1.00 42.83           N  \\nATOM  10981  CA  ALA G  40      42.428  65.968   4.157  1.00 42.83           C  \\nATOM  10982  C   ALA G  40      42.645  64.513   4.588  1.00 42.83           C  \\nATOM  10983  O   ALA G  40      43.739  64.139   5.026  1.00 42.83           O  \\nATOM  10984  CB  ALA G  40      42.036  66.024   2.723  1.00 18.09           C  \\nATOM  10985  N   GLU G  41      41.589  63.707   4.450  1.00 49.84           N  \\nATOM  10986  CA  GLU G  41      41.601  62.297   4.826  1.00 49.84           C  \\nATOM  10987  C   GLU G  41      42.359  61.515   3.776  1.00 49.84           C  \\nATOM  10988  O   GLU G  41      43.302  60.792   4.081  1.00 49.84           O  \\nATOM  10989  CB  GLU G  41      40.172  61.746   4.895  1.00167.51           C  \\nATOM  10990  CG  GLU G  41      39.341  62.249   6.051  1.00167.51           C  \\nATOM  10991  CD  GLU G  41      39.877  61.790   7.391  1.00167.51           C  \\nATOM  10992  OE1 GLU G  41      40.268  60.607   7.507  1.00167.51           O  \\nATOM  10993  OE2 GLU G  41      39.914  62.622   8.323  1.00167.51           O  \\nATOM  10994  N   ARG G  42      41.924  61.666   2.530  1.00 35.89           N  \\nATOM  10995  CA  ARG G  42      42.520  60.965   1.409  1.00 35.89           C  \\nATOM  10996  C   ARG G  42      42.999  61.958   0.369  1.00 35.89           C  \\nATOM  10997  O   ARG G  42      42.644  63.130   0.411  1.00 35.89           O  \\nATOM  10998  CB  ARG G  42      41.509  59.996   0.809  1.00 62.08           C  \\nATOM  10999  CG  ARG G  42      41.064  58.928   1.787  1.00 62.08           C  \\nATOM  11000  CD  ARG G  42      39.572  58.705   1.713  1.00 62.08           C  \\nATOM  11001  NE  ARG G  42      39.250  57.345   1.295  1.00 62.08           N  \\nATOM  11002  CZ  ARG G  42      38.999  56.984   0.038  1.00 62.08           C  \\nATOM  11003  NH1 ARG G  42      39.030  57.882  -0.948  1.00 62.08           N  \\nATOM  11004  NH2 ARG G  42      38.700  55.718  -0.226  1.00 62.08           N  \\nATOM  11005  N   VAL G  43      43.861  61.488  -0.527  1.00 25.79           N  \\nATOM  11006  CA  VAL G  43      44.428  62.316  -1.577  1.00 25.79           C  \\nATOM  11007  C   VAL G  43      44.461  61.558  -2.898  1.00 25.79           C  \\nATOM  11008  O   VAL G  43      45.056  60.478  -3.007  1.00 25.79           O  \\nATOM  11009  CB  VAL G  43      45.874  62.750  -1.229  1.00 23.57           C  \\nATOM  11010  CG1 VAL G  43      46.426  63.691  -2.310  1.00 23.57           C  \\nATOM  11011  CG2 VAL G  43      45.930  63.416   0.139  1.00 23.57           C  \\nATOM  11012  N   GLY G  44      43.872  62.182  -3.911  1.00 25.68           N  \\nATOM  11013  CA  GLY G  44      43.821  61.592  -5.231  1.00 25.68           C  \\nATOM  11014  C   GLY G  44      45.174  61.392  -5.882  1.00 25.68           C  \\nATOM  11015  O   GLY G  44      46.158  62.077  -5.595  1.00 25.68           O  \\nATOM  11016  N   ALA G  45      45.215  60.431  -6.784  1.00 34.26           N  \\nATOM  11017  CA  ALA G  45      46.427  60.105  -7.498  1.00 34.26           C  \\nATOM  11018  C   ALA G  45      46.949  61.292  -8.311  1.00 34.26           C  \\nATOM  11019  O   ALA G  45      48.158  61.496  -8.421  1.00 34.26           O  \\nATOM  11020  CB  ALA G  45      46.163  58.900  -8.409  1.00 19.85           C  \\nATOM  11021  N   GLY G  46      46.030  62.101  -8.828  1.00 35.16           N  \\nATOM  11022  CA  GLY G  46      46.412  63.231  -9.653  1.00 35.16           C  \\nATOM  11023  C   GLY G  46      46.749  64.531  -8.967  1.00 35.16           C  \\nATOM  11024  O   GLY G  46      47.476  65.326  -9.525  1.00 35.16           O  \\nATOM  11025  N   ALA G  47      46.257  64.739  -7.753  1.00 30.74           N  \\nATOM  11026  CA  ALA G  47      46.507  65.978  -7.027  1.00 30.74           C  \\nATOM  11027  C   ALA G  47      47.971  66.314  -6.943  1.00 30.74           C  \\nATOM  11028  O   ALA G  47      48.365  67.380  -7.387  1.00 30.74           O  \\nATOM  11029  CB  ALA G  47      45.910  65.925  -5.639  1.00 42.46           C  \\nATOM  11030  N   PRO G  48      48.814  65.396  -6.412  1.00 34.81           N  \\nATOM  11031  CA  PRO G  48      50.248  65.709  -6.322  1.00 34.81           C  \\nATOM  11032  C   PRO G  48      50.862  65.960  -7.678  1.00 34.81           C  \\nATOM  11033  O   PRO G  48      51.760  66.772  -7.808  1.00 34.81           O  \\nATOM  11034  CB  PRO G  48      50.839  64.466  -5.668  1.00 24.41           C  \\nATOM  11035  CG  PRO G  48      49.908  63.386  -6.084  1.00 24.41           C  \\nATOM  11036  CD  PRO G  48      48.556  64.031  -5.919  1.00 24.41           C  \\nATOM  11037  N   VAL G  49      50.353  65.286  -8.699  1.00 32.01           N  \\nATOM  11038  CA  VAL G  49      50.874  65.477 -10.039  1.00 32.01           C  \\nATOM  11039  C   VAL G  49      50.555  66.892 -10.515  1.00 32.01           C  \\nATOM  11040  O   VAL G  49      51.436  67.628 -10.970  1.00 32.01           O  \\nATOM  11041  CB  VAL G  49      50.289  64.438 -11.010  1.00 16.66           C  \\nATOM  11042  CG1 VAL G  49      50.724  64.761 -12.436  1.00 16.66           C  \\nATOM  11043  CG2 VAL G  49      50.769  63.055 -10.629  1.00 16.66           C  \\nATOM  11044  N   TYR G  50      49.291  67.268 -10.362  1.00 34.70           N  \\nATOM  11045  CA  TYR G  50      48.785  68.585 -10.735  1.00 34.70           C  \\nATOM  11046  C   TYR G  50      49.571  69.671 -10.010  1.00 34.70           C  \\nATOM  11047  O   TYR G  50      50.064  70.629 -10.605  1.00 34.70           O  \\nATOM  11048  CB  TYR G  50      47.309  68.692 -10.319  1.00 34.15           C  \\nATOM  11049  CG  TYR G  50      46.542  69.785 -11.026  1.00 34.15           C  \\nATOM  11050  CD1 TYR G  50      46.819  71.132 -10.795  1.00 34.15           C  \\nATOM  11051  CD2 TYR G  50      45.569  69.469 -11.968  1.00 34.15           C  \\nATOM  11052  CE1 TYR G  50      46.143  72.131 -11.493  1.00 34.15           C  \\nATOM  11053  CE2 TYR G  50      44.895  70.453 -12.671  1.00 34.15           C  \\nATOM  11054  CZ  TYR G  50      45.183  71.779 -12.433  1.00 34.15           C  \\nATOM  11055  OH  TYR G  50      44.502  72.747 -13.142  1.00 34.15           O  \\nATOM  11056  N   LEU G  51      49.648  69.518  -8.700  1.00 27.65           N  \\nATOM  11057  CA  LEU G  51      50.339  70.461  -7.860  1.00 27.65           C  \\nATOM  11058  C   LEU G  51      51.800  70.585  -8.254  1.00 27.65           C  \\nATOM  11059  O   LEU G  51      52.301  71.688  -8.339  1.00 27.65           O  \\nATOM  11060  CB  LEU G  51      50.193  70.055  -6.394  1.00 14.84           C  \\nATOM  11061  CG  LEU G  51      50.963  70.890  -5.363  1.00 14.84           C  \\nATOM  11062  CD1 LEU G  51      50.774  72.398  -5.625  1.00 14.84           C  \\nATOM  11063  CD2 LEU G  51      50.557  70.487  -3.938  1.00 14.84           C  \\nATOM  11064  N   ALA G  52      52.468  69.460  -8.512  1.00 16.58           N  \\nATOM  11065  CA  ALA G  52      53.882  69.422  -8.895  1.00 16.58           C  \\nATOM  11066  C   ALA G  52      54.114  70.246 -10.149  1.00 16.58           C  \\nATOM  11067  O   ALA G  52      55.054  71.062 -10.218  1.00 16.58           O  \\nATOM  11068  CB  ALA G  52      54.301  67.991  -9.121  1.00 12.08           C  \\nATOM  11069  N   ALA G  53      53.231  70.043 -11.126  1.00 23.58           N  \\nATOM  11070  CA  ALA G  53      53.264  70.767 -12.396  1.00 23.58           C  \\nATOM  11071  C   ALA G  53      53.225  72.252 -12.140  1.00 23.58           C  \\nATOM  11072  O   ALA G  53      54.031  72.981 -12.695  1.00 23.58           O  \\nATOM  11073  CB  ALA G  53      52.104  70.369 -13.255  1.00 24.26           C  \\nATOM  11074  N   VAL G  54      52.298  72.685 -11.284  1.00 20.76           N  \\nATOM  11075  CA  VAL G  54      52.144  74.093 -10.902  1.00 20.76           C  \\nATOM  11076  C   VAL G  54      53.370  74.703 -10.201  1.00 20.76           C  \\nATOM  11077  O   VAL G  54      53.805  75.800 -10.540  1.00 20.76           O  \\nATOM  11078  CB  VAL G  54      50.901  74.266 -10.009  1.00 26.53           C  \\nATOM  11079  CG1 VAL G  54      50.881  75.663  -9.343  1.00 26.53           C  \\nATOM  11080  CG2 VAL G  54      49.633  74.006 -10.846  1.00 26.53           C  \\nATOM  11081  N   LEU G  55      53.912  73.996  -9.215  1.00 23.53           N  \\nATOM  11082  CA  LEU G  55      55.091  74.445  -8.475  1.00 23.53           C  \\nATOM  11083  C   LEU G  55      56.250  74.645  -9.415  1.00 23.53           C  \\nATOM  11084  O   LEU G  55      56.896  75.694  -9.412  1.00 23.53           O  \\nATOM  11085  CB  LEU G  55      55.485  73.393  -7.465  1.00 11.87           C  \\nATOM  11086  CG  LEU G  55      54.460  73.258  -6.363  1.00 11.87           C  \\nATOM  11087  CD1 LEU G  55      54.879  72.145  -5.394  1.00 11.87           C  \\nATOM  11088  CD2 LEU G  55      54.348  74.641  -5.663  1.00 11.87           C  \\nATOM  11089  N   GLU G  56      56.502  73.616 -10.219  1.00 30.13           N  \\nATOM  11090  CA  GLU G  56      57.562  73.654 -11.193  1.00 30.13           C  \\nATOM  11091  C   GLU G  56      57.366  74.834 -12.125  1.00 30.13           C  \\nATOM  11092  O   GLU G  56      58.279  75.631 -12.298  1.00 30.13           O  \\nATOM  11093  CB  GLU G  56      57.566  72.383 -12.005  1.00 31.34           C  \\nATOM  11094  CG  GLU G  56      58.614  72.415 -13.083  1.00 31.34           C  \\nATOM  11095  CD  GLU G  56      58.751  71.099 -13.795  1.00 31.34           C  \\nATOM  11096  OE1 GLU G  56      58.920  70.077 -13.108  1.00 31.34           O  \\nATOM  11097  OE2 GLU G  56      58.701  71.098 -15.042  1.00 31.34           O  \\nATOM  11098  N   TYR G  57      56.182  74.944 -12.728  1.00 22.08           N  \\nATOM  11099  CA  TYR G  57      55.891  76.052 -13.638  1.00 22.08           C  \\nATOM  11100  C   TYR G  57      56.196  77.422 -13.053  1.00 22.08           C  \\nATOM  11101  O   TYR G  57      56.821  78.243 -13.715  1.00 22.08           O  \\nATOM  11102  CB  TYR G  57      54.441  76.046 -14.109  1.00 26.52           C  \\nATOM  11103  CG  TYR G  57      54.011  77.399 -14.641  1.00 26.52           C  \\nATOM  11104  CD1 TYR G  57      54.557  77.917 -15.815  1.00 26.52           C  \\nATOM  11105  CD2 TYR G  57      53.083  78.173 -13.953  1.00 26.52           C  \\nATOM  11106  CE1 TYR G  57      54.191  79.167 -16.290  1.00 26.52           C  \\nATOM  11107  CE2 TYR G  57      52.703  79.430 -14.422  1.00 26.52           C  \\nATOM  11108  CZ  TYR G  57      53.260  79.915 -15.589  1.00 26.52           C  \\nATOM  11109  OH  TYR G  57      52.872  81.141 -16.054  1.00 26.52           O  \\nATOM  11110  N   LEU G  58      55.696  77.708 -11.856  1.00 30.86           N  \\nATOM  11111  CA  LEU G  58      55.985  79.002 -11.246  1.00 30.86           C  \\nATOM  11112  C   LEU G  58      57.478  79.155 -10.945  1.00 30.86           C  \\nATOM  11113  O   LEU G  58      58.026  80.247 -11.059  1.00 30.86           O  \\nATOM  11114  CB  LEU G  58      55.144  79.226  -9.994  1.00 18.28           C  \\nATOM  11115  CG  LEU G  58      53.657  79.504 -10.239  1.00 18.28           C  \\nATOM  11116  CD1 LEU G  58      52.960  79.562  -8.905  1.00 18.28           C  \\nATOM  11117  CD2 LEU G  58      53.458  80.798 -11.047  1.00 18.28           C  \\nATOM  11118  N   THR G  59      58.134  78.065 -10.564  1.00 34.68           N  \\nATOM  11119  CA  THR G  59      59.570  78.096 -10.307  1.00 34.68           C  \\nATOM  11120  C   THR G  59      60.293  78.559 -11.582  1.00 34.68           C  \\nATOM  11121  O   THR G  59      61.177  79.415 -11.545  1.00 34.68           O  \\nATOM  11122  CB  THR G  59      60.071  76.709  -9.867  1.00 41.58           C  \\nATOM  11123  OG1 THR G  59      59.343  76.290  -8.707  1.00 41.58           O  \\nATOM  11124  CG2 THR G  59      61.526  76.755  -9.508  1.00 41.58           C  \\nATOM  11125  N   ALA G  60      59.888  78.014 -12.719  1.00 32.08           N  \\nATOM  11126  CA  ALA G  60      60.469  78.404 -14.000  1.00 32.08           C  \\nATOM  11127  C   ALA G  60      60.195  79.867 -14.273  1.00 32.08           C  \\nATOM  11128  O   ALA G  60      61.056  80.571 -14.750  1.00 32.08           O  \\nATOM  11129  CB  ALA G  60      59.890  77.570 -15.115  1.00 46.88           C  \\nATOM  11130  N   GLU G  61      58.978  80.315 -13.987  1.00 27.65           N  \\nATOM  11131  CA  GLU G  61      58.602  81.707 -14.208  1.00 27.65           C  \\nATOM  11132  C   GLU G  61      59.584  82.619 -13.517  1.00 27.65           C  \\nATOM  11133  O   GLU G  61      60.265  83.382 -14.168  1.00 27.65           O  \\nATOM  11134  CB  GLU G  61      57.187  81.965 -13.722  1.00 46.19           C  \\nATOM  11135  CG  GLU G  61      56.522  83.150 -14.392  1.00 46.19           C  \\nATOM  11136  CD  GLU G  61      56.426  83.009 -15.901  1.00 46.19           C  \\nATOM  11137  OE1 GLU G  61      56.002  81.923 -16.376  1.00 46.19           O  \\nATOM  11138  OE2 GLU G  61      56.764  83.996 -16.599  1.00 46.19           O  \\nATOM  11139  N   ILE G  62      59.733  82.486 -12.211  1.00 23.70           N  \\nATOM  11140  CA  ILE G  62      60.693  83.320 -11.490  1.00 23.70           C  \\nATOM  11141  C   ILE G  62      62.111  83.179 -12.011  1.00 23.70           C  \\nATOM  11142  O   ILE G  62      62.740  84.184 -12.294  1.00 23.70           O  \\nATOM  11143  CB  ILE G  62      60.696  83.044  -9.967  1.00 26.61           C  \\nATOM  11144  CG1 ILE G  62      59.372  83.498  -9.383  1.00 26.61           C  \\nATOM  11145  CG2 ILE G  62      61.840  83.785  -9.268  1.00 26.61           C  \\nATOM  11146  CD1 ILE G  62      59.345  83.476  -7.899  1.00 26.61           C  \\nATOM  11147  N   LEU G  63      62.619  81.952 -12.146  1.00 15.59           N  \\nATOM  11148  CA  LEU G  63      64.001  81.746 -12.633  1.00 15.59           C  \\nATOM  11149  C   LEU G  63      64.238  82.404 -13.974  1.00 15.59           C  \\nATOM  11150  O   LEU G  63      65.265  83.016 -14.185  1.00 15.59           O  \\nATOM  11151  CB  LEU G  63      64.380  80.266 -12.680  1.00  9.68           C  \\nATOM  11152  CG  LEU G  63      64.414  79.611 -11.292  1.00  9.68           C  \\nATOM  11153  CD1 LEU G  63      64.733  78.145 -11.440  1.00  9.68           C  \\nATOM  11154  CD2 LEU G  63      65.427  80.276 -10.355  1.00  9.68           C  \\nATOM  11155  N   GLU G  64      63.259  82.308 -14.858  1.00 24.00           N  \\nATOM  11156  CA  GLU G  64      63.323  82.936 -16.163  1.00 24.00           C  \\nATOM  11157  C   GLU G  64      63.645  84.409 -15.919  1.00 24.00           C  \\nATOM  11158  O   GLU G  64      64.765  84.875 -16.148  1.00 24.00           O  \\nATOM  11159  CB  GLU G  64      61.953  82.812 -16.835  1.00 81.17           C  \\nATOM  11160  CG  GLU G  64      61.802  83.589 -18.109  1.00 81.17           C  \\nATOM  11161  CD  GLU G  64      62.661  83.035 -19.213  1.00 81.17           C  \\nATOM  11162  OE1 GLU G  64      62.264  82.022 -19.821  1.00 81.17           O  \\nATOM  11163  OE2 GLU G  64      63.741  83.602 -19.472  1.00 81.17           O  \\nATOM  11164  N   LEU G  65      62.693  85.090 -15.294  1.00 28.28           N  \\nATOM  11165  CA  LEU G  65      62.796  86.504 -15.002  1.00 28.28           C  \\nATOM  11166  C   LEU G  65      64.052  86.957 -14.287  1.00 28.28           C  \\nATOM  11167  O   LEU G  65      64.608  87.995 -14.641  1.00 28.28           O  \\nATOM  11168  CB  LEU G  65      61.552  86.957 -14.252  1.00 33.43           C  \\nATOM  11169  CG  LEU G  65      60.274  86.748 -15.075  1.00 33.43           C  \\nATOM  11170  CD1 LEU G  65      59.077  87.304 -14.326  1.00 33.43           C  \\nATOM  11171  CD2 LEU G  65      60.405  87.422 -16.439  1.00 33.43           C  \\nATOM  11172  N   ALA G  66      64.479  86.207 -13.268  1.00 23.39           N  \\nATOM  11173  CA  ALA G  66      65.695  86.530 -12.511  1.00 23.39           C  \\nATOM  11174  C   ALA G  66      66.945  86.237 -13.344  1.00 23.39           C  \\nATOM  11175  O   ALA G  66      67.949  86.950 -13.235  1.00 23.39           O  \\nATOM  11176  CB  ALA G  66      65.736  85.761 -11.205  1.00  5.00           C  \\nATOM  11177  N   GLY G  67      66.880  85.184 -14.165  1.00 35.89           N  \\nATOM  11178  CA  GLY G  67      67.987  84.828 -15.037  1.00 35.89           C  \\nATOM  11179  C   GLY G  67      68.246  86.041 -15.902  1.00 35.89           C  \\nATOM  11180  O   GLY G  67      69.399  86.477 -16.055  1.00 35.89           O  \\nATOM  11181  N   ASN G  68      67.153  86.610 -16.429  1.00 27.46           N  \\nATOM  11182  CA  ASN G  68      67.214  87.821 -17.257  1.00 27.46           C  \\nATOM  11183  C   ASN G  68      67.828  89.013 -16.503  1.00 27.46           C  \\nATOM  11184  O   ASN G  68      68.706  89.699 -17.017  1.00 27.46           O  \\nATOM  11185  CB  ASN G  68      65.834  88.164 -17.807  1.00 43.30           C  \\nATOM  11186  CG  ASN G  68      65.423  87.242 -18.938  1.00 43.30           C  \\nATOM  11187  OD1 ASN G  68      66.274  86.733 -19.674  1.00 43.30           O  \\nATOM  11188  ND2 ASN G  68      64.121  87.008 -19.077  1.00 43.30           N  \\nATOM  11189  N   ALA G  69      67.374  89.248 -15.278  1.00 32.99           N  \\nATOM  11190  CA  ALA G  69      67.927  90.316 -14.455  1.00 32.99           C  \\nATOM  11191  C   ALA G  69      69.447  90.187 -14.360  1.00 32.99           C  \\nATOM  11192  O   ALA G  69      70.152  91.180 -14.500  1.00 32.99           O  \\nATOM  11193  CB  ALA G  69      67.309  90.292 -13.054  1.00 21.08           C  \\nATOM  11194  N   ALA G  70      69.949  88.976 -14.107  1.00 32.35           N  \\nATOM  11195  CA  ALA G  70      71.393  88.744 -14.009  1.00 32.35           C  \\nATOM  11196  C   ALA G  70      72.074  89.211 -15.278  1.00 32.35           C  \\nATOM  11197  O   ALA G  70      72.962  90.050 -15.227  1.00 32.35           O  \\nATOM  11198  CB  ALA G  70      71.689  87.281 -13.765  1.00 18.75           C  \\nATOM  11199  N   ARG G  71      71.626  88.689 -16.415  1.00 56.07           N  \\nATOM  11200  CA  ARG G  71      72.165  89.064 -17.715  1.00 56.07           C  \\nATOM  11201  C   ARG G  71      72.210  90.597 -17.883  1.00 56.07           C  \\nATOM  11202  O   ARG G  71      73.165  91.139 -18.441  1.00 56.07           O  \\nATOM  11203  CB  ARG G  71      71.306  88.445 -18.808  1.00 71.76           C  \\nATOM  11204  CG  ARG G  71      71.870  88.578 -20.173  1.00 71.76           C  \\nATOM  11205  CD  ARG G  71      70.903  88.039 -21.177  1.00 71.76           C  \\nATOM  11206  NE  ARG G  71      71.493  88.015 -22.513  1.00 71.76           N  \\nATOM  11207  CZ  ARG G  71      70.861  88.390 -23.625  1.00 71.76           C  \\nATOM  11208  NH1 ARG G  71      69.612  88.832 -23.562  1.00 71.76           N  \\nATOM  11209  NH2 ARG G  71      71.461  88.286 -24.808  1.00 71.76           N  \\nATOM  11210  N   ASP G  72      71.172  91.288 -17.413  1.00 44.90           N  \\nATOM  11211  CA  ASP G  72      71.104  92.748 -17.496  1.00 44.90           C  \\nATOM  11212  C   ASP G  72      72.178  93.420 -16.672  1.00 44.90           C  \\nATOM  11213  O   ASP G  72      72.663  94.485 -17.034  1.00 44.90           O  \\nATOM  11214  CB  ASP G  72      69.738  93.252 -17.040  1.00 56.77           C  \\nATOM  11215  CG  ASP G  72      68.624  92.846 -17.977  1.00 56.77           C  \\nATOM  11216  OD1 ASP G  72      68.909  92.396 -19.111  1.00 56.77           O  \\nATOM  11217  OD2 ASP G  72      67.453  92.974 -17.569  1.00 56.77           O  \\nATOM  11218  N   ASN G  73      72.454  92.870 -15.499  1.00 49.16           N  \\nATOM  11219  CA  ASN G  73      73.506  93.418 -14.653  1.00 49.16           C  \\nATOM  11220  C   ASN G  73      74.850  92.862 -15.088  1.00 49.16           C  \\nATOM  11221  O   ASN G  73      75.864  93.113 -14.442  1.00 49.16           O  \\nATOM  11222  CB  ASN G  73      73.266  93.075 -13.186  1.00105.63           C  \\nATOM  11223  CG  ASN G  73      72.346  94.053 -12.509  1.00105.63           C  \\nATOM  11224  OD1 ASN G  73      72.462  95.267 -12.702  1.00105.63           O  \\nATOM  11225  ND2 ASN G  73      71.422  93.537 -11.709  1.00105.63           N  \\nATOM  11226  N   LYS G  74      74.840  92.110 -16.189  1.00 48.20           N  \\nATOM  11227  CA  LYS G  74      76.032  91.476 -16.746  1.00 48.20           C  \\nATOM  11228  C   LYS G  74      76.608  90.515 -15.707  1.00 48.20           C  \\nATOM  11229  O   LYS G  74      77.746  90.673 -15.278  1.00 48.20           O  \\nATOM  11230  CB  LYS G  74      77.075  92.525 -17.142  1.00 82.49           C  \\nATOM  11231  CG  LYS G  74      76.544  93.671 -17.992  1.00 82.49           C  \\nATOM  11232  CD  LYS G  74      77.581  94.785 -18.074  1.00 82.49           C  \\nATOM  11233  CE  LYS G  74      76.981  96.102 -18.543  1.00 82.49           C  \\nATOM  11234  NZ  LYS G  74      78.013  97.178 -18.513  1.00 82.49           N  \\nATOM  11235  N   LYS G  75      75.790  89.555 -15.267  1.00 45.76           N  \\nATOM  11236  CA  LYS G  75      76.191  88.557 -14.265  1.00 45.76           C  \\nATOM  11237  C   LYS G  75      75.716  87.132 -14.611  1.00 45.76           C  \\nATOM  11238  O   LYS G  75      74.635  86.930 -15.181  1.00 45.76           O  \\nATOM  11239  CB  LYS G  75      75.644  88.943 -12.884  1.00 40.81           C  \\nATOM  11240  CG  LYS G  75      75.548  90.449 -12.631  1.00 40.81           C  \\nATOM  11241  CD  LYS G  75      76.653  91.009 -11.733  1.00 40.81           C  \\nATOM  11242  CE  LYS G  75      76.422  90.640 -10.274  1.00 40.81           C  \\nATOM  11243  NZ  LYS G  75      77.476  91.201  -9.410  1.00 40.81           N  \\nATOM  11244  N   THR G  76      76.533  86.152 -14.238  1.00 53.62           N  \\nATOM  11245  CA  THR G  76      76.251  84.736 -14.481  1.00 53.62           C  \\nATOM  11246  C   THR G  76      75.372  84.105 -13.387  1.00 53.62           C  \\nATOM  11247  O   THR G  76      74.405  83.401 -13.688  1.00 53.62           O  \\nATOM  11248  CB  THR G  76      77.572  83.928 -14.534  1.00 84.47           C  \\nATOM  11249  OG1 THR G  76      78.471  84.530 -15.474  1.00 84.47           O  \\nATOM  11250  CG2 THR G  76      77.309  82.474 -14.922  1.00 84.47           C  \\nATOM  11251  N   ARG G  77      75.764  84.316 -12.127  1.00 41.80           N  \\nATOM  11252  CA  ARG G  77      75.060  83.773 -10.969  1.00 41.80           C  \\nATOM  11253  C   ARG G  77      74.000  84.677 -10.384  1.00 41.80           C  \\nATOM  11254  O   ARG G  77      74.298  85.796  -9.939  1.00 41.80           O  \\nATOM  11255  CB  ARG G  77      76.033  83.366  -9.857  1.00 62.04           C  \\nATOM  11256  CG  ARG G  77      76.258  81.871  -9.813  1.00 62.04           C  \\nATOM  11257  CD  ARG G  77      76.873  81.400  -8.514  1.00 62.04           C  \\nATOM  11258  NE  ARG G  77      78.329  81.454  -8.526  1.00 62.04           N  \\nATOM  11259  CZ  ARG G  77      79.032  82.330  -7.822  1.00 62.04           C  \\nATOM  11260  NH1 ARG G  77      78.399  83.211  -7.063  1.00 62.04           N  \\nATOM  11261  NH2 ARG G  77      80.357  82.316  -7.856  1.00 62.04           N  \\nATOM  11262  N   ILE G  78      72.783  84.116 -10.341  1.00 35.39           N  \\nATOM  11263  CA  ILE G  78      71.563  84.736  -9.820  1.00 35.39           C  \\nATOM  11264  C   ILE G  78      71.631  84.870  -8.315  1.00 35.39           C  \\nATOM  11265  O   ILE G  78      71.813  83.873  -7.621  1.00 35.39           O  \\nATOM  11266  CB  ILE G  78      70.342  83.837 -10.046  1.00 18.12           C  \\nATOM  11267  CG1 ILE G  78      70.084  83.602 -11.526  1.00 18.12           C  \\nATOM  11268  CG2 ILE G  78      69.127  84.442  -9.399  1.00 18.12           C  \\nATOM  11269  CD1 ILE G  78      68.802  82.767 -11.832  1.00 18.12           C  \\nATOM  11270  N   ILE G  79      71.413  86.081  -7.815  1.00 43.09           N  \\nATOM  11271  CA  ILE G  79      71.424  86.322  -6.378  1.00 43.09           C  \\nATOM  11272  C   ILE G  79      70.082  86.887  -5.950  1.00 43.09           C  \\nATOM  11273  O   ILE G  79      69.231  87.190  -6.782  1.00 43.09           O  \\nATOM  11274  CB  ILE G  79      72.545  87.298  -5.955  1.00 11.11           C  \\nATOM  11275  CG1 ILE G  79      72.442  88.613  -6.729  1.00 11.11           C  \\nATOM  11276  CG2 ILE G  79      73.908  86.651  -6.165  1.00 11.11           C  \\nATOM  11277  CD1 ILE G  79      73.287  89.702  -6.141  1.00 11.11           C  \\nATOM  11278  N   PRO G  80      69.851  86.985  -4.638  1.00 31.82           N  \\nATOM  11279  CA  PRO G  80      68.589  87.521  -4.135  1.00 31.82           C  \\nATOM  11280  C   PRO G  80      68.093  88.792  -4.844  1.00 31.82           C  \\nATOM  11281  O   PRO G  80      66.935  88.846  -5.246  1.00 31.82           O  \\nATOM  11282  CB  PRO G  80      68.908  87.752  -2.665  1.00 14.81           C  \\nATOM  11283  CG  PRO G  80      69.760  86.557  -2.349  1.00 14.81           C  \\nATOM  11284  CD  PRO G  80      70.683  86.480  -3.530  1.00 14.81           C  \\nATOM  11285  N   ARG G  81      68.973  89.781  -5.054  1.00 28.27           N  \\nATOM  11286  CA  ARG G  81      68.597  91.040  -5.731  1.00 28.27           C  \\nATOM  11287  C   ARG G  81      67.963  90.779  -7.093  1.00 28.27           C  \\nATOM  11288  O   ARG G  81      67.044  91.467  -7.522  1.00 28.27           O  \\nATOM  11289  CB  ARG G  81      69.813  91.978  -5.897  1.00 33.83           C  \\nATOM  11290  CG  ARG G  81      69.478  93.364  -6.478  1.00 33.83           C  \\nATOM  11291  CD  ARG G  81      68.238  93.920  -5.790  1.00 33.83           C  \\nATOM  11292  NE  ARG G  81      67.924  95.360  -5.848  1.00 33.83           N  \\nATOM  11293  CZ  ARG G  81      68.399  96.249  -6.722  1.00 33.83           C  \\nATOM  11294  NH1 ARG G  81      69.265  95.888  -7.676  1.00 33.83           N  \\nATOM  11295  NH2 ARG G  81      67.952  97.512  -6.680  1.00 33.83           N  \\nATOM  11296  N   HIS G  82      68.423  89.725  -7.734  1.00 30.62           N  \\nATOM  11297  CA  HIS G  82      67.922  89.368  -9.033  1.00 30.62           C  \\nATOM  11298  C   HIS G  82      66.502  88.877  -8.917  1.00 30.62           C  \\nATOM  11299  O   HIS G  82      65.631  89.329  -9.649  1.00 30.62           O  \\nATOM  11300  CB  HIS G  82      68.842  88.329  -9.647  1.00 35.67           C  \\nATOM  11301  CG  HIS G  82      70.231  88.840  -9.869  1.00 35.67           C  \\nATOM  11302  ND1 HIS G  82      71.011  88.440 -10.929  1.00 35.67           N  \\nATOM  11303  CD2 HIS G  82      70.943  89.781  -9.211  1.00 35.67           C  \\nATOM  11304  CE1 HIS G  82      72.141  89.117 -10.915  1.00 35.67           C  \\nATOM  11305  NE2 HIS G  82      72.124  89.936  -9.882  1.00 35.67           N  \\nATOM  11306  N   LEU G  83      66.259  87.996  -7.952  1.00 34.03           N  \\nATOM  11307  CA  LEU G  83      64.923  87.456  -7.696  1.00 34.03           C  \\nATOM  11308  C   LEU G  83      63.926  88.602  -7.365  1.00 34.03           C  \\nATOM  11309  O   LEU G  83      62.822  88.641  -7.907  1.00 34.03           O  \\nATOM  11310  CB  LEU G  83      65.013  86.388  -6.579  1.00 12.72           C  \\nATOM  11311  CG  LEU G  83      65.829  85.110  -6.923  1.00 12.72           C  \\nATOM  11312  CD1 LEU G  83      66.148  84.282  -5.682  1.00 12.72           C  \\nATOM  11313  CD2 LEU G  83      65.077  84.270  -7.994  1.00 12.72           C  \\nATOM  11314  N   GLN G  84      64.368  89.566  -6.552  1.00 23.67           N  \\nATOM  11315  CA  GLN G  84      63.576  90.744  -6.168  1.00 23.67           C  \\nATOM  11316  C   GLN G  84      63.258  91.607  -7.373  1.00 23.67           C  \\nATOM  11317  O   GLN G  84      62.100  91.935  -7.604  1.00 23.67           O  \\nATOM  11318  CB  GLN G  84      64.346  91.596  -5.169  1.00 25.33           C  \\nATOM  11319  CG  GLN G  84      63.751  92.966  -4.899  1.00 25.33           C  \\nATOM  11320  CD  GLN G  84      62.568  92.917  -3.947  1.00 25.33           C  \\nATOM  11321  OE1 GLN G  84      61.948  91.865  -3.764  1.00 25.33           O  \\nATOM  11322  NE2 GLN G  84      62.242  94.056  -3.338  1.00 25.33           N  \\nATOM  11323  N   LEU G  85      64.282  92.019  -8.118  1.00 19.86           N  \\nATOM  11324  CA  LEU G  85      64.067  92.817  -9.318  1.00 19.86           C  \\nATOM  11325  C   LEU G  85      63.092  92.095 -10.223  1.00 19.86           C  \\nATOM  11326  O   LEU G  85      62.146  92.693 -10.701  1.00 19.86           O  \\nATOM  11327  CB  LEU G  85      65.370  93.032 -10.080  1.00 24.32           C  \\nATOM  11328  CG  LEU G  85      66.449  93.875  -9.400  1.00 24.32           C  \\nATOM  11329  CD1 LEU G  85      67.697  93.880 -10.245  1.00 24.32           C  \\nATOM  11330  CD2 LEU G  85      65.956  95.275  -9.155  1.00 24.32           C  \\nATOM  11331  N   ALA G  86      63.308  90.806 -10.451  1.00 31.36           N  \\nATOM  11332  CA  ALA G  86      62.409  90.019 -11.297  1.00 31.36           C  \\nATOM  11333  C   ALA G  86      60.941  90.125 -10.850  1.00 31.36           C  \\nATOM  11334  O   ALA G  86      60.050  90.425 -11.663  1.00 31.36           O  \\nATOM  11335  CB  ALA G  86      62.839  88.556 -11.293  1.00 40.57           C  \\nATOM  11336  N   VAL G  87      60.725  89.856  -9.557  1.00 25.69           N  \\nATOM  11337  CA  VAL G  87      59.415  89.869  -8.908  1.00 25.69           C  \\nATOM  11338  C   VAL G  87      58.682  91.203  -8.833  1.00 25.69           C  \\nATOM  11339  O   VAL G  87      57.587  91.337  -9.373  1.00 25.69           O  \\nATOM  11340  CB  VAL G  87      59.497  89.179  -7.490  1.00  9.27           C  \\nATOM  11341  CG1 VAL G  87      58.379  89.608  -6.573  1.00  9.27           C  \\nATOM  11342  CG2 VAL G  87      59.405  87.693  -7.649  1.00  9.27           C  \\nATOM  11343  N   ARG G  88      59.292  92.215  -8.244  1.00 19.87           N  \\nATOM  11344  CA  ARG G  88      58.578  93.482  -8.121  1.00 19.87           C  \\nATOM  11345  C   ARG G  88      58.428  94.206  -9.467  1.00 19.87           C  \\nATOM  11346  O   ARG G  88      57.701  95.179  -9.596  1.00 19.87           O  \\nATOM  11347  CB  ARG G  88      59.238  94.346  -7.052  1.00 21.18           C  \\nATOM  11348  CG  ARG G  88      60.002  93.500  -6.071  1.00 21.18           C  \\nATOM  11349  CD  ARG G  88      59.375  93.289  -4.689  1.00 21.18           C  \\nATOM  11350  NE  ARG G  88      58.146  92.490  -4.564  1.00 21.18           N  \\nATOM  11351  CZ  ARG G  88      57.905  91.612  -3.581  1.00 21.18           C  \\nATOM  11352  NH1 ARG G  88      58.806  91.352  -2.637  1.00 21.18           N  \\nATOM  11353  NH2 ARG G  88      56.680  91.130  -3.438  1.00 21.18           N  \\nATOM  11354  N   ASN G  89      59.092  93.682 -10.482  1.00 20.39           N  \\nATOM  11355  CA  ASN G  89      59.013  94.243 -11.815  1.00 20.39           C  \\nATOM  11356  C   ASN G  89      57.954  93.601 -12.695  1.00 20.39           C  \\nATOM  11357  O   ASN G  89      57.816  93.997 -13.864  1.00 20.39           O  \\nATOM  11358  CB  ASN G  89      60.353  94.117 -12.515  1.00 36.68           C  \\nATOM  11359  CG  ASN G  89      61.239  95.277 -12.249  1.00 36.68           C  \\nATOM  11360  OD1 ASN G  89      60.905  96.181 -11.481  1.00 36.68           O  \\nATOM  11361  ND2 ASN G  89      62.377  95.283 -12.899  1.00 36.68           N  \\nATOM  11362  N   ASP G  90      57.273  92.578 -12.164  1.00 45.29           N  \\nATOM  11363  CA  ASP G  90      56.213  91.848 -12.877  1.00 45.29           C  \\nATOM  11364  C   ASP G  90      54.910  92.035 -12.088  1.00 45.29           C  \\nATOM  11365  O   ASP G  90      54.815  91.632 -10.924  1.00 45.29           O  \\nATOM  11366  CB  ASP G  90      56.572  90.350 -12.989  1.00 30.78           C  \\nATOM  11367  CG  ASP G  90      55.538  89.547 -13.776  1.00 30.78           C  \\nATOM  11368  OD1 ASP G  90      55.487  89.682 -15.020  1.00 30.78           O  \\nATOM  11369  OD2 ASP G  90      54.783  88.780 -13.143  1.00 30.78           O  \\nATOM  11370  N   GLU G  91      53.908  92.646 -12.716  1.00 33.91           N  \\nATOM  11371  CA  GLU G  91      52.645  92.891 -12.035  1.00 33.91           C  \\nATOM  11372  C   GLU G  91      52.108  91.668 -11.286  1.00 33.91           C  \\nATOM  11373  O   GLU G  91      51.934  91.722 -10.075  1.00 33.91           O  \\nATOM  11374  CB  GLU G  91      51.593  93.461 -13.000  1.00141.14           C  \\nATOM  11375  CG  GLU G  91      51.888  94.887 -13.504  1.00141.14           C  \\nATOM  11376  CD  GLU G  91      51.765  95.981 -12.427  1.00141.14           C  \\nATOM  11377  OE1 GLU G  91      52.473  95.914 -11.395  1.00141.14           O  \\nATOM  11378  OE2 GLU G  91      50.969  96.928 -12.630  1.00141.14           O  \\nATOM  11379  N   GLU G  92      52.009  90.526 -11.965  1.00 25.44           N  \\nATOM  11380  CA  GLU G  92      51.454  89.322 -11.344  1.00 25.44           C  \\nATOM  11381  C   GLU G  92      52.254  88.631 -10.247  1.00 25.44           C  \\nATOM  11382  O   GLU G  92      51.714  88.319  -9.195  1.00 25.44           O  \\nATOM  11383  CB  GLU G  92      50.994  88.352 -12.419  1.00 31.91           C  \\nATOM  11384  CG  GLU G  92      49.873  88.939 -13.277  1.00 31.91           C  \\nATOM  11385  CD  GLU G  92      49.419  88.005 -14.370  1.00 31.91           C  \\nATOM  11386  OE1 GLU G  92      49.747  86.815 -14.281  1.00 31.91           O  \\nATOM  11387  OE2 GLU G  92      48.730  88.453 -15.314  1.00 31.91           O  \\nATOM  11388  N   LEU G  93      53.535  88.377 -10.476  1.00 13.21           N  \\nATOM  11389  CA  LEU G  93      54.367  87.760  -9.439  1.00 13.21           C  \\nATOM  11390  C   LEU G  93      54.442  88.665  -8.210  1.00 13.21           C  \\nATOM  11391  O   LEU G  93      54.528  88.174  -7.098  1.00 13.21           O  \\nATOM  11392  CB  LEU G  93      55.788  87.481  -9.959  1.00 31.43           C  \\nATOM  11393  CG  LEU G  93      56.084  86.297 -10.896  1.00 31.43           C  \\nATOM  11394  CD1 LEU G  93      57.567  86.291 -11.268  1.00 31.43           C  \\nATOM  11395  CD2 LEU G  93      55.732  84.996 -10.212  1.00 31.43           C  \\nATOM  11396  N   ASN G  94      54.442  89.983  -8.425  1.00 21.92           N  \\nATOM  11397  CA  ASN G  94      54.485  90.963  -7.339  1.00 21.92           C  \\nATOM  11398  C   ASN G  94      53.235  90.889  -6.469  1.00 21.92           C  \\nATOM  11399  O   ASN G  94      53.317  91.026  -5.255  1.00 21.92           O  \\nATOM  11400  CB  ASN G  94      54.633  92.376  -7.887  1.00 24.89           C  \\nATOM  11401  CG  ASN G  94      54.714  93.404  -6.789  1.00 24.89           C  \\nATOM  11402  OD1 ASN G  94      55.390  93.193  -5.780  1.00 24.89           O  \\nATOM  11403  ND2 ASN G  94      54.005  94.504  -6.956  1.00 24.89           N  \\nATOM  11404  N   LYS G  95      52.072  90.768  -7.099  1.00 15.91           N  \\nATOM  11405  CA  LYS G  95      50.833  90.634  -6.366  1.00 15.91           C  \\nATOM  11406  C   LYS G  95      50.909  89.311  -5.596  1.00 15.91           C  \\nATOM  11407  O   LYS G  95      50.714  89.276  -4.386  1.00 15.91           O  \\nATOM  11408  CB  LYS G  95      49.646  90.637  -7.326  1.00 48.08           C  \\nATOM  11409  CG  LYS G  95      48.282  90.476  -6.663  1.00 48.08           C  \\nATOM  11410  CD  LYS G  95      47.176  90.526  -7.708  1.00 48.08           C  \\nATOM  11411  CE  LYS G  95      45.885  89.829  -7.262  1.00 48.08           C  \\nATOM  11412  NZ  LYS G  95      44.902  89.640  -8.409  1.00 48.08           N  \\nATOM  11413  N   LEU G  96      51.282  88.234  -6.278  1.00 25.95           N  \\nATOM  11414  CA  LEU G  96      51.375  86.928  -5.634  1.00 25.95           C  \\nATOM  11415  C   LEU G  96      52.288  86.926  -4.439  1.00 25.95           C  \\nATOM  11416  O   LEU G  96      52.160  86.072  -3.568  1.00 25.95           O  \\nATOM  11417  CB  LEU G  96      51.863  85.870  -6.619  1.00 14.64           C  \\nATOM  11418  CG  LEU G  96      52.151  84.449  -6.124  1.00 14.64           C  \\nATOM  11419  CD1 LEU G  96      50.887  83.863  -5.591  1.00 14.64           C  \\nATOM  11420  CD2 LEU G  96      52.715  83.567  -7.242  1.00 14.64           C  \\nATOM  11421  N   LEU G  97      53.218  87.870  -4.397  1.00 23.05           N  \\nATOM  11422  CA  LEU G  97      54.164  87.940  -3.291  1.00 23.05           C  \\nATOM  11423  C   LEU G  97      54.121  89.269  -2.520  1.00 23.05           C  \\nATOM  11424  O   LEU G  97      55.059  89.640  -1.824  1.00 23.05           O  \\nATOM  11425  CB  LEU G  97      55.572  87.617  -3.823  1.00 12.64           C  \\nATOM  11426  CG  LEU G  97      55.750  86.189  -4.378  1.00 12.64           C  \\nATOM  11427  CD1 LEU G  97      57.161  86.012  -4.914  1.00 12.64           C  \\nATOM  11428  CD2 LEU G  97      55.443  85.137  -3.278  1.00 12.64           C  \\nATOM  11429  N   GLY G  98      52.981  89.933  -2.578  1.00  7.68           N  \\nATOM  11430  CA  GLY G  98      52.834  91.202  -1.912  1.00  7.68           C  \\nATOM  11431  C   GLY G  98      53.091  91.230  -0.419  1.00  7.68           C  \\nATOM  11432  O   GLY G  98      53.431  92.286   0.112  1.00  7.68           O  \\nATOM  11433  N   ARG G  99      52.884  90.132   0.297  1.00 22.70           N  \\nATOM  11434  CA  ARG G  99      53.128  90.177   1.732  1.00 22.70           C  \\nATOM  11435  C   ARG G  99      54.367  89.363   2.031  1.00 22.70           C  \\nATOM  11436  O   ARG G  99      54.616  88.953   3.160  1.00 22.70           O  \\nATOM  11437  CB  ARG G  99      51.899  89.714   2.519  1.00103.13           C  \\nATOM  11438  CG  ARG G  99      50.743  90.713   2.439  1.00103.13           C  \\nATOM  11439  CD  ARG G  99      49.416  90.136   2.944  1.00103.13           C  \\nATOM  11440  NE  ARG G  99      48.261  90.909   2.454  1.00103.13           N  \\nATOM  11441  CZ  ARG G  99      46.972  90.566   2.592  1.00103.13           C  \\nATOM  11442  NH1 ARG G  99      46.620  89.445   3.217  1.00103.13           N  \\nATOM  11443  NH2 ARG G  99      46.023  91.349   2.087  1.00103.13           N  \\nATOM  11444  N   VAL G 100      55.188  89.214   1.003  1.00 23.39           N  \\nATOM  11445  CA  VAL G 100      56.423  88.461   1.099  1.00 23.39           C  \\nATOM  11446  C   VAL G 100      57.648  89.334   0.883  1.00 23.39           C  \\nATOM  11447  O   VAL G 100      57.748  90.043  -0.127  1.00 23.39           O  \\nATOM  11448  CB  VAL G 100      56.463  87.290   0.066  1.00 17.83           C  \\nATOM  11449  CG1 VAL G 100      57.839  86.628   0.071  1.00 17.83           C  \\nATOM  11450  CG2 VAL G 100      55.367  86.259   0.389  1.00 17.83           C  \\nATOM  11451  N   THR G 101      58.567  89.273   1.847  1.00 11.33           N  \\nATOM  11452  CA  THR G 101      59.812  90.011   1.754  1.00 11.33           C  \\nATOM  11453  C   THR G 101      61.022  89.089   1.525  1.00 11.33           C  \\nATOM  11454  O   THR G 101      61.244  88.094   2.215  1.00 11.33           O  \\nATOM  11455  CB  THR G 101      60.009  91.049   2.904  1.00 19.35           C  \\nATOM  11456  OG1 THR G 101      61.356  90.983   3.387  1.00 19.35           O  \\nATOM  11457  CG2 THR G 101      59.004  90.862   4.020  1.00 19.35           C  \\nATOM  11458  N   ILE G 102      61.715  89.362   0.429  1.00 21.05           N  \\nATOM  11459  CA  ILE G 102      62.868  88.583   0.018  1.00 21.05           C  \\nATOM  11460  C   ILE G 102      64.139  89.128   0.653  1.00 21.05           C  \\nATOM  11461  O   ILE G 102      64.549  90.254   0.381  1.00 21.05           O  \\nATOM  11462  CB  ILE G 102      62.972  88.635  -1.500  1.00 10.21           C  \\nATOM  11463  CG1 ILE G 102      61.866  87.808  -2.124  1.00 10.21           C  \\nATOM  11464  CG2 ILE G 102      64.271  88.122  -1.967  1.00 10.21           C  \\nATOM  11465  CD1 ILE G 102      61.902  87.864  -3.610  1.00 10.21           C  \\nATOM  11466  N   ALA G 103      64.751  88.336   1.527  1.00 29.47           N  \\nATOM  11467  CA  ALA G 103      65.972  88.753   2.193  1.00 29.47           C  \\nATOM  11468  C   ALA G 103      67.057  89.087   1.173  1.00 29.47           C  \\nATOM  11469  O   ALA G 103      67.125  88.487   0.093  1.00 29.47           O  \\nATOM  11470  CB  ALA G 103      66.440  87.688   3.135  1.00 16.64           C  \\nATOM  11471  N   GLN G 104      67.860  90.089   1.521  1.00 38.53           N  \\nATOM  11472  CA  GLN G 104      68.946  90.593   0.688  1.00 38.53           C  \\nATOM  11473  C   GLN G 104      68.523  90.968  -0.729  1.00 38.53           C  \\nATOM  11474  O   GLN G 104      69.317  90.858  -1.662  1.00 38.53           O  \\nATOM  11475  CB  GLN G 104      70.148  89.638   0.691  1.00 49.57           C  \\nATOM  11476  CG  GLN G 104      71.063  89.805   1.914  1.00 49.57           C  \\nATOM  11477  CD  GLN G 104      71.760  91.186   1.986  1.00 49.57           C  \\nATOM  11478  OE1 GLN G 104      72.717  91.454   1.239  1.00 49.57           O  \\nATOM  11479  NE2 GLN G 104      71.313  92.040   2.921  1.00 49.57           N  \\nATOM  11480  N   GLY G 105      67.278  91.430  -0.872  1.00 25.06           N  \\nATOM  11481  CA  GLY G 105      66.754  91.846  -2.168  1.00 25.06           C  \\nATOM  11482  C   GLY G 105      66.735  93.362  -2.391  1.00 25.06           C  \\nATOM  11483  O   GLY G 105      66.747  93.822  -3.532  1.00 25.06           O  \\nATOM  11484  N   GLY G 106      66.688  94.148  -1.311  1.00 21.90           N  \\nATOM  11485  CA  GLY G 106      66.677  95.599  -1.429  1.00 21.90           C  \\nATOM  11486  C   GLY G 106      65.434  96.091  -2.125  1.00 21.90           C  \\nATOM  11487  O   GLY G 106      64.491  95.330  -2.287  1.00 21.90           O  \\nATOM  11488  N   VAL G 107      65.432  97.341  -2.585  1.00 36.17           N  \\nATOM  11489  CA  VAL G 107      64.249  97.886  -3.260  1.00 36.17           C  \\nATOM  11490  C   VAL G 107      64.549  98.243  -4.706  1.00 36.17           C  \\nATOM  11491  O   VAL G 107      65.683  98.122  -5.165  1.00 36.17           O  \\nATOM  11492  CB  VAL G 107      63.649  99.140  -2.528  1.00 24.30           C  \\nATOM  11493  CG1 VAL G 107      63.576  98.928  -1.023  1.00 24.30           C  \\nATOM  11494  CG2 VAL G 107      64.436 100.381  -2.840  1.00 24.30           C  \\nATOM  11495  N   LEU G 108      63.499  98.619  -5.426  1.00 23.56           N  \\nATOM  11496  CA  LEU G 108      63.588  99.015  -6.827  1.00 23.56           C  \\nATOM  11497  C   LEU G 108      63.890 100.493  -6.923  1.00 23.56           C  \\nATOM  11498  O   LEU G 108      63.306 101.288  -6.178  1.00 23.56           O  \\nATOM  11499  CB  LEU G 108      62.243  98.824  -7.522  1.00  8.97           C  \\nATOM  11500  CG  LEU G 108      61.790  97.472  -8.019  1.00  8.97           C  \\nATOM  11501  CD1 LEU G 108      60.489  97.685  -8.807  1.00  8.97           C  \\nATOM  11502  CD2 LEU G 108      62.820  96.887  -8.930  1.00  8.97           C  \\nATOM  11503  N   PRO G 109      64.830 100.887  -7.803  1.00 44.27           N  \\nATOM  11504  CA  PRO G 109      65.100 102.320  -7.903  1.00 44.27           C  \\nATOM  11505  C   PRO G 109      63.805 103.047  -8.307  1.00 44.27           C  \\nATOM  11506  O   PRO G 109      63.089 102.617  -9.221  1.00 52.17           O  \\nATOM  11507  CB  PRO G 109      66.207 102.393  -8.970  1.00 52.14           C  \\nATOM  11508  CG  PRO G 109      66.181 101.058  -9.652  1.00 52.14           C  \\nATOM  11509  CD  PRO G 109      65.856 100.122  -8.530  1.00 52.14           C  \\nATOM  11510  N   ASN G 110      63.476 104.078  -7.528  1.00 17.90           N  \\nATOM  11511  CA  ASN G 110      62.280 104.895  -7.703  1.00 17.90           C  \\nATOM  11512  C   ASN G 110      62.353 106.145  -6.814  1.00 17.90           C  \\nATOM  11513  O   ASN G 110      62.500 106.020  -5.582  1.00 17.90           O  \\nATOM  11514  CB  ASN G 110      61.032 104.072  -7.335  1.00 73.16           C  \\nATOM  11515  CG  ASN G 110      59.800 104.935  -7.097  1.00 73.16           C  \\nATOM  11516  OD1 ASN G 110      59.194 105.459  -8.038  1.00 73.16           O  \\nATOM  11517  ND2 ASN G 110      59.431 105.094  -5.827  1.00 73.16           N  \\nATOM  11518  N   ILE G 111      62.306 107.330  -7.442  1.00 34.95           N  \\nATOM  11519  CA  ILE G 111      62.324 108.607  -6.702  1.00 34.95           C  \\nATOM  11520  C   ILE G 111      61.146 109.477  -7.107  1.00 34.95           C  \\nATOM  11521  O   ILE G 111      61.029 109.865  -8.273  1.00 34.95           O  \\nATOM  11522  CB  ILE G 111      63.595 109.488  -6.951  1.00 37.55           C  \\nATOM  11523  CG1 ILE G 111      64.890 108.735  -6.620  1.00 37.55           C  \\nATOM  11524  CG2 ILE G 111      63.511 110.760  -6.086  1.00 37.55           C  \\nATOM  11525  CD1 ILE G 111      66.147 109.498  -6.984  1.00 37.55           C  \\nATOM  11526  N   GLN G 112      60.322 109.839  -6.125  1.00 32.33           N  \\nATOM  11527  CA  GLN G 112      59.157 110.683  -6.365  1.00 32.33           C  \\nATOM  11528  C   GLN G 112      59.584 111.918  -7.141  1.00 32.33           C  \\nATOM  11529  O   GLN G 112      60.405 112.695  -6.667  1.00 32.33           O  \\nATOM  11530  CB  GLN G 112      58.516 111.103  -5.037  1.00 37.18           C  \\nATOM  11531  CG  GLN G 112      57.906 109.957  -4.245  1.00 37.18           C  \\nATOM  11532  CD  GLN G 112      56.950 109.107  -5.076  1.00 37.18           C  \\nATOM  11533  OE1 GLN G 112      55.933 109.598  -5.585  1.00 37.18           O  \\nATOM  11534  NE2 GLN G 112      57.286 107.827  -5.233  1.00 37.18           N  \\nATOM  11535  N   SER G 113      59.001 112.099  -8.322  1.00 36.71           N  \\nATOM  11536  CA  SER G 113      59.322 113.225  -9.197  1.00 36.71           C  \\nATOM  11537  C   SER G 113      59.324 114.608  -8.540  1.00 36.71           C  \\nATOM  11538  O   SER G 113      60.135 115.458  -8.892  1.00 36.71           O  \\nATOM  11539  CB  SER G 113      58.377 113.248 -10.393  1.00 46.70           C  \\nATOM  11540  OG  SER G 113      57.061 113.574  -9.983  1.00 46.70           O  \\nATOM  11541  N   VAL G 114      58.442 114.822  -7.570  1.00 40.62           N  \\nATOM  11542  CA  VAL G 114      58.353 116.105  -6.882  1.00 40.62           C  \\nATOM  11543  C   VAL G 114      59.674 116.420  -6.185  1.00 40.62           C  \\nATOM  11544  O   VAL G 114      59.982 117.574  -5.887  1.00 40.62           O  \\nATOM  11545  CB  VAL G 114      57.221 116.091  -5.841  1.00 47.33           C  \\nATOM  11546  CG1 VAL G 114      56.917 117.504  -5.402  1.00 47.33           C  \\nATOM  11547  CG2 VAL G 114      55.957 115.402  -6.414  1.00 47.33           C  \\nATOM  11548  N   LEU G 115      60.485 115.384  -6.006  1.00 52.74           N  \\nATOM  11549  CA  LEU G 115      61.781 115.484  -5.351  1.00 52.74           C  \\nATOM  11550  C   LEU G 115      62.993 115.692  -6.250  1.00 52.74           C  \\nATOM  11551  O   LEU G 115      64.086 115.940  -5.748  1.00 25.03           O  \\nATOM  11552  CB  LEU G 115      62.019 114.232  -4.524  1.00 25.14           C  \\nATOM  11553  CG  LEU G 115      60.987 113.982  -3.435  1.00 25.14           C  \\nATOM  11554  CD1 LEU G 115      61.319 112.712  -2.666  1.00 25.14           C  \\nATOM  11555  CD2 LEU G 115      60.966 115.165  -2.504  1.00 25.14           C  \\nATOM  11556  N   LEU G 116      62.828 115.575  -7.561  1.00 41.27           N  \\nATOM  11557  CA  LEU G 116      63.958 115.756  -8.467  1.00 41.27           C  \\nATOM  11558  C   LEU G 116      64.381 117.222  -8.550  1.00 41.27           C  \\nATOM  11559  O   LEU G 116      63.609 118.117  -8.196  1.00 41.27           O  \\nATOM  11560  CB  LEU G 116      63.627 115.196  -9.852  1.00 34.03           C  \\nATOM  11561  CG  LEU G 116      63.449 113.670  -9.877  1.00 34.03           C  \\nATOM  11562  CD1 LEU G 116      63.123 113.239 -11.300  1.00 34.03           C  \\nATOM  11563  CD2 LEU G 116      64.691 112.937  -9.339  1.00 34.03           C  \\nATOM  11564  N   PRO G 117      65.646 117.485  -8.934  1.00 77.77           N  \\nATOM  11565  CA  PRO G 117      66.157 118.857  -9.049  1.00 77.77           C  \\nATOM  11566  C   PRO G 117      65.273 119.740  -9.943  1.00 77.77           C  \\nATOM  11567  O   PRO G 117      64.708 119.266 -10.937  1.00 77.77           O  \\nATOM  11568  CB  PRO G 117      67.547 118.642  -9.636  1.00100.50           C  \\nATOM  11569  CG  PRO G 117      67.960 117.354  -9.003  1.00100.50           C  \\nATOM  11570  CD  PRO G 117      66.723 116.512  -9.191  1.00100.50           C  \\nATOM  11571  N   LYS G 118      65.194 121.023  -9.585  1.00119.35           N  \\nATOM  11572  CA  LYS G 118      64.367 122.026 -10.265  1.00119.35           C  \\nATOM  11573  C   LYS G 118      64.731 122.479 -11.678  1.00119.35           C  \\nATOM  11574  O   LYS G 118      63.914 123.118 -12.348  1.00 83.28           O  \\nATOM  11575  CB  LYS G 118      64.237 123.249  -9.363  1.00148.44           C  \\nATOM  11576  CG  LYS G 118      63.675 122.911  -8.001  1.00148.44           C  \\nATOM  11577  CD  LYS G 118      64.003 123.980  -6.989  1.00148.44           C  \\nATOM  11578  CE  LYS G 118      63.553 123.556  -5.606  1.00148.44           C  \\nATOM  11579  NZ  LYS G 118      64.048 124.495  -4.566  1.00148.44           N  \\nATOM  11580  N   LYS G 119      65.953 122.186 -12.119  1.00163.83           N  \\nATOM  11581  CA  LYS G 119      66.405 122.574 -13.457  1.00163.83           C  \\nATOM  11582  C   LYS G 119      67.354 121.545 -14.092  1.00163.83           C  \\nATOM  11583  O   LYS G 119      67.095 120.332 -13.933  1.00153.86           O  \\nATOM  11584  CB  LYS G 119      67.069 123.957 -13.413  1.00153.86           C  \\nATOM  11585  CG  LYS G 119      66.124 125.087 -13.070  1.00153.86           C  \\nATOM  11586  CD  LYS G 119      66.754 126.425 -13.348  1.00153.86           C  \\nATOM  11587  CE  LYS G 119      65.734 127.520 -13.175  1.00153.86           C  \\nATOM  11588  NZ  LYS G 119      66.188 128.785 -13.801  1.00153.86           N  \\nATOM  11589  OXT LYS G 119      68.333 121.950 -14.763  1.00153.86           O  \\nTER   11590      LYS G 119                                                      \\nATOM  11591  N   LYS H  24      82.428  54.051  12.410  1.00170.84           N  \\nATOM  11592  CA  LYS H  24      81.172  53.806  13.176  1.00170.84           C  \\nATOM  11593  C   LYS H  24      80.201  55.004  13.183  1.00170.84           C  \\nATOM  11594  O   LYS H  24      79.193  54.980  12.472  1.00170.84           O  \\nATOM  11595  CB  LYS H  24      81.500  53.348  14.605  1.00108.34           C  \\nATOM  11596  CG  LYS H  24      82.596  54.152  15.290  1.00108.34           C  \\nATOM  11597  CD  LYS H  24      82.510  54.044  16.794  1.00108.34           C  \\nATOM  11598  CE  LYS H  24      83.540  54.933  17.446  1.00108.34           C  \\nATOM  11599  NZ  LYS H  24      83.342  54.971  18.912  1.00108.34           N  \\nATOM  11600  N   LYS H  25      80.507  56.038  13.977  1.00156.61           N  \\nATOM  11601  CA  LYS H  25      79.684  57.258  14.103  1.00156.61           C  \\nATOM  11602  C   LYS H  25      78.196  57.044  14.439  1.00156.61           C  \\nATOM  11603  O   LYS H  25      77.843  56.886  15.611  1.00156.61           O  \\nATOM  11604  CB  LYS H  25      79.829  58.160  12.862  1.00 99.20           C  \\nATOM  11605  CG  LYS H  25      81.110  58.996  12.789  1.00 99.20           C  \\nATOM  11606  CD  LYS H  25      81.131  59.803  11.494  1.00 99.20           C  \\nATOM  11607  CE  LYS H  25      82.360  60.688  11.378  1.00 99.20           C  \\nATOM  11608  NZ  LYS H  25      82.389  61.354  10.044  1.00 99.20           N  \\nATOM  11609  N   ARG H  26      77.341  57.063  13.412  1.00186.32           N  \\nATOM  11610  CA  ARG H  26      75.889  56.885  13.547  1.00186.32           C  \\nATOM  11611  C   ARG H  26      75.165  58.133  14.095  1.00186.32           C  \\nATOM  11612  O   ARG H  26      75.094  58.361  15.305  1.00186.32           O  \\nATOM  11613  CB  ARG H  26      75.573  55.608  14.349  1.00112.48           C  \\nATOM  11614  CG  ARG H  26      74.112  55.383  14.671  1.00112.48           C  \\nATOM  11615  CD  ARG H  26      73.819  53.915  14.941  1.00112.48           C  \\nATOM  11616  NE  ARG H  26      73.553  53.186  13.703  1.00112.48           N  \\nATOM  11617  CZ  ARG H  26      72.488  53.389  12.930  1.00112.48           C  \\nATOM  11618  NH1 ARG H  26      71.580  54.300  13.257  1.00112.48           N  \\nATOM  11619  NH2 ARG H  26      72.325  52.683  11.821  1.00112.48           N  \\nATOM  11620  N   ARG H  27      74.653  58.941  13.163  1.00142.46           N  \\nATOM  11621  CA  ARG H  27      73.934  60.195  13.436  1.00142.46           C  \\nATOM  11622  C   ARG H  27      73.512  60.753  12.062  1.00142.46           C  \\nATOM  11623  O   ARG H  27      74.367  60.942  11.192  1.00142.46           O  \\nATOM  11624  CB  ARG H  27      74.861  61.187  14.156  1.00 89.01           C  \\nATOM  11625  CG  ARG H  27      76.232  61.351  13.495  1.00 89.01           C  \\nATOM  11626  CD  ARG H  27      77.020  62.491  14.101  1.00 89.01           C  \\nATOM  11627  NE  ARG H  27      78.284  62.710  13.400  1.00 89.01           N  \\nATOM  11628  CZ  ARG H  27      78.520  63.704  12.543  1.00 89.01           C  \\nATOM  11629  NH1 ARG H  27      77.576  64.597  12.256  1.00 89.01           N  \\nATOM  11630  NH2 ARG H  27      79.725  63.822  11.997  1.00 89.01           N  \\nATOM  11631  N   LYS H  28      72.218  61.016  11.850  1.00111.25           N  \\nATOM  11632  CA  LYS H  28      71.772  61.502  10.533  1.00111.25           C  \\nATOM  11633  C   LYS H  28      71.082  62.872  10.410  1.00111.25           C  \\nATOM  11634  O   LYS H  28      71.662  63.786   9.817  1.00111.25           O  \\nATOM  11635  CB  LYS H  28      70.950  60.417   9.782  1.00 97.28           C  \\nATOM  11636  CG  LYS H  28      70.935  60.629   8.249  1.00 97.28           C  \\nATOM  11637  CD  LYS H  28      70.382  59.475   7.393  1.00 97.28           C  \\nATOM  11638  CE  LYS H  28      70.830  59.700   5.936  1.00 97.28           C  \\nATOM  11639  NZ  LYS H  28      70.039  59.053   4.854  1.00 97.28           N  \\nATOM  11640  N   THR H  29      69.855  62.992  10.932  1.00 85.41           N  \\nATOM  11641  CA  THR H  29      69.034  64.219  10.876  1.00 85.41           C  \\nATOM  11642  C   THR H  29      68.169  64.154   9.631  1.00 85.41           C  \\nATOM  11643  O   THR H  29      67.046  63.663   9.679  1.00 85.41           O  \\nATOM  11644  CB  THR H  29      69.868  65.560  10.802  1.00132.76           C  \\nATOM  11645  OG1 THR H  29      70.641  65.731  11.994  1.00132.76           O  \\nATOM  11646  CG2 THR H  29      68.955  66.779  10.615  1.00132.76           C  \\nATOM  11647  N   ARG H  30      68.758  64.591   8.515  1.00 50.05           N  \\nATOM  11648  CA  ARG H  30      68.142  64.668   7.190  1.00 50.05           C  \\nATOM  11649  C   ARG H  30      67.327  65.928   6.973  1.00 50.05           C  \\nATOM  11650  O   ARG H  30      66.506  66.317   7.800  1.00 50.05           O  \\nATOM  11651  CB  ARG H  30      67.336  63.423   6.833  1.00 92.86           C  \\nATOM  11652  CG  ARG H  30      68.153  62.401   6.069  1.00 92.86           C  \\nATOM  11653  CD  ARG H  30      67.266  61.323   5.503  1.00 92.86           C  \\nATOM  11654  NE  ARG H  30      66.270  61.892   4.605  1.00 92.86           N  \\nATOM  11655  CZ  ARG H  30      66.378  61.915   3.280  1.00 92.86           C  \\nATOM  11656  NH1 ARG H  30      67.444  61.392   2.683  1.00 92.86           N  \\nATOM  11657  NH2 ARG H  30      65.408  62.453   2.552  1.00 92.86           N  \\nATOM  11658  N   LYS H  31      67.562  66.565   5.834  1.00 59.31           N  \\nATOM  11659  CA  LYS H  31      66.877  67.794   5.498  1.00 59.31           C  \\nATOM  11660  C   LYS H  31      66.448  67.846   4.045  1.00 59.31           C  \\nATOM  11661  O   LYS H  31      67.221  68.278   3.197  1.00 59.31           O  \\nATOM  11662  CB  LYS H  31      67.800  68.979   5.784  1.00 63.91           C  \\nATOM  11663  CG  LYS H  31      67.352  69.869   6.918  1.00 63.91           C  \\nATOM  11664  CD  LYS H  31      66.707  71.140   6.397  1.00 63.91           C  \\nATOM  11665  CE  LYS H  31      66.085  71.934   7.537  1.00 63.91           C  \\nATOM  11666  NZ  LYS H  31      64.930  71.206   8.149  1.00 63.91           N  \\nATOM  11667  N   GLU H  32      65.226  67.410   3.749  1.00 43.81           N  \\nATOM  11668  CA  GLU H  32      64.741  67.490   2.375  1.00 43.81           C  \\nATOM  11669  C   GLU H  32      64.622  68.966   1.998  1.00 43.81           C  \\nATOM  11670  O   GLU H  32      64.391  69.830   2.853  1.00 43.81           O  \\nATOM  11671  CB  GLU H  32      63.397  66.802   2.216  1.00 69.68           C  \\nATOM  11672  CG  GLU H  32      63.460  65.315   2.448  1.00 69.68           C  \\nATOM  11673  CD  GLU H  32      62.180  64.608   2.070  1.00 69.68           C  \\nATOM  11674  OE1 GLU H  32      61.134  65.278   1.957  1.00 69.68           O  \\nATOM  11675  OE2 GLU H  32      62.219  63.374   1.885  1.00 69.68           O  \\nATOM  11676  N   SER H  33      64.785  69.243   0.713  1.00 26.28           N  \\nATOM  11677  CA  SER H  33      64.747  70.596   0.193  1.00 26.28           C  \\nATOM  11678  C   SER H  33      64.474  70.543  -1.292  1.00 26.28           C  \\nATOM  11679  O   SER H  33      64.959  69.655  -1.974  1.00 26.28           O  \\nATOM  11680  CB  SER H  33      66.113  71.232   0.433  1.00 34.90           C  \\nATOM  11681  OG  SER H  33      66.363  72.255  -0.503  1.00 34.90           O  \\nATOM  11682  N   TYR H  34      63.801  71.555  -1.818  1.00 32.25           N  \\nATOM  11683  CA  TYR H  34      63.468  71.599  -3.244  1.00 32.25           C  \\nATOM  11684  C   TYR H  34      64.648  71.980  -4.166  1.00 32.25           C  \\nATOM  11685  O   TYR H  34      64.519  71.964  -5.402  1.00 32.25           O  \\nATOM  11686  CB  TYR H  34      62.276  72.553  -3.466  1.00 31.74           C  \\nATOM  11687  CG  TYR H  34      60.936  72.027  -2.953  1.00 31.74           C  \\nATOM  11688  CD1 TYR H  34      60.212  71.057  -3.674  1.00 31.74           C  \\nATOM  11689  CD2 TYR H  34      60.382  72.505  -1.762  1.00 31.74           C  \\nATOM  11690  CE1 TYR H  34      58.970  70.580  -3.216  1.00 31.74           C  \\nATOM  11691  CE2 TYR H  34      59.137  72.037  -1.301  1.00 31.74           C  \\nATOM  11692  CZ  TYR H  34      58.435  71.077  -2.032  1.00 31.74           C  \\nATOM  11693  OH  TYR H  34      57.196  70.655  -1.593  1.00 31.74           O  \\nATOM  11694  N   ALA H  35      65.813  72.236  -3.567  1.00 33.99           N  \\nATOM  11695  CA  ALA H  35      67.006  72.656  -4.303  1.00 33.99           C  \\nATOM  11696  C   ALA H  35      67.408  71.971  -5.618  1.00 33.99           C  \\nATOM  11697  O   ALA H  35      67.581  72.654  -6.627  1.00 33.99           O  \\nATOM  11698  CB  ALA H  35      68.204  72.761  -3.363  1.00 19.82           C  \\nATOM  11699  N   ILE H  36      67.556  70.651  -5.656  1.00 42.65           N  \\nATOM  11700  CA  ILE H  36      67.965  70.054  -6.933  1.00 42.65           C  \\nATOM  11701  C   ILE H  36      66.957  70.167  -8.070  1.00 42.65           C  \\nATOM  11702  O   ILE H  36      67.348  70.269  -9.225  1.00 42.65           O  \\nATOM  11703  CB  ILE H  36      68.457  68.602  -6.810  1.00 32.26           C  \\nATOM  11704  CG1 ILE H  36      67.347  67.692  -6.332  1.00 32.26           C  \\nATOM  11705  CG2 ILE H  36      69.654  68.542  -5.870  1.00 32.26           C  \\nATOM  11706  CD1 ILE H  36      67.671  66.256  -6.546  1.00 32.26           C  \\nATOM  11707  N   TYR H  37      65.671  70.227  -7.739  1.00 25.08           N  \\nATOM  11708  CA  TYR H  37      64.621  70.342  -8.748  1.00 25.08           C  \\nATOM  11709  C   TYR H  37      64.651  71.770  -9.235  1.00 25.08           C  \\nATOM  11710  O   TYR H  37      64.492  72.018 -10.427  1.00 25.08           O  \\nATOM  11711  CB  TYR H  37      63.285  69.991  -8.140  1.00 32.60           C  \\nATOM  11712  CG  TYR H  37      63.381  68.696  -7.399  1.00 32.60           C  \\nATOM  11713  CD1 TYR H  37      63.433  67.486  -8.081  1.00 32.60           C  \\nATOM  11714  CD2 TYR H  37      63.499  68.677  -6.020  1.00 32.60           C  \\nATOM  11715  CE1 TYR H  37      63.602  66.288  -7.403  1.00 32.60           C  \\nATOM  11716  CE2 TYR H  37      63.674  67.489  -5.328  1.00 32.60           C  \\nATOM  11717  CZ  TYR H  37      63.724  66.295  -6.021  1.00 32.60           C  \\nATOM  11718  OH  TYR H  37      63.881  65.108  -5.322  1.00 32.60           O  \\nATOM  11719  N   VAL H  38      64.899  72.703  -8.311  1.00 28.64           N  \\nATOM  11720  CA  VAL H  38      65.020  74.115  -8.670  1.00 28.64           C  \\nATOM  11721  C   VAL H  38      66.169  74.188  -9.664  1.00 28.64           C  \\nATOM  11722  O   VAL H  38      65.979  74.612 -10.806  1.00 28.64           O  \\nATOM  11723  CB  VAL H  38      65.385  75.012  -7.461  1.00 21.73           C  \\nATOM  11724  CG1 VAL H  38      65.723  76.419  -7.929  1.00 21.73           C  \\nATOM  11725  CG2 VAL H  38      64.247  75.064  -6.464  1.00 21.73           C  \\nATOM  11726  N   TYR H  39      67.348  73.726  -9.238  1.00 36.86           N  \\nATOM  11727  CA  TYR H  39      68.529  73.732 -10.087  1.00 36.86           C  \\nATOM  11728  C   TYR H  39      68.198  73.149 -11.462  1.00 36.86           C  \\nATOM  11729  O   TYR H  39      68.398  73.816 -12.473  1.00 36.86           O  \\nATOM  11730  CB  TYR H  39      69.685  72.961  -9.438  1.00 67.49           C  \\nATOM  11731  CG  TYR H  39      71.031  73.278 -10.062  1.00 67.49           C  \\nATOM  11732  CD1 TYR H  39      71.731  74.438  -9.709  1.00 67.49           C  \\nATOM  11733  CD2 TYR H  39      71.596  72.439 -11.022  1.00 67.49           C  \\nATOM  11734  CE1 TYR H  39      72.960  74.754 -10.298  1.00 67.49           C  \\nATOM  11735  CE2 TYR H  39      72.823  72.747 -11.616  1.00 67.49           C  \\nATOM  11736  CZ  TYR H  39      73.497  73.901 -11.248  1.00 67.49           C  \\nATOM  11737  OH  TYR H  39      74.713  74.192 -11.816  1.00 67.49           O  \\nATOM  11738  N   LYS H  40      67.648  71.937 -11.512  1.00 31.85           N  \\nATOM  11739  CA  LYS H  40      67.295  71.340 -12.797  1.00 31.85           C  \\nATOM  11740  C   LYS H  40      66.504  72.312 -13.680  1.00 31.85           C  \\nATOM  11741  O   LYS H  40      66.787  72.454 -14.873  1.00 31.85           O  \\nATOM  11742  CB  LYS H  40      66.479  70.063 -12.611  1.00 42.34           C  \\nATOM  11743  CG  LYS H  40      67.207  68.948 -11.904  1.00 42.34           C  \\nATOM  11744  CD  LYS H  40      66.361  67.695 -11.907  1.00 42.34           C  \\nATOM  11745  CE  LYS H  40      66.823  66.729 -10.835  1.00 42.34           C  \\nATOM  11746  NZ  LYS H  40      65.803  65.652 -10.614  1.00 42.34           N  \\nATOM  11747  N   VAL H  41      65.526  72.992 -13.088  1.00 27.27           N  \\nATOM  11748  CA  VAL H  41      64.693  73.940 -13.823  1.00 27.27           C  \\nATOM  11749  C   VAL H  41      65.508  75.133 -14.334  1.00 27.27           C  \\nATOM  11750  O   VAL H  41      65.306  75.591 -15.465  1.00 27.27           O  \\nATOM  11751  CB  VAL H  41      63.495  74.419 -12.955  1.00 60.33           C  \\nATOM  11752  CG1 VAL H  41      62.544  75.258 -13.782  1.00 60.33           C  \\nATOM  11753  CG2 VAL H  41      62.741  73.231 -12.385  1.00 60.33           C  \\nATOM  11754  N   LEU H  42      66.421  75.636 -13.505  1.00 37.69           N  \\nATOM  11755  CA  LEU H  42      67.276  76.754 -13.901  1.00 37.69           C  \\nATOM  11756  C   LEU H  42      68.037  76.394 -15.168  1.00 37.69           C  \\nATOM  11757  O   LEU H  42      68.062  77.162 -16.120  1.00 37.69           O  \\nATOM  11758  CB  LEU H  42      68.279  77.091 -12.800  1.00 21.19           C  \\nATOM  11759  CG  LEU H  42      69.293  78.214 -13.076  1.00 21.19           C  \\nATOM  11760  CD1 LEU H  42      68.637  79.443 -13.728  1.00 21.19           C  \\nATOM  11761  CD2 LEU H  42      69.965  78.610 -11.756  1.00 21.19           C  \\nATOM  11762  N   LYS H  43      68.630  75.204 -15.169  1.00 59.02           N  \\nATOM  11763  CA  LYS H  43      69.395  74.703 -16.303  1.00 59.02           C  \\nATOM  11764  C   LYS H  43      68.581  74.471 -17.568  1.00 59.02           C  \\nATOM  11765  O   LYS H  43      69.149  74.270 -18.647  1.00 59.02           O  \\nATOM  11766  CB  LYS H  43      70.157  73.441 -15.900  1.00 39.98           C  \\nATOM  11767  CG  LYS H  43      71.227  73.745 -14.883  1.00 39.98           C  \\nATOM  11768  CD  LYS H  43      71.964  74.986 -15.368  1.00 39.98           C  \\nATOM  11769  CE  LYS H  43      72.855  75.611 -14.331  1.00 39.98           C  \\nATOM  11770  NZ  LYS H  43      73.518  76.762 -14.987  1.00 39.98           N  \\nATOM  11771  N   GLN H  44      67.257  74.462 -17.425  1.00 38.73           N  \\nATOM  11772  CA  GLN H  44      66.351  74.302 -18.561  1.00 38.73           C  \\nATOM  11773  C   GLN H  44      66.012  75.679 -19.191  1.00 38.73           C  \\nATOM  11774  O   GLN H  44      65.881  75.820 -20.412  1.00 38.73           O  \\nATOM  11775  CB  GLN H  44      65.068  73.590 -18.125  1.00 68.52           C  \\nATOM  11776  CG  GLN H  44      64.915  72.176 -18.661  1.00 68.52           C  \\nATOM  11777  CD  GLN H  44      63.542  71.582 -18.363  1.00 68.52           C  \\nATOM  11778  OE1 GLN H  44      63.058  71.644 -17.233  1.00 68.52           O  \\nATOM  11779  NE2 GLN H  44      62.911  71.001 -19.379  1.00 68.52           N  \\nATOM  11780  N   VAL H  45      65.848  76.687 -18.347  1.00 45.52           N  \\nATOM  11781  CA  VAL H  45      65.526  78.018 -18.826  1.00 45.52           C  \\nATOM  11782  C   VAL H  45      66.765  78.761 -19.290  1.00 45.52           C  \\nATOM  11783  O   VAL H  45      66.799  79.298 -20.401  1.00 45.52           O  \\nATOM  11784  CB  VAL H  45      64.836  78.847 -17.732  1.00 52.48           C  \\nATOM  11785  CG1 VAL H  45      64.379  80.156 -18.313  1.00 52.48           C  \\nATOM  11786  CG2 VAL H  45      63.655  78.095 -17.143  1.00 52.48           C  \\nATOM  11787  N   HIS H  46      67.758  78.802 -18.408  1.00 59.38           N  \\nATOM  11788  CA  HIS H  46      69.040  79.461 -18.637  1.00 59.38           C  \\nATOM  11789  C   HIS H  46      70.089  78.431 -18.283  1.00 59.38           C  \\nATOM  11790  O   HIS H  46      70.656  78.449 -17.182  1.00 59.38           O  \\nATOM  11791  CB  HIS H  46      69.176  80.653 -17.716  1.00 42.51           C  \\nATOM  11792  CG  HIS H  46      68.257  81.770 -18.064  1.00 42.51           C  \\nATOM  11793  ND1 HIS H  46      67.047  81.955 -17.438  1.00 42.51           N  \\nATOM  11794  CD2 HIS H  46      68.367  82.758 -18.980  1.00 42.51           C  \\nATOM  11795  CE1 HIS H  46      66.448  83.012 -17.951  1.00 42.51           C  \\nATOM  11796  NE2 HIS H  46      67.228  83.518 -18.888  1.00 42.51           N  \\nATOM  11797  N   PRO H  47      70.427  77.568 -19.254  1.00 54.63           N  \\nATOM  11798  CA  PRO H  47      71.408  76.498 -19.073  1.00 54.63           C  \\nATOM  11799  C   PRO H  47      72.749  76.982 -18.584  1.00 54.63           C  \\nATOM  11800  O   PRO H  47      73.423  76.277 -17.840  1.00 54.63           O  \\nATOM  11801  CB  PRO H  47      71.512  75.887 -20.470  1.00 24.80           C  \\nATOM  11802  CG  PRO H  47      70.200  76.282 -21.137  1.00 24.80           C  \\nATOM  11803  CD  PRO H  47      70.057  77.693 -20.676  1.00 24.80           C  \\nATOM  11804  N   ASP H  48      73.098  78.213 -18.949  1.00 33.94           N  \\nATOM  11805  CA  ASP H  48      74.386  78.786 -18.574  1.00 33.94           C  \\nATOM  11806  C   ASP H  48      74.382  79.766 -17.377  1.00 33.94           C  \\nATOM  11807  O   ASP H  48      75.396  80.421 -17.105  1.00 33.94           O  \\nATOM  11808  CB  ASP H  48      75.048  79.410 -19.814  1.00 71.30           C  \\nATOM  11809  CG  ASP H  48      75.197  78.409 -20.982  1.00 71.30           C  \\nATOM  11810  OD1 ASP H  48      75.797  77.328 -20.800  1.00 71.30           O  \\nATOM  11811  OD2 ASP H  48      74.720  78.701 -22.100  1.00 71.30           O  \\nATOM  11812  N   THR H  49      73.275  79.807 -16.625  1.00 46.35           N  \\nATOM  11813  CA  THR H  49      73.146  80.687 -15.455  1.00 46.35           C  \\nATOM  11814  C   THR H  49      73.260  79.875 -14.164  1.00 46.35           C  \\nATOM  11815  O   THR H  49      72.585  78.876 -14.008  1.00 46.35           O  \\nATOM  11816  CB  THR H  49      71.777  81.411 -15.443  1.00 43.30           C  \\nATOM  11817  OG1 THR H  49      71.601  82.132 -16.664  1.00 43.30           O  \\nATOM  11818  CG2 THR H  49      71.704  82.388 -14.305  1.00 43.30           C  \\nATOM  11819  N   GLY H  50      74.106  80.312 -13.241  1.00 27.19           N  \\nATOM  11820  CA  GLY H  50      74.265  79.605 -11.981  1.00 27.19           C  \\nATOM  11821  C   GLY H  50      73.379  80.228 -10.915  1.00 27.19           C  \\nATOM  11822  O   GLY H  50      72.549  81.064 -11.236  1.00 27.19           O  \\nATOM  11823  N   ILE H  51      73.597  79.905  -9.641  1.00 26.19           N  \\nATOM  11824  CA  ILE H  51      72.753  80.469  -8.581  1.00 26.19           C  \\nATOM  11825  C   ILE H  51      73.359  80.495  -7.166  1.00 26.19           C  \\nATOM  11826  O   ILE H  51      73.766  79.464  -6.623  1.00 26.19           O  \\nATOM  11827  CB  ILE H  51      71.374  79.755  -8.537  1.00 47.65           C  \\nATOM  11828  CG1 ILE H  51      70.401  80.518  -7.636  1.00 47.65           C  \\nATOM  11829  CG2 ILE H  51      71.538  78.310  -8.061  1.00 47.65           C  \\nATOM  11830  CD1 ILE H  51      68.980  80.025  -7.730  1.00 47.65           C  \\nATOM  11831  N   SER H  52      73.329  81.696  -6.579  1.00 28.12           N  \\nATOM  11832  CA  SER H  52      73.829  82.016  -5.244  1.00 28.12           C  \\nATOM  11833  C   SER H  52      73.204  81.051  -4.260  1.00 28.12           C  \\nATOM  11834  O   SER H  52      72.075  80.592  -4.445  1.00 28.12           O  \\nATOM  11835  CB  SER H  52      73.420  83.464  -4.897  1.00 40.74           C  \\nATOM  11836  OG  SER H  52      73.777  83.883  -3.585  1.00 40.74           O  \\nATOM  11837  N   SER H  53      73.922  80.752  -3.194  1.00 38.97           N  \\nATOM  11838  CA  SER H  53      73.398  79.834  -2.210  1.00 38.97           C  \\nATOM  11839  C   SER H  53      72.185  80.431  -1.537  1.00 38.97           C  \\nATOM  11840  O   SER H  53      71.173  79.749  -1.353  1.00 38.97           O  \\nATOM  11841  CB  SER H  53      74.441  79.548  -1.156  1.00 35.09           C  \\nATOM  11842  OG  SER H  53      74.140  78.330  -0.526  1.00 35.09           O  \\nATOM  11843  N   LYS H  54      72.268  81.730  -1.237  1.00 49.51           N  \\nATOM  11844  CA  LYS H  54      71.179  82.456  -0.576  1.00 49.51           C  \\nATOM  11845  C   LYS H  54      69.966  82.583  -1.504  1.00 49.51           C  \\nATOM  11846  O   LYS H  54      68.808  82.573  -1.066  1.00 49.51           O  \\nATOM  11847  CB  LYS H  54      71.668  83.828  -0.120  1.00 46.10           C  \\nATOM  11848  CG  LYS H  54      72.780  83.751   0.918  1.00 46.10           C  \\nATOM  11849  CD  LYS H  54      73.288  85.132   1.298  1.00 46.10           C  \\nATOM  11850  CE  LYS H  54      74.433  85.068   2.284  1.00 46.10           C  \\nATOM  11851  NZ  LYS H  54      74.679  86.435   2.776  1.00 46.10           N  \\nATOM  11852  N   ALA H  55      70.249  82.704  -2.794  1.00 26.70           N  \\nATOM  11853  CA  ALA H  55      69.211  82.772  -3.799  1.00 26.70           C  \\nATOM  11854  C   ALA H  55      68.434  81.446  -3.756  1.00 26.70           C  \\nATOM  11855  O   ALA H  55      67.203  81.422  -3.809  1.00 26.70           O  \\nATOM  11856  CB  ALA H  55      69.846  82.987  -5.175  1.00 28.72           C  \\nATOM  11857  N   MET H  56      69.161  80.336  -3.656  1.00 16.72           N  \\nATOM  11858  CA  MET H  56      68.515  79.027  -3.596  1.00 16.72           C  \\nATOM  11859  C   MET H  56      67.651  78.896  -2.344  1.00 16.72           C  \\nATOM  11860  O   MET H  56      66.581  78.315  -2.383  1.00 16.72           O  \\nATOM  11861  CB  MET H  56      69.554  77.907  -3.677  1.00 25.38           C  \\nATOM  11862  CG  MET H  56      68.963  76.507  -3.748  1.00 25.38           C  \\nATOM  11863  SD  MET H  56      67.937  76.233  -5.182  1.00 25.38           S  \\nATOM  11864  CE  MET H  56      69.160  75.779  -6.384  1.00 25.38           C  \\nATOM  11865  N   SER H  57      68.110  79.460  -1.238  1.00 25.03           N  \\nATOM  11866  CA  SER H  57      67.343  79.420   0.002  1.00 25.03           C  \\nATOM  11867  C   SER H  57      65.983  80.158  -0.141  1.00 25.03           C  \\nATOM  11868  O   SER H  57      64.976  79.806   0.473  1.00 25.03           O  \\nATOM  11869  CB  SER H  57      68.184  80.014   1.134  1.00 33.07           C  \\nATOM  11870  OG  SER H  57      67.569  79.747   2.378  1.00 33.07           O  \\nATOM  11871  N   ILE H  58      65.982  81.205  -0.952  1.00 16.25           N  \\nATOM  11872  CA  ILE H  58      64.789  81.982  -1.219  1.00 16.25           C  \\nATOM  11873  C   ILE H  58      63.873  81.184  -2.112  1.00 16.25           C  \\nATOM  11874  O   ILE H  58      62.722  81.029  -1.797  1.00 16.25           O  \\nATOM  11875  CB  ILE H  58      65.170  83.373  -1.824  1.00 14.66           C  \\nATOM  11876  CG1 ILE H  58      65.804  84.248  -0.718  1.00 14.66           C  \\nATOM  11877  CG2 ILE H  58      63.949  84.059  -2.467  1.00 14.66           C  \\nATOM  11878  CD1 ILE H  58      66.432  85.485  -1.231  1.00 14.66           C  \\nATOM  11879  N   MET H  59      64.386  80.625  -3.201  1.00 25.41           N  \\nATOM  11880  CA  MET H  59      63.540  79.831  -4.086  1.00 25.41           C  \\nATOM  11881  C   MET H  59      62.831  78.712  -3.328  1.00 25.41           C  \\nATOM  11882  O   MET H  59      61.621  78.517  -3.431  1.00 25.41           O  \\nATOM  11883  CB  MET H  59      64.350  79.245  -5.228  1.00 22.33           C  \\nATOM  11884  CG  MET H  59      64.669  80.232  -6.317  1.00 22.33           C  \\nATOM  11885  SD  MET H  59      63.220  81.040  -7.048  1.00 22.33           S  \\nATOM  11886  CE  MET H  59      62.422  79.728  -7.952  1.00 22.33           C  \\nATOM  11887  N   ASN H  60      63.594  77.996  -2.525  1.00 32.03           N  \\nATOM  11888  CA  ASN H  60      63.050  76.902  -1.733  1.00 32.03           C  \\nATOM  11889  C   ASN H  60      61.871  77.403  -0.891  1.00 32.03           C  \\nATOM  11890  O   ASN H  60      60.764  76.913  -1.035  1.00 32.03           O  \\nATOM  11891  CB  ASN H  60      64.169  76.343  -0.858  1.00 24.47           C  \\nATOM  11892  CG  ASN H  60      63.774  75.105  -0.138  1.00 24.47           C  \\nATOM  11893  OD1 ASN H  60      63.377  74.127  -0.754  1.00 24.47           O  \\nATOM  11894  ND2 ASN H  60      63.868  75.133   1.186  1.00 24.47           N  \\nATOM  11895  N   SER H  61      62.110  78.420  -0.064  1.00 29.76           N  \\nATOM  11896  CA  SER H  61      61.074  79.009   0.778  1.00 29.76           C  \\nATOM  11897  C   SER H  61      59.876  79.298  -0.092  1.00 29.76           C  \\nATOM  11898  O   SER H  61      58.751  78.959   0.227  1.00 29.76           O  \\nATOM  11899  CB  SER H  61      61.556  80.330   1.386  1.00 27.03           C  \\nATOM  11900  OG  SER H  61      62.781  80.155   2.068  1.00 27.03           O  \\nATOM  11901  N   PHE H  62      60.141  79.896  -1.229  1.00 13.47           N  \\nATOM  11902  CA  PHE H  62      59.101  80.226  -2.148  1.00 13.47           C  \\nATOM  11903  C   PHE H  62      58.221  79.039  -2.516  1.00 13.47           C  \\nATOM  11904  O   PHE H  62      57.003  79.119  -2.455  1.00 13.47           O  \\nATOM  11905  CB  PHE H  62      59.726  80.808  -3.385  1.00 20.06           C  \\nATOM  11906  CG  PHE H  62      58.780  80.942  -4.498  1.00 20.06           C  \\nATOM  11907  CD1 PHE H  62      57.715  81.818  -4.404  1.00 20.06           C  \\nATOM  11908  CD2 PHE H  62      58.951  80.208  -5.652  1.00 20.06           C  \\nATOM  11909  CE1 PHE H  62      56.828  81.966  -5.463  1.00 20.06           C  \\nATOM  11910  CE2 PHE H  62      58.074  80.348  -6.714  1.00 20.06           C  \\nATOM  11911  CZ  PHE H  62      57.009  81.227  -6.626  1.00 20.06           C  \\nATOM  11912  N   VAL H  63      58.846  77.947  -2.924  1.00 20.17           N  \\nATOM  11913  CA  VAL H  63      58.116  76.749  -3.301  1.00 20.17           C  \\nATOM  11914  C   VAL H  63      57.335  76.184  -2.127  1.00 20.17           C  \\nATOM  11915  O   VAL H  63      56.212  75.718  -2.289  1.00 20.17           O  \\nATOM  11916  CB  VAL H  63      59.053  75.700  -3.869  1.00  5.87           C  \\nATOM  11917  CG1 VAL H  63      58.284  74.456  -4.166  1.00  5.87           C  \\nATOM  11918  CG2 VAL H  63      59.763  76.238  -5.133  1.00  5.87           C  \\nATOM  11919  N   ASN H  64      57.923  76.224  -0.939  1.00 23.79           N  \\nATOM  11920  CA  ASN H  64      57.214  75.760   0.248  1.00 23.79           C  \\nATOM  11921  C   ASN H  64      55.988  76.642   0.442  1.00 23.79           C  \\nATOM  11922  O   ASN H  64      54.872  76.155   0.565  1.00 23.79           O  \\nATOM  11923  CB  ASN H  64      58.090  75.867   1.475  1.00 57.53           C  \\nATOM  11924  CG  ASN H  64      59.202  74.879   1.457  1.00 57.53           C  \\nATOM  11925  OD1 ASN H  64      58.978  73.703   1.197  1.00 57.53           O  \\nATOM  11926  ND2 ASN H  64      60.426  75.344   1.707  1.00 57.53           N  \\nATOM  11927  N   ASP H  65      56.202  77.948   0.397  1.00 26.79           N  \\nATOM  11928  CA  ASP H  65      55.130  78.899   0.567  1.00 26.79           C  \\nATOM  11929  C   ASP H  65      53.979  78.580  -0.393  1.00 26.79           C  \\nATOM  11930  O   ASP H  65      52.885  78.210   0.024  1.00 26.79           O  \\nATOM  11931  CB  ASP H  65      55.652  80.324   0.357  1.00 36.10           C  \\nATOM  11932  CG  ASP H  65      54.615  81.368   0.685  1.00 36.10           C  \\nATOM  11933  OD1 ASP H  65      53.921  81.224   1.712  1.00 36.10           O  \\nATOM  11934  OD2 ASP H  65      54.460  82.321  -0.097  1.00 36.10           O  \\nATOM  11935  N   VAL H  66      54.239  78.630  -1.683  1.00 23.66           N  \\nATOM  11936  CA  VAL H  66      53.185  78.348  -2.629  1.00 23.66           C  \\nATOM  11937  C   VAL H  66      52.582  76.953  -2.402  1.00 23.66           C  \\nATOM  11938  O   VAL H  66      51.369  76.779  -2.500  1.00 23.66           O  \\nATOM  11939  CB  VAL H  66      53.691  78.552  -4.036  1.00 28.19           C  \\nATOM  11940  CG1 VAL H  66      52.563  78.409  -5.020  1.00 28.19           C  \\nATOM  11941  CG2 VAL H  66      54.297  79.939  -4.140  1.00 28.19           C  \\nATOM  11942  N   PHE H  67      53.404  75.971  -2.029  1.00 23.40           N  \\nATOM  11943  CA  PHE H  67      52.865  74.649  -1.743  1.00 23.40           C  \\nATOM  11944  C   PHE H  67      51.816  74.777  -0.645  1.00 23.40           C  \\nATOM  11945  O   PHE H  67      50.661  74.428  -0.847  1.00 23.40           O  \\nATOM  11946  CB  PHE H  67      53.960  73.680  -1.278  1.00 18.81           C  \\nATOM  11947  CG  PHE H  67      53.431  72.312  -0.855  1.00 18.81           C  \\nATOM  11948  CD1 PHE H  67      53.010  72.076   0.455  1.00 18.81           C  \\nATOM  11949  CD2 PHE H  67      53.322  71.276  -1.770  1.00 18.81           C  \\nATOM  11950  CE1 PHE H  67      52.487  70.832   0.839  1.00 18.81           C  \\nATOM  11951  CE2 PHE H  67      52.800  70.030  -1.391  1.00 18.81           C  \\nATOM  11952  CZ  PHE H  67      52.384  69.812  -0.094  1.00 18.81           C  \\nATOM  11953  N   GLU H  68      52.221  75.340   0.496  1.00 27.75           N  \\nATOM  11954  CA  GLU H  68      51.349  75.488   1.667  1.00 27.75           C  \\nATOM  11955  C   GLU H  68      50.090  76.283   1.396  1.00 27.75           C  \\nATOM  11956  O   GLU H  68      49.000  75.875   1.789  1.00 27.75           O  \\nATOM  11957  CB  GLU H  68      52.123  76.040   2.871  1.00 54.84           C  \\nATOM  11958  CG  GLU H  68      53.311  75.144   3.281  1.00 54.84           C  \\nATOM  11959  CD  GLU H  68      54.006  75.523   4.617  1.00 54.84           C  \\nATOM  11960  OE1 GLU H  68      54.261  76.727   4.891  1.00 54.84           O  \\nATOM  11961  OE2 GLU H  68      54.331  74.586   5.391  1.00 54.84           O  \\nATOM  11962  N   ARG H  69      50.222  77.365   0.643  1.00 21.66           N  \\nATOM  11963  CA  ARG H  69      49.074  78.192   0.310  1.00 21.66           C  \\nATOM  11964  C   ARG H  69      48.062  77.441  -0.553  1.00 21.66           C  \\nATOM  11965  O   ARG H  69      46.850  77.444  -0.283  1.00 21.66           O  \\nATOM  11966  CB  ARG H  69      49.530  79.473  -0.372  1.00 17.19           C  \\nATOM  11967  CG  ARG H  69      50.352  80.370   0.529  1.00 17.19           C  \\nATOM  11968  CD  ARG H  69      50.159  81.820   0.138  1.00 17.19           C  \\nATOM  11969  NE  ARG H  69      51.360  82.417  -0.424  1.00 17.19           N  \\nATOM  11970  CZ  ARG H  69      51.357  83.433  -1.289  1.00 17.19           C  \\nATOM  11971  NH1 ARG H  69      50.212  83.980  -1.712  1.00 17.19           N  \\nATOM  11972  NH2 ARG H  69      52.514  83.931  -1.727  1.00 17.19           N  \\nATOM  11973  N   ILE H  70      48.567  76.747  -1.564  1.00 20.72           N  \\nATOM  11974  CA  ILE H  70      47.696  75.996  -2.433  1.00 20.72           C  \\nATOM  11975  C   ILE H  70      47.006  74.856  -1.730  1.00 20.72           C  \\nATOM  11976  O   ILE H  70      45.795  74.712  -1.850  1.00 20.72           O  \\nATOM  11977  CB  ILE H  70      48.425  75.470  -3.654  1.00 19.61           C  \\nATOM  11978  CG1 ILE H  70      48.709  76.637  -4.611  1.00 19.61           C  \\nATOM  11979  CG2 ILE H  70      47.585  74.383  -4.326  1.00 19.61           C  \\nATOM  11980  CD1 ILE H  70      49.005  76.228  -6.028  1.00 19.61           C  \\nATOM  11981  N   ALA H  71      47.772  74.036  -1.011  1.00 22.39           N  \\nATOM  11982  CA  ALA H  71      47.197  72.904  -0.295  1.00 22.39           C  \\nATOM  11983  C   ALA H  71      46.180  73.414   0.706  1.00 22.39           C  \\nATOM  11984  O   ALA H  71      45.106  72.835   0.836  1.00 22.39           O  \\nATOM  11985  CB  ALA H  71      48.267  72.105   0.400  1.00  8.44           C  \\nATOM  11986  N   GLY H  72      46.513  74.508   1.398  1.00 31.09           N  \\nATOM  11987  CA  GLY H  72      45.600  75.085   2.367  1.00 31.09           C  \\nATOM  11988  C   GLY H  72      44.259  75.452   1.744  1.00 31.09           C  \\nATOM  11989  O   GLY H  72      43.210  75.119   2.296  1.00 31.09           O  \\nATOM  11990  N   GLU H  73      44.280  76.127   0.591  1.00 21.31           N  \\nATOM  11991  CA  GLU H  73      43.040  76.509  -0.070  1.00 21.31           C  \\nATOM  11992  C   GLU H  73      42.224  75.279  -0.451  1.00 21.31           C  \\nATOM  11993  O   GLU H  73      41.036  75.218  -0.158  1.00 21.31           O  \\nATOM  11994  CB  GLU H  73      43.316  77.388  -1.291  1.00 45.11           C  \\nATOM  11995  CG  GLU H  73      42.105  78.222  -1.741  1.00 45.11           C  \\nATOM  11996  CD  GLU H  73      41.620  79.216  -0.674  1.00 45.11           C  \\nATOM  11997  OE1 GLU H  73      42.310  80.252  -0.459  1.00 45.11           O  \\nATOM  11998  OE2 GLU H  73      40.543  78.957  -0.071  1.00 45.11           O  \\nATOM  11999  N   ALA H  74      42.870  74.298  -1.082  1.00 21.07           N  \\nATOM  12000  CA  ALA H  74      42.238  73.037  -1.482  1.00 21.07           C  \\nATOM  12001  C   ALA H  74      41.666  72.270  -0.278  1.00 21.07           C  \\nATOM  12002  O   ALA H  74      40.669  71.547  -0.401  1.00 21.07           O  \\nATOM  12003  CB  ALA H  74      43.228  72.183  -2.198  1.00 17.97           C  \\nATOM  12004  N   SER H  75      42.347  72.361   0.862  1.00 19.21           N  \\nATOM  12005  CA  SER H  75      41.866  71.757   2.088  1.00 19.21           C  \\nATOM  12006  C   SER H  75      40.486  72.357   2.337  1.00 19.21           C  \\nATOM  12007  O   SER H  75      39.486  71.644   2.432  1.00 19.21           O  \\nATOM  12008  CB  SER H  75      42.769  72.144   3.250  1.00 16.36           C  \\nATOM  12009  OG  SER H  75      42.274  71.592   4.457  1.00 16.36           O  \\nATOM  12010  N   ARG H  76      40.440  73.683   2.444  1.00 16.36           N  \\nATOM  12011  CA  ARG H  76      39.192  74.394   2.662  1.00 16.36           C  \\nATOM  12012  C   ARG H  76      38.120  73.995   1.652  1.00 16.36           C  \\nATOM  12013  O   ARG H  76      37.053  73.569   2.054  1.00 16.36           O  \\nATOM  12014  CB  ARG H  76      39.446  75.896   2.697  1.00 38.08           C  \\nATOM  12015  CG  ARG H  76      39.983  76.347   4.050  1.00 38.08           C  \\nATOM  12016  CD  ARG H  76      40.575  77.752   4.024  1.00 38.08           C  \\nATOM  12017  NE  ARG H  76      41.992  77.723   4.379  1.00 38.08           N  \\nATOM  12018  CZ  ARG H  76      42.953  78.306   3.667  1.00 38.08           C  \\nATOM  12019  NH1 ARG H  76      42.650  78.991   2.559  1.00 38.08           N  \\nATOM  12020  NH2 ARG H  76      44.226  78.129   4.011  1.00 38.08           N  \\nATOM  12021  N   LEU H  77      38.389  74.090   0.357  1.00 31.08           N  \\nATOM  12022  CA  LEU H  77      37.397  73.664  -0.629  1.00 31.08           C  \\nATOM  12023  C   LEU H  77      36.765  72.319  -0.235  1.00 31.08           C  \\nATOM  12024  O   LEU H  77      35.545  72.214  -0.139  1.00 31.08           O  \\nATOM  12025  CB  LEU H  77      38.030  73.523  -2.000  1.00 19.29           C  \\nATOM  12026  CG  LEU H  77      38.343  74.820  -2.737  1.00 19.29           C  \\nATOM  12027  CD1 LEU H  77      39.290  74.530  -3.892  1.00 19.29           C  \\nATOM  12028  CD2 LEU H  77      37.058  75.458  -3.263  1.00 19.29           C  \\nATOM  12029  N   ALA H  78      37.584  71.301   0.043  1.00 23.77           N  \\nATOM  12030  CA  ALA H  78      37.041  69.996   0.435  1.00 23.77           C  \\nATOM  12031  C   ALA H  78      36.050  70.049   1.605  1.00 23.77           C  \\nATOM  12032  O   ALA H  78      34.973  69.487   1.501  1.00 23.77           O  \\nATOM  12033  CB  ALA H  78      38.155  69.014   0.724  1.00  6.30           C  \\nATOM  12034  N   HIS H  79      36.410  70.697   2.717  1.00 32.00           N  \\nATOM  12035  CA  HIS H  79      35.508  70.805   3.888  1.00 32.00           C  \\nATOM  12036  C   HIS H  79      34.181  71.483   3.540  1.00 32.00           C  \\nATOM  12037  O   HIS H  79      33.115  71.024   3.953  1.00 32.00           O  \\nATOM  12038  CB  HIS H  79      36.164  71.565   5.037  1.00105.78           C  \\nATOM  12039  CG  HIS H  79      37.254  70.805   5.720  1.00105.78           C  \\nATOM  12040  ND1 HIS H  79      38.405  70.407   5.072  1.00105.78           N  \\nATOM  12041  CD2 HIS H  79      37.383  70.392   7.003  1.00105.78           C  \\nATOM  12042  CE1 HIS H  79      39.196  69.782   5.926  1.00105.78           C  \\nATOM  12043  NE2 HIS H  79      38.599  69.760   7.105  1.00105.78           N  \\nATOM  12044  N   TYR H  80      34.258  72.577   2.785  1.00 26.59           N  \\nATOM  12045  CA  TYR H  80      33.076  73.327   2.362  1.00 26.59           C  \\nATOM  12046  C   TYR H  80      32.072  72.391   1.730  1.00 26.59           C  \\nATOM  12047  O   TYR H  80      30.884  72.433   2.033  1.00 26.59           O  \\nATOM  12048  CB  TYR H  80      33.478  74.408   1.356  1.00 36.67           C  \\nATOM  12049  CG  TYR H  80      34.364  75.462   1.974  1.00 36.67           C  \\nATOM  12050  CD1 TYR H  80      34.571  75.493   3.367  1.00 36.67           C  \\nATOM  12051  CD2 TYR H  80      34.968  76.456   1.188  1.00 36.67           C  \\nATOM  12052  CE1 TYR H  80      35.343  76.479   3.958  1.00 36.67           C  \\nATOM  12053  CE2 TYR H  80      35.748  77.457   1.776  1.00 36.67           C  \\nATOM  12054  CZ  TYR H  80      35.927  77.459   3.164  1.00 36.67           C  \\nATOM  12055  OH  TYR H  80      36.674  78.448   3.770  1.00 36.67           O  \\nATOM  12056  N   ASN H  81      32.586  71.514   0.880  1.00 27.08           N  \\nATOM  12057  CA  ASN H  81      31.779  70.542   0.188  1.00 27.08           C  \\nATOM  12058  C   ASN H  81      31.637  69.204   0.867  1.00 27.08           C  \\nATOM  12059  O   ASN H  81      31.168  68.248   0.257  1.00 27.08           O  \\nATOM  12060  CB  ASN H  81      32.309  70.403  -1.211  1.00 45.15           C  \\nATOM  12061  CG  ASN H  81      32.291  71.714  -1.919  1.00 45.15           C  \\nATOM  12062  OD1 ASN H  81      31.319  72.044  -2.598  1.00 45.15           O  \\nATOM  12063  ND2 ASN H  81      33.289  72.539  -1.658  1.00 45.15           N  \\nATOM  12064  N   LYS H  82      32.014  69.138   2.140  1.00 48.07           N  \\nATOM  12065  CA  LYS H  82      31.895  67.912   2.918  1.00 48.07           C  \\nATOM  12066  C   LYS H  82      32.514  66.719   2.194  1.00 48.07           C  \\nATOM  12067  O   LYS H  82      31.878  65.676   2.088  1.00 48.07           O  \\nATOM  12068  CB  LYS H  82      30.407  67.631   3.214  1.00 71.73           C  \\nATOM  12069  CG  LYS H  82      29.603  68.864   3.661  1.00 71.73           C  \\nATOM  12070  CD  LYS H  82      28.135  68.548   3.940  1.00 71.73           C  \\nATOM  12071  CE  LYS H  82      27.388  68.093   2.680  1.00 71.73           C  \\nATOM  12072  NZ  LYS H  82      25.966  67.667   2.942  1.00 71.73           N  \\nATOM  12073  N   ARG H  83      33.699  66.907   1.611  1.00 43.13           N  \\nATOM  12074  CA  ARG H  83      34.406  65.829   0.902  1.00 43.13           C  \\nATOM  12075  C   ARG H  83      35.653  65.372   1.649  1.00 43.13           C  \\nATOM  12076  O   ARG H  83      36.359  66.184   2.263  1.00 43.13           O  \\nATOM  12077  CB  ARG H  83      34.802  66.232  -0.522  1.00 59.74           C  \\nATOM  12078  CG  ARG H  83      33.805  65.827  -1.588  1.00 59.74           C  \\nATOM  12079  CD  ARG H  83      32.789  66.916  -1.789  1.00 59.74           C  \\nATOM  12080  NE  ARG H  83      31.421  66.425  -1.972  1.00 59.74           N  \\nATOM  12081  CZ  ARG H  83      31.005  65.724  -3.023  1.00 59.74           C  \\nATOM  12082  NH1 ARG H  83      31.859  65.415  -3.992  1.00 59.74           N  \\nATOM  12083  NH2 ARG H  83      29.729  65.371  -3.135  1.00 59.74           N  \\nATOM  12084  N   SER H  84      35.918  64.067   1.597  1.00 49.65           N  \\nATOM  12085  CA  SER H  84      37.076  63.476   2.275  1.00 49.65           C  \\nATOM  12086  C   SER H  84      38.390  63.574   1.508  1.00 49.65           C  \\nATOM  12087  O   SER H  84      39.457  63.555   2.114  1.00 49.65           O  \\nATOM  12088  CB  SER H  84      36.805  62.005   2.635  1.00 52.10           C  \\nATOM  12089  OG  SER H  84      36.106  61.885   3.866  1.00 52.10           O  \\nATOM  12090  N   THR H  85      38.324  63.688   0.185  1.00 39.29           N  \\nATOM  12091  CA  THR H  85      39.545  63.741  -0.603  1.00 39.29           C  \\nATOM  12092  C   THR H  85      39.842  65.006  -1.439  1.00 39.29           C  \\nATOM  12093  O   THR H  85      38.943  65.630  -2.021  1.00 39.29           O  \\nATOM  12094  CB  THR H  85      39.664  62.479  -1.541  1.00 41.14           C  \\nATOM  12095  OG1 THR H  85      39.097  62.764  -2.820  1.00 41.14           O  \\nATOM  12096  CG2 THR H  85      38.905  61.302  -0.974  1.00 41.14           C  \\nATOM  12097  N   ILE H  86      41.126  65.365  -1.470  1.00 23.49           N  \\nATOM  12098  CA  ILE H  86      41.654  66.478  -2.258  1.00 23.49           C  \\nATOM  12099  C   ILE H  86      42.167  65.879  -3.583  1.00 23.49           C  \\nATOM  12100  O   ILE H  86      43.167  65.156  -3.612  1.00 23.49           O  \\nATOM  12101  CB  ILE H  86      42.838  67.165  -1.541  1.00 27.76           C  \\nATOM  12102  CG1 ILE H  86      42.336  67.939  -0.313  1.00 27.76           C  \\nATOM  12103  CG2 ILE H  86      43.601  68.065  -2.517  1.00 27.76           C  \\nATOM  12104  CD1 ILE H  86      43.439  68.600   0.536  1.00 27.76           C  \\nATOM  12105  N   THR H  87      41.426  66.116  -4.658  1.00 33.91           N  \\nATOM  12106  CA  THR H  87      41.774  65.613  -5.972  1.00 33.91           C  \\nATOM  12107  C   THR H  87      42.380  66.753  -6.766  1.00 33.91           C  \\nATOM  12108  O   THR H  87      42.486  67.868  -6.278  1.00 33.91           O  \\nATOM  12109  CB  THR H  87      40.535  65.175  -6.697  1.00 27.22           C  \\nATOM  12110  OG1 THR H  87      39.843  66.338  -7.160  1.00 27.22           O  \\nATOM  12111  CG2 THR H  87      39.629  64.412  -5.755  1.00 27.22           C  \\nATOM  12112  N   SER H  88      42.719  66.501  -8.019  1.00 24.64           N  \\nATOM  12113  CA  SER H  88      43.306  67.544  -8.830  1.00 24.64           C  \\nATOM  12114  C   SER H  88      42.285  68.676  -9.109  1.00 24.64           C  \\nATOM  12115  O   SER H  88      42.654  69.810  -9.415  1.00 24.64           O  \\nATOM  12116  CB  SER H  88      43.816  66.929 -10.116  1.00 40.60           C  \\nATOM  12117  OG  SER H  88      42.770  66.194 -10.717  1.00 40.60           O  \\nATOM  12118  N   ARG H  89      41.001  68.396  -8.918  1.00 31.36           N  \\nATOM  12119  CA  ARG H  89      39.981  69.419  -9.155  1.00 31.36           C  \\nATOM  12120  C   ARG H  89      40.193  70.492  -8.087  1.00 31.36           C  \\nATOM  12121  O   ARG H  89      40.213  71.691  -8.366  1.00 31.36           O  \\nATOM  12122  CB  ARG H  89      38.582  68.810  -9.021  1.00 44.80           C  \\nATOM  12123  CG  ARG H  89      37.607  69.300 -10.064  1.00 44.80           C  \\nATOM  12124  CD  ARG H  89      36.209  69.206  -9.558  1.00 44.80           C  \\nATOM  12125  NE  ARG H  89      35.411  70.259 -10.163  1.00 44.80           N  \\nATOM  12126  CZ  ARG H  89      34.199  70.612  -9.747  1.00 44.80           C  \\nATOM  12127  NH1 ARG H  89      33.638  69.991  -8.716  1.00 44.80           N  \\nATOM  12128  NH2 ARG H  89      33.547  71.582 -10.374  1.00 44.80           N  \\nATOM  12129  N   GLU H  90      40.392  70.020  -6.862  1.00 14.46           N  \\nATOM  12130  CA  GLU H  90      40.659  70.880  -5.717  1.00 14.46           C  \\nATOM  12131  C   GLU H  90      41.915  71.716  -5.980  1.00 14.46           C  \\nATOM  12132  O   GLU H  90      41.934  72.926  -5.735  1.00 14.46           O  \\nATOM  12133  CB  GLU H  90      40.831  70.041  -4.452  1.00 37.26           C  \\nATOM  12134  CG  GLU H  90      39.517  69.626  -3.803  1.00 37.26           C  \\nATOM  12135  CD  GLU H  90      38.637  68.727  -4.684  1.00 37.26           C  \\nATOM  12136  OE1 GLU H  90      39.107  67.641  -5.072  1.00 37.26           O  \\nATOM  12137  OE2 GLU H  90      37.466  69.088  -4.964  1.00 37.26           O  \\nATOM  12138  N   ILE H  91      42.954  71.081  -6.510  1.00 13.90           N  \\nATOM  12139  CA  ILE H  91      44.165  71.820  -6.829  1.00 13.90           C  \\nATOM  12140  C   ILE H  91      43.838  72.916  -7.839  1.00 13.90           C  \\nATOM  12141  O   ILE H  91      44.169  74.068  -7.628  1.00 13.90           O  \\nATOM  12142  CB  ILE H  91      45.298  70.897  -7.364  1.00 12.86           C  \\nATOM  12143  CG1 ILE H  91      45.630  69.826  -6.310  1.00 12.86           C  \\nATOM  12144  CG2 ILE H  91      46.563  71.720  -7.694  1.00 12.86           C  \\nATOM  12145  CD1 ILE H  91      45.861  70.358  -4.906  1.00 12.86           C  \\nATOM  12146  N   GLN H  92      43.087  72.574  -8.877  1.00 20.84           N  \\nATOM  12147  CA  GLN H  92      42.732  73.538  -9.912  1.00 20.84           C  \\nATOM  12148  C   GLN H  92      42.042  74.783  -9.392  1.00 20.84           C  \\nATOM  12149  O   GLN H  92      42.568  75.882  -9.510  1.00 20.84           O  \\nATOM  12150  CB  GLN H  92      41.871  72.887 -10.986  1.00 28.65           C  \\nATOM  12151  CG  GLN H  92      41.729  73.754 -12.203  1.00 28.65           C  \\nATOM  12152  CD  GLN H  92      41.087  73.030 -13.365  1.00 28.65           C  \\nATOM  12153  OE1 GLN H  92      39.863  72.892 -13.419  1.00 28.65           O  \\nATOM  12154  NE2 GLN H  92      41.912  72.544 -14.295  1.00 28.65           N  \\nATOM  12155  N   THR H  93      40.878  74.621  -8.787  1.00 19.60           N  \\nATOM  12156  CA  THR H  93      40.191  75.787  -8.304  1.00 19.60           C  \\nATOM  12157  C   THR H  93      41.059  76.490  -7.265  1.00 19.60           C  \\nATOM  12158  O   THR H  93      41.214  77.712  -7.344  1.00 19.60           O  \\nATOM  12159  CB  THR H  93      38.796  75.455  -7.824  1.00 38.84           C  \\nATOM  12160  OG1 THR H  93      38.856  74.240  -7.100  1.00 38.84           O  \\nATOM  12161  CG2 THR H  93      37.863  75.230  -9.020  1.00 38.84           C  \\nATOM  12162  N   ALA H  94      41.733  75.737  -6.388  1.00 20.62           N  \\nATOM  12163  CA  ALA H  94      42.615  76.358  -5.393  1.00 20.62           C  \\nATOM  12164  C   ALA H  94      43.561  77.291  -6.117  1.00 20.62           C  \\nATOM  12165  O   ALA H  94      43.790  78.412  -5.675  1.00 20.62           O  \\nATOM  12166  CB  ALA H  94      43.419  75.329  -4.628  1.00  6.37           C  \\nATOM  12167  N   VAL H  95      44.094  76.832  -7.246  1.00 16.65           N  \\nATOM  12168  CA  VAL H  95      45.001  77.644  -8.059  1.00 16.65           C  \\nATOM  12169  C   VAL H  95      44.274  78.875  -8.611  1.00 16.65           C  \\nATOM  12170  O   VAL H  95      44.775  79.990  -8.487  1.00 16.65           O  \\nATOM  12171  CB  VAL H  95      45.620  76.810  -9.219  1.00 11.22           C  \\nATOM  12172  CG1 VAL H  95      46.127  77.709 -10.325  1.00 11.22           C  \\nATOM  12173  CG2 VAL H  95      46.765  75.956  -8.699  1.00 11.22           C  \\nATOM  12174  N   ARG H  96      43.084  78.666  -9.188  1.00 34.91           N  \\nATOM  12175  CA  ARG H  96      42.282  79.749  -9.769  1.00 34.91           C  \\nATOM  12176  C   ARG H  96      42.074  80.865  -8.778  1.00 34.91           C  \\nATOM  12177  O   ARG H  96      42.141  82.041  -9.126  1.00 34.91           O  \\nATOM  12178  CB  ARG H  96      40.949  79.232 -10.292  1.00 49.65           C  \\nATOM  12179  CG  ARG H  96      41.073  78.599 -11.660  1.00 49.65           C  \\nATOM  12180  CD  ARG H  96      39.719  78.283 -12.292  1.00 49.65           C  \\nATOM  12181  NE  ARG H  96      39.866  77.548 -13.558  1.00 49.65           N  \\nATOM  12182  CZ  ARG H  96      39.188  76.441 -13.880  1.00 49.65           C  \\nATOM  12183  NH1 ARG H  96      38.294  75.937 -13.037  1.00 49.65           N  \\nATOM  12184  NH2 ARG H  96      39.465  75.787 -15.006  1.00 49.65           N  \\nATOM  12185  N   LEU H  97      41.850  80.483  -7.533  1.00 20.13           N  \\nATOM  12186  CA  LEU H  97      41.687  81.446  -6.463  1.00 20.13           C  \\nATOM  12187  C   LEU H  97      43.015  82.121  -6.088  1.00 20.13           C  \\nATOM  12188  O   LEU H  97      43.121  83.342  -6.084  1.00 20.13           O  \\nATOM  12189  CB  LEU H  97      41.117  80.754  -5.232  1.00 20.91           C  \\nATOM  12190  CG  LEU H  97      39.729  80.144  -5.419  1.00 20.91           C  \\nATOM  12191  CD1 LEU H  97      39.307  79.429  -4.154  1.00 20.91           C  \\nATOM  12192  CD2 LEU H  97      38.725  81.227  -5.774  1.00 20.91           C  \\nATOM  12193  N   LEU H  98      44.043  81.325  -5.825  1.00 32.52           N  \\nATOM  12194  CA  LEU H  98      45.335  81.861  -5.418  1.00 32.52           C  \\nATOM  12195  C   LEU H  98      46.194  82.650  -6.393  1.00 32.52           C  \\nATOM  12196  O   LEU H  98      46.883  83.584  -5.989  1.00 32.52           O  \\nATOM  12197  CB  LEU H  98      46.180  80.746  -4.802  1.00 53.60           C  \\nATOM  12198  CG  LEU H  98      45.723  80.235  -3.436  1.00 53.60           C  \\nATOM  12199  CD1 LEU H  98      46.421  78.942  -3.140  1.00 53.60           C  \\nATOM  12200  CD2 LEU H  98      46.006  81.253  -2.340  1.00 53.60           C  \\nATOM  12201  N   LEU H  99      46.189  82.285  -7.662  1.00 30.01           N  \\nATOM  12202  CA  LEU H  99      47.055  82.979  -8.605  1.00 30.01           C  \\nATOM  12203  C   LEU H  99      46.445  84.047  -9.526  1.00 30.01           C  \\nATOM  12204  O   LEU H  99      45.287  83.929  -9.969  1.00 30.01           O  \\nATOM  12205  CB  LEU H  99      47.843  81.954  -9.416  1.00  8.34           C  \\nATOM  12206  CG  LEU H  99      48.511  80.822  -8.604  1.00  8.34           C  \\nATOM  12207  CD1 LEU H  99      49.457  80.020  -9.496  1.00  8.34           C  \\nATOM  12208  CD2 LEU H  99      49.256  81.366  -7.437  1.00  8.34           C  \\nATOM  12209  N   PRO H 100      47.183  85.167  -9.723  1.00 38.48           N  \\nATOM  12210  CA  PRO H 100      46.722  86.260 -10.582  1.00 38.48           C  \\nATOM  12211  C   PRO H 100      46.576  85.939 -12.066  1.00 38.48           C  \\nATOM  12212  O   PRO H 100      47.460  85.348 -12.691  1.00 38.48           O  \\nATOM  12213  CB  PRO H 100      47.739  87.380 -10.308  1.00 21.03           C  \\nATOM  12214  CG  PRO H 100      48.906  86.699  -9.682  1.00 21.03           C  \\nATOM  12215  CD  PRO H 100      48.265  85.648  -8.839  1.00 21.03           C  \\nATOM  12216  N   GLY H 101      45.387  86.257 -12.572  1.00 34.40           N  \\nATOM  12217  CA  GLY H 101      45.032  86.061 -13.967  1.00 34.40           C  \\nATOM  12218  C   GLY H 101      45.890  85.200 -14.872  1.00 34.40           C  \\nATOM  12219  O   GLY H 101      45.644  84.005 -14.997  1.00 34.40           O  \\nATOM  12220  N   GLU H 102      46.891  85.789 -15.520  1.00 25.81           N  \\nATOM  12221  CA  GLU H 102      47.732  85.015 -16.433  1.00 25.81           C  \\nATOM  12222  C   GLU H 102      48.420  83.857 -15.737  1.00 25.81           C  \\nATOM  12223  O   GLU H 102      48.206  82.713 -16.092  1.00 25.81           O  \\nATOM  12224  CB  GLU H 102      48.742  85.914 -17.136  1.00 82.06           C  \\nATOM  12225  CG  GLU H 102      48.578  85.933 -18.646  1.00 82.06           C  \\nATOM  12226  CD  GLU H 102      47.133  86.118 -19.092  1.00 82.06           C  \\nATOM  12227  OE1 GLU H 102      46.338  86.770 -18.369  1.00 82.06           O  \\nATOM  12228  OE2 GLU H 102      46.794  85.603 -20.179  1.00 82.06           O  \\nATOM  12229  N   LEU H 103      49.223  84.165 -14.731  1.00 21.99           N  \\nATOM  12230  CA  LEU H 103      49.929  83.182 -13.944  1.00 21.99           C  \\nATOM  12231  C   LEU H 103      49.011  81.977 -13.723  1.00 21.99           C  \\nATOM  12232  O   LEU H 103      49.384  80.838 -14.015  1.00 21.99           O  \\nATOM  12233  CB  LEU H 103      50.313  83.821 -12.604  1.00 17.31           C  \\nATOM  12234  CG  LEU H 103      51.772  83.902 -12.154  1.00 17.31           C  \\nATOM  12235  CD1 LEU H 103      52.746  84.144 -13.317  1.00 17.31           C  \\nATOM  12236  CD2 LEU H 103      51.869  84.986 -11.117  1.00 17.31           C  \\nATOM  12237  N   ALA H 104      47.769  82.247 -13.327  1.00 35.80           N  \\nATOM  12238  CA  ALA H 104      46.802  81.178 -13.075  1.00 35.80           C  \\nATOM  12239  C   ALA H 104      46.387  80.432 -14.345  1.00 35.80           C  \\nATOM  12240  O   ALA H 104      46.338  79.202 -14.374  1.00 35.80           O  \\nATOM  12241  CB  ALA H 104      45.582  81.726 -12.359  1.00 30.72           C  \\nATOM  12242  N   LYS H 105      46.059  81.186 -15.387  1.00 37.60           N  \\nATOM  12243  CA  LYS H 105      45.663  80.620 -16.668  1.00 37.60           C  \\nATOM  12244  C   LYS H 105      46.662  79.542 -17.097  1.00 37.60           C  \\nATOM  12245  O   LYS H 105      46.288  78.388 -17.319  1.00 37.60           O  \\nATOM  12246  CB  LYS H 105      45.589  81.750 -17.689  1.00 71.72           C  \\nATOM  12247  CG  LYS H 105      45.458  81.329 -19.117  1.00 71.72           C  \\nATOM  12248  CD  LYS H 105      45.321  82.562 -19.969  1.00 71.72           C  \\nATOM  12249  CE  LYS H 105      45.512  82.276 -21.450  1.00 71.72           C  \\nATOM  12250  NZ  LYS H 105      45.242  83.507 -22.266  1.00 71.72           N  \\nATOM  12251  N   HIS H 106      47.942  79.909 -17.092  1.00 41.27           N  \\nATOM  12252  CA  HIS H 106      49.027  79.008 -17.485  1.00 41.27           C  \\nATOM  12253  C   HIS H 106      49.222  77.872 -16.514  1.00 41.27           C  \\nATOM  12254  O   HIS H 106      49.417  76.733 -16.925  1.00 41.27           O  \\nATOM  12255  CB  HIS H 106      50.344  79.755 -17.652  1.00 30.19           C  \\nATOM  12256  CG  HIS H 106      50.311  80.784 -18.732  1.00 30.19           C  \\nATOM  12257  ND1 HIS H 106      51.431  81.476 -19.133  1.00 30.19           N  \\nATOM  12258  CD2 HIS H 106      49.290  81.251 -19.490  1.00 30.19           C  \\nATOM  12259  CE1 HIS H 106      51.105  82.324 -20.091  1.00 30.19           C  \\nATOM  12260  NE2 HIS H 106      49.810  82.208 -20.326  1.00 30.19           N  \\nATOM  12261  N   ALA H 107      49.206  78.177 -15.225  1.00 28.41           N  \\nATOM  12262  CA  ALA H 107      49.361  77.139 -14.230  1.00 28.41           C  \\nATOM  12263  C   ALA H 107      48.247  76.074 -14.395  1.00 28.41           C  \\nATOM  12264  O   ALA H 107      48.489  74.882 -14.202  1.00 28.41           O  \\nATOM  12265  CB  ALA H 107      49.378  77.758 -12.829  1.00 13.59           C  \\nATOM  12266  N   VAL H 108      47.046  76.484 -14.806  1.00 17.28           N  \\nATOM  12267  CA  VAL H 108      45.956  75.523 -15.021  1.00 17.28           C  \\nATOM  12268  C   VAL H 108      46.289  74.585 -16.172  1.00 17.28           C  \\nATOM  12269  O   VAL H 108      46.181  73.371 -16.032  1.00 17.28           O  \\nATOM  12270  CB  VAL H 108      44.582  76.222 -15.285  1.00 17.89           C  \\nATOM  12271  CG1 VAL H 108      43.589  75.259 -15.880  1.00 17.89           C  \\nATOM  12272  CG2 VAL H 108      44.010  76.742 -13.975  1.00 17.89           C  \\nATOM  12273  N   SER H 109      46.690  75.154 -17.308  1.00 36.24           N  \\nATOM  12274  CA  SER H 109      47.048  74.361 -18.474  1.00 36.24           C  \\nATOM  12275  C   SER H 109      48.213  73.419 -18.148  1.00 36.24           C  \\nATOM  12276  O   SER H 109      48.146  72.234 -18.455  1.00 36.24           O  \\nATOM  12277  CB  SER H 109      47.403  75.269 -19.631  1.00 31.11           C  \\nATOM  12278  OG  SER H 109      48.798  75.437 -19.700  1.00 31.11           O  \\nATOM  12279  N   GLU H 110      49.281  73.940 -17.538  1.00 22.70           N  \\nATOM  12280  CA  GLU H 110      50.426  73.106 -17.130  1.00 22.70           C  \\nATOM  12281  C   GLU H 110      49.935  71.955 -16.257  1.00 22.70           C  \\nATOM  12282  O   GLU H 110      50.313  70.806 -16.464  1.00 22.70           O  \\nATOM  12283  CB  GLU H 110      51.439  73.916 -16.329  1.00 40.78           C  \\nATOM  12284  CG  GLU H 110      52.223  74.903 -17.153  1.00 40.78           C  \\nATOM  12285  CD  GLU H 110      53.084  74.240 -18.221  1.00 40.78           C  \\nATOM  12286  OE1 GLU H 110      53.931  73.387 -17.875  1.00 40.78           O  \\nATOM  12287  OE2 GLU H 110      52.924  74.577 -19.412  1.00 40.78           O  \\nATOM  12288  N   GLY H 111      49.079  72.287 -15.287  1.00 30.27           N  \\nATOM  12289  CA  GLY H 111      48.509  71.305 -14.384  1.00 30.27           C  \\nATOM  12290  C   GLY H 111      47.806  70.217 -15.150  1.00 30.27           C  \\nATOM  12291  O   GLY H 111      48.184  69.058 -15.038  1.00 30.27           O  \\nATOM  12292  N   THR H 112      46.800  70.589 -15.940  1.00 31.38           N  \\nATOM  12293  CA  THR H 112      46.046  69.631 -16.746  1.00 31.38           C  \\nATOM  12294  C   THR H 112      46.971  68.814 -17.663  1.00 31.38           C  \\nATOM  12295  O   THR H 112      46.809  67.604 -17.790  1.00 31.38           O  \\nATOM  12296  CB  THR H 112      44.925  70.323 -17.567  1.00 39.79           C  \\nATOM  12297  OG1 THR H 112      45.273  71.691 -17.797  1.00 39.79           O  \\nATOM  12298  CG2 THR H 112      43.604  70.285 -16.818  1.00 39.79           C  \\nATOM  12299  N   LYS H 113      47.979  69.463 -18.245  1.00 23.38           N  \\nATOM  12300  CA  LYS H 113      48.937  68.783 -19.110  1.00 23.38           C  \\nATOM  12301  C   LYS H 113      49.656  67.642 -18.380  1.00 23.38           C  \\nATOM  12302  O   LYS H 113      49.718  66.523 -18.874  1.00 23.38           O  \\nATOM  12303  CB  LYS H 113      49.952  69.779 -19.653  1.00 74.85           C  \\nATOM  12304  CG  LYS H 113      50.163  69.655 -21.139  1.00 74.85           C  \\nATOM  12305  CD  LYS H 113      51.126  70.704 -21.646  1.00 74.85           C  \\nATOM  12306  CE  LYS H 113      52.525  70.488 -21.084  1.00 74.85           C  \\nATOM  12307  NZ  LYS H 113      53.462  71.553 -21.556  1.00 74.85           N  \\nATOM  12308  N   ALA H 114      50.196  67.932 -17.204  1.00 46.27           N  \\nATOM  12309  CA  ALA H 114      50.882  66.923 -16.412  1.00 46.27           C  \\nATOM  12310  C   ALA H 114      49.959  65.754 -16.102  1.00 46.27           C  \\nATOM  12311  O   ALA H 114      50.252  64.622 -16.447  1.00 46.27           O  \\nATOM  12312  CB  ALA H 114      51.389  67.524 -15.125  1.00 55.16           C  \\nATOM  12313  N   VAL H 115      48.816  66.025 -15.493  1.00 48.14           N  \\nATOM  12314  CA  VAL H 115      47.917  64.933 -15.162  1.00 48.14           C  \\nATOM  12315  C   VAL H 115      47.521  64.107 -16.380  1.00 48.14           C  \\nATOM  12316  O   VAL H 115      47.588  62.880 -16.342  1.00 48.14           O  \\nATOM  12317  CB  VAL H 115      46.670  65.409 -14.398  1.00 26.84           C  \\nATOM  12318  CG1 VAL H 115      45.641  64.296 -14.371  1.00 26.84           C  \\nATOM  12319  CG2 VAL H 115      47.049  65.801 -12.952  1.00 26.84           C  \\nATOM  12320  N   THR H 116      47.131  64.766 -17.465  1.00 51.83           N  \\nATOM  12321  CA  THR H 116      46.762  64.048 -18.680  1.00 51.83           C  \\nATOM  12322  C   THR H 116      47.924  63.170 -19.142  1.00 51.83           C  \\nATOM  12323  O   THR H 116      47.768  61.963 -19.261  1.00 51.83           O  \\nATOM  12324  CB  THR H 116      46.370  65.012 -19.810  1.00 35.63           C  \\nATOM  12325  OG1 THR H 116      45.088  65.595 -19.528  1.00 35.63           O  \\nATOM  12326  CG2 THR H 116      46.325  64.291 -21.127  1.00 35.63           C  \\nATOM  12327  N   LYS H 117      49.099  63.764 -19.336  1.00 36.81           N  \\nATOM  12328  CA  LYS H 117      50.283  63.032 -19.776  1.00 36.81           C  \\nATOM  12329  C   LYS H 117      50.606  61.828 -18.865  1.00 36.81           C  \\nATOM  12330  O   LYS H 117      51.206  60.842 -19.293  1.00 36.81           O  \\nATOM  12331  CB  LYS H 117      51.471  63.997 -19.854  1.00 65.44           C  \\nATOM  12332  CG  LYS H 117      52.744  63.402 -20.424  1.00 65.44           C  \\nATOM  12333  CD  LYS H 117      53.786  64.481 -20.696  1.00 65.44           C  \\nATOM  12334  CE  LYS H 117      55.016  63.911 -21.401  1.00 65.44           C  \\nATOM  12335  NZ  LYS H 117      55.778  62.954 -20.548  1.00 65.44           N  \\nATOM  12336  N   TYR H 118      50.245  61.937 -17.596  1.00 56.25           N  \\nATOM  12337  CA  TYR H 118      50.469  60.870 -16.636  1.00 56.25           C  \\nATOM  12338  C   TYR H 118      49.554  59.686 -16.914  1.00 56.25           C  \\nATOM  12339  O   TYR H 118      50.006  58.538 -16.940  1.00 56.25           O  \\nATOM  12340  CB  TYR H 118      50.196  61.405 -15.237  1.00 42.54           C  \\nATOM  12341  CG  TYR H 118      50.417  60.447 -14.086  1.00 42.54           C  \\nATOM  12342  CD1 TYR H 118      51.701  60.011 -13.756  1.00 42.54           C  \\nATOM  12343  CD2 TYR H 118      49.363  60.089 -13.241  1.00 42.54           C  \\nATOM  12344  CE1 TYR H 118      51.939  59.252 -12.604  1.00 42.54           C  \\nATOM  12345  CE2 TYR H 118      49.587  59.339 -12.091  1.00 42.54           C  \\nATOM  12346  CZ  TYR H 118      50.882  58.928 -11.773  1.00 42.54           C  \\nATOM  12347  OH  TYR H 118      51.135  58.250 -10.599  1.00 42.54           O  \\nATOM  12348  N   THR H 119      48.259  59.964 -17.057  1.00 49.36           N  \\nATOM  12349  CA  THR H 119      47.272  58.918 -17.320  1.00 49.36           C  \\nATOM  12350  C   THR H 119      47.491  58.310 -18.693  1.00 49.36           C  \\nATOM  12351  O   THR H 119      47.487  57.088 -18.855  1.00 49.36           O  \\nATOM  12352  CB  THR H 119      45.861  59.470 -17.265  1.00 66.31           C  \\nATOM  12353  OG1 THR H 119      45.778  60.407 -16.186  1.00 66.31           O  \\nATOM  12354  CG2 THR H 119      44.852  58.326 -17.053  1.00 66.31           C  \\nATOM  12355  N   SER H 120      47.664  59.188 -19.675  1.00105.20           N  \\nATOM  12356  CA  SER H 120      47.917  58.792 -21.048  1.00105.20           C  \\nATOM  12357  C   SER H 120      49.365  58.307 -21.082  1.00105.20           C  \\nATOM  12358  O   SER H 120      50.293  59.105 -21.254  1.00105.20           O  \\nATOM  12359  CB  SER H 120      47.722  59.985 -21.999  1.00 92.09           C  \\nATOM  12360  OG  SER H 120      46.396  60.497 -21.948  1.00 92.09           O  \\nATOM  12361  N   ALA H 121      49.517  57.006 -20.820  1.00 79.13           N  \\nATOM  12362  CA  ALA H 121      50.781  56.263 -20.783  1.00 79.13           C  \\nATOM  12363  C   ALA H 121      51.187  55.786 -19.390  1.00 79.13           C  \\nATOM  12364  O   ALA H 121      51.266  56.566 -18.436  1.00 79.13           O  \\nATOM  12365  CB  ALA H 121      51.929  57.036 -21.435  1.00115.59           C  \\nATOM  12366  N   LYS H 122      51.460  54.487 -19.303  1.00145.74           N  \\nATOM  12367  CA  LYS H 122      51.879  53.839 -18.068  1.00145.74           C  \\nATOM  12368  C   LYS H 122      52.287  52.400 -18.437  1.00145.74           C  \\nATOM  12369  O   LYS H 122      53.340  52.250 -19.093  1.00113.58           O  \\nATOM  12370  CB  LYS H 122      50.739  53.885 -17.028  1.00113.58           C  \\nATOM  12371  CG  LYS H 122      51.196  53.769 -15.576  1.00113.58           C  \\nATOM  12372  CD  LYS H 122      51.490  52.318 -15.192  1.00113.58           C  \\nATOM  12373  CE  LYS H 122      52.716  52.162 -14.281  1.00113.58           C  \\nATOM  12374  NZ  LYS H 122      52.547  52.651 -12.874  1.00113.58           N  \\nATOM  12375  OXT LYS H 122      51.549  51.443 -18.126  1.00113.58           O  \\nTER   12376      LYS H 122                                                      \\nHETATM12377 MN    MN I 147      75.436 135.124  -0.612  1.00 99.79          MN  \\nHETATM12378 MN    MN I 500      11.975 113.527 -10.909  1.00 63.71          MN  \\nHETATM12379 MN    MN I 600       6.117 129.617   7.536  1.00137.05          MN  \\nHETATM12380 MN    MN J 293      64.861 141.219   3.828  1.00109.80          MN  \\nHETATM12381 MN    MN J 300      89.596 109.237   3.400  1.00120.55          MN  \\nHETATM12382 MN    MN J 400      81.121  73.445 -14.719  1.00115.84          MN  \\nHETATM12383  O   HOH I 601      72.565  60.018  -6.320  1.00 21.96           O  \\nHETATM12384  O   HOH I 602      83.057  96.149  -9.118  1.00 12.83           O  \\nHETATM12385  O   HOH I 603      75.260  74.861  19.542  1.00 30.07           O  \\nHETATM12386  O   HOH I 604      90.802 107.070 -10.300  1.00 37.72           O  \\nHETATM12387  O   HOH J   3      10.823 104.968  19.458  1.00  8.50           O  \\nHETATM12388  O   HOH J   4      15.774  67.877  25.008  1.00 16.19           O  \\nHETATM12389  O   HOH J   5      75.384  69.631  28.629  1.00 15.33           O  \\nHETATM12390  O   HOH J  12      87.724 103.773 -19.719  1.00 32.26           O  \\nHETATM12391  O   HOH J  13      23.476  64.105  -7.557  1.00 49.16           O  \\nHETATM12392  O   HOH B  10      57.749  75.590  18.612  1.00 22.60           O  \\nHETATM12393  O   HOH E   6      26.412  91.978 -19.036  1.00  5.00           O  \\nHETATM12394  O   HOH F   7      30.887 124.400   2.610  1.00 19.00           O  \\nHETATM12395  O   HOH F   8      21.286 104.199  -3.703  1.00 13.03           O  \\nMASTER      335    0    6   37   20    0    1    612385   10    0   90          \\nEND                                                                             \\n\",\"pdb\");\n",
       "\tviewer_1705745312876235.setBackgroundColor(\"white\");\n",
       "\tviewer_1705745312876235.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}});\n",
       "\tviewer_1705745312876235.zoomTo();\n",
       "viewer_1705745312876235.render();\n",
       "});\n",
       "</script>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from urllib.request import urlopen\n",
    "\n",
    "# Specify the PDB ID you want to download\n",
    "ID = '1AOI'\n",
    "url = 'https://files.rcsb.org/download/' + ID + '.pdb'\n",
    "\n",
    "with urlopen(url) as fh:\n",
    "    pdb = fh.read().decode('utf-8')\n",
    "\n",
    "view = p3d.view()\n",
    "view.addModel(pdb,'pdb')\n",
    "view.setBackgroundColor('white')\n",
    "view.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.25}})\n",
    "view.zoomTo()\n",
    "view.show()"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.7"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
